;% 1. Title: Credit Approval
;%
;% 2. Sources:
;%     (confidential)
;%     Submitted by quinlan@cs.su.oz.au
;%
;% 3.  Past Usage:
;%
;%     See Quinlan,
;%     * "Simplifying decision trees", Int J Man-Machine Studies 27,
;%       Dec 1987, pp. 221-234.
;%     * "C4.5: Programs for Machine Learning", Morgan Kaufmann, Oct 1992
;%
;% 4.  Relevant Information:
;%
;%     This file concerns credit card applications.  All attribute names
;%     and values have been changed to meaningless symbols to protect
;%     confidentiality of the data.
;%
;%     This dataset is interesting because there is a good mix of
;%     attributes -- continuous, nominal with small numbers of
;%     values, and nominal with larger numbers of values.  There
;%     are also a few missing values.
;%
;% 5.  Number of Instances: 690
;%
;% 6.  Number of Attributes: 15 + class attribute
;%
;% 7.  Attribute Information:
;%
;%     A1:	b, a.
;%     A2:	continuous.
;%     A3:	continuous.
;%     A4:	u, y, l, t.
;%     A5:	g, p, gg.
;%     A6:	c, d, cc, i, j, k, m, r, q, w, x, e, aa, ff.
;%     A7:	v, h, bb, j, n, z, dd, ff, o.
;%     A8:	continuous.
;%     A9:	t, f.
;%     A10:	t, f.
;%     A11:	continuous.
;%     A12:	t, f.
;%     A13:	g, p, s.
;%     A14:	continuous.
;%     A15:	continuous.
;%     A16: +,-         (class attribute)
;%
;% 8.  Missing Attribute Values:
;%     37 cases (5%) have one or more missing values.  The missing
;%     values from particular attributes are:
;%
;%     A1:  12
;%     A2:  12
;%     A4:   6
;%     A5:   6
;%     A6:   9
;%     A7:   9
;%     A14: 13
;%
;% 9.  Class Distribution
;%
;%     +: 307 (44.5%)
;%     -: 383 (55.5%)
;%
;% 690 instances
;%
;%
;%
;%
;%
;%
;%
(defun credit-rating ()
  (data
    :name 'credit-rating
    :columns '(A1 A2 A3 A4 A5 A6 A7 A8 A9 A10 A11 A12 A13 A14 A15 class)
    :egs
    '(
      (b 30.83 0 u g w v 1.25 t t 01 f g 00202 0 +)
      (a 58.67 4.46 u g q h 3.04 t t 06 f g 00043 560 +)
      (a 24.50 0.5 u g q h 1.5 t f 0 f g 00280 824 +)
      (b 27.83 1.54 u g w v 3.75 t t 05 t g 00100 3 +)
      (b 20.17 5.625 u g w v 1.71 t f 0 f s 00120 0 +)
      (b 32.08 4 u g m v 2.5 t f 0 t g 00360 0 +)
      (b 33.17 1.04 u g r h 6.5 t f 0 t g 00164 31285 +)
      (a 22.92 11.585 u g cc v 0.04 t f 0 f g 00080 1349 +)
      (b 54.42 0.5 y p k h 3.96 t f 0 f g 00180 314 +)
      (b 42.50 4.915 y p w v 3.165 t f 0 t g 00052 1442 +)
      (b 22.08 0.83 u g c h 2.165 f f 0 t g 00128 0 +)
      (b 29.92 1.835 u g c h 4.335 t f 0 f g 00260 200 +)
      (a 38.25 6 u g k v 1 t f 0 t g 00000 0 +)
      (b 48.08 6.04 u g k v 0.04 f f 0 f g 00000 2690 +)
      (a 45.83 10.5 u g q v 5 t t 07 t g 00000 0 +)
      (b 36.67 4.415 y p k v 0.25 t t 10 t g 00320 0 +)
      (b 28.25 0.875 u g m v 0.96 t t 03 t g 00396 0 +)
      (a 23.25 5.875 u g q v 3.17 t t 10 f g 00120 245 +)
      (b 21.83 0.25 u g d h 0.665 t f 0 t g 00000 0 +)
      (a 19.17 8.585 u g cc h 0.75 t t 07 f g 00096 0 +)
      (b 25.00 11.25 u g c v 2.5 t t 17 f g 00200 1208 +)
      (b 23.25 1 u g c v 0.835 t f 0 f s 00300 0 +)
      (a 47.75 8 u g c v 7.875 t t 06 t g 00000 1260 +)
      (a 27.42 14.5 u g x h 3.085 t t 01 f g 00120 11 +)
      (a 41.17 6.5 u g q v 0.5 t t 03 t g 00145 0 +)
      (a 15.83 0.585 u g c h 1.5 t t 02 f g 00100 0 +)
      (a 47.00 13 u g i bb 5.165 t t 09 t g 00000 0 +)
      (b 56.58 18.5 u g d bb 15 t t 17 t g 00000 0 +)
      (b 57.42 8.5 u g e h 7 t t 03 f g 00000 0 +)
      (b 42.08 1.04 u g w v 5 t t 06 t g 00500 10000 +)
      (b 29.25 14.79 u g aa v 5.04 t t 05 t g 00168 0 +)
      (b 42.00 9.79 u g x h 7.96 t t 08 f g 00000 0 +)
      (b 49.50 7.585 u g i bb 7.585 t t 15 t g 00000 5000 +)
      (a 36.75 5.125 u g e v 5 t f 0 t g 00000 4000 +)
      (a 22.58 10.75 u g q v 0.415 t t 05 t g 00000 560 +)
      (b 27.83 1.5 u g w v 2 t t 11 t g 00434 35 +)
      (b 27.25 1.585 u g cc h 1.835 t t 12 t g 00583 713 +)
      (a 23.00 11.75 u g x h 0.5 t t 02 t g 00300 551 +)
      (b 27.75 0.585 y p cc v 0.25 t t 02 f g 00260 500 +)
      (b 54.58 9.415 u g ff ff 14.415 t t 11 t g 00030 300 +)
      (b 34.17 9.17 u g c v 4.5 t t 12 t g 00000 221 +)
      (b 28.92 15 u g c h 5.335 t t 11 f g 00000 2283 +)
      (b 29.67 1.415 u g w h 0.75 t t 01 f g 00240 100 +)
      (b 39.58 13.915 u g w v 8.625 t t 06 t g 00070 0 +)
      (b 56.42 28 y p c v 28.5 t t 40 f g 00000 15 +)
      (b 54.33 6.75 u g c h 2.625 t t 11 t g 00000 284 +)
      (a 41.00 2.04 y p q h 0.125 t t 23 t g 00455 1236 +)
      (b 31.92 4.46 u g cc h 6.04 t t 03 f g 00311 300 +)
      (b 41.50 1.54 u g i bb 3.5 f f 0 f g 00216 0 +)
      (b 23.92 0.665 u g c v 0.165 f f 0 f g 00100 0 +)
      (a 25.75 0.5 u g c h 0.875 t f 0 t g 00491 0 +)
      (b 26.00 1 u g q v 1.75 t f 0 t g 00280 0 +)
      (b 37.42 2.04 u g w v 0.04 t f 0 t g 00400 5800 +)
      (b 34.92 2.5 u g w v 0 t f 0 t g 00239 200 +)
      (b 34.25 3 u g cc h 7.415 t f 0 t g 00000 0 +)
      (b 23.33 11.625 y p w v 0.835 t f 0 t g 00160 300 +)
      (b 23.17 0 u g cc v 0.085 t f 0 f g 00000 0 +)
      (b 44.33 0.5 u g i h 5 t f 0 t g 00320 0 +)
      (b 35.17 4.5 u g x h 5.75 f f 0 t s 00711 0 +)
      (b 43.25 3 u g q h 6 t t 11 f g 00080 0 +)
      (b 56.75 12.25 u g m v 1.25 t t 04 t g 00200 0 +)
      (b 31.67 16.165 u g d v 3 t t 09 f g 00250 730 +)
      (a 23.42 0.79 y p q v 1.5 t t 02 t g 00080 400 +)
      (a 20.42 0.835 u g q v 1.585 t t 01 f g 00000 0 +)
      (b 26.67 4.25 u g cc v 4.29 t t 01 t g 00120 0 +)
      (b 34.17 1.54 u g cc v 1.54 t t 01 t g 00520 50000 +)
      (a 36.00 1 u g c v 2 t t 11 f g 00000 456 +)
      (b 25.50 0.375 u g m v 0.25 t t 03 f g 00260 15108 +)
      (b 19.42 6.5 u g w h 1.46 t t 07 f g 00080 2954 +)
      (b 35.17 25.125 u g x h 1.625 t t 01 t g 00515 500 +)
      (b 32.33 7.5 u g e bb 1.585 t f 0 t s 00420 0 -)
      (b 34.83 4 u g d bb 12.5 t f 0 t g ? 0 -)
      (a 38.58 5 u g cc v 13.5 t f 0 t g 00980 0 -)
      (b 44.25 0.5 u g m v 10.75 t f 0 f s 00400 0 -)
      (b 44.83 7 y p c v 1.625 f f 0 f g 00160 2 -)
      (b 20.67 5.29 u g q v 0.375 t t 01 f g 00160 0 -)
      (b 34.08 6.5 u g aa v 0.125 t f 0 t g 00443 0 -)
      (a 19.17 0.585 y p aa v 0.585 t f 0 t g 00160 0 -)
      (b 21.67 1.165 y p k v 2.5 t t 01 f g 00180 20 -)
      (b 21.50 9.75 u g c v 0.25 t f 0 f g 00140 0 -)
      (b 49.58 19 u g ff ff 0 t t 01 f g 00094 0 -)
      (a 27.67 1.5 u g m v 2 t f 0 f s 00368 0 -)
      (b 39.83 0.5 u g m v 0.25 t f 0 f s 00288 0 -)
      (a ? 3.5 u g d v 3 t f 0 t g 00300 0 -)
      (b 27.25 0.625 u g aa v 0.455 t f 0 t g 00200 0 -)
      (b 37.17 4 u g c bb 5 t f 0 t s 00280 0 -)
      (b ? 0.375 u g d v 0.875 t f 0 t s 00928 0 -)
      (b 25.67 2.21 y p aa v 4 t f 0 f g 00188 0 -)
      (b 34.00 4.5 u g aa v 1 t f 0 t g 00240 0 -)
      (a 49.00 1.5 u g j j 0 t f 0 t g 00100 27 -)
      (b 62.50 12.75 y p c h 5 t f 0 f g 00112 0 -)
      (b 31.42 15.5 u g c v 0.5 t f 0 f g 00120 0 -)
      (b ? 5 y p aa v 8.5 t f 0 f g 00000 0 -)
      (b 52.33 1.375 y p c h 9.46 t f 0 t g 00200 100 -)
      (b 28.75 1.5 y p c v 1.5 t f 0 t g 00000 225 -)
      (a 28.58 3.54 u g i bb 0.5 t f 0 t g 00171 0 -)
      (b 23.00 0.625 y p aa v 0.125 t f 0 f g 00180 1 -)
      (b ? 0.5 u g c bb 0.835 t f 0 t s 00320 0 -)
      (a 22.50 11 y p q v 3 t f 0 t g 00268 0 -)
      (a 28.50 1 u g q v 1 t t 02 t g 00167 500 -)
      (b 37.50 1.75 y p c bb 0.25 t f 0 t g 00164 400 -)
      (b 35.25 16.5 y p c v 4 t f 0 f g 00080 0 -)
      (b 18.67 5 u g q v 0.375 t t 02 f g 00000 38 -)
      (b 25.00 12 u g k v 2.25 t t 02 t g 00120 5 -)
      (b 27.83 4 y p i h 5.75 t t 02 t g 00075 0 -)
      (b 54.83 15.5 u g e z 0 t t 20 f g 00152 130 -)
      (b 28.75 1.165 u g k v 0.5 t f 0 f s 00280 0 -)
      (a 25.00 11 y p aa v 4.5 t f 0 f g 00120 0 -)
      (b 40.92 2.25 y p x h 10 t f 0 t g 00176 0 -)
      (a 19.75 0.75 u g c v 0.795 t t 05 t g 00140 5 -)
      (b 29.17 3.5 u g w v 3.5 t t 03 t g 00329 0 -)
      (a 24.50 1.04 y p ff ff 0.5 t t 03 f g 00180 147 -)
      (b 24.58 12.5 u g w v 0.875 t f 0 t g 00260 0 -)
      (a 33.75 0.75 u g k bb 1 t t 03 t g 00212 0 -)
      (b 20.67 1.25 y p c h 1.375 t t 03 t g 00140 210 -)
      (a 25.42 1.125 u g q v 1.29 t t 02 f g 00200 0 -)
      (b 37.75 7 u g q h 11.5 t t 07 t g 00300 5 -)
      (b 52.50 6.5 u g k v 6.29 t t 15 f g 00000 11202 +)
      (b 57.83 7.04 u g m v 14 t t 06 t g 00360 1332 +)
      (a 20.75 10.335 u g cc h 0.335 t t 01 t g 00080 50 +)
      (b 39.92 6.21 u g q v 0.04 t t 01 f g 00200 300 +)
      (b 25.67 12.5 u g cc v 1.21 t t 67 t g 00140 258 +)
      (a 24.75 12.5 u g aa v 1.5 t t 12 t g 00120 567 +)
      (a 44.17 6.665 u g q v 7.375 t t 03 t g 00000 0 +)
      (a 23.50 9 u g q v 8.5 t t 05 t g 00120 0 +)
      (b 34.92 5 u g x h 7.5 t t 06 t g 00000 1000 +)
      (b 47.67 2.5 u g m bb 2.5 t t 12 t g 00410 2510 +)
      (b 22.75 11 u g q v 2.5 t t 07 t g 00100 809 +)
      (b 34.42 4.25 u g i bb 3.25 t t 02 f g 00274 610 +)
      (a 28.42 3.5 u g w v 0.835 t f 0 f s 00280 0 +)
      (b 67.75 5.5 u g e z 13 t t 01 t g 00000 0 +)
      (b 20.42 1.835 u g c v 2.25 t t 01 f g 00100 150 +)
      (a 47.42 8 u g e bb 6.5 t t 06 f g 00375 51100 +)
      (b 36.25 5 u g c bb 2.5 t t 06 f g 00000 367 +)
      (b 32.67 5.5 u g q h 5.5 t t 12 t g 00408 1000 +)
      (b 48.58 6.5 u g q h 6 t f 0 t g 00350 0 +)
      (b 39.92 0.54 y p aa v 0.5 t t 03 f g 00200 1000 +)
      (b 33.58 2.75 u g m v 4.25 t t 06 f g 00204 0 +)
      (a 18.83 9.5 u g w v 1.625 t t 06 t g 00040 600 +)
      (a 26.92 13.5 u g q h 5 t t 02 f g 00000 5000 +)
      (a 31.25 3.75 u g cc h 0.625 t t 09 t g 00181 0 +)
      (a 56.50 16 u g j ff 0 t t 15 f g 00000 247 +)
      (b 43.00 0.29 y p cc h 1.75 t t 08 f g 00100 375 +)
      (b 22.33 11 u g w v 2 t t 01 f g 00080 278 +)
      (b 27.25 1.665 u g cc h 5.085 t t 09 f g 00399 827 +)
      (b 32.83 2.5 u g cc h 2.75 t t 06 f g 00160 2072 +)
      (b 23.25 1.5 u g q v 2.375 t t 03 t g 00000 582 +)
      (a 40.33 7.54 y p q h 8 t t 14 f g 00000 2300 +)
      (a 30.50 6.5 u g c bb 4 t t 07 t g 00000 3065 +)
      (a 52.83 15 u g c v 5.5 t t 14 f g 00000 2200 +)
      (a 46.67 0.46 u g cc h 0.415 t t 11 t g 00440 6 +)
      (a 58.33 10 u g q v 4 t t 14 f g 00000 1602 +)
      (b 37.33 6.5 u g m h 4.25 t t 12 t g 00093 0 +)
      (b 23.08 2.5 u g c v 1.085 t t 11 t g 00060 2184 +)
      (b 32.75 1.5 u g cc h 5.5 t t 03 t g 00000 0 +)
      (a 21.67 11.5 y p j j 0 t t 11 t g 00000 0 +)
      (a 28.50 3.04 y p x h 2.54 t t 01 f g 00070 0 +)
      (a 68.67 15 u g e z 0 t t 14 f g 00000 3376 +)
      (b 28.00 2 u g k h 4.165 t t 02 t g 00181 0 +)
      (b 34.08 0.08 y p m bb 0.04 t t 01 t g 00280 2000 +)
      (b 27.67 2 u g x h 1 t t 04 f g 00140 7544 +)
      (b 44.00 2 u g m v 1.75 t t 02 t g 00000 15 +)
      (b 25.08 1.71 u g x v 1.665 t t 01 t g 00395 20 +)
      (b 32.00 1.75 y p e h 0.04 t f 0 t g 00393 0 +)
      (a 60.58 16.5 u g q v 11 t f 0 t g 00021 10561 +)
      (a 40.83 10 u g q h 1.75 t f 0 f g 00029 837 +)
      (b 19.33 9.5 u g q v 1 t f 0 t g 00060 400 +)
      (a 32.33 0.54 u g cc v 0.04 t f 0 f g 00440 11177 +)
      (b 36.67 3.25 u g q h 9 t f 0 t g 00102 639 +)
      (b 37.50 1.125 y p d v 1.5 f f 0 t g 00431 0 +)
      (a 25.08 2.54 y p aa v 0.25 t f 0 t g 00370 0 +)
      (b 41.33 0 u g c bb 15 t f 0 f g 00000 0 +)
      (b 56.00 12.5 u g k h 8 t f 0 t g 00024 2028 +)
      (a 49.83 13.585 u g k h 8.5 t f 0 t g 00000 0 +)
      (b 22.67 10.5 u g q h 1.335 t f 0 f g 00100 0 +)
      (b 27.00 1.5 y p w v 0.375 t f 0 t g 00260 1065 +)
      (b 25.00 12.5 u g aa v 3 t f 0 t s 00020 0 +)
      (a 26.08 8.665 u g aa v 1.415 t f 0 f g 00160 150 +)
      (a 18.42 9.25 u g q v 1.21 t t 04 f g 00060 540 +)
      (b 20.17 8.17 u g aa v 1.96 t t 14 f g 00060 158 +)
      (b 47.67 0.29 u g c bb 15 t t 20 f g 00000 15000 +)
      (a 21.25 2.335 u g i bb 0.5 t t 04 f s 00080 0 +)
      (a 20.67 3 u g q v 0.165 t t 03 f g 00100 6 +)
      (a 57.08 19.5 u g c v 5.5 t t 07 f g 00000 3000 +)
      (a 22.42 5.665 u g q v 2.585 t t 07 f g 00129 3257 +)
      (b 48.75 8.5 u g c h 12.5 t t 09 f g 00181 1655 +)
      (b 40.00 6.5 u g aa bb 3.5 t t 01 f g 00000 500 +)
      (b 40.58 5 u g c v 5 t t 07 f g 00000 3065 +)
      (a 28.67 1.04 u g c v 2.5 t t 05 t g 00300 1430 +)
      (a 33.08 4.625 u g q h 1.625 t t 02 f g 00000 0 +)
      (b 21.33 10.5 u g c v 3 t f 0 t g 00000 0 +)
      (b 42.00 0.205 u g i h 5.125 t f 0 f g 00400 0 +)
      (b 41.75 0.96 u g x v 2.5 t f 0 f g 00510 600 +)
      (b 22.67 1.585 y p w v 3.085 t t 06 f g 00080 0 +)
      (b 34.50 4.04 y p i bb 8.5 t t 07 t g 00195 0 +)
      (b 28.25 5.04 y p c bb 1.5 t t 08 t g 00144 7 +)
      (b 33.17 3.165 y p x v 3.165 t t 03 t g 00380 0 +)
      (b 48.17 7.625 u g w h 15.5 t t 12 f g 00000 790 +)
      (b 27.58 2.04 y p aa v 2 t t 03 t g 00370 560 +)
      (b 22.58 10.04 u g x v 0.04 t t 09 f g 00060 396 +)
      (a 24.08 0.5 u g q h 1.25 t t 01 f g 00000 678 +)
      (a 41.33 1 u g i bb 2.25 t f 0 t g 00000 300 +)
      (b 24.83 2.75 u g c v 2.25 t t 06 f g ? 600 +)
      (a 20.75 10.25 u g q v 0.71 t t 02 t g 00049 0 +)
      (b 36.33 2.125 y p w v 0.085 t t 01 f g 00050 1187 +)
      (a 35.42 12 u g q h 14 t t 08 f g 00000 6590 +)
      (a 71.58 0 ? ? ? ? 0 f f 0 f p ? 0 +)
      (b 28.67 9.335 u g q h 5.665 t t 06 f g 00381 168 +)
      (b 35.17 2.5 u g k v 4.5 t t 07 f g 00150 1270 +)
      (b 39.50 4.25 u g c bb 6.5 t t 16 f g 00117 1210 +)
      (b 39.33 5.875 u g cc h 10 t t 14 t g 00399 0 +)
      (b 24.33 6.625 y p d v 5.5 t f 0 t s 00100 0 +)
      (b 60.08 14.5 u g ff ff 18 t t 15 t g 00000 1000 +)
      (b 23.08 11.5 u g i v 3.5 t t 09 f g 00056 742 +)
      (b 26.67 2.71 y p cc v 5.25 t t 01 f g 00211 0 +)
      (b 48.17 3.5 u g aa v 3.5 t f 0 f s 00230 0 +)
      (b 41.17 4.04 u g cc h 7 t t 08 f g 00320 0 +)
      (b 55.92 11.5 u g ff ff 5 t t 05 f g 00000 8851 +)
      (b 53.92 9.625 u g e v 8.665 t t 05 f g 00000 0 +)
      (a 18.92 9.25 y p c v 1 t t 04 t g 00080 500 +)
      (a 50.08 12.54 u g aa v 2.29 t t 03 t g 00156 0 +)
      (b 65.42 11 u g e z 20 t t 07 t g 00022 0 +)
      (a 17.58 9 u g aa v 1.375 t f 0 t g 00000 0 +)
      (a 18.83 9.54 u g aa v 0.085 t f 0 f g 00100 0 +)
      (a 37.75 5.5 u g q v 0.125 t f 0 t g 00228 0 +)
      (b 23.25 4 u g c bb 0.25 t f 0 t g 00160 0 +)
      (b 18.08 5.5 u g k v 0.5 t f 0 f g 00080 0 +)
      (a 22.50 8.46 y p x v 2.46 f f 0 f g 00164 0 +)
      (b 19.67 0.375 u g q v 2 t t 02 t g 00080 0 +)
      (b 22.08 11 u g cc v 0.665 t f 0 f g 00100 0 +)
      (b 25.17 3.5 u g cc v 0.625 t t 07 f g 00000 7059 +)
      (a 47.42 3 u g x v 13.875 t t 02 t g 00519 1704 +)
      (b 33.50 1.75 u g x h 4.5 t t 04 t g 00253 857 +)
      (b 27.67 13.75 u g w v 5.75 t f 0 t g 00487 500 +)
      (a 58.42 21 u g i bb 10 t t 13 f g 00000 6700 +)
      (a 20.67 1.835 u g q v 2.085 t t 05 f g 00220 2503 +)
      (b 26.17 0.25 u g i bb 0 t f 0 t g 00000 0 +)
      (b 21.33 7.5 u g aa v 1.415 t t 01 f g 00080 9800 +)
      (b 42.83 4.625 u g q v 4.58 t f 0 f s 00000 0 +)
      (b 38.17 10.125 u g x v 2.5 t t 06 f g 00520 196 +)
      (b 20.50 10 y p c v 2.5 t f 0 f s 00040 0 +)
      (b 48.25 25.085 u g w v 1.75 t t 03 f g 00120 14 +)
      (b 28.33 5 u g w v 11 t f 0 t g 00070 0 +)
      (a 18.75 7.5 u g q v 2.71 t t 05 f g ? 26726 +)
      (b 18.50 2 u g i v 1.5 t t 02 f g 00120 300 +)
      (b 33.17 3.04 y p c h 2.04 t t 01 t g 00180 18027 +)
      (b 45.00 8.5 u g cc h 14 t t 01 t g 00088 2000 +)
      (a 19.67 0.21 u g q h 0.29 t t 11 f g 00080 99 +)
      (? 24.50 12.75 u g c bb 4.75 t t 02 f g 00073 444 +)
      (b 21.83 11 u g x v 0.29 t t 06 f g 00121 0 +)
      (b 40.25 21.5 u g e z 20 t t 11 f g 00000 1200 +)
      (b 41.42 5 u g q h 5 t t 06 t g 00470 0 +)
      (a 17.83 11 u g x h 1 t t 11 f g 00000 3000 +)
      (b 23.17 11.125 u g x h 0.46 t t 01 f g 00100 0 +)
      (b ? 0.625 u g k v 0.25 f f 0 f g 00380 2010 -)
      (b 18.17 10.25 u g c h 1.085 f f 0 f g 00320 13 -)
      (b 20.00 11.045 u g c v 2 f f 0 t g 00136 0 -)
      (b 20.00 0 u g d v 0.5 f f 0 f g 00144 0 -)
      (a 20.75 9.54 u g i v 0.04 f f 0 f g 00200 1000 -)
      (a 24.50 1.75 y p c v 0.165 f f 0 f g 00132 0 -)
      (b 32.75 2.335 u g d h 5.75 f f 0 t g 00292 0 -)
      (a 52.17 0 y p ff ff 0 f f 0 f g 00000 0 -)
      (a 48.17 1.335 u g i o 0.335 f f 0 f g 00000 120 -)
      (a 20.42 10.5 y p x h 0 f f 0 t g 00154 32 -)
      (b 50.75 0.585 u g ff ff 0 f f 0 f g 00145 0 -)
      (b 17.08 0.085 y p c v 0.04 f f 0 f g 00140 722 -)
      (b 18.33 1.21 y p e dd 0 f f 0 f g 00100 0 -)
      (a 32.00 6 u g d v 1.25 f f 0 f g 00272 0 -)
      (b 59.67 1.54 u g q v 0.125 t f 0 t g 00260 0 +)
      (b 18.00 0.165 u g q n 0.21 f f 0 f g 00200 40 +)
      (b 37.58 0 ? ? ? ? 0 f f 0 f p ? 0 +)
      (b 32.33 2.5 u g c v 1.25 f f 0 t g 00280 0 -)
      (b 18.08 6.75 y p m v 0.04 f f 0 f g 00140 0 -)
      (b 38.25 10.125 y p k v 0.125 f f 0 f g 00160 0 -)
      (b 30.67 2.5 u g cc h 2.25 f f 0 t s 00340 0 -)
      (b 18.58 5.71 u g d v 0.54 f f 0 f g 00120 0 -)
      (a 19.17 5.415 u g i h 0.29 f f 0 f g 00080 484 -)
      (a 18.17 10 y p q h 0.165 f f 0 f g 00340 0 -)
      (b 24.58 13.5 y p ff ff 0 f f 0 f g ? 0 -)
      (b 16.25 0.835 u g m v 0.085 t f 0 f s 00200 0 -)
      (b 21.17 0.875 y p c h 0.25 f f 0 f g 00280 204 -)
      (b 23.92 0.585 y p cc h 0.125 f f 0 f g 00240 1 -)
      (b 17.67 4.46 u g c v 0.25 f f 0 f s 00080 0 -)
      (a 16.50 1.25 u g q v 0.25 f t 01 f g 00108 98 -)
      (b 23.25 12.625 u g c v 0.125 f t 02 f g 00000 5552 -)
      (b 17.58 10 u g w h 0.165 f t 01 f g 00120 1 -)
      (a ? 1.5 u g ff ff 0 f t 02 t g 00200 105 -)
      (b 29.50 0.58 u g w v 0.29 f t 01 f g 00340 2803 -)
      (b 18.83 0.415 y p c v 0.165 f t 01 f g 00200 1 -)
      (a 21.75 1.75 y p j j 0 f f 0 f g 00160 0 -)
      (b 23.00 0.75 u g m v 0.5 f f 0 t s 00320 0 -)
      (a 18.25 10 u g w v 1 f t 01 f g 00120 1 -)
      (b 25.42 0.54 u g w v 0.165 f t 01 f g 00272 444 -)
      (b 35.75 2.415 u g w v 0.125 f t 02 f g 00220 1 -)
      (a 16.08 0.335 u g ff ff 0 f t 01 f g 00160 126 -)
      (a 31.92 3.125 u g ff ff 3.04 f t 02 t g 00200 4 -)
      (b 69.17 9 u g ff ff 4 f t 01 f g 00070 6 -)
      (b 32.92 2.5 u g aa v 1.75 f t 02 t g 00720 0 -)
      (b 16.33 2.75 u g aa v 0.665 f t 01 f g 00080 21 -)
      (b 22.17 12.125 u g c v 3.335 f t 02 t g 00180 173 -)
      (a 57.58 2 u g ff ff 6.5 f t 01 f g 00000 10 -)
      (b 18.25 0.165 u g d v 0.25 f f 0 t s 00280 0 -)
      (b 23.42 1 u g c v 0.5 f f 0 t s 00280 0 -)
      (a 15.92 2.875 u g q v 0.085 f f 0 f g 00120 0 -)
      (a 24.75 13.665 u g q h 1.5 f f 0 f g 00280 1 -)
      (b 48.75 26.335 y p ff ff 0 t f 0 t g 00000 0 -)
      (b 23.50 2.75 u g ff ff 4.5 f f 0 f g 00160 25 -)
      (b 18.58 10.29 u g ff ff 0.415 f f 0 f g 00080 0 -)
      (b 27.75 1.29 u g k h 0.25 f f 0 t s 00140 0 -)
      (a 31.75 3 y p j j 0 f f 0 f g 00160 20 -)
      (a 24.83 4.5 u g w v 1 f f 0 t g 00360 6 -)
      (b 19.00 1.75 y p c v 2.335 f f 0 t g 00112 6 -)
      (a 16.33 0.21 u g aa v 0.125 f f 0 f g 00200 1 -)
      (a 18.58 10 u g d v 0.415 f f 0 f g 00080 42 -)
      (b 16.25 0 y p aa v 0.25 f f 0 f g 00060 0 -)
      (b 23.00 0.75 u g m v 0.5 t f 0 t s 00320 0 -)
      (b 21.17 0.25 y p c h 0.25 f f 0 f g 00280 204 -)
      (b 17.50 22 l gg ff o 0 f f 0 t p 00450 100000 +)
      (b 19.17 0 y p m bb 0 f f 0 t s 00500 1 +)
      (b 36.75 0.125 y p c v 1.5 f f 0 t g 00232 113 +)
      (b 21.25 1.5 u g w v 1.5 f f 0 f g 00150 8 +)
      (a 18.08 0.375 l gg cc ff 10 f f 0 t s 00300 0 +)
      (a 33.67 0.375 u g cc v 0.375 f f 0 f g 00300 44 +)
      (b 48.58 0.205 y p k v 0.25 t t 11 f g 00380 2732 +)
      (b 33.67 1.25 u g w v 1.165 f f 0 f g 00120 0 -)
      (a 29.50 1.085 y p x v 1 f f 0 f g 00280 13 -)
      (b 30.17 1.085 y p c v 0.04 f f 0 f g 00170 179 -)
      (? 40.83 3.5 u g i bb 0.5 f f 0 f s 01160 0 -)
      (b 34.83 2.5 y p w v 3 f f 0 f s 00200 0 -)
      (b ? 4 y p i v 0.085 f f 0 t g 00411 0 -)
      (b 20.42 0 ? ? ? ? 0 f f 0 f p ? 0 -)
      (a 33.25 2.5 y p c v 2.5 f f 0 t g 00000 2 -)
      (b 34.08 2.5 u g c v 1 f f 0 f g 00460 16 -)
      (a 25.25 12.5 u g d v 1 f f 0 t g 00180 1062 -)
      (b 34.75 2.5 u g cc bb 0.5 f f 0 f g 00348 0 -)
      (b 27.67 0.75 u g q h 0.165 f f 0 t g 00220 251 -)
      (b 47.33 6.5 u g c v 1 f f 0 t g 00000 228 -)
      (a 34.83 1.25 y p i h 0.5 f f 0 t g 00160 0 -)
      (a 33.25 3 y p aa v 2 f f 0 f g 00180 0 -)
      (b 28.00 3 u g w v 0.75 f f 0 t g 00300 67 -)
      (a 39.08 4 u g c v 3 f f 0 f g 00480 0 -)
      (b 42.75 4.085 u g aa v 0.04 f f 0 f g 00108 100 -)
      (b 26.92 2.25 u g i bb 0.5 f f 0 t g 00640 4000 -)
      (b 33.75 2.75 u g i bb 0 f f 0 f g 00180 0 -)
      (b 38.92 1.75 u g k v 0.5 f f 0 t g 00300 2 -)
      (b 62.75 7 u g e z 0 f f 0 f g 00000 12 -)
      (? 32.25 1.5 u g c v 0.25 f f 0 t g 00372 122 -)
      (b 26.75 4.5 y p c bb 2.5 f f 0 f g 00200 1210 -)
      (b 63.33 0.54 u g c v 0.585 t t 03 t g 00180 0 -)
      (b 27.83 1.5 u g w v 2.25 f t 01 t g 00100 3 -)
      (a 26.17 2 u g j j 0 f f 0 t g 00276 1 -)
      (b 22.17 0.585 y p ff ff 0 f f 0 f g 00100 0 -)
      (b 22.50 11.5 y p m v 1.5 f f 0 t g 00000 4000 -)
      (b 30.75 1.585 u g d v 0.585 f f 0 t s 00000 0 -)
      (b 36.67 2 u g i v 0.25 f f 0 t g 00221 0 -)
      (a 16.00 0.165 u g aa v 1 f t 02 t g 00320 1 -)
      (b 41.17 1.335 u g d v 0.165 f f 0 f g 00168 0 -)
      (a 19.50 0.165 u g q v 0.04 f f 0 t g 00380 0 -)
      (b 32.42 3 u g d v 0.165 f f 0 t g 00120 0 -)
      (a 36.75 4.71 u g ff ff 0 f f 0 f g 00160 0 -)
      (a 30.25 5.5 u g k v 5.5 f f 0 t s 00100 0 -)
      (b 23.08 2.5 u g ff ff 0.085 f f 0 t g 00100 4208 -)
      (b 26.83 0.54 u g k ff 0 f f 0 f g 00100 0 -)
      (b 16.92 0.335 y p k v 0.29 f f 0 f s 00200 0 -)
      (b 24.42 2 u g e dd 0.165 f t 02 f g 00320 1300 -)
      (b 42.83 1.25 u g m v 13.875 f t 01 t g 00352 112 -)
      (a 22.75 6.165 u g aa v 0.165 f f 0 f g 00220 1000 -)
      (b 39.42 1.71 y p m v 0.165 f f 0 f s 00400 0 -)
      (a 23.58 11.5 y p k h 3 f f 0 t g 00020 16 -)
      (b 21.42 0.75 y p r n 0.75 f f 0 t g 00132 2 -)
      (b 33.00 2.5 y p w v 7 f f 0 t g 00280 0 -)
      (b 26.33 13 u g e dd 0 f f 0 t g 00140 1110 -)
      (a 45.00 4.585 u g k h 1 f f 0 t s 00240 0 -)
      (b 26.25 1.54 u g w v 0.125 f f 0 f g 00100 0 -)
      (? 28.17 0.585 u g aa v 0.04 f f 0 f g 00260 1004 -)
      (a 20.83 0.5 y p e dd 1 f f 0 f g 00260 0 -)
      (b 28.67 14.5 u g d v 0.125 f f 0 f g 00000 286 -)
      (b 20.67 0.835 y p c v 2 f f 0 t s 00240 0 -)
      (b 34.42 1.335 u g i bb 0.125 f f 0 t g 00440 4500 -)
      (b 33.58 0.25 u g i bb 4 f f 0 t s 00420 0 -)
      (b 43.17 5 u g i bb 2.25 f f 0 t g 00141 0 -)
      (a 22.67 7 u g c v 0.165 f f 0 f g 00160 0 -)
      (a 24.33 2.5 y p i bb 4.5 f f 0 f g 00200 456 -)
      (a 56.83 4.25 y p ff ff 5 f f 0 t g 00000 4 -)
      (b 22.08 11.46 u g k v 1.585 f f 0 t g 00100 1212 -)
      (b 34.00 5.5 y p c v 1.5 f f 0 t g 00060 0 -)
      (b 22.58 1.5 y p aa v 0.54 f f 0 t g 00120 67 -)
      (b 21.17 0 u g c v 0.5 f f 0 t s 00000 0 -)
      (b 26.67 14.585 u g i bb 0 f f 0 t g 00178 0 -)
      (b 22.92 0.17 u g m v 0.085 f f 0 f s 00000 0 -)
      (b 15.17 7 u g e v 1 f f 0 f g 00600 0 -)
      (b 39.92 5 u g i bb 0.21 f f 0 f g 00550 0 -)
      (b 27.42 12.5 u g aa bb 0.25 f f 0 t g 00720 0 -)
      (b 24.75 0.54 u g m v 1 f f 0 t g 00120 1 -)
      (b 41.17 1.25 y p w v 0.25 f f 0 f g 00000 195 -)
      (a 33.08 1.625 u g d v 0.54 f f 0 t g 00000 0 -)
      (b 29.83 2.04 y p x h 0.04 f f 0 f g 00128 1 -)
      (a 23.58 0.585 y p ff ff 0.125 f f 0 f g 00120 87 -)
      (b 26.17 12.5 y p k h 1.25 f f 0 t g 00000 17 -)
      (b 31.00 2.085 u g c v 0.085 f f 0 f g 00300 0 -)
      (b 20.75 5.085 y p j v 0.29 f f 0 f g 00140 184 -)
      (b 28.92 0.375 u g c v 0.29 f f 0 f g 00220 140 -)
      (a 51.92 6.5 u g i bb 3.085 f f 0 t g 00073 0 -)
      (a 22.67 0.335 u g q v 0.75 f f 0 f s 00160 0 -)
      (b 34.00 5.085 y p i bb 1.085 f f 0 t g 00480 0 -)
      (a 69.50 6 u g ff ff 0 f f 0 f s 00000 0 -)
      (a 40.33 8.125 y p k v 0.165 f t 02 f g ? 18 -)
      (a 19.58 0.665 y p c v 1 f t 01 f g 02000 2 -)
      (b 16.00 3.125 u g w v 0.085 f t 01 f g 00000 6 -)
      (b 17.08 0.25 u g q v 0.335 f t 04 f g 00160 8 -)
      (b 31.25 2.835 u g ff ff 0 f t 05 f g 00176 146 -)
      (b 25.17 3 u g c v 1.25 f t 01 f g 00000 22 -)
      (a 22.67 0.79 u g i v 0.085 f f 0 f g 00144 0 -)
      (b 40.58 1.5 u g i bb 0 f f 0 f s 00300 0 -)
      (b 22.25 0.46 u g k v 0.125 f f 0 t g 00280 55 -)
      (a 22.25 1.25 y p ff ff 3.25 f f 0 f g 00280 0 -)
      (b 22.50 0.125 y p k v 0.125 f f 0 f g 00200 70 -)
      (b 23.58 1.79 u g c v 0.54 f f 0 t g 00136 1 -)
      (b 38.42 0.705 u g c v 0.375 f t 02 f g 00225 500 -)
      (a 26.58 2.54 y p ff ff 0 f f 0 t g 00180 60 -)
      (b 35.00 2.5 u g i v 1 f f 0 t g 00210 0 -)
      (b 20.42 1.085 u g q v 1.5 f f 0 f g 00108 7 -)
      (b 29.42 1.25 u g w v 1.75 f f 0 f g 00200 0 -)
      (b 26.17 0.835 u g cc v 1.165 f f 0 f g 00100 0 -)
      (b 33.67 2.165 u g c v 1.5 f f 0 f p 00120 0 -)
      (b 24.58 1.25 u g c v 0.25 f f 0 f g 00110 0 -)
      (a 27.67 2.04 u g w v 0.25 f f 0 t g 00180 50 -)
      (b 37.50 0.835 u g e v 0.04 f f 0 f g 00120 5 -)
      (b 49.17 2.29 u g ff ff 0.29 f f 0 f g 00200 3 -)
      (b 33.58 0.335 y p cc v 0.085 f f 0 f g 00180 0 -)
      (b 51.83 3 y p ff ff 1.5 f f 0 f g 00180 4 -)
      (b 22.92 3.165 y p c v 0.165 f f 0 f g 00160 1058 -)
      (b 21.83 1.54 u g k v 0.085 f f 0 t g 00356 0 -)
      (b 25.25 1 u g aa v 0.5 f f 0 f g 00200 0 -)
      (b 58.58 2.71 u g c v 2.415 f f 0 t g 00320 0 -)
      (b 19.00 0 y p ff ff 0 f t 04 f g 00045 1 -)
      (b 19.58 0.585 u g ff ff 0 f t 03 f g 00350 769 -)
      (a 53.33 0.165 u g ff ff 0 f f 0 t s 00062 27 -)
      (a 27.17 1.25 u g ff ff 0 f t 01 f g 00092 300 -)
      (b 25.92 0.875 u g k v 0.375 f t 02 t g 00174 3 -)
      (b 23.08 0 u g k v 1 f t 11 f s 00000 0 -)
      (b 39.58 5 u g ff ff 0 f t 02 f g 00017 1 -)
      (b 30.58 2.71 y p m v 0.125 f f 0 t s 00080 0 -)
      (b 17.25 3 u g k v 0.04 f f 0 t g 00160 40 -)
      (a 17.67 0 y p j ff 0 f f 0 f g 00086 0 -)
      (a ? 11.25 u g ff ff 0 f f 0 f g ? 5200 -)
      (b 16.50 0.125 u g c v 0.165 f f 0 f g 00132 0 -)
      (a 27.33 1.665 u g ff ff 0 f f 0 f g 00340 1 -)
      (b 31.25 1.125 u g ff ff 0 f t 01 f g 00096 19 -)
      (b 20.00 7 u g c v 0.5 f f 0 f g 00000 0 -)
      (b ? 3 y p i bb 7 f f 0 f g 00000 1 -)
      (b 39.50 1.625 u g c v 1.5 f f 0 f g 00000 316 -)
      (b 36.50 4.25 u g q v 3.5 f f 0 f g 00454 50 -)
      (? 29.75 0.665 u g w v 0.25 f f 0 t g 00300 0 -)
      (b 52.42 1.5 u g d v 3.75 f f 0 t g 00000 350 -)
      (b 36.17 18.125 u g w v 0.085 f f 0 f g 00320 3552 -)
      (b 34.58 0 ? ? ? ? 0 f f 0 f p ? 0 -)
      (b 29.67 0.75 y p c v 0.04 f f 0 f g 00240 0 -)
      (b 36.17 5.5 u g i bb 5 f f 0 f g 00210 687 -)
      (b 25.67 0.29 y p c v 1.5 f f 0 t g 00160 0 -)
      (a 24.50 2.415 y p c v 0 f f 0 f g 00120 0 -)
      (b 24.08 0.875 u g m v 0.085 f t 04 f g 00254 1950 -)
      (b 21.92 0.5 u g c v 0.125 f f 0 f g 00360 0 -)
      (a 36.58 0.29 u g ff ff 0 f t 10 f g 00200 18 -)
      (a 23.00 1.835 u g j j 0 f t 01 f g 00200 53 -)
      (a 27.58 3 u g m v 2.79 f t 01 t g 00280 10 -)
      (b 31.08 3.085 u g c v 2.5 f t 02 t g 00160 41 -)
      (a 30.42 1.375 u g w h 0.04 f t 03 f g 00000 33 -)
      (b 22.08 2.335 u g k v 0.75 f f 0 f g 00180 0 -)
      (b 16.33 4.085 u g i h 0.415 f f 0 t g 00120 0 -)
      (a 21.92 11.665 u g k h 0.085 f f 0 f g 00320 5 -)
      (b 21.08 4.125 y p i h 0.04 f f 0 f g 00140 100 -)
      (b 17.42 6.5 u g i v 0.125 f f 0 f g 00060 100 -)
      (b 19.17 4 y p i v 1 f f 0 t g 00360 1000 -)
      (b 20.67 0.415 u g c v 0.125 f f 0 f g 00000 44 -)
      (b 26.75 2 u g d v 0.75 f f 0 t g 00080 0 -)
      (b 23.58 0.835 u g i h 0.085 f f 0 t g 00220 5 -)
      (b 39.17 2.5 y p i h 10 f f 0 t s 00200 0 -)
      (b 22.75 11.5 u g i v 0.415 f f 0 f g 00000 0 -)
      (? 26.50 2.71 y p ? ? 0.085 f f 0 f s 00080 0 -)
      (a 16.92 0.5 u g i v 0.165 f t 06 t g 00240 35 -)
      (b 23.50 3.165 y p k v 0.415 f t 01 t g 00280 80 -)
      (a 17.33 9.5 u g aa v 1.75 f t 10 t g 00000 10 -)
      (b 23.75 0.415 y p c v 0.04 f t 02 f g 00128 6 -)
      (b 34.67 1.08 u g m v 1.165 f f 0 f s 00028 0 -)
      (b 74.83 19 y p ff ff 0.04 f t 02 f g 00000 351 -)
      (b 28.17 0.125 y p k v 0.085 f f 0 f g 00216 2100 -)
      (b 24.50 13.335 y p aa v 0.04 f f 0 t g 00120 475 -)
      (b 18.83 3.54 y p ff ff 0 f f 0 t g 00180 1 -)
      (? 45.33 1 u g q v 0.125 f f 0 t g 00263 0 -)
      (a 47.25 0.75 u g q h 2.75 t t 01 f g 00333 892 +)
      (b 24.17 0.875 u g q v 4.625 t t 02 t g 00520 2000 +)
      (b 39.25 9.5 u g m v 6.5 t t 14 f g 00240 4607 +)
      (a 20.50 11.835 u g c h 6 t f 0 f g 00340 0 +)
      (a 18.83 4.415 y p c h 3 t f 0 f g 00240 0 +)
      (b 19.17 9.5 u g w v 1.5 t f 0 f g 00120 2206 +)
      (a 25.00 0.875 u g x h 1.04 t f 0 t g 00160 5860 +)
      (b 20.17 9.25 u g c v 1.665 t t 03 t g 00040 28 +)
      (b 25.75 0.5 u g c v 1.46 t t 05 t g 00312 0 +)
      (b 20.42 7 u g c v 1.625 t t 03 f g 00200 1391 +)
      (b ? 4 u g x v 5 t t 03 t g 00290 2279 +)
      (b 39.00 5 u g cc v 3.5 t t 10 t g 00000 0 +)
      (a 64.08 0.165 u g ff ff 0 t t 01 f g 00232 100 +)
      (b 28.25 5.125 u g x v 4.75 t t 02 f g 00420 7 +)
      (a 28.75 3.75 u g c v 1.085 t t 01 t g 00371 0 +)
      (b 31.33 19.5 u g c v 7 t t 16 f g 00000 5000 +)
      (a 18.92 9 u g aa v 0.75 t t 02 f g 00088 591 +)
      (a 24.75 3 u g q h 1.835 t t 19 f g 00000 500 +)
      (a 30.67 12 u g c v 2 t t 01 f g 00220 19 +)
      (b 21.00 4.79 y p w v 2.25 t t 01 t g 00080 300 +)
      (b 13.75 4 y p w v 1.75 t t 02 t g 00120 1000 +)
      (a 46.00 4 u g j j 0 t f 0 f g 00100 960 +)
      (a 44.33 0 u g c v 2.5 t f 0 f g 00000 0 +)
      (b 20.25 9.96 u g e dd 0 t f 0 f g 00000 0 +)
      (b 22.67 2.54 y p c h 2.585 t f 0 f g 00000 0 +)
      (b ? 10.5 u g x v 6.5 t f 0 f g 00000 0 +)
      (a 60.92 5 u g aa v 4 t t 04 f g 00000 99 +)
      (b 16.08 0.75 u g c v 1.75 t t 05 t g 00352 690 +)
      (a 28.17 0.375 u g q v 0.585 t t 04 f g 00080 0 +)
      (b 39.17 1.71 u g x v 0.125 t t 05 t g 00480 0 +)
      (? 20.42 7.5 u g k v 1.5 t t 01 f g 00160 234 +)
      (a 30.00 5.29 u g e dd 2.25 t t 05 t g 00099 500 +)
      (b 22.83 3 u g m v 1.29 t t 01 f g 00260 800 +)
      (a 22.50 8.5 u g q v 1.75 t t 10 f g 00080 990 -)
      (a 28.58 1.665 u g q v 2.415 t f 0 t g 00440 0 -)
      (b 45.17 1.5 u g c v 2.5 t f 0 t g 00140 0 -)
      (b 41.58 1.75 u g k v 0.21 t f 0 f g 00160 0 -)
      (a 57.08 0.335 u g i bb 1 t f 0 t g 00252 2197 -)
      (a 55.75 7.08 u g k h 6.75 t t 03 t g 00100 50 -)
      (b 43.25 25.21 u g q h 0.21 t t 01 f g 00760 90 -)
      (a 25.33 2.085 u g c h 2.75 t f 0 t g 00360 1 -)
      (a 24.58 0.67 u g aa h 1.75 t f 0 f g 00400 0 -)
      (b 43.17 2.25 u g i bb 0.75 t f 0 f g 00560 0 -)
      (b 40.92 0.835 u g ff ff 0 t f 0 f g 00130 1 -)
      (b 31.83 2.5 u g aa v 7.5 t f 0 t g 00523 0 -)
      (a 33.92 1.585 y p ff ff 0 t f 0 f g 00320 0 -)
      (a 24.92 1.25 u g ff ff 0 t f 0 f g 00080 0 -)
      (b 35.25 3.165 u g x h 3.75 t f 0 t g 00680 0 -)
      (b 34.25 1.75 u g w bb 0.25 t f 0 t g 00163 0 -)
      (b 80.25 5.5 u g ? ? 0.54 t f 0 f g 00000 340 -)
      (b 19.42 1.5 y p cc v 2 t f 0 t g 00100 20 -)
      (b 42.75 3 u g i bb 1 t f 0 f g 00000 200 -)
      (b 19.67 10 y p k h 0.835 t f 0 t g 00140 0 -)
      (b 36.33 3.79 u g w v 1.165 t f 0 t g 00200 0 -)
      (b 30.08 1.04 y p i bb 0.5 t t 10 t g 00132 28 -)
      (b 44.25 11 y p d v 1.5 t f 0 f s 00000 0 -)
      (b 23.58 0.46 y p w v 2.625 t t 06 t g 00208 347 -)
      (b 23.92 1.5 u g d h 1.875 t t 06 f g 00200 327 +)
      (b 33.17 1 u g x v 0.75 t t 07 t g 00340 4071 +)
      (b 48.33 12 u g m v 16 t f 0 f s 00110 0 +)
      (b 76.75 22.29 u g e z 12.75 t t 01 t g 00000 109 +)
      (b 51.33 10 u g i bb 0 t t 11 f g 00000 1249 +)
      (b 34.75 15 u g r n 5.375 t t 09 t g 00000 134 +)
      (b 38.58 3.335 u g w v 4 t t 14 f g 00383 1344 +)
      (a 22.42 11.25 y p x h 0.75 t t 04 f g 00000 321 +)
      (b 41.92 0.42 u g c h 0.21 t t 06 f g 00220 948 +)
      (b 29.58 4.5 u g w v 7.5 t t 02 t g 00330 0 +)
      (a 32.17 1.46 u g w v 1.085 t t 16 f g 00120 2079 +)
      (b 51.42 0.04 u g x h 0.04 t f 0 f g 00000 3000 +)
      (a 22.83 2.29 u g q h 2.29 t t 07 t g 00140 2384 +)
      (a 25.00 12.33 u g cc h 3.5 t t 06 f g 00400 458 +)
      (b 26.75 1.125 u g x h 1.25 t f 0 f g 00000 5298 +)
      (b 23.33 1.5 u g c h 1.415 t f 0 f g 00422 200 +)
      (b 24.42 12.335 u g q h 1.585 t f 0 t g 00120 0 +)
      (b 42.17 5.04 u g q h 12.75 t f 0 t g 00092 0 +)
      (a 20.83 3 u g aa v 0.04 t f 0 f g 00100 0 +)
      (b 23.08 11.5 u g w h 2.125 t t 11 t g 00290 284 +)
      (a 25.17 2.875 u g x h 0.875 t f 0 f g 00360 0 +)
      (b 43.08 0.375 y p c v 0.375 t t 08 t g 00300 162 +)
      (a 35.75 0.915 u g aa v 0.75 t t 04 f g 00000 1583 +)
      (b 59.50 2.75 u g w v 1.75 t t 05 t g 00060 58 +)
      (b 21.00 3 y p d v 1.085 t t 08 t g 00160 1 +)
      (b 21.92 0.54 y p x v 0.04 t t 01 t g 00840 59 +)
      (a 65.17 14 u g ff ff 0 t t 11 t g 00000 1400 +)
      (a 20.33 10 u g c h 1 t t 04 f g 00050 1465 +)
      (b 32.25 0.165 y p c h 3.25 t t 01 t g 00432 8000 +)
      (b 30.17 0.5 u g c v 1.75 t t 11 f g 00032 540 +)
      (b 25.17 6 u g c v 1 t t 03 f g 00000 0 +)
      (b 39.17 1.625 u g c v 1.5 t t 10 f g 00186 4700 +)
      (b 39.08 6 u g m v 1.29 t t 05 t g 00108 1097 +)
      (b 31.67 0.83 u g x v 1.335 t t 08 t g 00303 3290 +)
      (b 41.00 0.04 u g e v 0.04 f t 01 f s 00560 0 +)
      (b 48.50 4.25 u g m v 0.125 t f 0 t g 00225 0 +)
      (b 32.67 9 y p w h 5.25 t f 0 t g 00154 0 +)
      (a 28.08 15 y p e z 0 t f 0 f g 00000 13212 +)
      (b 73.42 17.75 u g ff ff 0 t f 0 t g 00000 0 +)
      (b 64.08 20 u g x h 17.5 t t 09 t g 00000 1000 +)
      (b 51.58 15 u g c v 8.5 t t 09 f g 00000 0 +)
      (b 26.67 1.75 y p c v 1 t t 05 t g 00160 5777 +)
      (b 25.33 0.58 u g c v 0.29 t t 07 t g 00096 5124 +)
      (b 30.17 6.5 u g cc v 3.125 t t 08 f g 00330 1200 +)
      (b 27.00 0.75 u g c h 4.25 t t 03 t g 00312 150 +)
      (b 23.17 0 ? ? ? ? 0 f f 0 f p ? 0 +)
      (b 34.17 5.25 u g w v 0.085 f f 0 t g 00290 6 +)
      (b 38.67 0.21 u g k v 0.085 t f 0 t g 00280 0 +)
      (b 25.75 0.75 u g c bb 0.25 t f 0 f g 00349 23 +)
      (a 46.08 3 u g c v 2.375 t t 08 t g 00396 4159 +)
      (a 21.50 6 u g aa v 2.5 t t 03 f g 00080 918 +)
      (? 20.08 0.125 u g q v 1 f t 01 f g 00240 768 +)
      (b 20.50 2.415 u g c v 2 t t 11 t g 00200 3000 +)
      (a 29.50 0.46 u g k v 0.54 t t 04 f g 00380 500 +)
      (? 42.25 1.75 y p ? ? 0 f f 0 t g 00150 1 -)
      (b 29.83 1.25 y p k v 0.25 f f 0 f g 00224 0 -)
      (b 20.08 0.25 u g q v 0.125 f f 0 f g 00200 0 -)
      (b 23.42 0.585 u g c h 0.085 t f 0 f g 00180 0 -)
      (a 29.58 1.75 y p k v 1.25 f f 0 t g 00280 0 -)
      (b 16.17 0.04 u g c v 0.04 f f 0 f g 00000 0 +)
      (b 32.33 3.5 u g k v 0.5 f f 0 t g 00232 0 -)
      (b ? 0.04 y p d v 4.25 f f 0 t g 00460 0 -)
      (b 47.83 4.165 u g x bb 0.085 f f 0 t g 00520 0 -)
      (b 20.00 1.25 y p k v 0.125 f f 0 f g 00140 4 -)
      (b 27.58 3.25 y p q h 5.085 f t 02 t g 00369 1 -)
      (b 22.00 0.79 u g w v 0.29 f t 01 f g 00420 283 -)
      (b 19.33 10.915 u g c bb 0.585 f t 02 t g 00200 7 -)
      (a 38.33 4.415 u g c v 0.125 f f 0 f g 00160 0 -)
      (b 29.42 1.25 u g c h 0.25 f t 02 t g 00400 108 -)
      (b 22.67 0.75 u g i v 1.585 f t 01 t g 00400 9 -)
      (b 32.25 14 y p ff ff 0 f t 02 f g 00160 1 -)
      (b 29.58 4.75 u g m v 2 f t 01 t g 00460 68 -)
      (b 18.42 10.415 y p aa v 0.125 t f 0 f g 00120 375 -)
      (b 22.17 2.25 u g i v 0.125 f f 0 f g 00160 10 -)
      (b 22.67 0.165 u g c j 2.25 f f 0 t s 00000 0 +)
      (a 25.58 0 ? ? ? ? 0 f f 0 f p ? 0 +)
      (b 18.83 0 u g q v 0.665 f f 0 f g 00160 1 -)
      (b 21.58 0.79 y p cc v 0.665 f f 0 f g 00160 0 -)
      (b 23.75 12 u g c v 2.085 f f 0 f s 00080 0 -)
      (b 22.00 7.835 y p i bb 0.165 f f 0 t g ? 0 -)
      (b 36.08 2.54 u g ff ff 0 f f 0 f g 00000 1000 -)
      (b 29.25 13 u g d h 0.5 f f 0 f g 00228 0 -)
      (a 19.58 0.665 u g w v 1.665 f f 0 f g 00220 5 -)
      (a 22.92 1.25 u g q v 0.25 f f 0 t g 00120 809 -)
      (a 27.25 0.29 u g m h 0.125 f t 01 t g 00272 108 -)
      (a 38.75 1.5 u g ff ff 0 f f 0 f g 00076 0 -)
      (b 32.42 2.165 y p k ff 0 f f 0 f g 00120 0 -)
      (a 23.75 0.71 u g w v 0.25 f t 01 t g 00240 4 -)
      (b 18.17 2.46 u g c n 0.96 f t 02 t g 00160 587 -)
      (b 40.92 0.5 y p m v 0.5 f f 0 t g 00130 0 -)
      (b 19.50 9.585 u g aa v 0.79 f f 0 f g 00080 350 -)
      (b 28.58 3.625 u g aa v 0.25 f f 0 t g 00100 0 -)
      (b 35.58 0.75 u g k v 1.5 f f 0 t g 00231 0 -)
      (b 34.17 2.75 u g i bb 2.5 f f 0 t g 00232 200 -)
      (? 33.17 2.25 y p cc v 3.5 f f 0 t g 00200 141 -)
      (b 31.58 0.75 y p aa v 3.5 f f 0 t g 00320 0 -)
      (a 52.50 7 u g aa h 3 f f 0 f g 00000 0 -)
      (b 36.17 0.42 y p w v 0.29 f f 0 t g 00309 2 -)
      (b 37.33 2.665 u g cc v 0.165 f f 0 t g 00000 501 -)
      (a 20.83 8.5 u g c v 0.165 f f 0 f g 00000 351 -)
      (b 24.08 9 u g aa v 0.25 f f 0 t g 00000 0 -)
      (b 25.58 0.335 u g k h 3.5 f f 0 t g 00340 0 -)
      (a 35.17 3.75 u g ff ff 0 f t 06 f g 00000 200 -)
      (b 48.08 3.75 u g i bb 1 f f 0 f g 00100 2 -)
      (a 15.83 7.625 u g q v 0.125 f t 01 t g 00000 160 -)
      (a 22.50 0.415 u g i v 0.335 f f 0 t s 00144 0 -)
      (b 21.50 11.5 u g i v 0.5 t f 0 t g 00100 68 -)
      (a 23.58 0.83 u g q v 0.415 f t 01 t g 00200 11 -)
      (a 21.08 5 y p ff ff 0 f f 0 f g 00000 0 -)
      (b 25.67 3.25 u g c h 2.29 f t 01 t g 00416 21 -)
      (a 38.92 1.665 u g aa v 0.25 f f 0 f g 00000 390 -)
      (a 15.75 0.375 u g c v 1 f f 0 f g 00120 18 -)
      (a 28.58 3.75 u g c v 0.25 f t 01 t g 00040 154 -)
      (b 22.25 9 u g aa v 0.085 f f 0 f g 00000 0 -)
      (b 29.83 3.5 u g c v 0.165 f f 0 f g 00216 0 -)
      (a 23.50 1.5 u g w v 0.875 f f 0 t g 00160 0 -)
      (b 32.08 4 y p cc v 1.5 f f 0 t g 00120 0 -)
      (b 31.08 1.5 y p w v 0.04 f f 0 f s 00160 0 -)
      (b 31.83 0.04 y p m v 0.04 f f 0 f g 00000 0 -)
      (a 21.75 11.75 u g c v 0.25 f f 0 t g 00180 0 -)
      (a 17.92 0.54 u g c v 1.75 f t 01 t g 00080 5 -)
      (b 30.33 0.5 u g d h 0.085 f f 0 t s 00252 0 -)
      (b 51.83 2.04 y p ff ff 1.5 f f 0 f g 00120 1 -)
      (b 47.17 5.835 u g w v 5.5 f f 0 f g 00465 150 -)
      (b 25.83 12.835 u g cc v 0.5 f f 0 f g 00000 2 -)
      (a 50.25 0.835 u g aa v 0.5 f f 0 t g 00240 117 -)
      (? 29.50 2 y p e h 2 f f 0 f g 00256 17 -)
      (a 37.33 2.5 u g i h 0.21 f f 0 f g 00260 246 -)
      (a 41.58 1.04 u g aa v 0.665 f f 0 f g 00240 237 -)
      (a 30.58 10.665 u g q h 0.085 f t 12 t g 00129 3 -)
      (b 19.42 7.25 u g m v 0.04 f t 01 f g 00100 1 -)
      (a 17.92 10.21 u g ff ff 0 f f 0 f g 00000 50 -)
      (a 20.08 1.25 u g c v 0 f f 0 f g 00000 0 -)
      (b 19.50 0.29 u g k v 0.29 f f 0 f g 00280 364 -)
      (b 27.83 1 y p d h 3 f f 0 f g 00176 537 -)
      (b 17.08 3.29 u g i v 0.335 f f 0 t g 00140 2 -)
      (b 36.42 0.75 y p d v 0.585 f f 0 f g 00240 3 -)
      (b 40.58 3.29 u g m v 3.5 f f 0 t s 00400 0 -)
      (b 21.08 10.085 y p e h 1.25 f f 0 f g 00260 0 -)
      (a 22.67 0.75 u g c v 2 f t 02 t g 00200 394 -)
      (a 25.25 13.5 y p ff ff 2 f t 01 t g 00200 1 -)
      (b 17.92 0.205 u g aa v 0.04 f f 0 f g 00280 750 -)
      (b 35.00 3.375 u g c h 8.29 f f 0 t g 00000 0 -)
      )))
