;% 1. Title of Database: Primate splice-junction gene sequences (DNA)
;%                       with associated imperfect domain theory
;%
;% 2. Sources:
;%    (a) Creators:
;%        - all examples taken from Genbank 64.1 (ftp site: genbank.bio.net)
;%        - categories "ei" and "ie" include every "split-gene"
;%          for primates in Genbank 64.1
;%        - non-splice examples taken from sequences known not to include
;%          a splicing site
;%    (b) Donor: G. Towell, M. Noordewier, and J. Shavlik,
;%               {towell,shavlik}@cs.wisc.edu, noordewi@cs.rutgers.edu
;%    (c) Date received: 1/1/92
;%
;% 3. Past Usage:
;%    (a) machine learning:
;%        	-- M. O. Noordewier and G. G. Towell and J. W. Shavlik, 1991;
;%            "Training Knowledge-Based Neural Networks to Recognize Genes in
;%            DNA Sequences".  Advances in Neural Information Processing Systems,
;%            volume 3, Morgan Kaufmann.
;%
;% 	-- G. G. Towell and J. W. Shavlik and M. W. Craven, 1991;
;%            "Constructive Induction in Knowledge-Based Neural Networks",
;%            In Proceedings of the Eighth International Machine Learning
;% 	   Workshop, Morgan Kaufmann.
;%
;%         -- G. G. Towell, 1991;
;%            "Symbolic Knowledge and Neural Networks: Insertion, Refinement, and
;%            Extraction", PhD Thesis, University of Wisconsin - Madison.
;%
;%         -- G. G. Towell and J. W. Shavlik, 1992;
;%            "Interpretation of Artificial Neural Networks: Mapping
;%            Knowledge-based Neural Networks into Rules", In Advances in Neural
;%            Information Processing Systems, volume 4, Morgan Kaufmann.
;%
;%    (b) attributes predicted: given a position in the middle of a window
;%        60 DNA sequence elements (called "nucleotides" or "base-pairs"),
;%        decide if this is a
;% 	a) "intron -> exon" boundary (ie) [These are sometimes called "donors"]
;% 	b) "exon -> intron" boundary (ei) [These are sometimes called "acceptors"]
;% 	c) neither                      (n)
;%    (c) Results of study indicated that machine learning techniques (neural
;%        networks, nearest neighbor, contributors' KBANN system) performed as
;%        well/better than classification based on canonical pattern matching
;%        (method used in biological literature).
;%
;% 4. Relevant Information Paragraph:
;%    Problem Description:
;%       Splice junctions are points on a DNA sequence at which `superfluous' DNA is
;%       removed during the process of protein creation in higher organisms.  The
;%       problem posed in this dataset is to recognize, given a sequence of DNA, the
;%       boundaries between exons (the parts of the DNA sequence retained after
;%       splicing) and introns (the parts of the DNA sequence that are spliced
;%       out). This problem consists of two subtasks: recognizing exon/intron
;%       boundaries (referred to as EI sites), and recognizing intron/exon boundaries
;%       (IE sites). (In the biological community, IE borders are referred to
;%       a ``acceptors'' while EI borders are referred to as ``donors''.)
;%
;%    This dataset has been developed to help evaluate a "hybrid" learning
;%    algorithm (KBANN) that uses examples to inductively refine preexisting
;%    knowledge.  Using a "ten-fold cross-validation" methodology on 1000
;%    examples randomly selected from the complete set of 3190, the following
;%    error rates were produced by various ML algorithms (all experiments
;%    run at the Univ of Wisconsin, sometimes with local implementations
;%    of published algorithms).
;%
;%                 System	       Neither    EI      IE
;%                 ----------     -------  -----   -----
;% 		KBANN    	 4.62    7.56    8.47
;% 		BACKPROP    	 5.29    5.74   10.75
;% 		PEBLS    	 6.86    8.18    7.55
;% 		PERCEPTRON    	 3.99   16.32   17.41
;% 		ID3    		 8.84   10.58   13.99
;% 		COBWEB   	11.80   15.04    9.46
;% 		Near. Neighbor	31.11   11.65    9.09
;%
;%    Type of domain: non-numeric, nominal (one of A, G, T, C)
;%
;% 5. Number of Instances: 3190
;%
;% 6. Number of Attributes: 62
;%    -- class (one of n, ei, ie)
;%    -- instance name
;%    -- 60 sequential DNA nucleotide positions
;%
;% 7. Attribute information:
;%    -- Statistics for numeric domains: No numeric features used.
;%    -- Statistics for non-numeric domains
;%       -- Frequencies:  Neither	    EI	      IE
;%                        -------	  ------     -----
;% 		A  	24.984%	  22.153%   20.577%
;% 		G  	25.653%	  31.415%   22.383%
;% 		T  	24.273%	  21.771%   26.445%
;% 		C  	25.077%	  24.561%   30.588%
;% 		D	 0.001%    --        0.002%
;% 		N	 0.010%    0.010%    --
;%                 S        --        --        0.002%
;%                 R        --        --        0.002%
;%
;%    Attribute #:  Description:
;%    ============  ============
;%              1   One of {n ei ie}, indicating the class.
;%              2   The instance name.
;%           3-62   The remaining 60 fields are the sequence, starting at
;%                  position -30 and ending at position +30. Each of
;%                  these fields is almost always filled by one of
;%                  {a, g, t, c}. Other characters indicate ambiguity among
;%                  the standard characters according to the following table:
;% 			character	    meaning
;% 			---------	----------------
;% 			    D		  A or G or T
;% 			    N           A or G or C or T
;% 			    S                C or G
;% 			    R		     A or G
;%
;% 8. Missing Attribute Values: none
;%
;% 9. Class Distribution:
;% 	EI:       767  (25%)
;%         IE:       768  (25%)
;% 	Neither: 1655  (50%)
;%
;%
;%
;%
(defun splice ()
  (data
    :name 'splice
    :columns '(Instance_name attribute_1 attribute_2 attribute_3 attribute_4 attribute_5 attribute_6 attribute_7 attribute_8 attribute_9 attribute_10 attribute_11 attribute_12 attribute_13 attribute_14 attribute_15 attribute_16 attribute_17 attribute_18 attribute_19 attribute_20 attribute_21 attribute_22 attribute_23 attribute_24 attribute_25 attribute_26 attribute_27 attribute_28 attribute_29 attribute_30 attribute_31 attribute_32 attribute_33 attribute_34 attribute_35 attribute_36 attribute_37 attribute_38 attribute_39 attribute_40 attribute_41 attribute_42 attribute_43 attribute_44 attribute_45 attribute_46 attribute_47 attribute_48 attribute_49 attribute_50 attribute_51 attribute_52 attribute_53 attribute_54 attribute_55 attribute_56 attribute_57 attribute_58 attribute_59 attribute_60 Class)
    :egs
    '(
      (ATRINS-DONOR-521 C C A G C T G C A T C A C A G G A G G C C A G C G A G C A G G T C T G T T C C A A G G G C C T T C G A G C C A G T C T G EI)
      (ATRINS-DONOR-905 A G A C C C G C C G G G A G G C G G A G G A C C T G C A G G G T G A G C C C C A C C G C C C C T C C G T G C C C C C G C EI)
      (BABAPOE-DONOR-30 G A G G T G A A G G A C G T C C T T C C C C A G G A G C C G G T G A G A A G C G C A G T C G G G G G C A C G G G G A T G EI)
      (BABAPOE-DONOR-867 G G G C T G C G T T G C T G G T C A C A T T C C T G G C A G G T A T G G G G C G G G G C T T G C T C G G T T T T C C C C EI)
      (BABAPOE-DONOR-2817 G C T C A G C C C C C A G G T C A C C C A G G A A C T G A C G T G A G T G T C C C C A T C C C G G C C C T T G A C C C T EI)
      (CHPIGECA-DONOR-378 C A G A C T G G G T G G A C A A C A A A A C C T T C A G C G G T A A G A G A G G G C C A A G C T C A G A G A C C A C A G EI)
      (CHPIGECA-DONOR-903 C C T T T G A G G A C A G C A C C A A G A A G T G T G C A G G T A C G T T C C C A C C T G C C C T G G T G G C C G C C A EI)
      (CHPIGECA-DONOR-1313 C C C T C G T G C G G T C C A C G A C C A A G A C C A G C G G T G A G C C A C G G G C A G G C C G G G G T C G T G G G G EI)
      (GCRHBBA1-DONOR-1260 T G G C G A C T A C G G C G C G G A G G C C C T G G A G A G G T G A G G A C C C T C C T G T C C C T G C T C C A G T C C EI)
      (GCRHBBA1-DONOR-1590 A A G C T G A C A G T G G A C C C G G T C A A C T T C A A G G T G A G C C A G G A G T C G G G T G G G A G G G T G A G A EI)
      (GCRHBBA6-DONOR-461 T G G C G A C T A C G G C G C G G A G G C C C T G G A G A G G T G A G G A C C C T G G T A T C C C T G C T G C C A G T C EI)
      (GCRHBBA6-DONOR-795 A A G C T G A G A G T G G A C C C T G T C A A C T T C A A G G T G A G C C A C C A G T C G G G T G G G G A G G G T G A G EI)
      (GIBHBGGL-DONOR-2278 G G A A G A T G C T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G G A G G G EI)
      (GIBHBGGL-DONOR-2624 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T G A G T A C A G G A G A T G T T T C A G C C C T G T T G EI)
      (GIBHBGGL-DONOR-7198 G G A A G A T G T T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G G A G G G EI)
      (GIBHBGGL-DONOR-7544 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T G A G T A C A G G A G A T G T T T C A G C C C T G T T G EI)
      (HUMA1ATP-DONOR-1972 G G C A C C A C C A C T G A C C T G G G A C A G T G A A T C G T A A G T A T G C C T T T C A C T G C G A G G G G T T C T EI)
      (HUMA1ATP-DONOR-7932 T T G C T C T G G T G A A T T A C A T C T T C T T T A A A G G T A A G G T T G C T C A A C C A G C C T G A G C T G T T T EI)
      (HUMA1ATP-DONOR-9653 C A C C A A G T T C C T G G A A A A T G A A G A C A G A A G G T G A T T C C C C A A C C T G A G G G T G A C C A A G A A EI)
      (HUMA1ATP-DONOR-11057 A C A G A G G A G G C A C C C C T G A A G C T C T C C A A G G T G A G A T C A C C C T G A C G A C C T T G T T G C A C C EI)
      (HUMA1GLY2-DONOR-1693 G T G C C C A T C A C C A A C G C C A C C C T G G A C C G G G T G A G T G C C T G G G C T A G C C C T G T C C T G A G C EI)
      (HUMA1GLY2-DONOR-2251 C A C G A T C T T T C T C A G A G A G T A C C A G A C C C G G T G A G A G C C C C C A T T C C A A T G C A C C C C C G A EI)
      (HUMA1GLY2-DONOR-2540 A G C G G G A G A A T G G G A C C G T C T C C A G A T A C G G T G A G G G C C A G C C C T C A G G C A G G A G G G T T C EI)
      (HUMA1GLY2-DONOR-3352 A T G A G A A G A A C T G G G G G C T G T C T T T C T A T G G T A G G C A T G C T T A G C A G C C C C A A A C T C A T G EI)
      (HUMA1GLY2-DONOR-3606 T C A G A T G T C A T G T A C A C C G A C T G G A A A A A G G T A A A C G C A A G G G A T T G G A C A T T G C C C A C C EI)
      (HUMACCYBA-DONOR-289 G A T C C G C C G C C C G T C C A C A C C C G C C G C C A G G T A A G C C C G G C C A G C C G A C C G G G G C A T G C G EI)
      (HUMACCYBA-DONOR-1250 C C C T C C A T C G T G G G G C G C C C C A G G C A C C A G G T A G G G G A G C T G G C T G G G T G G G G C A G C C C C EI)
      (HUMACCYBA-DONOR-1624 C C C A A G G C C A A C C G C G A G A A G A T G A C C C A G G T G A G T G G C C C G C T A C C T C T T C T G G T G G C C EI)
      (HUMACCYBA-DONOR-2504 C T G A G G C A C T C T T C C A G C C T T C C T T C C T G G G T G A G T G G A G A C T G T C T C C C G G C T C T G C C T EI)
      (HUMACCYBA-DONOR-2781 G C C C T G G C A C C C A G C A C A A T G A A G A T C A A G G T G G G T G T C T T T C C T G C C T G A G C T G A C C T G EI)
      (HUMACCYBB-DONOR-290 G A T C C G C C G C C C G T C C A C A C C C G C C G C C A G G T A A G C C C G G C C A G C C G A C C G G G G C A T G C G EI)
      (HUMACCYBB-DONOR-1186 C C C T C C A T C G T G G G G C G C C C C A G G C A C C A G G T A G G G G A G C T G G C T G G G T G G G G C A G C C C C EI)
      (HUMACCYBB-DONOR-1558 C C C A A G G C C A A C C G C G A G A A G A T G A C C C A G G T G A G T G G C C C G C T A C C T C T T C T G G T G G C C EI)
      (HUMACCYBB-DONOR-2438 C T G A G G C A C T C T T C C A G C C T T C C T T C C T G G G T G A G T G G A G A C T G T C T C C C G G C T C T G C C T EI)
      (HUMACCYBB-DONOR-2715 G C C C T G G C A C C C A G C A C A A T G A A G A T C A A G G T G G G T G T C T T T C C T G C C T G A G C T G A C C T G EI)
      (HUMACTGA-DONOR-513 C C G C C C C T C C G C C G T C G C G T T T C T C T G C C G G T G A G C G C C C C G C C C C G G G G C C T G A G C T G G EI)
      (HUMACTGA-DONOR-1015 C C T T C C A T C G T C G G G C G C C C C A G A C A C C A G G T G A G T G G A T G G C G C C G C G G G G C T C C T G G G EI)
      (HUMACTGA-DONOR-1344 C C C A A G G C C A A C A G A G A G A A G A T G A C T C A G G T G A G G C T C G G C C G A C G C C C G T G C T C C T C C EI)
      (HUMACTGA-DONOR-2060 C G G A G G C G C T G T T C C A G C C T T C C T T C C T G G G T A G G T G T T G T G A G C T A A A G G T T T C T A C T C EI)
      (HUMACTGA-DONOR-2321 G C C C T G G C G C C C A G C A C C A T G A A G A T C A A G G T G A G T C G A G G G G T T G G T G G C C C T C T G C C T EI)
      (HUMADAG-DONOR-4034 G C C C A G A C G C C C G C C T T C G A C A A G C C C A A A G T G A G C G C G C G C G G G G G C T C C G G G G A C G G G EI)
      (HUMADAG-DONOR-19262 C A A G C C T G A A A C C A T C T T A T A C T A T G G C A G G T A A G T C C A T A C A G A A G A G C C C T C T C T C C C EI)
      (HUMADAG-DONOR-26437 C A A G T T T G A C T A C T A C A T G C C T G C T A T C G C G T G A G T T G C C C C C A A C C C A C A G G T C C T A G G EI)
      (HUMADAG-DONOR-29022 A G T G G A G C C A A T C C C C T G G A A C C A G G C T G A G T G A G T G A T G G G C C T G G A A G G G G C C A T G C T EI)
      (HUMADAG-DONOR-29909 C C A T C C T G T G C T G C A T G C G C C A C C A G C C C A G T G A G T A G G A T C A C C G C C C T G C C C A G G G C C EI)
      (HUMADAG-DONOR-31274 C T C T T G C C T G G A C A T G T C C A G G C C T A C C A G G T G G G T C C T G T G A G A A G G A A T G G A G A G G C T EI)
      (HUMADAG-DONOR-32467 G A G G T G G G C T C G G C C G A A G T A G T A A A A G A G G T G A G G G C C T G G G C T G G C C A T G G G G T C C C T EI)
      (HUMADAG-DONOR-32645 A G G C T G C G G C A G G A A A A C A T G C A C T T C G A G G T A A G C G G G C C A G G G A G T G G G G A G G A A C C A EI)
      (HUMADAG-DONOR-32886 G A A G C C G G A C A C G G A G C A T G C A G T C A T T C G G T G A G C T C T G T T C C C C T G G G C C T G T T C A A T EI)
      (HUMADAG-DONOR-34454 G G C T T T A C T G A A G A G G A G T T T A A A A G G C T G G T G A G T G G G T G T G A G C C A T A C T G G C C T T G A EI)
      (HUMADAG-DONOR-35173 C C T A T G G G A T G C C A C C T T C A G C C T C T G C A G G T A G G T T C C T G T C T G G G C T T C T G G G C A G T T EI)
      (HUMADAM2-DONOR-708 G A G G T G G G C T C G G C C G A A G T A G T A A A A G A G G T G A G G G C C T G G G C T G G C C A T G G G G T C C C T EI)
      (HUMAFP-DONOR-970 G A A C A C T G C A T A G A A A T G A A T A T G G A A T A G G T G A G A T A T T T T G T G T T T T T C T T G T C T T T T EI)
      (HUMAFP-DONOR-1834 A T G T A C T G C A G A G A T A A G T T T A G C T G A C C T G T A A G T T T T G C T T A T A T A A A T G T A C T T T A A EI)
      (HUMAFP-DONOR-2929 G A A C A G T C T T C A G G G T G T T T A G A A A A C C A G G T G A G T G A A T A A T T T T A A A A A A G C A T T G T G EI)
      (HUMAFP-DONOR-5428 T G A A G A A G A C A G G G A G A C A T T C A T G A A C A A G T A A G G A T C C A G T T T A A A G G T A G A T G C A A A EI)
      (HUMAFP-DONOR-7047 G A A A A T G C A G T T G A A T G C T T C C A A A C A A A G G T A T C A T A T T T G C G T G G A T A T C T G A A C C A G EI)
      (HUMAFP-DONOR-8063 A A A T T T T G G G A C C C G A A C T T T C C A A G C C A T G T A A G T T C A A G T T C T A T C T A G G G A A G A G G G EI)
      (HUMAFP-DONOR-9741 G G A G A T G T G C T G G A T T G T C T G C A G G A T G G G G T G A G G A G T C T T G C T T C T T A A A A T A G A A G A EI)
      (HUMAFP-DONOR-12231 T T C A G G G G A A A A A A A T A T C T T C T T G G C A A G G T A A C A C A C T C T G T A A A T G C A T G T T C A T G C EI)
      (HUMAFP-DONOR-14021 G A A A A C C C T C T T G A A T G C C A A G A T A A A G G A G T A A G T T G C T C T A G A A T T T T A G G G G A G T A T EI)
      (HUMAFP-DONOR-14687 G A A A C T A G G A G A A T A T T A C T T A C A A A A T G C G T A T G T T T T T G T A A A C A G T A T T T T T A G T G A EI)
      (HUMAFP-DONOR-15308 G A C A A A C T A T T G G C C T G T G G C G A G G G A G C G G T G A G T G T C T G C T T G G T T T G G T C C C A T C T C EI)
      (HUMAFP-DONOR-17179 G G G T G T A G C G C T G C A A A C G A T G A A G C A A G A G T A A G A A A C T G T T A C T T G C T A G C A T G G A A A EI)
      (HUMAFP-DONOR-18452 C A G G A A C A G G A A G T C T G C T T T G C T G A A G A G G T A C A T G C A G C T C A T T T C A T A C T C A A A A T A EI)
      (HUMAFP-DONOR-19845 G T G C T G C T T T G G G A G T T T A A A T T A C T T C A G G T A A C A A A A C A T T C A G A C A A G C C T G A A T A C EI)
      (HUMAK1-DONOR-954 G C C C C G G C G C C C A C C C G C A C C C C T C C C C A G G T C A G T G C G T G C C C G C G C G T G T C T G G G G G G EI)
      (HUMAK1-DONOR-3959 A C G G C T C C C G G G A C C T C G G C A G G A T G G A A G G T A T G A G C C T C C T C T C C T T T T G C C C A T T G C EI)
      (HUMAK1-DONOR-5540 T G A A G A A A A C C A A G A T C A T C T T T G T G G T G G G T G A G T T G C G G G C A G G C G G G T G G T G C A G C A EI)
      (HUMAK1-DONOR-5876 A T C A T G G A G A A G G G G C A G C T G G T T C C A C T G G T G A G T G G G C C C T G G T G G G G T G A G A G G C A G EI)
      (HUMAK1-DONOR-6743 G T G C A G C A A G G A G A A G A G T T T G A G C G A C G G G T A A G G C A C T G A C C C A A G T G G G G A T C C T G G EI)
      (HUMAK1-DONOR-10237 T T C T A T G A G A A A C G T G G C A T T G T G C G C A A G G T G G G C C C C G C G G G A C G G G G C A G C T C C G G G EI)
      (HUMALBGC-DONOR-1825 A T T C C A G G G G T G T G T T T C G T C G A G A T G C A C G T A A G A A A T C C A T T T T T C T A T T G T T C A A C T EI)
      (HUMALBGC-DONOR-2592 A G A T T T G G G A G A A G A A A A T T T C A A A G C C T T G T A A G T T A A A A T A T T G A T G A A T C A A A T T T A EI)
      (HUMALBGC-DONOR-4179 G A G T C A G C T G A A A A T T G T G A C A A A T C A C T T G T A A G T A C A T T C T A A T T G T G G A G A T T C T T T EI)
      (HUMALBGC-DONOR-6223 T C A T G A C A A T G A A G A G A C A T T T T T G A A A A A G T A A G T A A T C A G A T G T T T A T A G T T C A A A A T EI)
      (HUMALBGC-DONOR-6905 G C T G A T A A A G C T G C C T G C C T G T T G C C A A A G G T A T T A T G C A A A A G A A T A G A A A A A A A G A G T EI)
      (HUMALBGC-DONOR-7827 A A A A T T T G G A G A A A G A G C T T T C A A A G C A T G G T A A A T A C T T T T A A A C A T A G T T G G C A T C T T EI)
      (HUMALBGC-DONOR-9544 G G A G A T C T G C T T G A A T G T G C T G A T G A C A G G G T A A A G A G T C G T C G A T A T G C T T T T T G G T A G EI)
      (HUMALBGC-DONOR-11052 T G C T G A G G C A A A G G A T G T C T T C C T G G G C A T G T A A G T A G A T A A G A A A T T A T T C T T T T A T A G EI)
      (HUMALBGC-DONOR-12584 G C A G A T C C T C A T G A A T G C T A T G C C A A A G T G G T A G G T T T A T T G T T G G A A A A A A A T G T A G T T EI)
      (HUMALBGC-DONOR-13770 G C A G C T T G G A G A G T A C A A A T T C C A G A A T G C G T A A G T A A T T T T T A T T G A C T G A T T T T T T T T EI)
      (HUMALBGC-DONOR-15086 G C A A A A A G A A T G C C C T G T G C A G A A G A C T A T G T G A G T C T T T A A A A A A A T A T A A T A A A T T A A EI)
      (HUMALBGC-DONOR-15728 T G A G A A G G A G A G A C A A A T C A A G A A A C A A A C G T G A G G A G T A T T T C A T T A C T G C A T G T G T T T EI)
      (HUMALBGC-DONOR-17044 G A C G A T A A G G A G A C C T G C T T T G C C G A G G A G G T A C T A C A G T T C T C T T C A T T T T A A T A T G T C EI)
      (HUMALBGC-DONOR-17726 C T T A T A A C A T C A C A T T T A A A A G C A T C T C A G G T A A C T A T A T T T T G A A T T T T T T A A A A A A G T EI)
      (HUMALBGC-DONOR-17044 G A C G A T A A G G A G A C C T G C T T T G C C G A G G A G G T A C T A C A G T T C T C T T C A T T T T A A T A T G T C EI)
      (HUMALPHA-DONOR-487 G G C T A C A G C T C T C C C T G G G C A T C A T C C C A G G T A A T G A G G C T C C C C A G C C T G C C C T A C A C A EI)
      (HUMALPHA-DONOR-698 C C A A G A A C C T C A T C A T G T T C C T G G G T G A C G G T G A G T G A G C C A G C C T T C C A G C C C C G C A G C EI)
      (HUMALPHA-DONOR-925 G A C C G C T T C C C G T A C G T G G C T C T G T C C A A G G T A A G T G C T G G G C T A C C T T A G A G T C C T C C A EI)
      (HUMALPHA-DONOR-1292 T C T C C G T G G T G A A T C G G G C C A A G A A A G C A G G T G G A G C T G G G G C C C G G C T G T G G G G T C A G G EI)
      (HUMALPHA-DONOR-1542 A C G C A G C T C A T C T C C A A C A T G G A C A T T G A T G T G C G A C C C C C G G G C C A A G G G T G G G G C T G G EI)
      (HUMALPHA-DONOR-1924 C T G G T G C A G G A A T G G C T G G C G A A G C A C C A G G T G A T G G G G G C T G G T G G G T G T G C T G G G C A C EI)
      (HUMALPHA-DONOR-2096 C C C T G G A C C C G T C T G T G A C C C A T C T C A T G G G T A A T G A C C C C C T T C C T G C C C T G G C A T C C T EI)
      (HUMALPHA-DONOR-2359 A C C C C C G C G G C T T C T T C C T C T T C G T G G A G G G T G C G T G G T G G C C C T G G G A G T G G G G G G T T G EI)
      (HUMALPHA-DONOR-2632 G C T A C C C C C T G C G A G G G A G C T C C A T C T T C G G T A G G C C T G G G G A T G A G T G G C A G G T G C T G C EI)
      (HUMALPHA-DONOR-2968 C C C G G C C G G A T G T T A C G G A G A G C G A G A G C G G T G A G T G C C G T G G G G T G G C C T G A G G G G G A C EI)
      (HUMALPI-DONOR-333 G G C T A C A G C T C T C C C T G G G C G T C A T C C C A G G T A A T G A G G C T C C C C A A G C T G T T C C A C A C A EI)
      (HUMALPI-DONOR-532 C C A A G A A C C T C A T C C T C T T C C T G G G C G A T G G T G A G T G A G C A A G G C C T G T C C A G C C C C G T A EI)
      (HUMALPI-DONOR-762 G A C C G C T T C C C A T A C C T G G C T C T G T C C A A G G T A A G G G C T G G G C C A C C T C A G A G T C C T C C A EI)
      (HUMALPI-DONOR-1140 T C T C C G T G A T G A A C C G G G C C A A G C A A G C A G G T G A G C T G G G G C C C G C T G T G G G G T C A G G A C EI)
      (HUMALPI-DONOR-1389 A C T C A G C T C A T C T C C A A C A T G G A C A T T G A C G T G C G A C C C C C G G G C C A A G G G C T G G G G C T G EI)
      (HUMALPI-DONOR-1766 C T G G T G C A G G A A T G G C T G G C A A A G C A C C A G G T G A T G G G G G C T G G T G G G T G T G G G A G G C A C EI)
      (HUMALPI-DONOR-1934 C C C T G G A C C A G T C T G T G A C C C A T C T C A T G G G T A A T G A C C C C C T T C C T G C C C T G G C A T T C C EI)
      (HUMALPI-DONOR-2199 A C C C C C G C G G C T T C T A C C T C T T T G T G G A G G G T G C G T G G T G G C C C C T G G G G A G T G G A G G A A EI)
      (HUMALPI-DONOR-2475 G C T A C A C C T T G C G A G G G A G C T C C A T C T T C G G T A G G C C T G G G G A G A G T G G C A G G T G C T G C T EI)
      (HUMALPI-DONOR-2815 T G C G A C C A G A C G T G A A T G A G A G C G A G A G C G G T G A G T G A G G C T G A A T G G C C C G T G C A G G G G EI)
      (HUMALPI1-DONOR-42 C A C A C A G G G C A C C C C C T C A N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N N EI)
      (HUMALPPD-DONOR-100 G G C T A C A G C T C T C C C T G G G C A T C A T C C C A G G T A A T G A G G C T C C C C G A G C T G C C C C T A C A C EI)
      (HUMALPPD-DONOR-309 C C A A G A A C C T C A T C A T C T T C C T G G G C G A T G G T G A G T G A G C C A G G C C T T C C A G C C C T G C A G EI)
      (HUMALPPD-DONOR-537 G A C C G C T T C C C A T A T G T G G C T C T G T C C A A G G T A A G T G C T G G G C T A C C T T A G A G T C C T C C A EI)
      (HUMALPPD-DONOR-909 T C T C C G T G A T G A A T C G G G C C A A G A A A G C A G G T G A G C T G G G G C C C G C T G C T G G G T C A C G G C EI)
      (HUMALPPD-DONOR-1158 A C G C A G C T C A T C T C C A A C A T G G A C A T T G A C G T G C G A C C C C C A G G A C C A A G G G C T G G G G C T EI)
      (HUMALPPD-DONOR-1543 C T G G T G C A G G A A T G G C T G G C G A A G C G C C A G G T G A T G G G G G C T G G C G G G T G C A G G G G G C A C EI)
      (HUMALPPD-DONOR-1715 C C C T G G A C C C G T C T G T G A C C C A T C T C A T G G G T A A T G A C C C C C T T C C T G C C C T G G C A T C C C EI)
      (HUMALPPD-DONOR-1980 A C C C C C G C G G C T T C T T C C T C T T C G T G G A G G G T G C G T G G T G G C C C C T G G G G A G T G G G G G T T EI)
      (HUMALPPD-DONOR-2254 G C T A C C C C C T G C G A G G G A G C T C C A T C T T C G G T A G G C C T G G G G A G A G T G G C A G G T G C T G C T EI)
      (HUMALPPD-DONOR-2590 C C C G G C C G G A T G T T A C C G A G A G C G A G A G C G G T G A G T G C C G C G G G G T G G C C C C C T G A G G G G EI)
      (HUMANFA-DONOR-663 G T G T C C A A C G C A G A C C T G A T G G A T T T C A A G G T A G G G C C A G G A A A G C G G G T G C A G T C T G G G EI)
      (HUMANFA-DONOR-1112 C A G A G C G G A C T G G G C T G T A A C A G C T T C C G G G T A A G A G G A A C T G G G G A T G G A A A T G G G A T G EI)
      (HUMANT1-DONOR-1688 C C C A T C G A G A G G G T C A A A C T G C T G C T G C A G G T G A G G A C C G C G C G G T G C A A G A G G C G G G C G EI)
      (HUMANT1-DONOR-3442 C C T A C T T C G G A G T C T A T G A T A C T G C C A A G G G T G A G A G A G G G G C A T C G G G G A G A A G G A G G G EI)
      (HUMANT1-DONOR-4091 G A A T G A T G A T G C A G T C C G G C C G G A A A G G G G G T A A G C T T G T G C T C T A C T C A T C T A A A C T T G EI)
      (HUMAPOA4A-DONOR-1025 T C C T G A C C C T G G C C C T G G T G G C T G T C G C C G G T G A G T A G A A G C T G T C T T T G G A T G G C A C T C EI)
      (HUMAPOA4A-DONOR-1509 C C A G A A A T C T G A A C T C A C C C A G C A A C T C A A G T A A G A G G G A C T A C A G T G T G T G G T G G T G A C EI)
      (HUMAPOAI1-DONOR-457 A G C T G G C T G C T T A G A G A C T G C G A G A A G G A G G T G C G T C C T G C T G C C T G C C C C G G C A C T C T G EI)
      (HUMAPOAI1-DONOR-716 T G C T G A C C T T G G C C G T G C T C T T C C T G A C G G G T A G G T G T C C C C T A A C C T A G G A G C C A A C C A EI)
      (HUMAPOAI1-DONOR-1059 T G A A G G C T C C G C C T T G G G A A A A C A G C T A A A G T A A G G A C C C A G C C T G G G G T T G A G G G C A G G EI)
      (HUMAPOAIT-DONOR-201 A G C T G G C T G C T T A G A G A C T G C G A G A A G G A G G T G C G T C C T G C T G C C T G C C C C G G T C A C T C T EI)
      (HUMAPOAIT-DONOR-461 T G C T G A C C T T G G C C G T G C T C T T C C T G A C G G G T A G G T G T C C C C T A A C C T A G G G A G C C A A C C EI)
      (HUMAPOAIT-DONOR-805 T G A A G G C T C C G C C T T G G G A A A A C A G C T A A A G T A A G G A C C C A G C C T G G G G T T G A G G G C A G G EI)
      (HUMAPOC2-DONOR-522 G A G C T G G T G A G G A C A G C C T G C C A G A G T C T G G T A A G A A A G G G A C T C A G G G T G C G G G G A C A G EI)
      (HUMAPOC2-DONOR-2976 T G T T T C T T G T C C T C C T G G T A T T G G G A T T T G G T G A G T G T G G G C T T C C G G G G A G G G A A G C C T EI)
      (HUMAPOC2-DONOR-3303 A T A C C T G C C C G C T G T A G A T G A G A A A C T C A G G T A G C A C C T G C C C C T G G A G A A A T G G G G T C T EI)
      (HUMAPOC2G-DONOR-225 G A G C T G G T G A G G A C A G C C T G C C A G A G T C T G G T A A G A A A G G G A C T C A G G G T G C G G G G A C A G EI)
      (HUMAPOC2G-DONOR-2684 T G T T T C T T G T C C T C C T G G T A T T G G G A T T T G G T G A G T G T G G G C T T C C G G G G A G G G A A G C C T EI)
      (HUMAPOC2G-DONOR-3011 A T A C C T G C C C G C T G T A G A T G A G A A A C T C A G G T A G C A C C T G C C C C T G G A G A A A T G G G G T C T EI)
      (HUMAPOCIA-DONOR-496 T C C C A A C C A A G C C C T C C A G C A A G G A T T C A G G T T G G T G C T G A G T G C C T G G G A G G G A C A C C C EI)
      (HUMAPOCIA-DONOR-712 T G G T G G T G G T T C T G T C G A T C G T C T T G G A A G G T A A A A G T G G G A T G G G A G A A T T G G G G A G T T EI)
      (HUMAPOCIA-DONOR-2092 C A A A C A G A G T G A A C T T T C T G C C A A G A T G C G G T T A G A A C C C T T C C C A G G G C A C G G G A G A G C EI)
      (HUMAPOCII-DONOR-541 G A G C T G G T G A G G A C A G C C T G C C A G A G T C T G G T A A G A A A G G G A C T C A G G G T G C G G G G A C A G EI)
      (HUMAPOCII-DONOR-2965 T G T T T C T T G T C C T C C T G G T A T T G G G A T T T G G T G A G T G T G G G C T T C C G G G G A G G G A A G C C T EI)
      (HUMAPOCII-DONOR-3291 A T A C C T G C C C G C T G T A G A T G A G A A A C T C A G G T A G C A C C T G C C C C T G G A G A A A T G G G G T C T EI)
      (HUMAPOE4-DONOR-1061 G A G G T G A A G G A C G T C C T T C C C C A G G A G C C G G T G A G A A G C G C A G T C G G G G G C A C G G G G A T G EI)
      (HUMAPOE4-DONOR-1884 G G G C T G C G T T G C T G G T C A C A T T C C T G G C A G G T A T G G G G G C G G G G C T T G C T C G G T T C C C C C EI)
      (HUMAPOE4-DONOR-3170 G C T C A G C T C C C A G G T C A C C C A G G A A C T G A G G T G A G T G T C C C C A T C C T G G C C C T T G A C C C T EI)
      (HUMAPRTA-DONOR-618 C G A C T T C C C C A C C C C A G G C G T G G T A T T C A G G T G C A C G C A C A G G C C G C C C T C G T G G C C C C G EI)
      (HUMAPRTA-DONOR-881 C C C A C G G G G G C C G C A T C G A C T A C A T C G C A G G C G A G T G C C A G T G G C C G C A T C T A G G G C G C T EI)
      (HUMAPRTA-DONOR-1982 T G G G C C T C C T A T T C C C T G G A G T A C G G G A A G G T A A G A G G G C T G G G G T G G C C G G A G G A A G G G EI)
      (HUMAPRTA-DONOR-2331 T C G T C G T G G A T G A T C T G C T G G C C A C T G G T G G T A A G G G T C T C C C C G C A G C C A A C T C T G T G C EI)
      (HUMATP1A2-DONOR-1663 C A G C C A C T C T G C C C C A A G A T G G G C C G T G G G G T G A G T A T C C C T A A A G A G C A G G G G T C G C A G EI)
      (HUMATP1A2-DONOR-6788 C T G G A T G A G C T G A A G A A G G A G G T G G C A A T G G T G A G G G A A C T G C T G G G C C A T G G A G G A G G G EI)
      (HUMATP1A2-DONOR-7029 G G C C G C A A A T A C C A A G T G G A C C T G T C C A A G G T G A G T G G A G G G G C T T C T A G G G A A G G A A C A EI)
      (HUMATP1A2-DONOR-9194 G C C A T G G A G G A T G A A C C A T C C A A C G A C A A T G T G A G C C C A C A C G C C T G A C C C G G G A A C A G C EI)
      (HUMATP1A2-DONOR-9834 A T G G A T T C C T T C A A G A A C A T G G T A C C T C A G G T A A G A T G G C A G G G C T G G G C T C T G G G C T A G EI)
      (HUMATP1A2-DONOR-10208 C T C C G G A T C A T C T C T T C T C A T G G C T G T A A G G T G A G G A G G T C A T A C C A G A G C A A G C A G T T G EI)
      (HUMATP1A2-DONOR-11031 T C T G T T T C T T C T C C A C C A A C T G T G T T G A A G G T G A G A A G C C A G G C T G C C C C C T G T A G G A A A EI)
      (HUMATP1A2-DONOR-12719 G T G C C T G A G G G G C T T C T G G C C A C T G T C A C T G T G A G T G G G T C A G G C T G A G G T G C C A C C A G G EI)
      (HUMATP1A2-DONOR-13749 A T G A G G C T G A C A C C A C C G A A G A T C A G T C T G G T G A T T G G G T G C T C C A G A G G G G G T G G A T A G EI)
      (HUMATP1A2-DONOR-14299 A T T C C T T T C A A C T C T A C C A A C A A G T A C C A G G T C T G C T T G G G T T G C C A G G A C A G A G G A A G A EI)
      (HUMATP1A2-DONOR-15190 A G C T G G G G G G A C T T G G G G A G C G T G T G C T G G G T G A G A G G C C A G A A A C A G G A G G C T C A G A A G EI)
      (HUMATP1A2-DONOR-15496 G T G G G C A A G T G C C G A A G C G C A G G C A T C A A G G T A C T G G C C T C C C A T C C T C C C C T C C A T T C T EI)
      (HUMATP1A2-DONOR-19518 C A A C A T T C C C A T G A G T C A A G T C A A C C C C A G G T G A G G C C T C T G C A G G A A G C C C C T G T G C C C EI)
      (HUMATP1A2-DONOR-20193 C T C A T C A T T G T G G A G G G A T G T C A G A G G C A G G T G A G C A C A G C C A C G G G A G G C A G A T G A C A G EI)
      (HUMATP1A2-DONOR-20500 T T G C C T C C A T C G T C A C G G G G G T G G A G G A G G G T G A G G A G G C T G C A T G G G T T G G G A T G G T T T EI)
      (HUMATP1A2-DONOR-20891 A T C C T T T G C A T T G A C C T G G G C A C A G A T A T G G T G A G C G C A G G A G G T G G A G G A G G G G A C A G G EI)
      (HUMATP1A2-DONOR-21268 G G C T C A T C A G C A T G G C C T A C G G A C A G A T C G G T G C G C C A A G C C C C G G G C C T C G G G A G G G A A EI)
      (HUMATP1A2-DONOR-21613 G A T C T G G A G G A C A G C T A T G G A C A G G A G T G G G T G A G T G G T G C T G T G T A A A C A C A G C G C A C A EI)
      (HUMATP1A2-DONOR-21929 C C G C A A C T C A G T C T T C C A G C A G G G C A T G A A G T G A G T G C C C A C C C C C A T G G C A C C T A C C C A EI)
      (HUMATP1A2-DONOR-22719 G G G T G T A G C C C T C C G C A T G T A C C C G C T C A A G T G A G T G T C T C T T T C G G G C G G C C T G A G T A G EI)
      (HUMATP1A2-DONOR-22962 G A A A G C T C A T C C T G C G G C G G T A T C C T G G T G G T A A G C C C C T C C A C A T T C C C C C C A G C A A A G EI)
      (HUMATPSYB-DONOR-2217 T G C G G G C C G C T C C G A C G G C G G T C C A T C C T G G T A A G T G C T T T T C T C T A G G A G C T A A C G T T C EI)
      (HUMATPSYB-DONOR-2881 G A C T G G T T T T G G A G G T G G C C C A G C A T T T G G G T A A G T A G A G T T T G T T A G G A A T A G T A A A G A EI)
      (HUMATPSYB-DONOR-3271 T G A T G A A A G A G G T C C C A T C A A A A C C A A A C A G T A A G T T G C T C T T A T T G C A T C T A T G C A C A A EI)
      (HUMATPSYB-DONOR-4215 T A G C T C C C T A T G C C A A G G G T G G C A A A A T T G G T A T G T T A T T A A G G G G T A C A T A T T T T C C A A EI)
      (HUMATPSYB-DONOR-4649 G T T A T C A A C T T A A A A G A T G C C A C C T C T A A G G T A A G C A T T G A G C T A A T T G A T G T C C A C G T G EI)
      (HUMATPSYB-DONOR-5379 A T C T T T C G C T T C A C C C A G G C T G G T T C A G A G G T A A G A G G G A A G G C T T G A G A G G A C C T G G T T EI)
      (HUMATPSYB-DONOR-5594 A C C A A G A A G G G A T C T A T C A C C T C T G T A C A G G T A A G A A A A A T T A C A T A G A T G A A G A T C T G A EI)
      (HUMATPSYB-DONOR-8071 G T T G C C C G T G G G G T G C A A A A G A T C C T G C A G G T G A G T A T A T T A C T A T G T G G G A T C A G T G T C EI)
      (HUMATPSYB-DONOR-8947 C C A T C A A A G G A T T C C A G C A G A T T T T G G C A G G T G A G A T T T T G A G T A C A A A T C T T G A A T G T T EI)
      (HUMBLYM1-DONOR-127 A C T T C A G T G G A G G A A A C A A C T G A A G A T G A G G T G G A A A T A A C A G A T C A T A G A A T G A G A A G C EI)
      (HUMBNPA-DONOR-600 G C C T C G G A C T T G G A A A C G T C C G G G T T A C A G G T G A G A G C G G A G G G C A G C T C A G G G G G A T T G EI)
      (HUMBNPA-DONOR-1087 T C A G C T C C T C C A G T G G C C T G G G C T G C A A A G G T A A G C A C C C C C T G C C A C C C C G G C C G C C T T EI)
      (HUMCACY-DONOR-1386 C T C G C G T C G C A T T T G G C C G C C T C C C T A C C G G T G A G T T C T C T C C A G G A G C C C T G G G T A C T T EI)
      (HUMCACY-DONOR-2132 C T G A T C C A G A A G G A G C T C A C C A T T G G C T C G G T G A G T G G C C T C C T C C C C A G G A C C C C T T T T EI)
      (HUMCAPG-DONOR-375 C C T T T C T C C T A C C C A C T G G G G C T G A G G C A G G T G A G T G A C C A T C C C C A C C C T C A G A G G C C T EI)
      (HUMCAPG-DONOR-1279 T G T G C T G A C A G C A G C T C A T T G C T G G G G A A G G T G A G G A G C T A A G G A A C T T C C T G G C C A G C C EI)
      (HUMCAPG-DONOR-1869 A C C A T C C A G A A T G A C A T C A T G T T A T T G C A G G T A C C A C C T A C C T G G C C C T C T G G C T C C T T C EI)
      (HUMCAPG-DONOR-2299 G A C C G G C G G G A A C G G A A G G C T G C C T T C A A G G T A A G G C A T G G G C A T T G G C C A A C A C A C C C C EI)
      (HUMCATF-DONOR-646 T T T C C A T T T A A T C C A T T C G A T C T C A C C A A G G T G A G T C A G T A A A C A A C T A T A T T G T T T T C T EI)
      (HUMCFVII-DONOR-556 T G C T T G G G C T T C A G G G C T G C C T G G C T G C A G G T G C G T C C G G G G A G G T T T T C T C C A T A A A C T EI)
      (HUMCFVII-DONOR-1690 A C A T G C C G T G G A A G C C G G G G C C T C A C A G A G G T G A G C A G G G A C T G C C A C T G G T T T T G T C C T EI)
      (HUMCFVII-DONOR-4425 C G G G A G A T C T T C A A G G A C G C G G A G A G G A C G G T G A G C C C A G C C T C G G G G C G C C C C G C G C G G EI)
      (HUMCFVII-DONOR-6378 T T C A G A A G C T G T T C T G G A T T T C T T A C A G T G G T G A G T G G A T G A T C A C C A C C A G T C C T G C C T EI)
      (HUMCFVII-DONOR-6562 C T G C C T T C G A G G G C C G G A A C T G T G A G A C G C G T A A G G C C C C A C T T T G G G T C C C A T A T T T G C EI)
      (HUMCFVII-DONOR-8418 T G G C A G A C G G G G T G T C C T G C A C A C C C A C A G G T G A C C A G G C T T C A T G T C C C A G T C C C A G A T EI)
      (HUMCFVII-DONOR-9499 G T G T G C C C C A A A G G G G A G T G T C C A T G G C A G G T A A G G C T T C C C C T G G C T T C A G G A T T C C A A EI)
      (HUMCFVII-DONOR-10218 A G A A C T G G A G G A A C C T G A T C G C G G T G C T G G G T G G G T A C C A C T C T C C C C T G T C C G A C C G C G EI)
      (HUMCKMT-DONOR-523 C A G T G A A C G A C G G A G G C T G T A T C C C C C G A G G T A A C A G T G C C T G A G G C G C G G G A G G A G G C G EI)
      (HUMCKMT-DONOR-1326 A T G G T G G C T G G A G A T G A G G A G A C C T A T G A G G T A G G G G G T C C C C A G A G T C T C C C T G A T G A T EI)
      (HUMCKMT-DONOR-1625 A A G C A C A C C A C G G A T C T A G A T G C C A G T A A A G T G A G T T C A A A T A T C C C A C T T C T G A T T T G C EI)
      (HUMCKMT-DONOR-2233 A C A G A G G C T G A A C A G C A G C A G C T T A T T G A T G T G A G G G C C T T A A G A G G G T G C T G G T T G G T G EI)
      (HUMCKMT-DONOR-2448 T C G A G A C T G G C C A G A T G C T C G T G G A A T T T G G T A T G A A G C T G C T C A T T A C C T C T T T T G T C T EI)
      (HUMCKMT-DONOR-2687 T T T G A A A G A T T C T G C C G A G G C C T C A A A G A G G T T A G A G A A G A C T A T G T A G G G G A G C T A G G T EI)
      (HUMCKMT-DONOR-4483 G T G C A C A T C A A A C T G C C C C T G C T A A G C A A A G T A A A G G A G T T G T G G G G T T A C A G A G G G G T G EI)
      (HUMCKMT-DONOR-5110 T C T A A T T T G G A C C G A C T A G G C A A A T C A G A G G T G A G A T C C T A A G G G A T T A G G A C A A G G A G A EI)
      (HUMCP21OH-DONOR-917 C C A T C T A C A G G C T C C A C C T T G G G C T G C A A G G T G A G A G G C T G A T C T C G C T C T G G C C C T C A C EI)
      (HUMCP21OH-DONOR-1104 A C T T T G C T G G C A G A C C T G A G C C A C T T A C C T G T A A G G G C T G G G G G C A T T T T T T C T T T C T T A EI)
      (HUMCP21OH-DONOR-1541 G T G G A G C A G C T G A C C C A G G A G T T C T G T G A G G T A A G G C T G G G C T C C T G A G G C C A C C T C G G G EI)
      (HUMCP21OH-DONOR-1750 T G T T A C C T C A C C T T C G G A G A C A A G A T C A A G G T G C C T C A C A G C C C C T C A G G C C C A C C C C C A EI)
      (HUMCP21OH-DONOR-1940 C A A A T T G T G G A C G T G A T T C C C T T T C T C A G G G T G A G G A C C T G G A G C C T A G A C A C C C C T G G G EI)
      (HUMCP21OH-DONOR-2128 A T C G T G G A G A T G C A G C T G A G G C A G C A C A A G G T G G G G A C T G T A C G T G G A C G G C C T C C C C T C EI)
      (HUMCP21OH-DONOR-2498 G C C G T G G T T T T T T T G C T T C A C C A C C C T G A G G T G C G T C C T G G G G A C A A G C A A A A G G C T C C T EI)
      (HUMCP21OH-DONOR-2877 C T T G C C C C A C C G C A C C A C A C G G C C C A G C A G G T G A C T C C C G A G G G T T G G G G A T G A G T G A G G EI)
      (HUMCP21OH-DONOR-3064 T C T G G G A G A G G C C A C A T G A G T T C T G G C C T G G T A T G T G G G G G G C C G G G G G C C T G C C G T G A A EI)
      (HUMCP21OHC-DONOR-918 C C A T C T A C A G G C T C C A C C T T G G G C T G C A A G G T G A G A G G C T G A T C T C G C T C T G G C C C T C A C EI)
      (HUMCP21OHC-DONOR-1105 A C T T T G C T G G C A G A C C T G A G C C A C T T A C C T G T A A G G G C T G G G G G C A T T T T T T C T T T C T T A EI)
      (HUMCP21OHC-DONOR-1542 G T G G A G C A G C T G A C C C A G G A G T T C T G T G A G G T A A G G C T G G G C T C C T G A G G C C A C C T C G G G EI)
      (HUMCP21OHC-DONOR-1751 T G T T A C C T C A C C T T C G G A G A C A A G A T C A A G G T G C C T C A C A G C C C C T C A G G C C C A C C C C C A EI)
      (HUMCP21OHC-DONOR-1941 C A A A T T G T G G A C G T G A T T C C C T T T C T C A G G G T G A G G A C C T G G A G C C T A G A C A C C C C T G G G EI)
      (HUMCP21OHC-DONOR-2129 A T C G T G G A G A T G C A G C T G A G G C A G C A C A A G G T G G G G A C T G T G T G T G G A C G G C C T C C C C T C EI)
      (HUMCP21OHC-DONOR-2499 G C C G T G G T T T T T T T G C T T C A C C A C C C T G A G G T G C G T C C T G G G G A C A A G C A A A A G G C T C C T EI)
      (HUMCP21OHC-DONOR-2878 C T T G C C C C A C C G C A C C A C A C G G C C C A G C A G G T G A C T C T C C G A G G G T T G G G G A T G A G T G A G EI)
      (HUMCP21OHC-DONOR-3066 T C T G G G A G A G G C C A C A T G A G T T C T G G C C T G G T A T G T G G G G G G C C G G G G G C C T G C C G T G A A EI)
      (HUMCRPG-DONOR-300 C C A G C C T C T C T C A T G C T T T T G G C C A G A C A G G T A A G G G C C A C C C C A G G C T A T G G G A G A G T T EI)
      (HUMCRPGA-DONOR-261 C C A G C C T C T C T C A T G C T T T T G G C C A G A C A G G T A A G G G C C A C C C C A G G C T A T G G G A G A G T T EI)
      (HUMCRYGBC-DONOR-2131 C A T C T G C T C A C T T C C T T C A A A A T G G G A A A G G T A A G T C C T G G G T A C C G G A T G C T C A G C C T T EI)
      (HUMCRYGBC-DONOR-2468 T C C A T C C G C T C C T G C T G C C T C A T C C C C C C G G T G A G T G T G G C T C T G T C T T T G C C T T C C A T C EI)
      (HUMCRYGBC-DONOR-18389 C A T C A T C C G T G T C A A C C A G C C A T G G G G A A G G T G A G C A G A A C A C A A A T T A A A T A A A A T G A A EI)
      (HUMCRYGBC-DONOR-18732 T C C A T C C G C T C C T G T T G T C T C A T C C C C C A A G T G A G T T T T C T A G A T T T C C A T C A T G C C G C C EI)
      (HUMCS1-DONOR-535 G G A C A G C T C A C C T A G T G G C A A T G G C T C C A G G T A A G C G C C C C T A A A A T C C C T T T G G G C A C A EI)
      (HUMCS1-DONOR-961 C A G C T G G C C A T T G A C A C C T A C C A G G A G T T T G T A A G T T C T T G G G G A A T G G G T G C G G G T C A G EI)
      (HUMCS1-DONOR-1304 T C C A A C A T G G A G G A A A C G C A A C A G A A A T C C G T G A G T G G A T G C C G T C T C C C C T A G G C G G G G EI)
      (HUMCS1-DONOR-1561 C T A G A G G A A G G C A T C C A A A C G C T G A T G G G G G T G A G G G T G G C G C C A G G G G T C A C C A A T C T T EI)
      (HUMCSFGMA-DONOR-793 A A C C T G A G T A G A G A C A C T G C T G C T G A G A T G G T A A G T G A G A G A A T G T G G G C C T G T G C C T A G EI)
      (HUMCSFGMA-DONOR-933 G A A G T C A T C T C A G A A A T G T T T G A C C T C C A G G T A A G A T G C T T C T C T C T G A C A T A G C T T T C C EI)
      (HUMCSFGMA-DONOR-1746 C A C T A C A A G C A G C A C T G C C C T C C A A C C C C G G T G A G T G C C T A C G G C A G G G C C T C C A G C A G G EI)
      (HUMCSPB-DONOR-258 C C T T C C T C C T G C T G C C C A G G G C A G A T G C A G G T G A G T G A C C G T C T C C A C C C T C G G G G G C C C EI)
      (HUMCSPB-DONOR-1408 C G T G C T G A C A G C T G C T C A C T G T T G G G G A A G G T G A G G A G C A G A A A A C A G C C C A C A C C C T C C EI)
      (HUMCSPB-DONOR-2010 A A C T T C T C C A A C G A C A T C A T G C T A C T G C A G G T N A G G C A C A C T C C T G C C A C T C T T G C T C T T EI)
      (HUMCSPB-DONOR-2478 G A C C C A G A G A T T A A A A A G A C T T C C T T T A A G G T A A G A C T A T G C A C C T G C C T G G A T T G G C T C EI)
      (HUMCYC1A-DONOR-1506 C C C G G G C A G C T C C C G C T A C G G A C A C C T C A G G T G A G C G C T G G G C C G G G C C C C G G C C T C C G C EI)
      (HUMCYC1A-DONOR-2305 T G G C C T C C T C T C T T C C T T G G A C C A C A C C A G G T G T G C A G C T G G C T G G C T G G C T G G C A G C G G EI)
      (HUMCYC1A-DONOR-2526 G A G G A T G A A G C T A A G G A G C T G G C T G C G G A G G T G T G G G G T C T G G G A T G C C T G G G A C C C A G G EI)
      (HUMCYC1A-DONOR-2769 C C C T G A C C T C A G C T A C A T C G T G C G A G C T A G G T A C A C G G G C T G C C C A T G G G G T G G T G C T G G EI)
      (HUMCYC1A-DONOR-3019 T C T A C A C A G A T G T C T T A G A G T T T G A C G A T G G T A A G A G G C C T C C A G T C T C C T A C C C C C A G G EI)
      (HUMCYC1A-DONOR-3382 C A C G A C C A T C G A A A A C G C A T G G G G C T C A A G G T A A A A G G G T T G G G A G G C C A T G G T G G G T A T EI)
      (HUMCYCAA-DONOR-115 A G T G T T C G T T G T G C C A G C G A C T A A A A A G A G G T G A G A G C G G G T C G C G G A G G C C G C A C C T G G EI)
      (HUMCYCAA-DONOR-1365 A C T C T T A C A C A G C C G C C A A T A A G A A C A A A G G T A A G A G T C A C T T G T T A A A T A A A A C A A C A C EI)
      (HUMCYPIIE-DONOR-2972 T T G A A G A A T A T T C C C A A G T C C T T C A C C C G G G T A A G A G A A A T A G T G T T G A T T T T A G G G A G A EI)
      (HUMCYPIIE-DONOR-4037 T C C C C G C G T T C C A T G C G C A C A G G G A C A G G G G T G A G T C C G C G T C C C T G G C A C G G A G C G G G G EI)
      (HUMCYPIIE-DONOR-7126 T C C T G C T G G A A G C A C T C A G G A A G A C C C A A G G T G C G T A T C T G C T G C C T A G C A G G G C C C A G T EI)
      (HUMCYPIIE-DONOR-7676 T T C C A C C T A C T C A G C A C T C C C T G G C T C C A G G T G A A G C C A C T T T C C T C T T T C A T C A G T C A T EI)
      (HUMCYPIIE-DONOR-8260 A C C G A C T G C C T G C T C G T G G A A A T G G A G A A G G T A G G C T C G G C C T C C C A T G A T G T G G G C T C T EI)
      (HUMCYPIIE-DONOR-9284 T G A T T C T C A T G A A A T A C C C T G A G A T C G A A G G T A G G C A A G T G A C T G A A G G G A C A C C G T G C G EI)
      (HUMCYPIIE-DONOR-12309 A C C A T T T T C A G A G G A T A C C T C A T C C C C A A G G T T A A G C A A T G A G C C T G C A G C A C A C A G C A T EI)
      (HUMCYPIIE-DONOR-12950 A C A G T G A C T A T T T C A A G C C A T T T T C C A C A G G T G A G A A A G A T C A G A G G C A G T A C C T T C C C T EI)
      (HUMDAFA-DONOR-1117 C C A C T T C A G G T A C T A C C C G T C T T C T A T C T G G T T C T C G T C C T G T C A C C C A G G C T G G T A T G C EI)
      (HUMDES-DONOR-711 G C T C G A C G A C C T G C A G C G G C T C A A G G C C A A G T G A G G G C C C G G C A C C C C A G A C T C C T C T T T EI)
      (HUMDES-DONOR-1824 G C A G A G A A C A A T T T G G C T G C C T T C C G A G C G G T G A G T G C C C T T C T T T T C C C C T T G C A T G G C EI)
      (HUMDES-DONOR-2016 A T C G C G T T C C T T A A G A A A G T G C A T G A A G A G G T A T A C T T G G C C C C T C T T C C T G G G G T C A C T EI)
      (HUMDES-DONOR-2326 T C T G A A G C T G A G G A G T G G T A C A A G T C G A A G G T G G G T G G C C T C G C C C G G G G A C T G G G A T C T EI)
      (HUMDES-DONOR-2630 A C C T G C G A G A T T G A C G C C C T C A A G G G C A C T G T G A G T C C C T G C C C A C C T G G G C C A G G C C C T EI)
      (HUMDES-DONOR-3236 C C G G A A G C T G C T G G A G G G A G A G G A G A G C C G G T G A G G G G C C A G G C A G G A G C C G A G T G G G A G EI)
      (HUMDES-DONOR-5457 T C C A G A C C T A C T C T G C C C T C A A C T T C C G A G G T G A G T G T C T G C T G G A G G C G G A G G C T G G A G EI)
      (HUMDES-DONOR-7366 A T C A A G A C C A T C G A G A C A C G G G A T G G G G A G G T A A G T G G T C T G T C T G G G C T C C T T A C C C T T EI)
      (HUMEDHB17-DONOR-1938 T G G C T T C A G A T C C A T C C C A G A G C T T C A A A G G T A T A G A T A G G C A G G G A C A G G G A G G G A G A G EI)
      (HUMEDHB17-DONOR-2199 G C G T G A C T G A G G G C C G C G T G G A C G T G C T G G G T G A G C C T C C T G G A A G C A T A T G G G C T C C T A EI)
      (HUMEDHB17-DONOR-2526 T G G T G A C C G G G A G C G T G G G A G G A T T G A T G G G T G A G T G G T A G G G A G T G G C C T C G G C A G C T C EI)
      (HUMEDHB17-DONOR-2795 G G C G G T T C T G C T G C T G C C C T T T G G G G T C C A G T G A G T C A A C A C C C C C G T T C C C C G A A C C C T EI)
      (HUMEDHB17-DONOR-3489 G C G G C G C A G A A C C C T G A G G A G G T G G C G G A G G T G A G C G C C G G G C T G G A C T C C A G G A G T G G G EI)
      (HUMEF1A-DONOR-579 T T T C G C A A C G G G T T T G C C G C C A G A A C A C A G G T A A G T G C C G T G T G T G G T T C C C G C G G G C C T EI)
      (HUMEF1A-DONOR-1696 A T T G A A A A A T T T G A G A A G G A G G C T G C T G A G G T A T G T T T A A T A C C A G A A A G G G A A A G A T C A EI)
      (HUMEF1A-DONOR-2242 A T C A A A A A C A T G A T T A C A G G G A C A T C T C A G G T T G G G A T T A A T A A T T C T A G G T T T C T T T A T EI)
      (HUMEF1A-DONOR-2644 G G T G A C A A C A T G C T G G A G C C A A G T G C T A A C G T A A G T G G C T T T C A A G A C C A T T G T T A A A A A EI)
      (HUMEF1A-DONOR-2878 T G C C T C T C C A G G A T G T C T A C A A A A T T G G T G G T A A G T T G G C T G T A A A C A A A G T T G A A T T T G EI)
      (HUMEF1A-DONOR-3222 C C A A T G G A A G C A G C T G G C T T C A C T G C T C A G G T A A C A A T T T A A A G T A A C A T T A A C T T A T T G EI)
      (HUMEF1A-DONOR-3546 T T G A G A G C T T C T C A G A C T A T C C A C C T T T G G G T A A G G A T G A C T A C T T A A A T G T A A A A A A G T EI)
      (HUMERP-DONOR-598 C C C G G C C A G G C G C G G A G A T G G G G G T G C A C G G T G A G T A C T C G C G G G C T G G G C G C T C C C G C C EI)
      (HUMERP-DONOR-1310 T T G G A G G C C A A G G A G G C C G A G A A T A T C A C G G T G A G A C C C C T T C C C C A G C A C A T T C C A C A G EI)
      (HUMERP-DONOR-1653 G T T A A T T T C T A T G C C T G G A A G A G G A T G G A G G T G A G T T C C T T T T T T T T T T T T T T T C C T T T C EI)
      (HUMERP-DONOR-2444 A C C A C T C T G C T T C G G G C T C T G G G A G C C C A G G T G A G T A G G A G C G G A C A C T T C T G C T T G C C C EI)
      (HUMERPA-DONOR-608 C C C G G C C A G G C G C G G A G A T G G G G G T G C A C G G T G A G T A C T C G C G G G C T G G G C G C T C C C G C C EI)
      (HUMERPA-DONOR-1317 T T G G A G G C C A A G G A G G C C G A G A A T A T C A C G G T G A G A C C C C T T C C C C A G C A C A T T C C A C A G EI)
      (HUMERPA-DONOR-1662 G T T A A T T T C T A T G C C T G G A A G A G G A T G G A G G T G A G T T C C T T T T T T T T T T T T T T T C C T T T C EI)
      (HUMERPA-DONOR-2453 A C C A C T C T G C T T C G G G C T C T G G G A G C C C A G G T G A G T A G G A G C G G A C A C T T C T G C T T G C C C EI)
      (HUMETN3-DONOR-227 G A A T T T T T G C C A A G C A G G A A A A G A A C T C A G G T G A G C A G A A A C A C C T T T G C T T T T C A A T C A EI)
      (HUMFABP-DONOR-1126 A A A A C T A T G A C A A G T T C A T G G A A A A A A T G G G T A A A G A C T T T A T T T C T T T G T G G C T C A T T C EI)
      (HUMFABP-DONOR-2493 T A C A A C C T A G C A G A C G G A A C T G A A C T C A G G G T A A G A A T T T T T T T T T T T A T G A G C A A T G C A EI)
      (HUMFABP-DONOR-3624 C G A G A A A T T A T A G G T G A T G A A C T A G T C C A G G T G A G T T G T C A A A T T T A T A G C T A T T T T C A A EI)
      (HUMFIXG-DONOR-3053 T A G G A T A T C T A C T C A G T G C T G A A T G T A C A G G T T T G T T T C C T T T T T T A A A A T A C A T T G A G T EI)
      (HUMFIXG-DONOR-9425 C G A G A A G T T T T T G A A A A C A C T G A A A G A A C A G T G A G T A T T T C C A C A T A A T A C C C T T C A G A T EI)
      (HUMFIXG-DONOR-9638 T A T A G A C T G A A T T T T G G A A G C A G T A T G T T G G T A A G C A A T T C A T T T T A T C C T C T A G C T A A T EI)
      (HUMFIXG-DONOR-13441 T T G G A T T T G A A G G A A A G A A C T G T G A A T T A G G T A A G T A A C T A T T T T T T G A A T A C T C A T G G T EI)
      (HUMFIXG-DONOR-20733 C A G A A A A C C A G A A G T C C T G T G A A C C A G C A G G T C A T A A T C T G A A T A A G A T T T T T T A A A G A A EI)
      (HUMFIXG-DONOR-23501 G A T G C C A A A C C A G G T C A A T T C C C T T G G C A G G T A C T T T A T A C T G A T G G T G T G T C A A A A C T G EI)
      (HUMFIXG-DONOR-33089 A A A C T G G T G T T A A A A T T A C A G T T G T C G C A G G T A A A T A C A C A G A A A G A A T A A T A A T C T G C A EI)
      (HUMFOS-DONOR-1000 T C C A G C A T G G G C T C G C C T G T C A A C G C G C A G G T A A G G C T G G C T T C C C G T C G C C G C G G G G C C EI)
      (HUMFOS-DONOR-2005 A G C A T T G G C A G G A G G G G C A A G G T G G A A C A G G T G A G G A A C T C T A G C G T A C T C T T C C T G G G A EI)
      (HUMFOS-DONOR-2544 A G G A G G G A G C T G A C T G A T A C A C T C C A A G C G G T A G G T A C T C T G T G G G T T G C T C C T T T T T A A EI)
      (HUMFVII-DONOR-70 T G C T T G G G C T T C A G G G C T G C C T G G C T G C A G G C G G G G T C G C T A A G G C C T C A G G A G G A G A A A EI)
      (HUMG0S19A-DONOR-2124 T G G C T C T C T G C A A C C A G T T C T C T G C A T C A C G T G A G T C T G A G T T T C G T T G T G G G T A T C A C C EI)
      (HUMG0S19A-DONOR-2927 G A G C A G C C A G T G C T C C A A G C C C G G T G T C A T G T A A G T G C C A G T C T T C C T G C T C A C C T C T A T EI)
      (HUMG0S19B-DONOR-2263 C T C T C T G C A A C C A G G T C C T C T C T G C A C C A C G T G A G T C C A T G T T G T T G T T G T G G G T A T C A C EI)
      (HUMG0S19B-DONOR-3063 G A G C A G C C A G T G C T C C A A G C C C A G T G T C A T G T A A G T G C C A G T C T T C C T G C T C A C C T C T A G EI)
      (HUMGAST2-DONOR-786 G A C C C C A G G G T C C C C C A C A C C T C G T G G C A G G T A G G A G C T G C T G A C T G C C C T G C T T G C C T C EI)
      (HUMGASTA-DONOR-3213 C G T G G C A C C A C A C A C C T C C C A G C T C T G C A G G T G A G A A A A C C C A G G A G G A G A G G G G A G A G G EI)
      (HUMGASTA-DONOR-6470 G A C C C C A G G G T C C C C C A C A C C T C G T G G C A G G T A G G A G C T G C T G A C T G C C C T G C T T G C C T C EI)
      (HUMGCB1-DONOR-581 G G G A T G G A G T T T T C A A G T C C T T C C A G A G A G G T A A G A G A G A G A G C T C C C A A T C A G C A T T G T EI)
      (HUMGCB1-DONOR-1037 T T C T A C T T C A G G C A G T G T C G T G G G C A T C A G G T G A G T G A G T C A A G G C A G T G G G G A G G T A G C EI)
      (HUMGCB1-DONOR-1782 G G C C C A T C C A G G C T A A T C A C A C G G G C A C A G G T A A C C A T T A C A C C C C T C A C C C C C T G G G C C EI)
      (HUMGCB1-DONOR-2052 T G C T A C T T A A A T C G T A C T T C T C T G A A G A A G G T G A G G A G G A A G G G G A C A A G A T G A C A T A G A EI)
      (HUMGCB1-DONOR-3143 A G C C T C C C A G A G G A A G A T A C C A A G C T C A A G G T A G G C A T T C T A G C T T T T T C A G G C C C T G A G EI)
      (HUMGCB1-DONOR-3526 C C A C C A G A C C T G G G C C A G A T A C T T T G T G A A G T A A G G G A T C A G C A A G G A T G T G G G A T C A G G EI)
      (HUMGCB1-DONOR-4319 C G C T T G C T G C T G C C C C A C T G G G C A A A G G T G G T A A G G C C T G G A C C T C C A T G G T G C T C C A G T EI)
      (HUMGCB1-DONOR-5411 G G G A T G C A G T A C A G C C A C A G C A T C A T C A C G G T A A G C C A C C C C A G T C T C C C T T C C T G C A A A EI)
      (HUMGCB1-DONOR-5974 G C C C A T G T T C T A C C A C C T T G G C C A C T T C A G G T G A G T G G A G G G C G G G C A C C C C C A T T C C A T EI)
      (HUMGCB1-DONOR-6461 T G G C T C T G C T G T T G T G G T C G T G C T A A A C C G G T G A G G G C A A T G G T G A G G T C T G G G A A G T G G EI)
      (HUMGFP40H-DONOR-880 G A C A T C A A C T T C C T C A T C A A C A A G A T G C A G G T A G G C T G C A G G G G G A G C C C A T G G G A A A G A EI)
      (HUMGFP40H-DONOR-1028 C C A G C T T C C A A G T G C C A C T G C A G T G C T A A T G T G A G T G A A T G C T C T T T A A G A A C T T T C C A A EI)
      (HUMGFP40H-DONOR-1143 A C C A G T T G T C T C T G T T T G G G C A T T C C C T C T G T A A G T A T A G T G A A A T A A C A T A A T G T T G A C EI)
      (HUMGFP40H-DONOR-2563 G T T G A A G T A C T A A A G A A C A A C A A G T G T C C A G T A A G T T T G T T T T C A T A T G T G A T A T G T T C C EI)
      (HUMGG-DONOR-230 T T C C C T T C A A G A C A C A G A G G A G A A A T C C A G G T A T T A A A T C C G T A G T C T C G A A C T A A C A T A EI)
      (HUMGG-DONOR-1964 G C A G T G G T T G A T G A A T A C C A A G A G G A A C A G G T A A G A G T C T A A G C C T G G C T C A A A A C T T G C EI)
      (HUMGG-DONOR-3769 T T G G C T G G T G A A A G G C C G A G G A A G G C G A G A G T A A G T C T G T A C A T T C T T A T T T G A C A T T T T EI)
      (HUMGH-DONOR-315 T G G A C G C T C A C C T A G C T G C A A T G G C T A C A G G T A A G C G C C C C T A A A A T C C C T T T G G G C A C A EI)
      (HUMGH-DONOR-732 C A G C T G G C C T T T G A C A C C T A C C A G G A G T T T G T A A G C T C T T G G G G A A T G G G T G C G C A T C A G EI)
      (HUMGH-DONOR-1061 T C C A A C A G G G A G G A A A C A C A A C A G A A A T C C G T G A G T G G A T G C C T T G A C C C C A G G C G G G G A EI)
      (HUMGH-DONOR-1319 C T A G A G G A A G G C A T C C A A A C G C T G A T G G G G G T G G G G G T G G C G C T A G G G G T C C C C A A T C T T EI)
      (HUMGHCSA-DONOR-5205 G G A C A G C T C A C C T A G C G G C A A T G G C T A C A G G T A A G C G C C C C T A A A A T C C C T T T G G G C A C A EI)
      (HUMGHCSA-DONOR-5626 C A G C T G G C C T T T G A C A C C T A C C A G G A G T T T G T A A G C T C T T G G G G A A T G G G T G C G C A T C A G EI)
      (HUMGHCSA-DONOR-5955 T C C A A C A G G G A G G A A A C A C A A C A G A A A T C C G T G A G T G G A T G C C T T C T C C C C A G G C G G G G A EI)
      (HUMGHCSA-DONOR-6212 C T A G A G G A A G G C A T C C A A A C G C T G A T G G G G G T G A G G G T G G C G C C A G G G G T C C C C A A T C C T EI)
      (HUMGHCSA-DONOR-12784 G G A C A G C T C A C C T A G C G G C A A T G G C T G C A G G T A A G C G C C C C T A A A A T C C C T T T G G G C A C A EI)
      (HUMGHCSA-DONOR-13226 A C C A G G A G T T T A T A A G C T C T T G G G G A A T G G G T G C G G G T C A G G G G T G G C A A G A A G G G G T G A EI)
      (HUMGHCSA-DONOR-13551 T C C A A C A T G G A G G A A A C G C A G C A G A A A T C C G T G A G T G G A T G C T G T C T C C T A G G C G G G G A T EI)
      (HUMGHCSA-DONOR-13807 C T A G A G G A A G G C A T C C A A A T G C T G A T G G G G G T G A G G G T G G C A C C A G G G G T C C C C A A T C C T EI)
      (HUMGHCSA-DONOR-27451 G G A C A G C T C A C C T A G T G G C A A T G G C T C C A G G T A A G C G C C C C T A A A A T C C C T T T G G G C A C A EI)
      (HUMGHCSA-DONOR-27878 C A G C T G G C C A T T G A C A C C T A C C A G G A G T T T G T A A G T T C T T G G G G A A T G G G T G C G G G T C A G EI)
      (HUMGHCSA-DONOR-28221 T C C A A C A T G G A G G A A A C G C A A C A G A A A T C C G T G A G T G G A T G C C G T C T C C C T A G G C G G G G A EI)
      (HUMGHCSA-DONOR-28478 C T A G A G G A A G G C A T C C A A A C G C T G A T G G G G G T G A G G G T G G C G C C A G G G G T C A C C A A T C C T EI)
      (HUMGHCSA-DONOR-42122 G G A C A G C T C A C C T A G C G G C A A T G G C T G C A G G T A A G C G C C C C T A A A A T C C C T T T G G G C A C A EI)
      (HUMGHCSA-DONOR-42555 C A G C T G G C A T A T G A C A C C T A T C A G G A G T T T G T A A G C T C T T G G G T A A T G G G T G C G C T T C A G EI)
      (HUMGHCSA-DONOR-42885 T C C A A C A G G G T G A A A A C G C A G C A G A A A T C T G T G A G T G G A T G C C T T C T C C C C A G G T G G G A T EI)
      (HUMGHCSA-DONOR-43141 C T A G A G G A A G G C A T C C A A A C G C T G A T G T G G G T G A G G G T G G C A C C A G G G A T C C C A A T C C T G EI)
      (HUMGHCSA-DONOR-50275 G G A C A G C T C A C C T A G C G G C A A T G G C T G C A G G T A A G C G C C C C T A A A A T C C T T T G G G C A C A A EI)
      (HUMGHCSA-DONOR-50700 C A G C T G G C C A T T G A C A C C T A C C A G G A G T T T G T A A G T T C T T G G G G A A T G G G T G C G G G T C A G EI)
      (HUMGHCSA-DONOR-51042 T C C A A C A T G G A G G A A A C G C A A C A G A A A T C C G T G A G T G G A T G C C G T C T C C C C T A G G C G G G G EI)
      (HUMGHCSA-DONOR-51300 C T A G A G G A A G G C A T C C A A A C G C T G A T G G G G G T G A G G G T G G C G C C A G G G G T C G C C A A T C C T EI)
      (HUMGHN-DONOR-539 G G A C A G C T C A C C T A G C T G C A A T G G C T A C A G G T A A G C G C C C C T A A A A T C C C T T T G G C A C A A EI)
      (HUMGHN-DONOR-959 C A G C T G G C C T T T G A C A C C T A C C A G G A G T T T G T A A G C T C T T G G G G A A T G G G T G C G C A T C A G EI)
      (HUMGHN-DONOR-1286 T C C A A C A G G G A G G A A A C A C A A C A G A A A T C C G T G A G T G G A T G C C T T C T C C C C A G G C G G G G A EI)
      (HUMGHN-DONOR-1544 C T A G A G G A A G G C A T C C A A A C G C T G A T G G G G G T G A G G G T G G C G C C A G G G G T C C C C A A T C C T EI)
      (HUMGHVA-DONOR-488 C T A G A G G A A G G C A T C C A A A C G C T G A T G T G G G T G A G G G T G G C A C C A G G G A T C C C C A A T C C T EI)
      (HUMGPIBAA-DONOR-2800 C T G T G C C T T C G G A G G T C T T T C T G C C T G C C T G T A A G C C G G G G T T G G T G C T G G G G C A G G A G A EI)
      (HUMGRP78-DONOR-685 C G G C A T C G A C T T G G G G A C C A C C T A C T C C T G G T A A G T G G G G T T G C G G A T G A G G G G G A C G G G EI)
      (HUMGRP78-DONOR-1007 C A G C A G G A C A T C A A G T T C T T G C C G T T C A A G G T T C G A C C G G T T T T C C T C A T C C A G T T A G A G EI)
      (HUMGRP78-DONOR-1510 G A A A C C G C T G A G G C T T A T T T G G G A A A G A A G G T A A A T A T T T C T A G A A C A A T G T T A A G T A T T EI)
      (HUMGRP78-DONOR-2258 C C T A A A T G T T A T G A G G A T C A T C A A C G A G C C G T A A G T A T G A A A T T C A G G G A T A C G G C A T A T EI)
      (HUMGRP78-DONOR-2735 A C T C G G G C C A A A T T T G A A G A G C T C A A C A T G G T A T G T T C C T T G T T T T C T G C T T T G C T A A T G EI)
      (HUMGRP78-DONOR-3086 C T G G T G T G C T C T C T G G T G A T C A A G A T A C A G G T A G G T C A T C A T C G C A G C A T C T T T C T T A G T EI)
      (HUMGRP78-DONOR-3539 A A C C A A C T G T T A C A A T C A A G G T C T A T G A A G G T A A T T A C C T T A A G T T T G G T T A A T A T C A T G EI)
      (HUMGSHPXG-DONOR-690 G G C T T C C C G T G C A A C C A G T T T G G G C A T C A G G T G C G C C G G G C G G A G C G G G A C G G G A C G G G G EI)
      (HUMH19-DONOR-2128 G G T G C C T C A G C G T T C G G G C T G G A G A C G A G G G T G A G T T T T T C C C C C T C T G C C A C C C T C A G C EI)
      (HUMH19-DONOR-2359 A G G A C A G A G G A G G C G C G T C C G G C C T T C C T G G T G A G C G T G T C T G C C C T C C C T G C G T C A G G A EI)
      (HUMH19-DONOR-2562 T C T G G G C T C C C A G A A C C C A C A A C A T G A A A G G T G A G G G N C T T C C T G C C A C A C T T G G G G T G G EI)
      (HUMH19-DONOR-2766 A C T A C C T G A C T C A G G A A T C G G C T C T G G A A G G T G A G C A C C A G C G C T C C T T N G G A A G C C T C C EI)
      (HUMHBA4-DONOR-6768 T G G C G A G T A T G G T G C G G A G G C C C T G G A G A G G T G A G G C T C C C T C C C C T G C T C C G A C C C G G G EI)
      (HUMHBA4-DONOR-7090 A A G C T T C G G G T G G A C C C G G T C A A C T T C A A G G T G A G C G G C G G G C C G G G A G C G A T C T G G G T C EI)
      (HUMHBA4-DONOR-10579 T G G C G A G T A T G G T G C G G A G G C C C T G G A G A G G T G A G G C T C C C T C C C C T G C T C C G A C C C G G G EI)
      (HUMHBA4-DONOR-10901 A A G C T T C G G G T G G A C C C G G T C A A C T T C A A G G T G A G C G G C G G G C C G G G A G C G A T C T G G G T C EI)
      (HUMHBBAG-DONOR-1344 G G A A G A T G C T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G G A G G G EI)
      (HUMHBBAG-DONOR-1689 A A G C T G C A T G T G G A T C C T G A G A A C T T C A A G G T G A G T C C A G G A G A T G T T T C A G C C C T G T T G EI)
      (HUMHBBGG-DONOR-2241 G G A A G A T G C T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G G A G G G EI)
      (HUMHIAPPA-DONOR-629 C T G A T A T T G C T G A C A T T G A A A C A T T A A A A G G T A A A G A A T T T C C T A T T T C T G G G A A A G T T T EI)
      (HUMHIAPPA-DONOR-1054 G A A C C A T C T G A A A G C T A C A C C C A T T G A A A G G T T G G T A A C G T T T A A A A T C C T G T T T C T T T G EI)
      (HUMHMG14A-DONOR-1039 T T C C C C G C C G C C A C G A T G C C C A A G A G G A A G G T G A G C G G C G G C C G C G G C C C G C A C A C G C C C EI)
      (HUMHMG14A-DONOR-1394 A G C T C C G C C G A A G G C G C C G C C A A G G A A G A G G T G A G T G C G G G C C T T C T G C G G G G G G T G G T G EI)
      (HUMHMG14A-DONOR-1517 C C C A A G A G G A G A T C G G C G C G G T T G T C A G C T G T A A G T A A A G C G A G C C C C G T A A C C G T T C G T EI)
      (HUMHMG14A-DONOR-1647 G A A G C G A A G C C G A A A A A G G C A G C A G C G A A G G T A A G C C T C G A A A C G C G C A T T G G G A T G C A G EI)
      (HUMHMG14A-DONOR-4792 G C G G A A A A C G G G G A A A C G A A G A C T G A G G A G G T C A G A A G T G T G T G T G T G T G T G T G T G T G T G EI)
      (HUMHPARS1-DONOR-1016 T C T T C C A G A G G C A A G A C C A A C C A A G A T G A G G T G G G T C C A C A G C T T T C C C T C C T G C C T T T C EI)
      (HUMHPARS1-DONOR-2602 A C T C A G G C A A T G A T G T C A C G G A T A T C G C A G G T C A G T C T T T G G T T G G G T A G G A G T G T G C A T EI)
      (HUMHPARS1-DONOR-2990 A C T A C T A C A A A C T G C G C A C A G A A G G A G A T G G T A A G A T G T G G A C A A C T G T C T C C A T G C C C T EI)
      (HUMHPARS1-DONOR-3825 T T G G A G A T A A A C T T C C T G A A T G T G A A G C A G G T G G G T G C T G A G C A C T G A G C A C T T A A G A G A EI)
      (HUMHPARS1-DONOR-4714 A C T A C T A C A A A C T G C G C A C A G A A G G A G A T G G T A A G A T G T G G A C A A C T G T C T C C A T G C C C T EI)
      (HUMHPARS1-DONOR-5547 T T G G A G A T A A A C T T C C T G A A T G T G A A G C A G G T G G G T G C T G A G C A C T T A A G A G A G C A G G C A EI)
      (HUMHPRTB-DONOR-1674 G T T A T G G C G A C C C G C A G C C C T G G C G T C G T G G T G A G C A G C T C G G C C T G C C G G C C C T G G C C G EI)
      (HUMHPRTB-DONOR-14857 G T T T A T T C C T C A T G G A C T A A T T A T G G A C A G G T A A G T A A G A T C T T A A A A T G A G G T T T T T T A EI)
      (HUMHPRTB-DONOR-16757 G T A G A T T T T A T C A G A C T G A A G A G C T A T T G T G T G A G T A T A T T T A A T A T A T G A T T C T T T T T A EI)
      (HUMHPRTB-DONOR-27927 G G A G A T G A T C T C T C A A C T T T A A C T G G A A A G G T A T G T A T C T T G A A A G G G A A G A A A A A A A A G EI)
      (HUMHPRTB-DONOR-31605 T T T T T C T T C T A G A A T G T C T T G A T T G T G G A A G T A A G T T C A C A T T T A C T T T T A A T A T A A C A T EI)
      (HUMHPRTB-DONOR-34990 G T A T A A T C C A A A G A T G G T C A A G G T C G C A A G G T A T G T A T G A C A T T T T G A C A C A G A A T A T T T EI)
      (HUMHPRTB-DONOR-39832 C C C C A C G A A G T G T T G G A T A T A A G C C A G A C T G T A A G T G A A T T A C T T T T T T T G T C A A T C A T T EI)
      (HUMHPRTB-DONOR-40080 G A C T A T A A T G A A T A C T T C A G G G A T T T G A A T G T A A G T A A T T G C T T C T T T T T C T C A C T C A T T EI)
      (HUMHSP90B-DONOR-1172 A C T A T T A C G T A T A A T C C T T T T C T T T T C A A G G T A A G G C T G A G A T C T C C G C T A G G C T T C T T T EI)
      (HUMHSP90B-DONOR-2752 C T T C G G G A G T T G A T C T C T A A T G C T T C T G A T G T A G G T G C T C T G G T T T C C A C A T T T G G C A T G EI)
      (HUMHSP90B-DONOR-3558 G G T A C T A A A G C A T T C A T G G A G G C T C T T C A G G T A T T G C A G T T C T G T A G G C A T T C A T A C T T A EI)
      (HUMHSP90B-DONOR-3809 G A G G T T C C T T C A C T G T G C G T G C T G A C C A T G G T A A G T T A G C T T T T C T G T T A C A A G G T A G T T EI)
      (HUMHSP90B-DONOR-4129 C A G T T C A T A G G C T A T C C C A T C A C C C T T T A T G T G A G T A T G G A C T T T T A A A T C T T T T A C A C T EI)
      (HUMHSP90B-DONOR-4574 A A T G A C T G G G A A G A C C A C T T G G C A G T C A A G G T G T G A G A A G C C T T T G C A T G T T G G C T C A A C EI)
      (HUMHSP90B-DONOR-5188 G C T G T G A T G A G T T G A T A C C A G A G T A T C T C A G T G A G T A T C T C C T T G G C C T A A T T T A G T T G G EI)
      (HUMHSP90B-DONOR-5582 T T C T A T G A G G C A T T C T C T A A A A A T C T C A A G G T A A A A A G G C A A A T A A T G C T T A T T C C C T T T EI)
      (HUMHSP90B-DONOR-5858 A G A C A C A G A A G T C C A T C T A T T A C A T C A C T G G T G C G T T G A C T C T G A T T G A A G C C T T T T T G G EI)
      (HUMHSP90B-DONOR-6241 A A A G A A A T C T T A G A T A A G A A G G T T G A G A A G G T A A G C C A T T C T G G G G C T A G G A T A T A T T T T EI)
      (HUMHSP90B-DONOR-7352 G C A T C T A T C G C A T G A T C A A G C T A G G T C T A G G T A A G T A G C T T T G G T A C T T G G T G T G G C A A G EI)
      (HUMHST-DONOR-2861 T C G G C G G C G C G C A C G C G G A C A C C C G C G A C A G T G A G T G G C G C G G C C A G G C G C G A A G G G G C G EI)
      (HUMHST-DONOR-3582 A T G A G C A G C A A G G G C A A G C T C T A T G G C T C G G T G A G T A C C G C A G G G G T C T G G C T A G G C A C C EI)
      (HUMIFNINI-DONOR-2232 T T A T C T T T C T G A C T C T A A G T G G C A T T C A A G G T A A G G A A C A T C A A A G G A T A C T T A A T T T G T EI)
      (HUMIFNINI-DONOR-2912 A A G C C A A T T T T G T C C A C G T G T T G A G A T C A T G T G A G T G A A A T C C C A T C T G A T T A T C A C T T C EI)
      (HUMIFNINI-DONOR-3237 G A A T T T A C T G A A A G C A G T T A G C A A G G A A A G G T A G G T T T G C T G T T G C C T G C A G C C G A A T T G EI)
      (HUMIL1B-DONOR-416 G A T T C T C T T C A G C C A A T C T T C A T T G C T C A A G T A T G A C T T T A A T C T T C C T T A C A A C T A G G T EI)
      (HUMIL1B-DONOR-941 G C T C G C C A G T G A A A T G A T G G C T T A T T A C A G G T C A G T G G A G A C G C T G A G A C C A G T A A C A T G EI)
      (HUMIL1B-DONOR-1558 T T T G A A G C T G A T G G C C C T A A A C A G A T G A A G G T A A G A C T A T G G G T T T A A C T C C C A A C C C A A EI)
      (HUMIL1B-DONOR-3748 G C A C C T T C T T T C C C T T C A T C T T T G A A G A A G G T A G T T A G C C A A G A G C A G G C A G T A G A T C T C EI)
      (HUMIL1B-DONOR-4458 A C C T C C A G G G A C A G G A T A T G G A G C A A C A A G G T A A A T G G A A A C A T C C T G G T T T C C C T G C C T EI)
      (HUMIL1B-DONOR-5824 A A A G A T G A T A A G C C C A C T C T A C A G C T G G A G G T A A G T G A A T G C T A T G G A A T G A A G C C C T T C EI)
      (HUMIL2-DONOR-595 G A T T T A C A G A T G A T T T T G A A T G G A A T T A A T G T A A G T A T A T T T C C T T T C T T A C T A A A A T T A EI)
      (HUMIL2-DONOR-745 C T C A C A T T T A A G T T T T A C A T G C C C A A G A A G G T A A G T A C A A T A T T T T A T G T T C A A T T T C T G EI)
      (HUMIL2-DONOR-3182 A A T A T C A A C G T A A T A G T T C T G G A A C T A A A G G T A A G G C A T T A C T T T A T T T G C T C T C C T G G A EI)
      (HUMIL2A-DONOR-1533 G A T T T A C A G A T G A T T T T G A A T G G A A T T A A T G T A A G T A T A T T T C C T T T C T T A C T A A A A T T A EI)
      (HUMIL2A-DONOR-1683 C T C A C A T T T A A G T T T T A C A T G C C C A A G A A G G T A A G T A C A A T A T T T T A T G T T C A A T T T C T G EI)
      (HUMIL2A-DONOR-4119 A A T A T C A A C G T A A T A G T T C T G G A A C T A A A G G T A A G G C A T T A C T T T A T T T G C T C T C C T G G A EI)
      (HUMIL2B-DONOR-410 G A T T T A C A G A T G A T T T T G A A T G G A A T T A A T G T A A G T A T A T T T C C T T T C T T A C T A A A A T T A EI)
      (HUMIL2B-DONOR-560 C T C A C A T T T A A G T T T T A C A T G C C C A A G A A G G T A A G T A C A A T A T T T T A T G T T C A A T T T C T G EI)
      (HUMIL2B-DONOR-2996 A A T A T C A A C G T A A T A G T T C T G G A A C T A A A G G T A A G G C A T T A C T T T A T T T G C T C T C C T G G A EI)
      (HUMIL5-DONOR-667 A C T C A T C G A A C T C T G C T G A T A G C C A A T G A G G T A A T T T T C T T T A T G A T T C C T A C A G T C T G T EI)
      (HUMIL5-DONOR-908 C T G A G G A T T C C T G T T C C T G T A C A T A A A A A T G T A A G T T A A A T T A T G A T T C A G T A A A A T G A T EI)
      (HUMIL5-DONOR-1982 T T A A T A A A G A A A T A C A T T G A C G G C C A A A A A G T A A G T T A C A C A C A T T C A A T G G A A G C T A T A EI)
      (HUMIL5A-DONOR-666 A C T C A T C G A A C T C T G C T G A T A G C C A A T G A G G T A A T T T T C T T T A T G A T T C C T A C A G T C T G T EI)
      (HUMIL5A-DONOR-907 C T G A G G A T T C C T G T T C C T G T A C A T A A A A A T G T A A G T T A A A T T A T G A T T C A G T A A A A T G A T EI)
      (HUMIL5A-DONOR-1986 T T A A T A A A G A A A T A C A T T G A C G G C C A A A A A G T A A G T T A C A C A C A T T C A A T G G A A G C T A T A EI)
      (HUMINCP-DONOR-539 C C G C T G C G G G T A C T A A G A G C C A G G C A A C A G G T A G G T G C T C C C T C C A C C C C A G G G G T C C T G EI)
      (HUMINCP-DONOR-2163 G C C T T C C A T G A A C A G C C A G A A C T G C A G A A G G T A C G T T C C T G A T G C A G G T C C C G G G C C A G T EI)
      (HUMINCPPS-DONOR-940 T C A T C C T C C T C C C T G A G T C C T C T C T G C A G G G G C C A C A C C A G G A G C C T A G C T C C T T G T C C T EI)
      (HUMINCPPS-DONOR-2825 G T G T G T A T G T G G G T A G A T G G A T G T T T G A G G G A G T A T G C A T G T G G G T T C A T G C A T A G A T C T EI)
      (HUMIRBPG-DONOR-3151 G A C C G C A T T C C T G G A A T T G T G C C C A T G C A G G T G A G A C C C A A G A G A G A C C T G G C T G A A C C C EI)
      (HUMIRBPG-DONOR-5127 G C A C A C G G A T G C C A T G A T C A T C G A C A T G A G G T C A G T G G C C A G G G G T C A G T G C T T C C T A G C EI)
      (HUMIRBPG-DONOR-7130 G T G A A C T C T G G A C A C A C G C C C A G G T T G T A G G T A C G T G G A G A A G C T T T C T C C T T T C T G C T G EI)
      (HUMKAL2-DONOR-539 T C T C C A T C G C C T T G T C T G T G G G G T G C A C T G G T G A G A T T G G G G G G A T A A A G G A A G G G G G G C EI)
      (HUMKAL2-DONOR-1905 G G T G C T C A C A G C T G C C C A T T G C C T A A A G A A G T A A G T A G G A C C C T G G G A T C T G G G G A G G G A EI)
      (HUMKAL2-DONOR-3781 C A G G C T G G G G C A G C A T C G A A C C A G A G G A G T G T A C G C C T G G G C C A G A T G G T G T A G C T G G G A EI)
      (HUMKAL2-DONOR-4031 C T C T G G A C A G G T G G T A A A G A C A C T T G T G G G G T G A G T C A T C C C T A C T C C C A A C A T C T G G A G EI)
      (HUMKER18-DONOR-2967 T T C A A G A T C A T C G A G G A C C T G A G G G C T C A G G T A A G G G G T A G G A G G G A C C T C A A C T C C C A G EI)
      (HUMKER18-DONOR-3791 C C G T C T T G C T G C T G A T G A C T T T A G A G T C A A G T A A G T T T G G G G G C T A G A G A G C T G G G G G T C EI)
      (HUMKER18-DONOR-4285 C T G C T C T T C A T G A A G A A G A A C C A C G A A G A G G C A A G C A G G G G C C A C T G G C C A G G C C A G G G A EI)
      (HUMKER18-DONOR-5022 G A G G A G C T A G A C A A G T A C T G G T C T C A G C A G G T G C G T G A G G G G A G G G G A T G G C T G C C A A G G EI)
      (HUMKER18-DONOR-5233 G A G A T C G A C C T G G A C T C C A T G A G A A A T C T G G T G A G T G C C T T C A C A T C A C C T G C C C A G C T C EI)
      (HUMKER18-DONOR-5719 C C G C C T G C T G G A A G A T G G C G A G G A C T T T A A G T G A G T G G G G C T C T C C T A C C C A C A C G T G C T EI)
      (HUMKEREP-DONOR-814 T T C A A G A C C A T T G A G G A C C T G A G G A A C A A G G T G G G T G A A T G G G C A G C A G A A G G C A C C A T T EI)
      (HUMKEREP-DONOR-2153 C C G T C T G G C C G C G G A T G A C T T C C G C A C C A A G T G A G T T T G A A A T G G T G G G C C A G A A C A T C C EI)
      (HUMKEREP-DONOR-2872 C T G G C C T A C C T G A A G A A G A A C C A C G A G G A G G T G A G A A C T A T A T G G A A A A G T C A G C T T A A A EI)
      (HUMKEREP-DONOR-3368 A A G G A T G C C G A G G A A T G G T T C T T C A C C A A G G T G G G T G T C A T T T G A G G T G G A A G G A A C C C A EI)
      (HUMKEREP-DONOR-3577 G A G A T T G A G C T G C A G T C C C A G C T C A G C A T G G T A G G A A T A G T G C C A G G A A G G G T G G T G C A C EI)
      (HUMKEREP-DONOR-3892 C C G C C G C C T G C T G G A G G G C G A G G A C G C C C A G T G A G T C T T G G C C C T C C C C T T A G T C C G C C C EI)
      (HUMKEREP-DONOR-4033 T C T C C T C T G G A T C G C A G T C A T C C A G A G A T G G T A A G A C C C T C C T C C T C T G C A G G C C T G G G C EI)
      (HUMLACTA-DONOR-865 A T G G T T A T G G A G G C A T C G C T T T G C C T G A A T G T G A G T T C C C T G C C T C T G T G T T T C A T C C A T EI)
      (HUMLACTA-DONOR-1671 C A A G G A A C A T C T G T G A C A T C T C C T G T G A C A G T G A G T A G C C C C T A T A A C C C T C T T T C T C T G EI)
      (HUMLACTA-DONOR-2236 G A T C C T G G A T A T T A A A G G A A T T G A C T A C T G G T G A A T C C T T A T T C T A T T T T C T A T T T C C C C EI)
      (HUMLYL1B-DONOR-882 A G C C A G G G C A C T C A C C A G G C T G C A A G A A C A G T G C T G G G G T A A G A G G G G A G C G G G G G A T C C EI)
      (HUMLYL1B-DONOR-2543 G C A C T A C C A C C C T C A C C C C T T C C T C A A C A G G T A G T G G G G A T C T G G G G T G G G G G G C A G T G G EI)
      (HUMLYL1B-DONOR-2722 C A A G C C A C T G T G A G C T G G A C C T G G C T G A G G G T G A G T G T G G G T T T G T G T G C C T T G T G G G T T EI)
      (HUMMETIF1-DONOR-480 C A A T G G A C C C C A A C T G C T C C T G C G C C G C T G G T A A G G A A C G C C G G G T T C C G T G C C T G G G G A EI)
      (HUMMETIF1-DONOR-1131 A A G A G T G C A A A T G C A C C T C C T G C A A G A A G A G T G A G T G T G A G G C C A T C T C C A T G G T C T G G G EI)
      (HUMMH6-DONOR-826 G G G C C C T G A C C C T G A C C G A G A C C T G G G C G G G T G A G T G C G G G G T C A G G A G G G A A A C G G C C C EI)
      (HUMMH6-DONOR-1225 T G C G C G G C T A C T A C A A C C A G A G C G A G G C C A G T G A G T A A C T C C G G C C C A G G G A G C A G A T C A EI)
      (HUMMH6-DONOR-1727 A G A A C G G G A A G G A G A T G C T G C A G C G C G C G G G T A C C A G G G G C A G T G G G G C G C C T C C C T G A T EI)
      (HUMMH6-DONOR-2602 G G C T G C C G G A G C C C C T C A T G C T G A G A T G G A G T A A G G A G G G A G A T G G A G G C A T C A T G T C T G EI)
      (HUMMH6-DONOR-2841 C T G C T G T G C T G T G G A G A A A G A A G A G C T C A G G T A A G G A A G G G G T G A C A A G T G G G G T C T G A G EI)
      (HUMMH6-DONOR-3321 A G G A G G G A G C T A C T C T C A G G C T G C A A G T A A G T A T G A A G G A G G C T G A T C C C T G A G A T C C T T EI)
      (HUMMH6-DONOR-3506 G C T C T A A T G T G T C T C T C A C G G C T T G T A A A T G T G A C A C C C C G G G G G G C C T G A T G T G T G T G G EI)
      (HUMMHANTLE-DONOR-1239 G G G C C C T G G C C C T G A C C C A G A C C T G G G C G C G T G A G T G C A G G G T C T G C A G G G A A A T G G T C G EI)
      (HUMMHANTLE-DONOR-1633 C G C T C C G C T A C T A C A A C C A G A G C G A G G G C G G T G A G T G A C C C C G G C C C G G G A C G C A G G T C A EI)
      (HUMMHANTLE-DONOR-2150 A G A A C G G G A A G G A G A C G C T G C A G C G C G C G G G T A C C A G G G G C C A C A G G G C G C C T C C C G G A T EI)
      (HUMMHANTLE-DONOR-3008 G T C T G C C A G A G C C C C T C A C C C T G A G A T G G G G T A A G G A G G G A G A T G G G G G T G T C A T G T C C C EI)
      (HUMMHANTLE-DONOR-3227 C T G C T G T A A T G T G G A G G A A G A A G A G C T C A G G T A A G G A A G G G G T G A G G A G T G T G G T C T G A G EI)
      (HUMMHANTLE-DONOR-3700 G A A A A G G A G G G A G C T A C T C T C A G G C T G C A A G T A A G T A T G A A G G A G G C T G A T C C C T G A A A T EI)
      (HUMMHANTLE-DONOR-3889 G G C T C T G A T G T G T C T C T C A C G G C G T G A A A G G T G A G A C C T T G G G G G G C C T G A T G T G T G G G G EI)
      (HUMMHB27B-DONOR-561 G G G C A G T G G C C C T G A C C G A G A C C T G G G C T G G T G A G T G C G G G G T C A G G C A G G G A A A T G G C C EI)
      (HUMMHB27B-DONOR-960 T G C T C C G C T A C T A C A A C C A G A G C G A G G C C G G T G A G T G A C C C C G G C C C G G G C G C A G G T C A C EI)
      (HUMMHB27B-DONOR-1478 A G A A C G G G A A G G A G A C G C T G C A G C G C G C G G G T A C C A G G G G C A G T G G G G A G C C T T C C C C A T EI)
      (HUMMHB27B-DONOR-2329 G G C T G C C G A A G C C C C T C A C C C T G A G A T G G G G T A A G G A G G G G G A T G A G G G G T C A T A T C T C T EI)
      (HUMMHB27B-DONOR-2538 C T G C T G T G A T G T G T A G G A G G A A G A G C T C A G G T A G G G A A G G G G T G A G G G G T G G G G T C T G A G EI)
      (HUMMHB27B-DONOR-3013 G A A A A G G A G G G A G C T A C T C T C A G G C T G C G T G T A A G T G A T G G G G G T G G G A G T G T G G A G G A G EI)
      (HUMMHCD8A-DONOR-638 C C T T G C T C C T G C C G C T G G C C T T G C T G C T C C G T G A G T T T G A G A C G C C C G G G A A G G C A G G G G EI)
      (HUMMHCD8A-DONOR-1087 T C A G C C A C T T C G T G C C G G T C T T C C T G C C A G G T C C G C G C G C C G G G T T G C N N C A C C T C T C C G EI)
      (HUMMHCD8A-DONOR-1781 A G G C G T G C C G G C C A G C G G C G G G G G G C G C A G G T G A G G C G T G C G G G G G C C C G G G G C G G G G G C EI)
      (HUMMHCD8A-DONOR-2098 C A C T G G T T A T C A C C C T T T A C T G C A A C C A C A G T A A G T C C C G A G G A A T C G C G G C G G G A A G G A EI)
      (HUMMHCD8A-DONOR-2891 G A A C C G A A G A C G T G T T T G C A A A T G T C C C C G G T G A G T C T C T T T T G A A C T C T C A G C C T G C T C EI)
      (HUMMHCP42-DONOR-1848 C C A T C T A C A G G C T C C A C C T T G G G C T G C A A G G T G A G A G G C T G A T C T C G C T C T G G C C C T C A C EI)
      (HUMMHCP42-DONOR-2035 A C T T T G C T G G C A G A C C T G A G C C A C T T A C C T G T A A G G G C T G G G G G C A T T T T T T C T T T C T T A EI)
      (HUMMHCP42-DONOR-2471 G T G G A G C A G C T G A C C C A G G A G T T C T G T G A G G T A A G G C T G G G C T C C T G A G G C C A C C T C G G G EI)
      (HUMMHCP42-DONOR-2679 T G T T A C C T C A C C T T C G G A G A C A A G A T C A A G G T G C C T C A C A G C C C C T C A G G C C C A C C C C C A EI)
      (HUMMHCP42-DONOR-2869 C A A A T T G T G G A C G T G A T T C C C T T T C T C A G G G T G A G G A C C T G G A G C C T A G A C A C C C C T G G G EI)
      (HUMMHCP42-DONOR-3057 A T C G T G G A G A T G C A G C T G A G G C A G C A C A A G G T G G G G A C T G T A C G T G G A C G G C C T C C C C T C EI)
      (HUMMHCP42-DONOR-3427 G C C G T G G T T T T T T T G C T T C A C C A C C C T G A G G T G C G T C C T G G G G A C A A G C A A A A G G C T C C T EI)
      (HUMMHCP42-DONOR-3806 C T T G C C C C A C C G C A C C A C A C G G C C C A G C A G G T G A C T C C C G A G G G T T G G G G A T G A G T G A G G EI)
      (HUMMHCP42-DONOR-3993 T C T G G G A G A G G C C A C A T G A G T T C T G G C C T G G T A T G T G G G G G C C G G G G G C C T G C C G T C A A A EI)
      (HUMMHCP52-DONOR-382 C C A T C T A C A G G C T C C A C C T T G G G C T G C A A G G T G A G A G G C T G A T C T C G C T C T G G C C C T C A C EI)
      (HUMMHCP52-DONOR-569 A C T T T G C T G G C A G A C C T G A G C C A C T T A C C T G T A A G G G C T G G G G G C A T T T T T T C T T T C T T A EI)
      (HUMMHCP52-DONOR-1006 G T G G A G C A G C T G A C C C A G G A G T T C T G T G A G G T A A G G C T G G G C T C C T G A G G C C A C C T C G G G EI)
      (HUMMHCP52-DONOR-1216 T G T T A C C T C A C C T T C G G A G A C A A G A T C A A G G T G C C T C A C A G C C C C T C A G G C C C A C C C C C A EI)
      (HUMMHCP52-DONOR-1406 C A A A T T G T G G A C G T G A T T C C C T T T C T C A G G G T G A G G A C C T G G A G C C T A G A C A C C C C T G G G EI)
      (HUMMHCP52-DONOR-1594 A T C G T G G A G A T G C A G C T G A G G C A G C A C A A G G T G G G G A C T C T A C G T G G A C G G C C T C C C C T C EI)
      (HUMMHCP52-DONOR-1964 G C C G T G G T T T T T T T G C T T C A C C A C C C T G A G G T G C G T C C T G G G G A C A A G C A A A A G G C T C C T EI)
      (HUMMHCP52-DONOR-2344 C T T G C C C C A C C G C A C C A C A C G G C C C A G C A G G T G A C T C C C G A G G G T T G G G G A T G A G T G A G G EI)
      (HUMMHCP52-DONOR-2531 T C T G G G A G A G G C C A C A T G A G T T C T G G C C T G G T A T G T G G G G G G C C G G G G G C C T G C C G T G A A EI)
      (HUMMHCW1B-DONOR-754 G A G C C C T G G C C C T G A C C G A G A C C T G G G C C T G T G A G T G C G G G G T T G G G A G G G A A A C G G C C T EI)
      (HUMMHCW1B-DONOR-1152 T G C G C G G C T A C T A C A A C C A G A G C G A G G C C G G T G A G T G A C C C C G G C C C G G G G C G C A G G T C A EI)
      (HUMMHCW1B-DONOR-1674 A G A A C G G G A A G G A G A G C C T G C A G C G C G C G G G T A C C A G G G G C A G T G G G G A G C C T T C C C C A T EI)
      (HUMMHCW1B-DONOR-2537 G G C T G C C G G A G C C C C T C A C C C T G A G A T G G G G T A A G G A G G G G G A T G A G G G G T G A T G T G T C T EI)
      (HUMMHCW1B-DONOR-2778 C T G T T G T G A T G T G T A G G A G G A A G A G C T C A G G T A G G G A A G G G G T G A G G A G T G G G G T C T G G G EI)
      (HUMMHCW1B-DONOR-3250 G A A A A G G A G G G A G C T G C T C T C A G G C T G C G T G T A A G T G A T G G C G G T G G G C G T G T G G A G G A G EI)
      (HUMMHCW1B-DONOR-3405 G C T C T G A T G A G T C T C T C A T C G C T T G T A A A G G T C A G A T T C T G G G G A G C T G A A G T G G T C G G G EI)
      (HUMMHCW2B-DONOR-756 G A G C C C T G G C C C T G A C C G A G A C C T G G G C C T G T G A G T G C G G G G T T G G G A G G G A A A C G G C C T EI)
      (HUMMHCW2B-DONOR-1155 T G C G C G G C T A C T A C A A C C A G A G C G A G G C C G G T G A G T G A C C C C G G C C C G G G C G C A G G T C A C EI)
      (HUMMHCW2B-DONOR-1675 A G A A C G G G A A G G A G A A G C T G C A G C G C G C G G G T A C C A G G G G C A G T G G G G A G C C T T C C C C A T EI)
      (HUMMHCW2B-DONOR-2539 G G C T G C C G G A G C C C C T C A C C C T G A G A T G G G G T A A G G A G G G G G A T G A G G G G T A C T G T G T C T EI)
      (HUMMHCW2B-DONOR-2780 C T G T T G T G A T G T G T A G G A G G A A G A G C T C A G G T A G G G A A G G G G T G A G G A G T G G G G T C T G G G EI)
      (HUMMHCW2B-DONOR-3252 G A A A A G G A G G G A G C T G C T C T C A G G C T G C G T G T A A G T G A T G G C G G C A G G C G T G T G G A G G A G EI)
      (HUMMHCW2B-DONOR-3407 G C T C T G A T G A G T C T C T C A T C G C T T G T A A A G G T C A G A T T C T G G G A G C T G A A G T G G T C G G G G EI)
      (HUMMHDOB-DONOR-1105 C C T C C A T G A C T C A A G G C A C A G A C T C T C C A G G T A A G A A C A G A G C A A T T G T T T T T T T C C A G T EI)
      (HUMMHDOB-DONOR-2919 T G G G C G C A C C C T T C A C T G T G G G G A G A A A A G G T G A G C T G G A A G C T G A G G T C T G G C G G G G C T EI)
      (HUMMHDOB-DONOR-3639 G C C T G C T G A G C C C T G T T T C T G T G G A G T G G A G T G A G A A T T A G T T T C T A G T A C T C T C T G G G C EI)
      (HUMMHDOB-DONOR-4235 G A A T C G T C A T C C A G C T A A G G G C T C A G A A A G G T A A T G A G C C T G T G A G G A G T G C C C T G C C A C EI)
      (HUMMHDOB-DONOR-4518 T A T G T G A G G A C G C A G A T G T C T G G T A A T G A G G T A A T G T C T C T T T T T C C T T G T C T T T G A G T G EI)
      (HUMMHDRHA-DONOR-565 T G A G C G C T C A G G A A T C A T G G G C T A T C A A A G G T A G G T G C T G A G G G A A T G A A A T C T G G G A C G EI)
      (HUMMHDRHA-DONOR-3215 A G C G C T C C A A C T A T A C T C C G A T C A C C A A T G G T A C C T C C C T C T C T G C T G C A C T C C T G G A C A EI)
      (HUMMHDRHA-DONOR-3987 G C T T G G A T G A G C C T C T T C T C A A G C A C T G G G G T A T G G A C C A A C A C T C A A T C T C C T T T A T T T EI)
      (HUMMHDRHA-DONOR-4442 A C G C A G G G G G C C T C T G T A A G G C A C A T G G A G G T G A G T T A G G T G T G G T C A G A G G A A G A C A T A EI)
      (HUMMHEA-DONOR-739 A G G C C C T G G C C C T T A C C C A G A C C T G G G C G G G T G A G T G C G G G G T C G G G A T G G A A A C G G C C T EI)
      (HUMMHEA-DONOR-1139 T G C G G C G C T A C T A C A A T C A G A G C G A G G C C G G T G A G T G A C C C C G G C C A G G A G C A G G T C A C G EI)
      (HUMMHEA-DONOR-1657 A G A A G G G G A A G G A G A C G C T G C T T C A C C T G G G T A A G A G G G T C C A C A G G G C T A C T C T C C C A T EI)
      (HUMMHEA-DONOR-2554 G G C T A C C C G A G C C C G T C A C C C T G A G A T G G A G T A A G G A G G G G G A T G G G A G G T C A T G T C T C T EI)
      (HUMMHEA-DONOR-2795 C T G C T G T G A T A T G G A G G A A G A A G A G C T C A G G T G G G G A A G G G A G A A G G G T G G G G T C T G A G T EI)
      (HUMMHEA-DONOR-3578 G A A A A G G A G G G A G C T A C T C T A A G G C T G A G T G T A A G T G C G G G G C G G G A G C G T G G A G G A G C T EI)
      (HUMMHEA-DONOR-3725 C C A G G G G T C T G A G T C T C A C A G C T T G T A A A G G T G A G A T T C T G G G G G T C T G A A G T G G G T G G A EI)
      (HUMMIS-DONOR-593 A G C G C C T G G T G G T C C T A C A C C T G G A G G A A G G T A T G T G G G G C C C A G C C C C A A G C T T G G C A C EI)
      (HUMMIS-DONOR-1328 G T G A C G A G G G C T G G G C T G C C G G G T G C C C A G G T A C C A G G G A G T T G C A T G G G G C A G T G C C C G EI)
      (HUMMIS-DONOR-1609 T G G C C T T G A C C C T G C A G C C C C G C G G A G A G G G T A G G T C C G C G T G G A G A G G G A C G G G G A G C C EI)
      (HUMMIS-DONOR-1857 G C T G G A C A C C G T G C C C T T C C C G C C G C C C A G G T G C G C G C A G G C A C C G G G A C A C G G G G C A G G EI)
      (HUMMRP14A-DONOR-999 G C A A A C A C T C T G T G T G G C T C C T C G G C T T T G G T A A G T G A G C T G C C A G C T T C C C C A G G C A G A EI)
      (HUMMRP14A-DONOR-1551 G T G C G A A A A G A T C T G C A A A A T T T T C T C A A G G T A G G G C T G G A C T C T G G C A G G T C T G A C C C A EI)
      (HUMMRP8A-DONOR-1504 T C T C T T G T C A G C T G T C T T T C A G A A G A C C T G G T A A G T G G G A C T G T C T G G G T T G G C C C C G C A EI)
      (HUMMRP8A-DONOR-2152 C T A G A G A C C G A G T G T C C T C A G T A T A T C A G G G T G A G G A G G G G C T G G G T G T G G C G G G G G C T C EI)
      (HUMMT2A-DONOR-421 C A A T G G A C C C C A A C T G C T C C T G T G C C G C T G G T A A G G G A C G C C C G G G T T C T G T G C C T T G G A EI)
      (HUMMT2A-DONOR-1113 A A G A G T G C A A A T G C A C C T C C T G C A A G A A G A G T G A G T G C G G G G C C A T C T C C A G G A A T C T G G EI)
      (HUMMYC3L-DONOR-402 C C G C T C C A G G T G G C G G G C G G C T G G A G C G A G G T G A G G C T G C G G G T G G C C A G G G C A C G G G C G EI)
      (HUMMYC3L-DONOR-1271 G C T C C G G G T C C G A G A G C C C A A G C G A C T C G G G T A A G G A C C T C C C C G A G C C A T C C A A G A G G G EI)
      (HUMMYC3L-DONOR-2594 G A T C A A A A A A C C A A T A A A G A T G T A T C T C T A C A A C G G C T G G T G G A G T G G T A G A G T G G A A A G EI)
      (HUMMYCC-DONOR-2852 C T G G A T T T T T T T C G G G T A G T G G A A A A C C A G G T A A G C A C C G A A G T C C A C T T G C C T T T T A A T EI)
      (HUMMYCC-DONOR-5248 A G A C A C C G C C C A C C A C C A G C A G C G A C T C T G G T A A G C G A A G C C C G C C C A G G C C T G T C A A A A EI)
      (HUMMYCRT-DONOR-888 G C C A T C G A C A G T T T T C T C A G A A T A C C T T T G G T A A G T G G G G C T G G G G T G G G C G T T A T T T C A EI)
      (HUMMYCRT-DONOR-1883 A G A C A T C G C C C A C C A C C A G C A G C G A C T C T G G T A A G C G A A G C G C G C C C A G G C C T G T C A A A A EI)
      (HUMMYLCA-DONOR-644 A A G G T C C C G G A G A G C T G A G C A G T C A A G A T G G T G G G G C C C A G G T C T T G G G A G A C G G G C A G G EI)
      (HUMMYLCA-DONOR-952 A G T G T G A C T T C A C C G A A G A C C A G A C C G C A G G T A G G T T A T C T C T G A T C C C T A C C G A G G T C C EI)
      (HUMMYLCA-DONOR-1975 T C A A G G T C C T G G G G A A C C C C A A G A G T G A T G G T G A G G G G C C T A A A G A A C A A C T C C T C A T T G EI)
      (HUMMYLCA-DONOR-2388 C T G A A A T C C G G C A T G T T C T T G T C A C A C T G G G T A A G G T T C T G T G T C C T T G T C C T T G A G C T G EI)
      (HUMMYLCA-DONOR-2559 A G G A C A G C A A T G G T T G T A T C A A C T A T G A A G G T A A G A G G T G A A C T G C G C T T T C T C A G A G A A EI)
      (HUMMYLCA-DONOR-644 A A G G T C C C G G A G A G C T G A G C A G T C A A G A T G G T G G G G C C C A G G T C T T G G G A G A C G G G C A G G EI)
      (HUMMYLCA-DONOR-952 A G T G T G A C T T C A C C G A A G A C C A G A C C G C A G G T A G G T T A T C T C T G A T C C C T A C C G A G G T C C EI)
      (HUMMYLCA-DONOR-1975 T C A A G G T C C T G G G G A A C C C C A A G A G T G A T G G T G A G G G G C C T A A A G A A C A A C T C C T C A T T G EI)
      (HUMMYLCA-DONOR-2388 C T G A A A T C C G G C A T G T T C T T G T C A C A C T G G G T A A G G T T C T G T G T C C T T G T C C T T G A G C T G EI)
      (HUMMYLCA-DONOR-2559 A G G A C A G C A A T G G T T G T A T C A A C T A T G A A G G T A A G A G G T G A A C T G C G C T T T C T C A G A G A A EI)
      (HUMOPS-DONOR-626 A T T T G G A G G G C T T C T T T G C C A C C C T G G G C G G T A T G A G C C G G G T G T G G G T G G G G T G T G C A G EI)
      (HUMOPS-DONOR-2578 C G C C G C A C C C C C A C T C G C C G G C T G G T C C A G G T A A T G G C A C T G A G C A G A A G G G A A G A A G C T EI)
      (HUMOPS-DONOR-3949 T A T G G G C A G C T C G T C T T C A C C G T C A A G G A G G T A C G G G C C G G G G G G T G G G C G G C C T C A C G G EI)
      (HUMOPS-DONOR-4305 C C T G T C A T C T A T A T C A T G A T G A A C A A G C A G G T G C C T A C T G C G G G T G G G A G G G C C C C A G T G EI)
      (HUMOTNPI-DONOR-508 A G G G C C G C G C C G G A C C T C G A C G T G C G C A A G G T G A G T C C C C A G C C C T G G T C C C G C G G C G C T EI)
      (HUMOTNPI-DONOR-1007 G C T G C G C C T T G G G C C T C T G C T G C A G C C C G G G T G A G C G G G G C A A G G C G C T C C G G G G C C A G G EI)
      (HUMP3A-DONOR-1299 C C A C C C G T C C G A C A A C T T C C G G A C T C C C A G G T A G G G A G G A G C C C C T G T T A G C A C T G C C A G EI)
      (HUMP45C17-DONOR-2106 G G C A A G G A C T T C T C T G G G C G G C C T C A A A T G G T A A G T G G T G C C C A T C T C C T C C C T G C C C C C EI)
      (HUMP45C17-DONOR-3913 A G G A T G G C G A T C A G A A G C T G G A G A A G A T C A G T G A G T G C C A G G C T G G C C C C T G G G G C T G G G EI)
      (HUMP45C17-DONOR-4376 A G C C T G G T G G A C C T A G T C C C C T G G T T G A A G G T G A G A T G C T G C C A G C C C T G C C T T C A G G T T EI)
      (HUMP45C17-DONOR-5125 C T G C T G A A T A A A A T A C T T G A A A A T T A C A A G G T A G G T G A T A G A G C A G A A G A G A A T A T G A G T EI)
      (HUMP45C17-DONOR-6035 A C C C T G G C C T T C C T G C T G C A C A A T C C T C A G G T G T G C T T C C C C C T C A T T G A T C C T A G A C C C EI)
      (HUMP45C17-DONOR-6437 C A T C C C C C A C A A G G C C A A C G T T G A C T C C A G G T G T G C C T G C C C T C C C A G T G A C A T C T A G C C EI)
      (HUMP45C17-DONOR-7438 A G T G G C A C C A G C C G G A T C A G T T C A T G C C T G G T G A G T C T G T C C T G T C C T G C G C C C T G G G C C EI)
      (HUMPCNA-DONOR-1618 C A A C C T G G C C A T G G G C G T G A A C C T C A C C A G G T G A G C C T C G C G C C C C G G G A A G C C G C C C C G EI)
      (HUMPCNA-DONOR-2424 A T A C C T T G G C G C T A G T A T T T G A A G C A C C A A G T A A G T C G T A C C T T T T T A C C G A G T C A C G A A EI)
      (HUMPCNA-DONOR-2588 G A T T T A G A T G T T G A A C A A C T T G G A A T T C C A G T G A G T A T C A G T T T C T C A T T G T A G A G A G T G EI)
      (HUMPCNA-DONOR-3721 A C A A G T A A T G T C G A T A A A G A G G A G G A A G C T G T A A G T A G T T T T T A A G T A A A A A G A A A A T A G EI)
      (HUMPCNA-DONOR-5730 C A C T C A G T A T G T C T G C A G A T G T A C C C C T T G G T A A G A T A A T A A A T T T G A A C C T T G T T T T G A EI)
      (HUMPGAMMG-DONOR-1347 A A G C A C C C C T A C T A C A A C T C C A T T A G C A A G G T G G G C T G C C T T T G C T G G G A A G G C C T C T G G EI)
      (HUMPGAMMG-DONOR-1631 G C C T G C G G G G C A T T G T C A A G C A C C T G G A A G G T A G G C C A C C T T C A G G A G C C T G G G C A G G G T EI)
      (HUMPIM1A-DONOR-1222 A C G A C C T G C A C G C C A C C A A G C T G G C G C C C G G T G A G A G C A C C C C C C G C T C C G G C C G G G G A T EI)
      (HUMPIM1A-DONOR-1442 T C A G G C A T C C G C G T C T C C G A C A A C T T G C C G G T G A G T G G G C G C C C C G C G G T G G G G A G G G C G EI)
      (HUMPIM1A-DONOR-1594 A A G G A C C G G A T T T C C G A C T G G G G A G A G C T G G T G A G T G C C C T G C A G G A G C G A C C C C C A G G A EI)
      (HUMPIM1A-DONOR-2054 T C A A G G A C A C C G T C T A C A C G G A C T T C G A T G G T G A G C C A G G C C C G G G A G G G A G C T G C C C A G EI)
      (HUMPIM1A-DONOR-3735 A G G T T T T C T T C A G G C A G A G G G T C T C T T C A G G T A A C T G A T G G A A A C C C C T G G C C A T G G G G T EI)
      (HUMPLAPL-DONOR-373 G G C T A C A G C T C T C C C T G G G C A T C A T C C C A G G T A A T G A G G C T C C C C C A G C T G C C C C T A C A G EI)
      (HUMPLAPL-DONOR-569 C C A A G A A C C T C A T C A T C T T C C T G G G T G A C G G T G A G T G A G C C A G G C C T T C C A G C C C C G C A G EI)
      (HUMPLAPL-DONOR-797 G A C C G C T T C C C G T A C G T G G C T C T G T C C A A G G T A A G T G C T G G G C T A C C T T A G A G T C C T C C A EI)
      (HUMPLPSPC-DONOR-628 A G C A A A G A G G T C C T G A T G G A G A G C C C G C C G G T G A G T G T G G T T G C G T G T G T G T A T G T A T G T EI)
      (HUMPLPSPC-DONOR-1485 C T C C A C A T G A G C C A G A A A C A C A C G G A G A T G G T G A G A G G T G T G G G A T G C A C A G C A G T G G G C EI)
      (HUMPLPSPC-DONOR-1953 A C T G G C C T C G T G G T G T A T G A C T A C C A G C A G G T G G G T A T G C C A G A C C T C C T G A C C T G G A C C EI)
      (HUMPLPSPC-DONOR-2287 G C T C T C A C T A G A A A A G T C C A C A A C T T C C A G G T G T G T G T G T G T G G G T G A A A A G A G T G G G C T EI)
      (HUMPNMTA-DONOR-2130 T G C G C T G C T T G G C G C A G A C C T T C G C C A C C G G T G A G C G G G G G A A A C T G A G G C A C G A G G G A C EI)
      (HUMPNMTA-DONOR-3337 C C A A C A T G C C T G C C T C A T T G A G G G C A A G G G G T A A G G A C T G G G G G G T G A G G G T T G G G A G G A EI)
      (HUMPOMC-DONOR-737 C C G C C C T C A G A G A G C A G C C T C C C G A G A C A G G T A A G G G C G C A G C G T G G G G G A C C C G T G C T C EI)
      (HUMPOMC-DONOR-4597 C A G G A C C T C A C C A C G G A A A G C A A C C T G C T G G T A C G T G G G C C A T G A C T G C C A T C T T G G C T T EI)
      (HUMPPPA-DONOR-965 G G T C T A G T G C C C A T T T A C T C T G G A C T C C G G G T A A G T G G G C T C A C G C C T G C C T G G G G C T C T EI)
      (HUMPPPA-DONOR-1912 T A G A T A C A T C A A C A T G C T G A C C A G G C C T A G G T G T G T G C C A C A G T T G G G G A G A G A G A T C C C EI)
      (HUMPPPA-DONOR-2234 G T G G G G G T C C C C G C A T G C T G C T G T C C C C A G G T G A G T T T G A C T C C C T G C C C T G T C T G T C C A EI)
      (HUMPRCA-DONOR-2171 G G G G A A T T T C C G G C A C A C C A G C T C C T C T T G G T A A G G C C A C C C C A C C C C T A C C C C G G G A C C EI)
      (HUMPRCA-DONOR-3601 A A G G A A A T T T T C C A A A A T G T G G A T G A C A C A G T A A G G C C A C C A T G G G T C C A G A G G A T G A G G EI)
      (HUMPRCA-DONOR-5088 C G C A G C T G G C C T T C T G G T C C A A G C A C G T C G G T G A G T G C G T T C T A G A T C C C C G G C T G G A C T EI)
      (HUMPRCA-DONOR-5318 G C G G C T G G G A G G G C C G C T T C T G C C A G C G C G G T G A G G G G G A G A G G T G G A T G C T G G C G G G C G EI)
      (HUMPRCA-DONOR-5555 G G G A C G A C C T C C T G C A G T G T C A C C C C G C A G G T G A G A A G C C C C C A A T A C A T C G C C C A G G A A EI)
      (HUMPRCA-DONOR-8366 A T G A C C A G G C G G G G A G A C A G C C C C T G G C A G G T G G G A G G C G A G G C A G C A C C G G C T C G T C A C EI)
      (HUMPRCA-DONOR-9357 A T G A G T C C A A G A A G C T C C T T G T C A G G C T T G G T A T G G G C T G G A G C C A G G C A G A A G G G G G C T EI)
      (HUMPRF1A-DONOR-1477 G T G T A G C C G C T T C T C T A T A C G G G A T T C C A G G T A A G G A G A G A G C A G G G A T T G G G G G C C T G G EI)
      (HUMPRF1A-DONOR-3783 C A C T G A C A C G G T G G A G T G C C G C T T C T A C A G G T G A G A G C T G G G G C T A G G G G T G G G G G G C T G EI)
      (HUMPRPH1-DONOR-1687 C C T T C A G C T C A G C T C A G G A T T T A A A T G A A G G T A A G A T G A A T T G G G G G A A G A T A T T G T G A C EI)
      (HUMPRPH1-DONOR-2774 G C C A G G A A G A T G T T C C C C T C G T A A T A T C A G G T A A A T C C C A A T A A A T T C T C A G T A A A C T C T EI)
      (HUMPRPH1-DONOR-3555 T C T C C T C A G T A A T C T A G G A T T C A A T G A C A G G T A C G A T T C C A G T T T A T T A T C C A T C A A A G G EI)
      (HUMPRPH2-DONOR-917 C C T T C A G C T C A G C T C A G G A C T T A G A T G A A G G T A A G C C G A A T T G G G G G A A G A T A T T G T G A C EI)
      (HUMPRPH2-DONOR-1884 G C C A A G A A G A C G T T C C C T T G G T A A T A T C A G G T A A A T C C C A A T A A A T T C T C A G T A A A C T C T EI)
      (HUMPRPH2-DONOR-2660 T C T C C T C A G T A A T C T A G G A T T C A A T G A C A G G T A T G A T T C C A G T T T A T T A T C C A T C A A A G G EI)
      (HUMPRT1A-DONOR-118 G G A G C T G C C A G A C A C G G A G G A G A G C C A T G A G T A A G T G G G C C C A G C T G A G G G T G G G C T G G G EI)
      (HUMPSAA-DONOR-691 T C T T C C T C A C C C T G T C C G T G A C G T G G A T T G G T G A G A G G G G C C A T G G T T G G G G G G A T G C A G EI)
      (HUMPSAA-DONOR-2089 G G T C C T C A C A G C T G C C C A C T G C A T C A G G A A G T G A G T A G G G G C C T G G G G T C T G G G G A G C A G EI)
      (HUMPSAA-DONOR-4013 C A G G C T G G G G C A G C A T T G A A C C A G A G G A G T G T A C G C C T G G G C C A G A T G G T G C A G C C G G G A EI)
      (HUMPSAA-DONOR-4293 C G C T G G A C A G G G G G C A A A A G C A C C T G C T C G G T G A G T C A T C C C T A C T C C C A A G A T C T T G A G EI)
      (HUMPSAP-DONOR-170 G A C C C A A G C A G C T G G A G G C T C T G T G T G T G G G T G A G T T T A G C C C C A T C C C C T A G G T G T T C T EI)
      (HUMPSAP-DONOR-1188 A T G G T C T C A A A G G A G A C C T G G G C C C T C C A G G T A C T G T G C T G C A G A C C C C A C C C T C A G C T G EI)
      (HUMPSAP-DONOR-1621 A G G G G G A G C C T G G C G A G A G G G G C C C T C C A G G T G A G C A G G G T G G G G C A G G T G G G C A G T G G A EI)
      (HUMPSAP-DONOR-2452 T T A G A C A T C A A A T C C T G C A G A C A A G G G G A G G T A A G G G G A C C C C C T G G G C T C A C G G G G T A G EI)
      (HUMRASH-DONOR-1745 T T T G T G G A C G A A T A C G A C C C C A C T A T A G A G G T G A G C C T A G C G C C G C C G T C C A G G T G C C A G EI)
      (HUMRASH-DONOR-2191 C A A G T C T T T T G A G G A C A T C C A C C A G T A C A G G T G A A C C C C G T G A G G C T G G C C C G G G A G C C C EI)
      (HUMRASH-DONOR-2504 T A C A T C G A G A C C T C G G C C A A G A C C C G G C A G G T G A G G C A G C T C T C C A C C C C A C A G C T A G C C EI)
      (HUMRPS14-DONOR-225 T C C G G T G T G G A G T C T G G A G A C G A C G T G C A G G T A G G A G C C C G G G C G C G A C A A T C G G G G G G C EI)
      (HUMRPS14-DONOR-2259 T T T T G T C C A T G T C A C T G A T C T T T C T G G C A A G T G A G T A C C T G G G T G G A G A G G C A T C C A G C T EI)
      (HUMRPS14-DONOR-3034 C A T C A A A C T C C G G G C C A C A G G A G G A A A T A G G T A C G A G T C G C A G A G G G G A T G G C T G G G T G G EI)
      (HUMRPS14-DONOR-4214 C C C G C T C G G G T A T G A A G A T C G G G C G G A T T G G T A A G T G C C C C C C T C T A G C T A A T G C T T G G G EI)
      (HUMRPS17A-DONOR-171 T T C C T C T T T T A C C A A G G A C C C G C C A A C A T G G T A G G T G T T T T G G C T C G A G G C C G C C A T C C T EI)
      (HUMRPS17A-DONOR-615 C A G C A A A A A G C T C C G C A A C A A G A T A G C A G G G T G A G T C G G G C C T T C C T C G G C C T C C G G G C G EI)
      (HUMRPS17A-DONOR-1717 A G A G A A A G G A G A G A C A A T T A T G T T C C T G A G G T A A A C T T T C T G G A T A T T T G G G C T T C T G G C EI)
      (HUMRPS17A-DONOR-2291 C C T G A C A C T A A G G A A A T G C T G A A G C T T T T G G T A A G T G T T T G C T G G A T T C C T A A A G T G G T A EI)
      (HUMSAA-DONOR-34 G A C C C G C A G C T C A G C T A C A G C A C A G A T C A G G T G A G G A G C A C A C A A G G A G T G A T T T T T A A A EI)
      (HUMSAA-DONOR-701 T C T T T T C G T T C C T T G G C G A G G C T T T T G A T G G T A A G G C T T C A G A A G G T T T G C A G G A T T T C T EI)
      (HUMSAA-DONOR-2706 T G G G G G T G C C T G G G C T G C A G A A G T G A T C A G G T A A C T G A G C T C C T G G G A C G T T A G G G C T G G EI)
      (HUMSAA1A-DONOR-1815 G T G G A G A T G G G G T C T T G C T A T G T T T C C C A G G T T G G T C T T G A G T T C C T G G C C T C G A G T G A T EI)
      (HUMSAA1A-DONOR-3240 G G T T A A C A T T C C T C A A G G C A G C T G G C C A A G G T G A G G T C C A C A G G A T A G G G G G C A G G A G G C EI)
      (HUMSAA1A-DONOR-6017 T G G G G G T G T C T G G G C T A C A G A A G T G A T C A G G T A A T G C A C A T T C C T G A T G T T G C C A G G A A T EI)
      (HUMSAACT-DONOR-769 C G A G A G T A G C A G T T G T A G C T A C C C G C C C A G G T A G G G C A G G A G T T G G G A G G G G A C A G G G G G EI)
      (HUMSAACT-DONOR-1779 C C G T C C A T C G T G G G C C G C C C C C G A C A C C A G G T C A G G C T G C C C C T C C G C A G A G G G A G C C G G EI)
      (HUMSAACT-DONOR-2210 T G T C C C T C T A C G C C T C C G G A A G G A C C A C C G G T G A G T G C C C G C T G G C C C C C A G T C C C C T C G EI)
      (HUMSAACT-DONOR-2499 C T G A G C G T G G C T A C T C C T T C G T G A C C A C A G G T G C G C G G C G C C C C T G C A C C C G G G C G G A G G EI)
      (HUMSAACT-DONOR-2770 C G G A G A C G C T C T T C C A G C C C T C C T T C A T C G G T G A G C C C C G C T C G C C C T C G C C C C G G C C C C EI)
      (HUMSAACT-DONOR-3038 G C G C T G G C A C C C A G C A C C A T G A A G A T C A A G G T G G G T G G T G G C C T G C G C G G G C T G T C G G C G EI)
      (HUMSHBGA-DONOR-2724 T G G G C C C T G A G A C C T G T T C T C C C C A C C C A G G T G C A G G A G C G G G A C A G G G C A C T C A G C T C A EI)
      (HUMSHBGA-DONOR-2948 C A T G A C C T T T G A C C T C A C C A A G A T C A C A A A G T A T G G G G T T G G C C T A G C C C T T G A C C C A G T EI)
      (HUMSHBGA-DONOR-3310 C C A C G G C T G G A T G A T G G G A G A T G G C A C C A G G T A A G C T A G C T C T G G T C C T C A G G G G A G G G A EI)
      (HUMSHBGA-DONOR-3802 C T C T T C C C C G C T T C C A A C C T T C G G T T G C C G G T A A C T A C A C C C C A G G G G T G G A A C C C T A G C EI)
      (HUMSHBGA-DONOR-4189 C A G G G A C T C A G G C A G A A T T C A A T C T C C G A G G T A G A T T T C C T C G G A G T C T A T T T T T C C C A C EI)
      (HUMSHBGA-DONOR-4456 T C T T G G C T C A G T C T C C A C C T C C A A G A T C A A G T A A G G G A C A G T G G G C A T T G C C T G T A T T C A EI)
      (HUMSHBGA-DONOR-5396 A A G G G C G T C T C T T C C T G G G G G C T T T A C C A G G T A A G A G A G A A T G A T G T T C A A G T T C A T G A G EI)
      (HUMSODA-DONOR-327 G G C T G G C C T G C G G C G C C T G G G C G C T C T G A G G T G A G G G A C T C C C C G G C C G C G G A G G A A G G G EI)
      (HUMSODA-DONOR-3286 T T C T T T C A A T T C C A T C T C T T A G T T T T C C A T G T A A G T A T T C A G T T T A C A T T T A T G T T G C A G EI)
      (HUMSODA-DONOR-3510 G A C C A G A A A A T T A A T G A A G T T T C T T C T T C T G T A A G T A T A T G A G G C C C A T G C T G G C A G T G C EI)
      (HUMSODA-DONOR-3967 A C C G G G A C A G G A T T T G A C T G T G C T A G C A A G G T A A G C G A T A G C A G C A G G C C T C A A A A G C G T EI)
      (HUMSODA-DONOR-4346 G A A A G T T G C C A G A G C A C A T C C C A A A G C A A A G T G A G T T A T T C C C C C A T C T G A G G G C A A G A T EI)
      (HUMSODA-DONOR-4739 A G A G C T A A A T A T C G A T G T T G T T G G T G T C A G G T G A G A T T T T G G T G G G A T A G C T A G A G G T C A EI)
      (HUMSODA-DONOR-4951 T C T G A T G C C C G C T G T G T T T T T G A C A T G G G G G T G A G T A T A C G T G A C C C T G T T A G G G A A G G G EI)
      (HUMSODA-DONOR-5211 T C T G A G G A T G T G A A A C T T A A A T T T G A A G A G G T A A T T T A G A A C A A A A C T G T A A T A C T C A G T EI)
      (HUMSODA-DONOR-6429 T T G T A T T A A A G G A A C A G A C G G G C T C T G A T G G T A T G T A T A A A G G A C G A A T C A C T T C A T G T A EI)
      (HUMSODA-DONOR-6624 C A C G C A C A T G T A A A G C C C C T T C T G C A A A A G G T A A T T T C T G A G C A T A C T G T A T A A A A C A A T EI)
      (HUMSODA-DONOR-6932 G A T C T A C T A T G T G A T G T C A G G G C C T G C G T G G T A A G T A A G C C A T G C A T G T T G A T G G T G C T G EI)
      (HUMSPRO-DONOR-1735 T G C T G G C A T G G G T T G C T C T G G C T G A C C A A G G T A C A G G G G A T G T T G G T G G C C A T C T G G G T C EI)
      (HUMSPRO-DONOR-1947 C A G A C T A T A C G G C T G A G T G C A A G C C C C A A G G T G T G T T C A G A G C C C A G G T G G G T G G G C T G G EI)
      (HUMSPRO-DONOR-2367 T C A A G A A C G G T T C C C T C T T T G C C T T C C G A G G T G A A T C C A G G G C A G G T A C T G G G G A T G C G G EI)
      (HUMSPRO-DONOR-2585 A A C T G T C A G G G G A A G A C C T A C C T C T T C A A G G T G C C A G G G G C T G T G G G C C A G G G T A G A A A G EI)
      (HUMSPRO-DONOR-2998 G T G G C C G G G A G C G G G T C T A C T T C T T C A A G G G T A C T C A G G G G G T G G T G G G A G A C T G A G C A G EI)
      (HUMSPRO-DONOR-3348 T C G A G C T T C T C T T C T G G G G C A G A A C C T C T G G T A T G G A G A G A G G G C A A G T C T T G C T T C T C C EI)
      (HUMSPRO-DONOR-4152 C C A T C C A G A G T G T C T T C T T C T T C T C T G G A G G T A G G A G C C G C T G C C A C C C C T G A A G C T G G T EI)
      (HUMTFPB-DONOR-992 G G G T C T T C G C C C A G G T G G C C G G C G C T T C A G G T G A G T G G C A C C A G C C C C T G G A A G C C C G G G EI)
      (HUMTFPB-DONOR-2272 C G T C A A T C A A G T C T A C A C T G T T C A A A T A A G G T A A G C T G G G T A C A G A A A A A G A A A A T T A A G EI)
      (HUMTFPB-DONOR-6562 A C T C C C C A G A G T T C A C A C C T T A C C T G G A G A G T A A G T G G C T T G G G C T G T A A T A C C G T T C A T EI)
      (HUMTFPB-DONOR-9438 T A T T A T T G G A A A T C T T C A A G T T C A G G A A A G G T G A G C A T T T T T T A A T T T G T T T T T A T G A C C EI)
      (HUMTFPB-DONOR-10205 G T A T G G G C C A G G A G A A A G G G G A A T T C A G A G G T G A G T G G C T C T G C C A G C C A T T T G C C T G G G EI)
      (HUMTHB-DONOR-497 C C C T G T G T A G C C T T G T G C A C A G C C A G C A T G G T A A G G G A G T G C T T G C A G G C T G G A A C A G G C EI)
      (HUMTHB-DONOR-1044 T T C G A G G C T C T G G A G T C C T C C A C G G C T A C G G T G A G C C T G G G C T G C T C G G A C G G T G C C G G G EI)
      (HUMTHB-DONOR-1728 T T C A G G A T G T G T T C T G G G C C A A G T A C A C A G G T G A G C A C C G G G A A G G A T T T G C C C C A G G A A EI)
      (HUMTHB-DONOR-2021 C T C G A G A T A A G C T T G C T G C A T G T C T G G A A G G T G A G C A A C T G A C A C G G G T T T G G G G A G C A G EI)
      (HUMTHB-DONOR-4453 A T G G A G G A G T C G C T A C C C A C A T A A G C C T G A G T G A G T G A G G G G T C G G C C T T C C C A C C A T G G EI)
      (HUMTHB-DONOR-4686 G G A G G C A G G A A T G C A G C A T C C C T G T C T G T G G T A G G C T G G G G G C A G T G G G G C G A C C C A T G A EI)
      (HUMTHB-DONOR-7339 A C T T T G G G T A C T G C G A C C T C A A C T A T T G T G G T G A G C T G C C T G G G T A G G G G G C C T G A G T T G EI)
      (HUMTHB-DONOR-7792 A T C C G A G G A C C T T T G G C T C G G G A G A G G C A G G T G A G G T A G T G G G C A T C C G A G G G G A T G C G G EI)
      (HUMTHB-DONOR-8003 C T C G G A T G C A G A G A T C G G C A T G T C A C C T T G G T G T G T C C T G G A G C C C T G C G C T A C C A T T C A EI)
      (HUMTHB-DONOR-9328 G G T G C G C A T T G G C A A G C A C T C C C G C A C A A G G T A C A G A A C T G G T G G C C C G T G G G T G T C T G G EI)
      (HUMTHB-DONOR-9999 G T G T C T G C C C G A C A G G G A G A C G G C A G C C A G G T G G G C C A C C A G A T G C T T G T T A G C T G A G G G EI)
      (HUMTHB-DONOR-10723 T C C G C A T C A C T G A C A A C A T G T T C T G T G C T G G C A A G T C T G T G C A G G G C G G G C T G A G G G A A C EI)
      (HUMTHB-DONOR-20241 G G T G A C A G T G G G G G A C C C T T T G T C A T G A A G G T A A G C T T C T C T A A A G C C C A G G G C C T G G T G EI)
      (HUMTHY1A-DONOR-34 T G G C C A T C A G C A T C G C T C T C C T G C T A A C A G G T A C C C G G C A T G G G G C A G G A C T G G G G C T C C EI)
      (HUMTHY1A-DONOR-853 T C T C C T C C C A G A A C G T C A C A G T G C T C A G A G G T G A G A C A A G C C C C T A A C A A G G T C A A G T G A EI)
      (HUMTKRA-DONOR-556 T C C C C C A G C A A G A C C C G G G G G C A G A T C C A G G T G C G G G G G C C A G C C C T G C G C G T G G C T G G G EI)
      (HUMTKRA-DONOR-698 G A T T C T C G G G C C G A T G T T C T C A G G A A A A A G G T A A T G G C T T C G C G G G G C T G G G G T G G A G C T EI)
      (HUMTKRA-DONOR-2441 C T A C A G C A G C A G C T T C T G C A C A C A T G A C C G G T C A G T C C C T G C C C C C T G C A G T C C T G T C C A EI)
      (HUMTKRA-DONOR-4909 G C T G T C A T A G G C A T C G A C G A G G G G C A G T T T G T A A G T T G G C T T G T C T T G G C A T C A C T C T T C EI)
      (HUMTKRA-DONOR-11961 G C T G C A C T G G A T G G G A C C T T C C A G A G G A A G G T A A G G C G T C T G A T C C A G G T C T G G A G C T G G EI)
      (HUMTKRA-DONOR-12438 T A T A C C A A G A G G C T C G G C A C A G A G A A G G A G G T A G C T C C A C C T G C C T T C C C T G C A G G C C G G EI)
      (HUMTNFA-DONOR-952 T T T G G A G T G A T C G G C C C C C A G A G G G A A G A G G T G A G T G C C T G G C C A G C C T T C A T C C A C T C T EI)
      (HUMTNFA-DONOR-1604 C T C T A A T C A G C C C T C T G G C C C A G G C A G T C A G T A A G T G T C T C C A A A C C T C T T T C C T A A T T C EI)
      (HUMTNFA-DONOR-1839 C G A G T G A C A A G C C T G T A G C C C A T G T T G T A G G T A A G A G C T C T G A G G A T G T G T C T T G G A A C T EI)
      (HUMTNFAB-DONOR-950 G A T C C C C G G C C T G C C T G G G C C T G G G C C T T G G T G G G T T T G G T T T T G G T T T C C T T C T C T G T C EI)
      (HUMTNFAB-DONOR-1345 C T G C T G C T G G T T C T G C T G C C T G G G G C C C A G G T G A G G C A G C A G G A G A A T G G G G G C T G C T G G EI)
      (HUMTNFAB-DONOR-1537 G C A C C C T C A A A C C T G C T G C T C A C C T C A T T G G T A A A C A T C C A C C T G A C C T C C C A G A C A T G T EI)
      (HUMTNFAB-DONOR-4431 T T T G G A G T G A T C G G C C C C C A G A G G G A A G A G G T G A G T G C C T G G C C A G C C T T C A T C C A C T C T EI)
      (HUMTNFAB-DONOR-5083 C T C T A A T C A G C C C T C T G G C C C A G G C A G T C A G T A A G T G T C T C C A A A C C T C T T T C C T A A T T C EI)
      (HUMTNFAB-DONOR-5318 C G A G T G A C A A G C C T G T A G C C C A T G T T G T A G G T A A G A G C T C T G A G G A T G T G T C T T G G A A C T EI)
      (HUMTNFX-DONOR-726 T T T G G A G T G A T C G G C C C C C A G A G G G A A G A G G T G A G T G C C T G G C C A G C C T T C A T C C A C T C T EI)
      (HUMTNFX-DONOR-1378 C T C T A A T C A G C C C T C T G G C C C A G G C A G T C A G T A A G T G T C T C C A A A C C T C T T T C C T A A T T C EI)
      (HUMTNFX-DONOR-1613 C G A G T G A C A A G C C T G T A G C C C A T G T T G T A G G T A A G A G C T C T G A G G A T G T G T C T T G G A A C T EI)
      (HUMTPA-DONOR-3683 T C T G C G A G G A A A G G G A A G G A G C A A G C C G T G G T A G G T C G G G T T T C T G T A C C T T G G G G T C T G EI)
      (HUMTPA-DONOR-18038 T G T G G A G C A G T C T T C G T T T C G C C C A G C C A G G T T G G T G T G C A G G A T C C C T G T G T C C C G C C C EI)
      (HUMTPA-DONOR-19780 G A T T C A G A A G A G G A G C C A G A T C T T A C C A A G G T C G G G T G A A G C T G A G G G G T G C A T G G G G T C EI)
      (HUMTPA-DONOR-22213 G G G C A C A G T G C C A C T C A G T G C C T G T C A A A A G T A T G T G C T G A G G C T G G A A G G T G G T G C A T G EI)
      (HUMTPA-DONOR-23241 A A G G A T T T G C T G G G A A G T G C T G T G A A A T A G G T G A G T A G G T G A G A G C A C G T G A A A C G A G C T EI)
      (HUMTPA-DONOR-23748 G C T G G G C C T G G G G A A C C A C A A C T A C T G C A G G T G A G G G C A C A T C C C C A A G G A G G G A T T C C C EI)
      (HUMTPA-DONOR-26070 A G T T C T G C A G C A C C C C T G C C T G C T C T G A G G G T A A G T G G C A G C C A C C C C G C C T T T C C C T G A EI)
      (HUMTPA-DONOR-28433 A C T G G G C C T G G G C A A A C A T A A T T A C T G C C G G T A G G T A G C A C A G G G G T G G G G G G T T C A G G T EI)
      (HUMTPA-DONOR-29526 C G T G G G A G T A C T G T G A T G T G C C C T C C T G C T G T A A G G G C T G G G C C C C G G C T G C C T C C C T G C EI)
      (HUMTPA-DONOR-30972 T C T C T C T G C C G C C C A C T G C T T C C A G G A G A G G T A G G G G C T C G G A A A C C C A G T T G G T T T T T C EI)
      (HUMTPA-DONOR-31220 T C G A T G A T G A C A C T T A C G A C A A T G A C A T T G G T A A G A G C T C G T C A T T C C C G G C T C C A G T T C EI)
      (HUMTPA-DONOR-31536 A G C T C T C C G G C T A C G G C A A G C A T G A G G C C T G T A A G T G G A A G G A A G C C T C G G C C C C A T C C T EI)
      (HUMTPA-DONOR-32565 C C C C A G G C A A A C T T G C A C G A C G C C T G C C A G G T A A C C A G G A G T G G C G G C C C A T G C T G G G C A EI)
      (HUMTUBAG-DONOR-506 A A G A T A C C C A C A C A T T C C C G G G A A A A C A T G G T G A G T T T C T G C C C G G A G C C C C C G G A G C G G EI)
      (HUMTUBAG-DONOR-2257 T G T T T G T A G A C T T G G A A C C C A C A G T C A T T G G T G A G T T G A C C T C A G T A A C C C A A G T G A G A T EI)
      (HUMTUBAG-DONOR-2554 G A C C T C G T G T T G G A C C G A A T T C G C A A G C T G G T A T G T T T C T T T T C A A G A A T A A A G T A A A T T EI)
      (HUMTUBBM-DONOR-775 G G G C A G T G C G G C A A C C A A A T C G G C G C C A A G G T A A G T T G C C G G G G C G C T G G G G C C A G G C G G EI)
      (HUMTUBBM-DONOR-1187 G C A T C A A C G T G T A C T A C A A T G A G G C C A C C G G T G A G G C C C C G G C C C C T T C C C C G A C C G C C T EI)
      (HUMTUBBM-DONOR-1376 A G A T C T T C C G G C C G G A C A A C T T C G T T T T C G G T G A G C C G T G G C T G G G G A C T G G G C G G C G G C EI)
      (HUMUBILP-DONOR-603 G C G C T G C A G G G C C G C G A G T G C A G C C T G C A G G T A G G G T C C C C G G G C C G G G C C G C C G G G T C C EI)
      (HUMUBILP-DONOR-912 G G C T G C T G T T C A A G G G C A A G G C C C T G G C A G G T A C C C A G G G A G A G G A G A C G C C C G G G G A G C EI)
      (HUMUBILP-DONOR-1367 G C C A G C A G G G T C C T G G A A C A G C T A C A G A G G G T G A G A A G G G T A A C C C T G G G C A T C C T C T T C EI)
      (HUMVPNP-DONOR-315 A G G G C C A T G T C C G A C C T G G A G C T G A G A C A G G T A C T T C C C A C T G T G G G C C A T C T C A G G G C A EI)
      (HUMVPNP-DONOR-1890 G C G C C G C C T T C G G C G T T T G C T G C A A C G A C G G T G C G C G G C G G G G G C G G G C C T G G G G G G G G G EI)
      (LEMHBB-DONOR-216 A G A G A A A G T T G G T G G C G A G G C C T T G G G C A G G T T G G T A T C G G G G T T A T A G G G C A G G C T T A A EI)
      (LEMHBB-DONOR-569 A A G T T G C A C G T G G A T C C T C A G A A C T T C A C T G T G A G T C T A T G G G A C C T T C A A T G T T T C T C T EI)
      (LEMHBE-DONOR-288 G G A A G A G G C T G G A G G C G A A G C C T T G G G C A G G T A A A C A T T G T T T C T C G A T G C A T G G G A A T A EI)
      (LEMHBE-DONOR-633 A A A C T G C A C G T G G A T C C T G A G A A C T T C A A G G T G A G T G C A G G A G A T G C T C A T G T C C T C T T T EI)
      (LEMHBG-DONOR-241 G G A A G A G G C T G G A G G A G A A G C T C T G G G A A G G T A T G C T C T G G G G G C C A G G A C A A G G G A G G G EI)
      (LEMHBG-DONOR-587 A G G C T G C A C G T G G A T C C T G A A A A C T T T A A G G T A A G T C C A G G A G A T G T T A A A G C C C T G T T G EI)
      (LEMHBGA-DONOR-302 G G A A G A G G C T G G A G G A G A A G C C C T G G G A A G G T A C G C T C T G G G G G C C A G G A C A A G G G A G G G EI)
      (LEMHBGA-DONOR-648 A G G C T G C A T G T G G A C C C T G A A A A C T T T A A G G T A A G C C C A G G A G A T G T T A A A G C C C T T T T G EI)
      (MACHBA-DONOR-121 T G G C G A G T A T G G T G C G G A G G C C C T G G A G A G G T G A G G C T C C C T C C C C T G C T C C G A C C C G G G EI)
      (MACHBA-DONOR-443 A A G C T T C G G G T G G A C C C G G T C A A C T T C A A G G T G A G C G G C G A G C C G G G A G C G A T C T G G G G T EI)
      (MACHBCA2-DONOR-463 G G A A G A T G C T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G A A G G G EI)
      (MACHBCA2-DONOR-809 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T G A G T C C A G G A G T T T C A G C A G T T T C A G A G EI)
      (MACHBGA1-DONOR-465 G G A A G A T G C T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G A A G G G EI)
      (MACHBGA1-DONOR-811 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T G A G T C C A G G A G T T T C A G C A G T T T C A G A G EI)
      (MNKHBD-DONOR-347 G G A C G A A G T T G G T G G T G A G G C C C T G G G C A G G T T G G T A T C A A G G T T A C A A G G C A G G T T T A A EI)
      (MNKHBD-DONOR-698 A A G C T G C A C G T G G A T C C T G A G A A C T T C A G G G T G G G T C C A G G A G A T G T T T C A C T T T T C T C C EI)
      (ORAHBD-DONOR-466 G G A T G C A G T T G G T G G T G A G G C C C T G G G C A G G T T G G T A T C A A G G T T A C A A G A C A G T C T C A A EI)
      (ORAHBD-DONOR-819 A A G C T G C A C G T G G A T C C T G A G A A C T T C A G G G T G A G T C C A G G A G A T G C T T C A C T T T T C T C T EI)
      (ORAHBG1F-DONOR-269 G G A A G A T G C T G G A G G A G A A A C T C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G G A G G G EI)
      (ORAHBG1F-DONOR-614 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T G A G T C C A G G A G A T G T T T C A G C C C T G T T G EI)
      (ORAHBG2F-DONOR-269 G G A A G A T G C T G G A G G A G A A A C C C T G G G A A G G T A G G C T C T G G T G A C C A G G A C A A G G G A G G G EI)
      (ORAHBG2F-DONOR-615 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T G A G T C C A G G A G T T T C A G C A C T G T T G C C T EI)
      (ORAIGECA-DONOR-378 C A G A C T G G G T C T A C A A C A A A A C T T T C G G C G G T A A G A G A G G G C C A A G C T C A G A G A C C A C A G EI)
      (ORAIGECA-DONOR-904 C C T T T G A G G A C A G C A C C A A G A A G T G T G C A G G T A C G T T C C C A C C T G C C C T G G T G G C C G C C A EI)
      (ORAIGECA-DONOR-1314 C C C T C G T G C G C T C C A C G A C C A A G A C C A G C G G T G A G C C A C G G G C A G G C T G G G G T C G T G G G G EI)
      (TARHBB-DONOR-1560 G G A A G A T G T T G G T G G T G A G G C C C T G G G C A G G T C A G T A T C A T G G C T A T G A G G C A G G C T T A A EI)
      (TARHBB-DONOR-1909 A A A T T G C A C G T G G A T C C T G A G A A T T T C A G G G T A A G T C T A T G G A A T C T T T G A T G T T T T C C T EI)
      (TARHBD-DONOR-468 G G A A G A T G T T G G T G G T G A G G C C C T G G G C A G G T C A G T A T C A T G G C T A T G A G G C A G G C T T A A EI)
      (TARHBD-DONOR-817 A A G C T G C A T G T G G A T C C T G A G A A C T T C A G G G T A A G T C T A G G A G A T G T T C T T C T T T G T C C T EI)
      (ATRINS-ACCEPTOR-701 T T C A G C G G C C T C A G C C T G C C T G T C T C C C A G G T C T C T G T C C T T C C A C C A T G G C C C T G T G G A IE)
      (ATRINS-ACCEPTOR-1678 G G A C C T G C T C T G C G T G G C T C G C C C T G G C A G T G G G G C A G G T G G A G C T G G G T G G G G G C T C T A IE)
      (BABAPOE-ACCEPTOR-801 G C G G T T G A T T G A C A G T T T C T C C T T C C C C A G A C T G G C C A A T C A C A G G C A G G A A G A T G A A G G IE)
      (BABAPOE-ACCEPTOR-2624 C C T G A A C C A C C T T C A A C T T G T T C C A C A C A G G A T G C C A G G C C A A G G T G G A G C A A C C G G T G G IE)
      (BABAPOE-ACCEPTOR-3437 G C G C A C A C C C T C C C G C T C T T T C G G C T G C A G G A C G C T G A T G G A C G A G A C C A T G A A G G A G T T IE)
      (CHPIGECA-ACCEPTOR-585 C A A C C C T C A T G A C C A C C A G C T C T C C C C C A G T C T G C T C C A G G G A C T T C A C G C C C A C C G T G A IE)
      (CHPIGECA-ACCEPTOR-989 G G C C T C A C A C A G C C C T C C G G T G T A C C A C A G A T T C C A A C C C G A G A G G G G T G A G C G C C T A C C IE)
      (CHPIGECA-ACCEPTOR-1392 G G C C T G G G C T G A C C C C A C G T C T G G C C A C A G G C C C G C G T G C T G C C C C G G A A G T C T A T G C G T IE)
      (GCRHBBA1-ACCEPTOR-1385 C C C A C C C T C A C T C T T T G C T T G T C C T G G C A G G A T G T T C C T G T C C T T C C C C A C C A C C A A G A C IE)
      (GCRHBBA1-ACCEPTOR-1706 G T T C T G A A G G G T A G G G C A G G G G C A G C A C A G C T C C T A A G C C A C T G C C T G C T G G T G A C C C T G IE)
      (GCRHBBA6-ACCEPTOR-590 A C C C C T T C A C G T C T T T G C T T G T C C T G G C A G G A T G T T C C T G T C C T T C C C C A C C A C C A A G A C IE)
      (GCRHBBA6-ACCEPTOR-920 C T G A A G G A A C G G G T A G G G C C A G G G C A G C A G C T C C T G A G G C A C T G C C T G C T G G T G A C C C T G IE)
      (GIBHBGGL-ACCEPTOR-2401 C T G T C A A A C T G C T C T T G T T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (GIBHBGGL-ACCEPTOR-3506 C A T C T T T G T T G T C T C T T T C C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C C G T T T T G IE)
      (GIBHBGGL-ACCEPTOR-7321 C T G T C A A A C T G C T C T T G T T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (GIBHBGGL-ACCEPTOR-8438 C A T C T T T G T T G T C T C T T T T C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C C G T T T T G IE)
      (HUMA1ATP-ACCEPTOR-7282 G G G C C T G G C C C C C C C A T C T C T G T C T T G C A G G A C A A T G C C G T C T T C T G T C T C G T G G G G C A T IE)
      (HUMA1ATP-ACCEPTOR-9382 C T G G T G A T G C C C A C C T T C C C C T C T C T C C A G G C A A A T G G G A G A G A C C C T T T G A A G T C A A G G IE)
      (HUMA1ATP-ACCEPTOR-10909 C A T G C C T T G A A T T T C T T T T C T G C A C G A C A G G T C T G C C A G C T T A C A T T T A C C C A A A C T G T C IE)
      (HUMA1ATP-ACCEPTOR-11880 A C A A C G T G T C T C T G C T T C T C T C C C C T C C A G G C C G T G C A T A A G G C T G T G C T G A C C A T C G A C IE)
      (HUMA1GLY2-ACCEPTOR-2108 C C C C A T C A C C A G C T C C C C C C T T C T C C C C A G A T C A C T G G C A A G T G G T T T T A T A T C G C A T C G IE)
      (HUMA1GLY2-ACCEPTOR-2469 G T T T T T C T T C C G C C T T C T G G T T G A C T T T A G C C A G A A C C A G T G C T T C T A T A A C T C C A G T T A IE)
      (HUMA1GLY2-ACCEPTOR-3244 T C T C A C C C A G A G G C T C T T T T T C T C T T C C A G A G G G A G G C C G A G A A C A T G T T G C T C A C C T G C IE)
      (HUMA1GLY2-ACCEPTOR-3502 C C C C A G T C A G T C T C C T T G C T C C C C C T G C A G C T G A C A A G C C A G A G A C G A C C A A G G A G C A A C IE)
      (HUMA1GLY2-ACCEPTOR-4746 C C C T C A C C C C A A T T C C C C G C T G C C T T C T A G G A T A A G T G T G A G C C A C T G G A G A A G C A G C A C IE)
      (HUMACCYBA-ACCEPTOR-1121 G G C T C A C A G C G C G C C C G G C T A T T C T C G C A G C T C A C C A T G G A T G A T G A T A T C G C C G C G C T C IE)
      (HUMACCYBA-ACCEPTOR-1384 G C T C A G G G C T T C T T G T C C T T T C C T T C C C A G G G C G T G A T G G T G G G C A T G G G T C A G A A G G A T IE)
      (HUMACCYBA-ACCEPTOR-2065 A G T G T G A C A T G G T G C A T C T C T G C C T T A C A G A T C A T G T T T G A G A C C T T C A A C A C C C C A G C C IE)
      (HUMACCYBA-ACCEPTOR-2599 A G C T A A G T C C T G C C C T C A T T T C C C T C T C A G G C A T G G A G T C C T G T G G C A T C C A C G A A A C T A IE)
      (HUMACCYBA-ACCEPTOR-2893 T C C T C A C T G C C T G T C C C C T T C C C T C C T C A G A T C A T T G C T C C T C C T G A G C G C A A G T A C T C C IE)
      (HUMACCYBB-ACCEPTOR-1057 G G C T C A C A G C G C G C C C G G C T A T T C T C G C A G C T C A C C A T G G A T G A T G A T A T C G C C G C G C T C IE)
      (HUMACCYBB-ACCEPTOR-1318 G C T C A G G G C T T C T T G T C C T T T C C T T C C C A G G G C G T G A T G G T G G G C A T G G G T C A G A A G G A T IE)
      (HUMACCYBB-ACCEPTOR-1999 A G T G T G A C A T G G T G C A T C T C T G C C T T A C A G A T C A T G T T T G A G A C C T T C A A C A C C C C A G C C IE)
      (HUMACCYBB-ACCEPTOR-2533 A G C T A A G T C C T G C C C T C A T T T C C C T C T C A G G C A T G G A G T C C T G T G G C A T C C A C G A A A C T A IE)
      (HUMACCYBB-ACCEPTOR-2827 T C C T C A C T G C C T G T C C C C T T C C C T C C T C A G A T C A T T G C T C C T C C T G A G C G C A A G T A C T C C IE)
      (HUMACTGA-ACCEPTOR-886 G C C C G C C T G A G T C C A T C C T T T T C C G G G C A G G T C G C A A T G G A A G A A G A G A T C G C C G C G C T G IE)
      (HUMACTGA-ACCEPTOR-1104 C C G G C G A G G C T G A C G G A T C G T C C C C T G C A G G G C G T C A T G G T G G G C A T G G G C C A G A A G G A C IE)
      (HUMACTGA-ACCEPTOR-1621 C T G A C T A A G C C G C C C C T T G T C C C T T C T C A G A T T A T G T T T G A G A C C T T C A A C A C C C C G G C C IE)
      (HUMACTGA-ACCEPTOR-2139 G C A T C A C T A A G G G A G G G C T C T G T C C C C T A G G T A T G G A A T C T T G C G G C A T C C A C G A G A C C A IE)
      (HUMACTGA-ACCEPTOR-2414 A G C T G A A G C C G T G C C T G G C T G T C T T T G C A G A T C A T C G C A C C C C C A G A G C G C A A G T A C T C A IE)
      (HUMADAG-ACCEPTOR-19200 T C T C T C T C T C T T C C C C C T G C C C C C T T G C A G G T A G A A C T G C A T G T C C A C C T A G A C G G A T C C IE)
      (HUMADAG-ACCEPTOR-26314 T T G G T C C A C C A C T C A C T G T T T T G T T T C C A G G A G G A G A G G G A T C G C C C T C C C A G C T A A C A C IE)
      (HUMADAG-ACCEPTOR-28878 T T G T T C C C A A C C C C T T T C T T C C C T T C C C A G G G G C T G C C G G G A G G C T A T C A A A A G G A T C G C IE)
      (HUMADAG-ACCEPTOR-29793 A G G C C C A T C C C T A C T C C T C T C C T C A C A C A G A G G G G A C C T C A C C C C A G A C G A G G T G G T G G C IE)
      (HUMADAG-ACCEPTOR-31146 G A C A G A G C C T G G G T G G G C A T C T G C C C A C A G A C T G G T C C C C C A A G G T G G T G G A G C T G T G T A IE)
      (HUMADAG-ACCEPTOR-32395 G C A C C C A T G A C C T G G C T C T C C C C C T T C C A G G A G G C T G T G A A G A G C G G C A T T C A C C G T A C T IE)
      (HUMADAG-ACCEPTOR-32543 C A T A C T T G G C T C T A T T C T G C T T C T C T A C A G G C T G T G G A C A T A C T C A A G A C A G A G C G G C T G IE)
      (HUMADAG-ACCEPTOR-32821 T C C C T G C C A G C C A C A C A C C T G C T C T T C C A G A T C T G C C C C T G G T C C A G C T A C C T C A C T G G T IE)
      (HUMADAG-ACCEPTOR-34324 G C T G A T T C T C T C C T C C T C C C T C T T C T G C A G G C T C A A A A A T G A C C A G G C T A A C T A C T C G C T IE)
      (HUMADAG-ACCEPTOR-35070 C C A T G T T G T C T G C C A T T C T G G C C T T T C C A G A A C A T C A A T G C G G C C A A A T C T A G T T T C C T C IE)
      (HUMADAG-ACCEPTOR-35621 A T C T T T T T G C T T C T C T G A A C C A A C G A G C A G G G C A G A A C C T C T G A A G A C G C C A C T C C T C C A IE)
      (HUMADAM2-ACCEPTOR-784 C A T A C T T G G C T C T A T T C T G C T T C T C T A C A G G C T G T G G A C A T A C T C A A G A C A G A G C G G C T G IE)
      (HUMAFP-ACCEPTOR-1782 A C G T T T C A T G A A G T T T A T T T T G C C T T C C A G C T T C C A T A T T G G A T T C T T A C C A A T G T A C T G IE)
      (HUMAFP-ACCEPTOR-2796 C T T A A G G A T T C A C A C G T A T T T T T G T T T C A G G G C T A C C A T A T T T T T T G C C C A G T T T G T T C A IE)
      (HUMAFP-ACCEPTOR-5216 C T T T C T C C A A A C A T A A A A T A T T T C T T A T A G C T A C C T G C C T T T C T G G A A G A A C T T T G C C A T IE)
      (HUMAFP-ACCEPTOR-6914 T A A A T C T T C T A G C T C T A T T T T A T T T C A C A G A T T C A T T T A T G A G A T A G C A A G A A G G C A T C C IE)
      (HUMAFP-ACCEPTOR-7965 T T C A T G A C A T T T T G T T T C C T C T A C A T C T A G G C A G C A A C A G T T A C A A A A G A A T T A A G A G A A IE)
      (HUMAFP-ACCEPTOR-9611 A T T A A T T T C T A A T T T C T T T T T T T T C C C T A G A A C T G T T A C T A A A C T G A G T C A G A A G T T T A C IE)
      (HUMAFP-ACCEPTOR-12016 A A A A C T T A T A C T T T A T T T T C C C T G T T G C A G G A A A A A A T C A T G T C C T A C A T A T G T T C T C A A IE)
      (HUMAFP-ACCEPTOR-13888 A C T T G A A A T A T T T T T C T C C A C A T A T T T C A G T T T T G T T C A T G A A T A T T C A A G A A G A C A T C C IE)
      (HUMAFP-ACCEPTOR-14589 A A T G T A T A T G T A A T A A T T C T T C A T T T T C A G G A A G A A G A A T T A C A G A A A T A C A T C C A G G A G IE)
      (HUMAFP-ACCEPTOR-15169 C A G G A C T T A G T T A A A A A A T G C T T C T T T C A G G T T T C T C G T T G C T T A C A C A A A G A A A G C C C C IE)
      (HUMAFP-ACCEPTOR-16955 C T T A C T T T T T T T T C T C A T T C T C C T A A C C A G G C T G A C A T T A T T A T C G G A C A C T T A T G T A T C IE)
      (HUMAFP-ACCEPTOR-18319 T C T T G T A T T T T G T T T T G T T T T A A A T C A C A G G T T T C T C A T T A A C C T T G T G A A G C A A A A G C C IE)
      (HUMAFP-ACCEPTOR-19790 T A T C T G A T T A T G T T T A T T C T T A A T T T T C A G G G A C A A A A A C T G A T T T C A A A A A C T C G T G C T IE)
      (HUMAFP-ACCEPTOR-20185 G T A T T T A A T A T A T T T T T G C T C A T A T T G C A G G G G A A G A G A A G A C A A A A C G A G T C T T T C A T T IE)
      (HUMAK1-ACCEPTOR-3918 A T C C C T C C C C A A C C T G T G C C C T T G T C T T A C A G A G C A C T G A C A C G G C T C C C G G G A C C T C G G IE)
      (HUMAK1-ACCEPTOR-5504 T G A G C C C T G C T C C C C T T T T C T C T C C C G C A G A G A A G C T G A A G A A A A C C A A G A T C A T C T T T G IE)
      (HUMAK1-ACCEPTOR-5712 C G G G G T T T A T G A A T G G G T G G G C G T T T G C A G G T G G G C C T G G C T C A G G G A A G G G C A C C C A G T IE)
      (HUMAK1-ACCEPTOR-6626 A T G G C C C C T T C C T C C T T T G C T G T G C C C C A G G A G A C A G T G T T G G A C A T G C T C C G G G A T G C C IE)
      (HUMAK1-ACCEPTOR-10045 G G G T C C C T G T G A C A T G G T G C C C G C C T G C A G A T T G G A C A G C C C A C A C T G C T G C T G T A T G T G IE)
      (HUMAK1-ACCEPTOR-10488 C A C G G C C C A T C T C C C C A C A G G T C A A C G C T G A G G G C T C C G T G G A C A G T G T C T T C T C C C A G G IE)
      (HUMALBGC-ACCEPTOR-2534 A A C A A T C C T T T T T T T T C T T C C C T T G C C C A G A C A A G A G T G A G G T T G C T C A T C G G T T T A A A G IE)
      (HUMALBGC-ACCEPTOR-4046 T A C T A C A T T T T T C T A C A T C C T T T G T T T C A G G G T G T T G A T T G C C T T T G C T C A G T A T C T T C A IE)
      (HUMALBGC-ACCEPTOR-6011 A G C A A C T G A A A C C T G C T T T C T T C C A T T T A G C A T A C C C T T T T T G G A G A C A A A T T A T G C A C A IE)
      (HUMALBGC-ACCEPTOR-6772 A A G T G A C T G T T T T T C T T T T T C A A A A T T T A G A T A C T T A T A T G A A A T T G C C A G A A G A C A T C C IE)
      (HUMALBGC-ACCEPTOR-7729 T A A T T T T C A T C A A A T T A T T C C T T T T T G T A G C T C G A T G A A C T T C G G G A T G A A G G G A A G G C T IE)
      (HUMALBGC-ACCEPTOR-9414 T A C C A T T T T G A T T G G C G A T T T T C T T T T T A G G G C A G T A G C T C G C C T G A G C C A G A G A T T T C C IE)
      (HUMALBGC-ACCEPTOR-10837 G T T G A A C A A T T T C C A C C A A C T T A C T T A T A G G C G G A C C T T G C C A A G T A T A T C T G T G A A A A T IE)
      (HUMALBGC-ACCEPTOR-12451 C A A A G T C T A T T T T A T T T T C A T C T T A A T T A G G T T T T T G T A T G A A T A T G C A A G A A G G C A T C C IE)
      (HUMALBGC-ACCEPTOR-13672 T A C T A T T A A C A C A A T T C T T T T A T G T T T C A G T T C G A T G A A T T T A A A C C T C T T G T G G A A G A G IE)
      (HUMALBGC-ACCEPTOR-14947 T G C T G A A A A C A C A T G A C T T C T T T T T T T C A G G C T A T T A G T T C G T T A C A C C A A G A A A G T A C C IE)
      (HUMALBGC-ACCEPTOR-15504 T G A A T T T C T G C T C T C C T G C C T G T T C T T T A G C T A T C C G T G G T C C T G A A C C A G T T A T G T G T G IE)
      (HUMALBGC-ACCEPTOR-16911 T T T T T T T T T T C T T T T T C C A T T C A A A C T C A G T G C A C T T G T T G A G C T C G T G A A A C A C A A G C C IE)
      (HUMALBGC-ACCEPTOR-17658 T C C T A A C A T C T G T C A T G T C T T T G T G T T C A G G G T A A A A A A C T T G T T G C T G C A A G T C A A G C T IE)
      (HUMALBGC-ACCEPTOR-18496 A A G A C T T A T A T T T G T C C T T T T G T T T T T C A G C C T A C C A T G A G A A T A A G A G A A A G A A A A T G A IE)
      (HUMALBGC-ACCEPTOR-18496 A A G A C T T A T A T T T G T C C T T T T G T T T T T C A G C C T A C C A T G A G A A T A A G A G A A A G A A A A T G A IE)
      (HUMALPHA-ACCEPTOR-581 T G A C C T G A T C T T T G C T C T C C C C C T G G C C A G T T G A G G A G G A G A A C C C G G A C T T C T G G A A C C IE)
      (HUMALPHA-ACCEPTOR-809 A G C A A G C C T C A C A C A C T T C T G C T C C T T C A G G G A T G G G G G T G T C T A C G G T G A C A G C T G C C A IE)
      (HUMALPHA-ACCEPTOR-1117 G A G A A G A G C T C A G A G T G T C T C T G T C C C C A G A C A T A C A G T G T A G A C A A G C A T G T G C C A G A C IE)
      (HUMALPHA-ACCEPTOR-1369 A T C G C A T A T C C T G A C C T C T A T C A C C C T C A G G A A A G T C A G T G G G A G T G G T A A C C A C C A C A C IE)
      (HUMALPHA-ACCEPTOR-1789 A A G T C C A C C T G C C C C A T C C T C T G T T C C C A G G T G A T C C T A G G T G G A G G C C G A A A G T A C A T G IE)
      (HUMALPHA-ACCEPTOR-2023 G C T G A G G C C T G G C T C T C T C C C T C C C C G C A G G G T G C C C G G T A C G T G T G G A A C C G C A C T G A G IE)
      (HUMALPHA-ACCEPTOR-2224 C C A G T C A C C A C A G G A C C C C T T G T C C C A C A G G T C T C T T T G A G C C T G G A G A C A T G A A A T A C G IE)
      (HUMALPHA-ACCEPTOR-2440 C A G C A T C T C C C C C C T C T G G C C T T C C T G C A G G T G G T C G C A T C G A C C A T G G T C A T C A T G A A A IE)
      (HUMALPHA-ACCEPTOR-2851 G C T C A A C C A C A G G G A C C C C T C T C T C T G C A G G G C T G G C C C C T G G C A A G G C C C G G G A C A G G A IE)
      (HUMALPHA-ACCEPTOR-3090 C T T C C T A C T G A A A C T G A A C C C T C C A A C C A G G G A G C C C C G A G T A T C G G C A G C A G T C A G C A G IE)
      (HUMALPI-ACCEPTOR-415 T G A C C T G A T C T C T A C T C T C C C C C T G G C C A G C T G A G G A G G A G A A C C C G G C C T T C T G G A A C C IE)
      (HUMALPI-ACCEPTOR-646 C C C A G G A C T C A C A C A T T T C T G C T C C T T C A G G G T T G G G G G T G C C C A C G G T G A C A G C C A C C A IE)
      (HUMALPI-ACCEPTOR-965 A A G T A G A G C T C A G G G T G T C T C C G T T C G C A G A C A T A C A A T G T G G A C A G A C A G G T G C C A G A C IE)
      (HUMALPI-ACCEPTOR-1216 G T C A C C G A T C C T G A C C T C T G T C A C C C T C A G G A A A G T C A G T A G G A G T G G T G A C C A C C A C A C IE)
      (HUMALPI-ACCEPTOR-1631 C A A A C C A C C T G C C C C A T C C A T T G T C C T C A G G T G A T C C T T G G C G G A G G C C G C A A G T A C A T G IE)
      (HUMALPI-ACCEPTOR-1861 G T G G G C T G A A G C C T G G C T C T G T C C C T G C A G G G T G C C T G G T A T G T G T G G A A C C G C A C T G A G IE)
      (HUMALPI-ACCEPTOR-2064 C C A A T C A C C A C C A A G C T C C T T G T C C C A C A G G C C T C T T T G A G C C C G G A G A C A C G A A A T A T G IE)
      (HUMALPI-ACCEPTOR-2283 A A G C A T C A C C C C C C T C T G G C C T T C C T G C A G G C G G C C G C A T C G A C C A T G G T C A T C A T G A G G IE)
      (HUMALPI-ACCEPTOR-2698 T C A A C T A C A G G G A C C C G C A T C T C C C T A C A G G G T T G G C C C C C A G C A A G G C T C A G G A C A G C A IE)
      (HUMALPI-ACCEPTOR-2926 T G C C C T G A A G T G C A C T C A C C C T C C T A C C A G G G A G C C C C G A T T A C C A G C A G C A G G C G G C G G IE)
      (HUMALPI1-ACCEPTOR-124 A G G C T G A C C T G A T C T C T A C T C T C C C C C T G G C C A G C T G A G G A G G A G A A C C C G G C C T T C T G G IE)
      (HUMALPPD-ACCEPTOR-192 T G A C C T G A T C T T T G C T C T C C C C C T G G C C A G T T G A G G A G G A G A A C C C G G A C T T C T G G A A C C IE)
      (HUMALPPD-ACCEPTOR-421 C C C A A G C C T C A C A C A T T T C T G T T C C T T C A G G G A T G G G G G T G T C T A C G G T G A C A G C T G C C A IE)
      (HUMALPPD-ACCEPTOR-734 G A G A A G A G C T C A G A G T G T C T C T G T C C C C A G A C A T A C A A T G T A G A C A A A C A T G T G C C A G A C IE)
      (HUMALPPD-ACCEPTOR-985 G T C A C A T A T A C T G A C C T C T G A C A C C C T T A G G G A A G T C A G T G G G A G T G G T A A C C A C C A C A C IE)
      (HUMALPPD-ACCEPTOR-1408 A A A T C C A C C T G C C C C A T C C T C T G T T C C C A G G T G A T C C T A G G T G G A G G C C G A A A G T A C A T G IE)
      (HUMALPPD-ACCEPTOR-1642 G C T G A G G C C T G G C T C T C T C C C T C C C C A C A G G G T G C C C G G T A C G T G T G G A A C C G C A C T G A G IE)
      (HUMALPPD-ACCEPTOR-1845 C C A G T C A C C A C A G G A C C C C T T G T C C C A C A G G T C T C T T T G A G C C T G G A G A C A T G A A A T A C G IE)
      (HUMALPPD-ACCEPTOR-2062 C A G C A T C T C C C C C C T C T G G C C T T C C T G C A G G T G G T C G C A T C G A C C A T G G T C A T C A T G A A A IE)
      (HUMALPPD-ACCEPTOR-2473 G C T C A A C C A C A G G G A C C C C T C T C T C T G C A G G G C T G G C C C C T G G C A A G G C C C G G G A C A G G A IE)
      (HUMALPPD-ACCEPTOR-2719 C C C T C C T A C C G G A A C T G A A C C C T C C A A C A G G G A G C C C C G A G T A T C G G C A G C A G T C A G C A G IE)
      (HUMANFA-ACCEPTOR-785 T C C C T T T C C C T G T A T T T T C C T T T T C T A A A G A A T T T G C T G G A C C A T T T G G A A G A A A A G A T G IE)
      (HUMANFA-ACCEPTOR-2205 A A G C C A G A T A T G T C T G T G T T C T C T T T G C A G T A C T G A A G A T A A C A G C C A G G G A G G A C A A G C IE)
      (HUMANT1-ACCEPTOR-2955 T C C T C T G T C A C C C A C C C T C C C C T C C A C C A G G T C C A G C A T G C C A G C A A A C A G A T C A G T G C T IE)
      (HUMANT1-ACCEPTOR-3950 A G C C G T T C G G C T T C T G G G C T C T G T C C A C A G G G A T G C T G C C T G A C C C C A A G A A C G T G C A C A IE)
      (HUMANT1-ACCEPTOR-5005 C G G A G C C C T C A C C A G C A T T T G T T T C C A C A G C C G A T A T T A T G T A C A C G G G G A C A G T T G A C T IE)
      (HUMAPOA4A-ACCEPTOR-1382 C C T C A T G A A T T G C T C T C T G T T A C C A C C C A G G A G C C A G G G C T G A G G T C A G T G C T G A C C A G G IE)
      (HUMAPOA4A-ACCEPTOR-2286 A A C G T G G C C T C C T T G T G C C C T T C C C C A C A G T G C C C T C T T C C A G G A C A A A C T T G G A G A A G T IE)
      (HUMAPOAI1-ACCEPTOR-653 C C A C T C A G C C A G G C C C T T C T T C T C C T C C A G G T C C C C C A C G G C C C T T C A G G A T G A A A G C T G IE)
      (HUMAPOAI1-ACCEPTOR-902 C C T G A T C T G G G T C T C C C C T C C C A C C C T C A G G G A G C C A G G C T C G G C A T T T C T G G C A G C A A G IE)
      (HUMAPOAI1-ACCEPTOR-1647 A G C C C T C A A C C C T T C T G T C T C A C C C T C C A G C C T A A A G C T C C T T G A C A A C T G G G A C A G C G T IE)
      (HUMAPOAIT-ACCEPTOR-398 C C A C T C A G C C A G G C C C T T C T T C T C C T C C A G G T C C C C C A C G G C C C T T C A G G A T G A A A G C T G IE)
      (HUMAPOAIT-ACCEPTOR-648 C C T G A T C T G G G T C T C C C C T C C C A C C C T C A G G G A G C C A G G C T C G G C A T T T C T G G C A G C A A G IE)
      (HUMAPOAIT-ACCEPTOR-1394 A G C C C T C A A C C C T T C T G T C T C A C C C T C C A G C C T A A A G C T C C T T G A C A A C T G G G A C A G C G T IE)
      (HUMAPOC2-ACCEPTOR-2908 C T G C C A C A T G A C A C C C C C T C A A T G T T C C A G G T C T C T G G A C A C T A T G G G C A C A C G A C T C C T IE)
      (HUMAPOC2-ACCEPTOR-3143 G G G C T C T C C T G A C A C A C T C T C C C C C T G C A G A G G T C C A G G G G A C C C A A C A G C C C C A G C A A G IE)
      (HUMAPOC2-ACCEPTOR-3599 T C C C T C T A A C C A T C T G T G C T T T C T C C C C A G G G A C T T G T A C A G C A A A A G C A C A G C A G C C A T IE)
      (HUMAPOC2G-ACCEPTOR-2616 C T G C C A C A T G A C A C C C C C T C A A T G T T C C A G G T C T C T G G A C A C T A T G G G C A C A C G A C T C C T IE)
      (HUMAPOC2G-ACCEPTOR-2851 G G G C T C T C C T G A C A C A C T C T C C C C C T G C A G A G G T C C A G G G G A C C C A A C A G C C C C A G C A A G IE)
      (HUMAPOC2G-ACCEPTOR-3309 T C C C T C T A A C C A T C T G T G C T T T C T C C C C A G G G A C T T G T A C A G C A A A A G C A C A G C A G C C A T IE)
      (HUMAPOCIA-ACCEPTOR-634 G A T C C C C T G A A C C C C T G C C T C T G C C T C C A G A G T G C C C C T C C G G C C T C G C C A T G A G G C T C T IE)
      (HUMAPOCIA-ACCEPTOR-1956 A T T T T G A A C C C C T G C C C A T C T T C C T G G C A G G C C C A G C C C C A G C C C A G G G G A C C C C A G A C G IE)
      (HUMAPOCIA-ACCEPTOR-4946 A G T G A C C C C C T T C C T T A T T C C T C C C C A C A G G G A G T G G T T T T C A G A G A C A T T T C A G A A A G T IE)
      (HUMAPOCII-ACCEPTOR-2897 C T G C C A C A T G A C A C C C C C T C A A T G T T C C A G G T C T C T G G A C A C T A T G G G C A C A C G A C T C C T IE)
      (HUMAPOCII-ACCEPTOR-3131 C C C C T T A C C T G A C A C A C T C T C C C C C T G C A G A G G T C C A G G G G A C C C A A C A G C C C C A G C A A G IE)
      (HUMAPOCII-ACCEPTOR-3595 C C C C T C T A A C C A T C T G T G C T T T C T C C C C A G G G A C T T G T A C A G C A A A A G C A C A G C A G C C A T IE)
      (HUMAPOE4-ACCEPTOR-1818 G C G G T T G A T T G A C A G T T T C T C C T T C C C C A G A C T G G C C A A T C A C A G G C A G G A A G A T G A A G G IE)
      (HUMAPOE4-ACCEPTOR-2977 C T G A C C C G A C C T T G A A C T T G T T C C A C A C A G G A T G C C A G G C C A A G G T G G A G C A A G C G G T G G IE)
      (HUMAPOE4-ACCEPTOR-3751 T G C G A C A C C C T C C C G C C C T C T C G G C C G C A G G G C G C T G A T G G A C G A G A C C A T G A A G G A G T T IE)
      (HUMAPRTA-ACCEPTOR-774 C C G C G T C A C C A G G C C T G T C C T T G G G T C C A G G G A C A T C T C G C C C G T C C T G A A G G A C C C C G C IE)
      (HUMAPRTA-ACCEPTOR-1848 C C G A G T C A C T C C T G T C A C T T A C C C T G A C A G G C C T A G A C T C C C G A G G C T T C C T C T T T G G C C IE)
      (HUMAPRTA-ACCEPTOR-2252 C T G A G G A C C A C A C A C C A C T T C C C A C T C C A G G C T G A G C T G G A G A T T C A G A A A G A C G C C C T G IE)
      (HUMAPRTA-ACCEPTOR-2558 C A A C T G G G G A C C T C A C C C T C C C A T C C C C A G G A A C C A T G A A C G C T G C C T G T G A G C T G C T G G IE)
      (HUMATP1A2-ACCEPTOR-6683 T C C C T G A C T C T C C G G C T C T C C C T C C C T C A G G C T G G C C G T G A G T A C T C A C C T G C C G C C A C C IE)
      (HUMATP1A2-ACCEPTOR-6969 C C C C A A A G T A A C T C A C C C T C C C T T C C C C A G G A T G A C C A C A A G C T G T C C T T G G A T G A G C T G IE)
      (HUMATP1A2-ACCEPTOR-8990 G T G C C C C T A C G C C T C T C C T T G C T C C C T C A G G G C C T C A C C A A C C A G C G G G C T C A G G A C G T T IE)
      (HUMATP1A2-ACCEPTOR-9720 C A G G T C C C T G A A A C T C T T T C T C C T T A C C A G C T A T A T C T G G G T G T G G T G C T G G C A G C T G T G IE)
      (HUMATP1A2-ACCEPTOR-10073 A T T T C A T G A G C T G C C T G T G G C T C C C C A C A G C A A G C C C T T G T G A T C C G G G A G G G A G A G A A G IE)
      (HUMATP1A2-ACCEPTOR-10913 T C T G A T G A C T A T G C A C T C C T T C C T C C T C A G G T G G A T A A C T C A T C C T T A A C A G G A G A G T C G IE)
      (HUMATP1A2-ACCEPTOR-12450 C A C C C A A C C T G A T G C C C C A C C A T G T T G C A G G C A C T G C C A G G G G C A T T G T G A T T G C C A C A G IE)
      (HUMATP1A2-ACCEPTOR-13550 A C C T T T T T T A T T C T C C T C T T T C T C T A C C A G G T G T G C C T G A C C C T G A C A G C C A A G C G C A T G IE)
      (HUMATP1A2-ACCEPTOR-13878 C G C T C C T G G T T C C C C C T C A T T T C C T C C C A G G G G C C A C T T T T G A C A A A C G A T C C C C T A C G T IE)
      (HUMATP1A2-ACCEPTOR-15000 C C T C T C T G T A A C T A C C T G T T G T C T C T C C A G C T G T C T A T C C A C G A G C G A G A A G A C A G C C C C IE)
      (HUMATP1A2-ACCEPTOR-15320 A T C T C A C T G A T C C C T T C T G C C C C C C T T T A G G A T T C T G T C A A C T G A A T C T G C C A T C T G G A A IE)
      (HUMATP1A2-ACCEPTOR-19381 T T T C C T G T T G T C T C C T C T C C T T C C C A C T A G G T G A T C A T G G T A A C C G G G G A T C A C C C T A T C IE)
      (HUMATP1A2-ACCEPTOR-20042 C A G C T G T C T C T G T C C C C A C C C A C C C T C C A G A G A A G C C A A G G C A T G C G T G G T G C A C G G C T C IE)
      (HUMATP1A2-ACCEPTOR-20331 C G T C C T C A A G T G T G G C C G T C T T C C C T C C A G G G A G C C A T T G T G G C C G T G A C G G G T G A C G G G IE)
      (HUMATP1A2-ACCEPTOR-20736 C T C C C T G A T G C C C T C A G A A T C T C C C C A C A G G C C G C C T G A T C T T T G A C A A C T T G A A G A A A T IE)
      (HUMATP1A2-ACCEPTOR-21144 C C T C C C T G C C C C A T T T C C T A C C C C A C A C A G G T C C C T G C C A T C T C C T T G G C C T A T G A G G C A IE)
      (HUMATP1A2-ACCEPTOR-21467 C T G C C C C T G C C T T T G G C C C T C T A C C C A C A G G G A T G A T C C A G G C A C T G G G T G G C T T C T T C A IE)
      (HUMATP1A2-ACCEPTOR-21798 C T C A T C T G T C T C T G C C C A C C C T C C C T C C A G A C C T A T G A G C A G C G G A A G G T G G T G G A G T T C IE)
      (HUMATP1A2-ACCEPTOR-22617 C A C C T G C C A C C T C C T T T C T T T G C C T T T C A G G A A C A A G A T C C T G A T T T T T G G G C T C C T G G A IE)
      (HUMATP1A2-ACCEPTOR-22870 G C T G C T G A C A C T C T C C T C C A T T G C T T T C A G A G T C A C C T G G T G G T T C T G C G C C T T C C C C T A IE)
      (HUMATP1A2-ACCEPTOR-24266 T G C A A T C T C C A C T C C C A A T C T C T C T A A C A G G C T G G G T G G A G A A G G A G A C A T A C T A C T G A C IE)
      (HUMATPSYB-ACCEPTOR-2698 C A G C T C C T T C C A A T A T C T T T T G T C T G T T A G T C A G G G A C T A T G C G G C G C A A A C A T C T C C T T IE)
      (HUMATPSYB-ACCEPTOR-3096 G T A T A A C C C T G C G A T G C C T G T A T C T A A C A G G T G A G A G C A C A G T A A G G A C T A T T G C T A T G G IE)
      (HUMATPSYB-ACCEPTOR-4093 T A G A T A C T A T C C T C T C T T C T A C C T T T A C A G A T T T G C T C C C A T T C A T G C T G A G G C T C C A G A IE)
      (HUMATPSYB-ACCEPTOR-4464 T A A A T A T T C T T T C T T T T C A A C C T C T T A T A G G G C T T T T T G G T G G T G C T G G A G T T G G C A A G A IE)
      (HUMATPSYB-ACCEPTOR-5220 A G G T T T T A C G A T T A T G T A T G A T T A C T G C A G G T A G C G C T G G T A T A T G G T C A A A T G A A T G A A IE)
      (HUMATPSYB-ACCEPTOR-5471 G T A G A C A C C T A A G A C C T T T T T T T C T T T T A G G T G T C T G C A T T A T T G G G C C G A A T C C C T T C T IE)
      (HUMATPSYB-ACCEPTOR-7858 G T T C C T G T T C T T C A T G G G A T C T C A C T T T A G G C T A T C T A T G T G C C T G C T G A T G A C T T G A C T IE)
      (HUMATPSYB-ACCEPTOR-8745 T A C T T A A C T C A G T C T T C T T T T T T C T C A T A G G A C T A C A A A T C C C T C C A G G A T A T C A T T G C C IE)
      (HUMATPSYB-ACCEPTOR-9633 C T C T T T T T T T T T T T C T C C C C C A T C A T A C A G G T G A A T A T G A C C A T C T C C C A G A A C A G G C C T IE)
      (HUMBLYM1-ACCEPTOR-505 C T T G C C A C T G C A C T C C A T A C T G C A T G A C A G A G C A A G A C C C T G T C T C T T A G A A A A A A G A A A IE)
      (HUMBNPA-ACCEPTOR-831 C T G A G G C T T G G A C G C C C C C A T T C A T T G C A G G A G C A G C G C A A C C A T T T G C A G G G C A A A C T G IE)
      (HUMBNPA-ACCEPTOR-1629 C C A T C A T C A C C C T C T C T C T T T C C C T G A C A G T G C T G A G G C G G C A T T A A G A G G A A G T C C T G G IE)
      (HUMCACY-ACCEPTOR-1973 C A T G G C A C T G A C T A G G C C C T C T G C T G C C A G C T C C A A G C C C A G C C C T C A G C C A T G G C A T G C IE)
      (HUMCACY-ACCEPTOR-2504 G A G T A T G G A T T T C A C A T T C T A A C A C A T T A G A A G C T G C A G G A T G C T G A A A T T G C A A G G C T G IE)
      (HUMCAPG-ACCEPTOR-1131 T A G A G C T A A G T G C C A A A T G C T T C C T T C C A G G G G A G A T C A T C G G A G G C C G G G A G A G C A G G C IE)
      (HUMCAPG-ACCEPTOR-1733 G C A G C C C A G A C C T A C C T C T T G C T T T T G C A G C A A T A T A A A T G T C A C C C T G G G C G C C C A C A A IE)
      (HUMCAPG-ACCEPTOR-2044 T G A G C G G G A A C G C C T A C A T T C T T C C T C C A G C T G A G C A G A A G A G T C A G A C G G A A T C G A A A C IE)
      (HUMCAPG-ACCEPTOR-2733 C T C A G T C T C C C T T C T C C T C T C T A C C T A C A G G G G G A T T C C G G A G G C C C C C T G C T G T G T A A C IE)
      (HUMCATF-ACCEPTOR-1108 T G G T A A T T G T G A A T A T G A C A T C A T T T T C A G G T T T G G C C T C A C A A G G A C T A C C C T C T C A T C IE)
      (HUMCFVII-ACCEPTOR-1624 C C T T A T G A C C C C G G C C A C C T T C C T G C C C A G G C G G G G T C G C T A A G G C C T C A G G A G G A G A A A IE)
      (HUMCFVII-ACCEPTOR-4264 T G G G C G C T T C A C G G A A C T C G C A T T T C C C A G T C T T C G T A A C C C A G G A G G A A G C C C A C G G C G IE)
      (HUMCFVII-ACCEPTOR-6353 C T C A C G A G G C T T G C T C T C T T G T T C C T T C A G A A G C T G T T C T G G A T T T C T T A C A G T G G T G A G IE)
      (HUMCFVII-ACCEPTOR-6448 T C A G C T T A C T G A C A C C A G C C C A C T C C A C A G A T G G G G A C C A G T G T G C C T C A A G T C C A T G C C IE)
      (HUMCFVII-ACCEPTOR-8277 C C T C T C A G G G T G T C C C C T T C C T G T C C C C A G A C A A G G A T G A C C A G C T G A T C T G T G T G A A C G IE)
      (HUMCFVII-ACCEPTOR-9389 C T G C A T C T T T C T G A C T T T T G T T T T A C A C A G T T G A A T A T C C A T G T G G A A A A A T A C C T A T T C IE)
      (HUMCFVII-ACCEPTOR-10094 G A C T T C C A C A C C T C C T G T C C C C C C G C C C A G G T C C T G T T G T T G G T G A A T G G A G C T C A G T T G IE)
      (HUMCFVII-ACCEPTOR-11034 A A G G G C C T G A G G G G G G C T T C T T C C T T C C A G G C G A G C A C G A C C T C A G C G A G C A C G A C G G G G IE)
      (HUMCKMT-ACCEPTOR-1127 C T C C A T G G T T A C T G G G T A C C C C C T C C C C A G C G C T G A G T A C C C A G A C C T C C G A A A G C A C A A IE)
      (HUMCKMT-ACCEPTOR-1529 T A A C C A T C T C T C C C T C T T A A C T C C C C T T A G G T A T T T G C T G A C C T G T T T G A C C C T G T G A T C IE)
      (HUMCKMT-ACCEPTOR-2011 T G A C T T A C A T T C A T T T C C C T T A T C T C C C A G A T C C G T T C T G G C T A C T T T G A T G A G A G G T A T IE)
      (HUMCKMT-ACCEPTOR-2362 T C T T A A C C C A A G T C C C G T T A C T C T T C C C A G G A C C A C T T T C T G T T T G A T A A G C C T G T G T C C IE)
      (HUMCKMT-ACCEPTOR-2563 T C T T G A T C A C T G T C C C T C T C C G G C C C T C A G G C A C A A C A A T G A G A A G A G C T T C C T G A T C T G IE)
      (HUMCKMT-ACCEPTOR-4348 T T T T C G T T A A C A A A A C C T T T G T G G A C T C A G G T G G A G A G A C T T A T C C A A G A A C G T G G C T G G IE)
      (HUMCKMT-ACCEPTOR-4984 C C C T G C T C C C A A T C C C T A T C T C C T C T C T A G G A T A G C C G C T T C C C A A A G A T C C T G G A G A A C IE)
      (HUMCKMT-ACCEPTOR-5313 G G A A G C A G A T C A A A G A T T A G T G T C C C T T A G G T G G A G C T G G T G C A A C T G G T C A T C G A T G G A IE)
      (HUMCP21OH-ACCEPTOR-1014 T C C G C T G A C G C T G C T T T G G C T G T C T C C C A G A T G T G G T G G T G C T G A A C T C C A A G A G G A C C A IE)
      (HUMCP21OH-ACCEPTOR-1386 C C A C C C T C C A G C C C C C A C C T C C T C C T G C A G A C A A G C T G G T G T C T A G G A A C T A C C C G G A C C IE)
      (HUMCP21OH-ACCEPTOR-1648 G C C T G C T G A A C T C A C A C T G T T T C T C C A C A G C G C A T G A G A G C C C A G C C C G G C A C C C C T G T G IE)
      (HUMCP21OH-ACCEPTOR-1838 A A C T G A A A G T A C T C C C T C C T T T T C T G G C A G G A C G A C A A C T T A A T G C C T G C C T A T T A C A A A IE)
      (HUMCP21OH-ACCEPTOR-2041 A C A G C T G C A T T C T C A T G C T T C C T G C C G C A G T T C T T C C C C A A T C C A G G T C T C C G G A G G C T G IE)
      (HUMCP21OH-ACCEPTOR-2297 C G C T C A G C C C G C T C C T T T C A C C C T C T G C A G G A G A G C C T C G T G G C A G G C C A G T G G A G G G A C IE)
      (HUMCP21OH-ACCEPTOR-2698 G G G G C A G G A C T C C A C C C G A T C A T T C C C C A G A T T C A G C A G C G A C T G C A G G A G G A G C T A G A C IE)
      (HUMCP21OH-ACCEPTOR-2960 T G G C C A G C C T C T A A C T C C A G C C C C C T T C A G C A T C T C C G G C T A C G A C A T C C C T G A G G G C A C IE)
      (HUMCP21OH-ACCEPTOR-3161 C T C C C C A C C C A C C T G T C C A C C C G C C C G C A G A T C G C T T C C T G G A G C C A G G C A A G A A C T C C A IE)
      (HUMCP21OHC-ACCEPTOR-1015 T C C G C T G A C G C T G C T T T G G C T G T C T C C C A G A T G T G G T G G T G C T G A A C T C C A A G A G G A C C A IE)
      (HUMCP21OHC-ACCEPTOR-1387 C C A C C C T C C A G C C C C C A G C T C C T C C T G C A G A C A A G C T G G T G T C T A G G A A C T A C C C G G A C C IE)
      (HUMCP21OHC-ACCEPTOR-1649 G C C T G C T G A A C T C A C A C T G T T T C T C C A C A G C G C A T G A G A G C C C A G C C C G G C A C C C C T G T G IE)
      (HUMCP21OHC-ACCEPTOR-1839 A A C T G A A A G T A C T C C C T C C T T T T C T G G C A G G A C G A C A A C T T A A T G C C T G C C T A T T A C A A A IE)
      (HUMCP21OHC-ACCEPTOR-2042 A C A G C T G C A T T C T C A T G C T T C C T G C C G C A G T T C T T C C C C A A T C C A G G T C T C C G G A G G C T G IE)
      (HUMCP21OHC-ACCEPTOR-2298 C G C T C A G C C C G C T C C T T T C A C C C T C T G C A G G A G A G C C T C G T G G C A G G C C A G T G G A G G G A C IE)
      (HUMCP21OHC-ACCEPTOR-2699 G G G G C A G G A C T C C A C C C G A T C A T T C C C C A G A T T C A G C A G C G A C T G C A G G A G G A G C T A G A C IE)
      (HUMCP21OHC-ACCEPTOR-2962 T G G C C A G C C T C T A A C T C C A G C C C C C T T C A G C A T C T C C G G C T A C G A C A T C C C T G A G G G C A C IE)
      (HUMCP21OHC-ACCEPTOR-3163 C T C C C C A C C C A C C T G T C C A C C C G C C C G C A G A T C G C T T C C T G G A G C C A G G C A A G A A C T C C A IE)
      (HUMCRPG-ACCEPTOR-578 C T C A C A T T T G C T T G T T T T T C T G G C T C A C A G A C A T G T C G A G G A A G G C T T T T G T G T T T C C C A IE)
      (HUMCRPGA-ACCEPTOR-539 C T C A C A T T T G C T T G T T T T T C T G G C T C A C A G A C A T G T C G A G G A A G G C T T T T G T G T T T C C C A IE)
      (HUMCRYGBC-ACCEPTOR-2225 C T C C A T G C T C C C A C A T C T T C C A T T T T T C A G A T C A C C T T C T A C G A G G A C A G G G C C T T C C A G IE)
      (HUMCRYGBC-ACCEPTOR-5283 T A C T C T T G C G T T T T C T G T C T G C C A C T C C A G C A C T C T G G C G C T T A C A G A A T G A A G A T C T A C IE)
      (HUMCRYGBC-ACCEPTOR-18489 A T G T A A T T C G G A A C G A T T C T T C C T T T G C A G A T C A C C T T C T A T G A G G A C A G G G C C T T C C A G IE)
      (HUMCRYGBC-ACCEPTOR-19693 T T T C C A T C C T T C T T T C T G T G G A C C G A G T A G A C A G T C T C C C A C A G G C T G C G G C T G T A C G A G IE)
      (HUMCS1-ACCEPTOR-800 T C C C T C C A T T G C C C T C C G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMCS1-ACCEPTOR-1184 G T C C T T C T T G G T G G G G G G T C C T T C T C C T A G G A A G A A A C C T A T A T C C C A A A G G A C C A G A A G IE)
      (HUMCS1-ACCEPTOR-1396 G C A C A G C C A C T G C C G G T C C T T C C C C T G C A G A A T C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMCS1-ACCEPTOR-1814 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A C G G C A G C C G C C G G A C T G G G IE)
      (HUMCSFGMA-ACCEPTOR-891 T T G A T A A C A T G A C A T T T T C C T T T T C T A C A G A A T G A A A C A G T A G A A G T C A T C T C A G A A A T G IE)
      (HUMCSFGMA-ACCEPTOR-1620 C T G C T C A C C G A C G A A C G A C A T T T T C C A C A G G A G C C G A C C T G C C T A C A G A C C C G C C T G G A G IE)
      (HUMCSFGMA-ACCEPTOR-2554 C A A G T G T T T T T T A T T T T T C T T T T T T T A A A G G A A A C T T C C T G T G C A A C C C A G A T T A T C A C C IE)
      (HUMCSPB-ACCEPTOR-1260 T G C C C A C A A G C A G A C A G A C T T T T C C T T C A G G G G A G A T C A T C G G G G G A C A T G A G G C C A A G C IE)
      (HUMCSPB-ACCEPTOR-1874 A C C C C C A T C C T C A C T C T G C T C T C T C T G C A G C T C C A T A A A T G T C A C C T T G G G G G C C C A C A A IE)
      (HUMCSPB-ACCEPTOR-2217 C C T G G A C T T T C T T G C C T C T T C C C C C A C C A G C T G G A G A G A A A G G C C A A G C G G A C C A G A G C T IE)
      (HUMCSPB-ACCEPTOR-3118 C A G C T C A G T C C T T C C A C T C T C T A T T C A C A G G G G G A C T C T G G A G G C C C T C T T G T G T G T A A C IE)
      (HUMCYC1A-ACCEPTOR-2108 C C T G G C A A G C G C T G A G C G G A G A T C T T G C A G G C A G T G G C C T T G T C G T C G A A G T C T G G C C T T IE)
      (HUMCYC1A-ACCEPTOR-2399 C A G C T T T C C T A A C C C T T T C C C T C C C T C C A G C A T C C G G A G G G G T T T C C A G G T A T A T A A G C A IE)
      (HUMCYC1A-ACCEPTOR-2611 G C A G G G T T G T G A T G A G G C T C T C G G T G G C A G G T G G A G G T T C A A G A C G G C C C C A A T G A A G A T IE)
      (HUMCYC1A-ACCEPTOR-2858 G G A A C T A A G G A G C C A T G G A T C T G G T C C T A G G C A T G G T G G T G A G G A C T A C G T C T T C T C C C T IE)
      (HUMCYC1A-ACCEPTOR-3281 G A A T A G C C C T C A C T G C T T G T C G T T G G C C A G G C A C C C C A G C T A C C A T G T C C C A G A T A G C C A IE)
      (HUMCYC1A-ACCEPTOR-3478 C T C C C T T C T C T G A G C C T T C C T T G T C T G C A G A T G T T G A T G A T G A T G G C T C T G C T G G T G C C C IE)
      (HUMCYCAA-ACCEPTOR-1188 A A T T T A C T A A G T T G A A G C T T T C G T T T T T A G A A T T A A A T A T G G G T G A T G T T G A G A A A G G C A IE)
      (HUMCYCAA-ACCEPTOR-1466 G A A A T A A C C G A T G C A T T C T T T C T T G T T T A G G C A T C A T C T G G G G A G A G G A T A C A C T G A T G G IE)
      (HUMCYPIIE-ACCEPTOR-3877 G G C C T G A C T T C T A G C C A C G G G T C T C C G C A G T T G G C C C A G C G C T T C G G G C C G G T G T T C A C G IE)
      (HUMCYPIIE-ACCEPTOR-6976 A A T A A C C T T C T G C T G G C C C C T C T G C C T T A G G A A T C A T T T T T A A T A A T G G A C C T A C C T G G A IE)
      (HUMCYPIIE-ACCEPTOR-7515 T T C T G G T T G C C C T G A C T G C C T G T T T T G T A G G C C A G C C T T T C G A C C C C A C C T T C C T C A T C G IE)
      (HUMCYPIIE-ACCEPTOR-8083 A A G T A G T A A A A T A T T T T T T T C C C T C T C T A G C T T T A C A A T A A T T T T C C C A G C T T T C T A C A C IE)
      (HUMCYPIIE-ACCEPTOR-9142 C T T C T C T C C G G T C T G T C T C C G G T A T C A C A G G A A A A G C A C A G T G C A G A G C G C T T G T A C A C A IE)
      (HUMCYPIIE-ACCEPTOR-12121 C T G A A A T T T G T C C C A T T C A T A T C T T G G C A G A G A A G C T C C A T G A A G A A A T T G A C A G G G T G A IE)
      (HUMCYPIIE-ACCEPTOR-12808 A C T C A C T G A G A C A G T C T T T G T T T C T C C T A G G G C A C A G T C G T A G T G C C A A C T C T G G A C T C T IE)
      (HUMCYPIIE-ACCEPTOR-13834 G T G T C T C A T C A A T A C C A T T G T T A C T T C T A G G A A A A C G A G T G T G T G C T G G A G A A G G C C T G G IE)
      (HUMDAFA-ACCEPTOR-1235 C T T C A G C C T C C C A A G T A G C T G G T A C T A C A G G G C A C A C G T G T T T C A C G T T G A C A G G T T T G C IE)
      (HUMDES-ACCEPTOR-1763 A C T G T C T G T C T T T C T G T C T G T C C C A C C C A G G C T G C A G G A G G A G A T T C A G T T G A A G G A A G A IE)
      (HUMDES-ACCEPTOR-1920 A C C A T G T C C T T C T C G C T T G G C C T C T C C C A G G A C G T G G A T G C A G C T A C T C T A G C T C G C A T T IE)
      (HUMDES-ACCEPTOR-2164 G A G G G A C T G A A G C C C A G T C A T G C C C T A C A G G A G A T C C G T G A G T T G C A G G C T C A G C T T C A G IE)
      (HUMDES-ACCEPTOR-2504 T C A T T T T T G G G C C C C T T T C T C T G C C C T T A G G T G T C A G A C C T G A C C C A G G C A G C C A A C A A G IE)
      (HUMDES-ACCEPTOR-3015 T C C T T G A C C T G G G T T C C C C C T C T C C T G C A G A A C G A T T C C C T G A T G A G G C A G A T G C G G G A A IE)
      (HUMDES-ACCEPTOR-5413 T C T T A G G A G G T T T T G T C T C T T C C C T T T T A G G A T C A A T C T C C C C A T C C A G A C C T A C T C T G C IE)
      (HUMDES-ACCEPTOR-7283 A G G C T G A G T G T G C G A T G G A C C C T G T T A C A G A A A C C A G C C C T G A G C A A A G G G G T T C T G A G G IE)
      (HUMDES-ACCEPTOR-7550 T A G C A C A T G T G A C T G G A C T C C T C T C C C C A G G T C G T C A G T G A G G C C A C A C A G C A G C A G C A T IE)
      (HUMEDHB17-ACCEPTOR-2031 C A G A T C T T C C T C C T C T C C C A A A A C C T C C A G T G T A T G C C A C G T T G A G G G A C C T G A A A A C A C IE)
      (HUMEDHB17-ACCEPTOR-2346 G C G G G C T G G T C G G G C C T C T T G T C T C C G C A G T G T G T A A C G C A G G C C T G G G C C T G C T G G G G C IE)
      (HUMEDHB17-ACCEPTOR-2701 C G C C T C A G G A A C C T C G T C T C C C C A C C T A A G G G C T G C C T T T C A A T G A C G T T T A T T G C G C C A IE)
      (HUMEDHB17-ACCEPTOR-3311 C C C T C C C A C T C G T T G C T C T C C G G C C A G C A G C T T G A G C C T G A T C G A G T G C G G C C C A G T G C A IE)
      (HUMEDHB17-ACCEPTOR-3575 G T G G C C A C A G C T C T C C T C C C G C C G C C G C A G G T C T T C C T C A C C G C T T T G C G C G C C C C G A A G IE)
      (HUMEF1A-ACCEPTOR-1522 G T G G T T C A A A G T T T T T T T C T T C C A T T T C A G G T G T C G T G A A A A C T A C C C C T A A A A G C C A A A IE)
      (HUMEF1A-ACCEPTOR-2062 T A A C C A A G T A A C G A C T C T T A A T C C T T A C A G A T G G G A A A G G G C T C C T T C A A G T A T G C C T G G IE)
      (HUMEF1A-ACCEPTOR-2347 G A C A G G G A T A T G T C T T T G C T T T C T T T A A A G G C T G A C T G T G C T G T C C T G A T T G T T G C T G C T IE)
      (HUMEF1A-ACCEPTOR-2727 C T T A C A C A A A T T G G C A T G C T T G T G T T T C A G A T G C C T T G G T T C A A G G G A T G G A A A G T C A C C IE)
      (HUMEF1A-ACCEPTOR-2965 A G G T A T T T A G T A T G C T G T A A A T A T T T T T A G G T A T T G G T A C T G T T C C T G T T G G C C G A G T G G IE)
      (HUMEF1A-ACCEPTOR-3311 T T T G C A C T G A A T G C A A A T C T T T T T T C C A A G G T G A T T A T C C T G A A C C A T C C A G G C C A A A T A IE)
      (HUMEF1A-ACCEPTOR-3641 T T G G G T A A T A A T T A A C T T T T T T T T T A A T A G G T C G C T T T G C T G T T C G T G A T A T G A G A C A G A IE)
      (HUMERP-ACCEPTOR-1164 C C T G A C T C T C A G C C T G G C T A T C T G T T C T A G A A T G T C C T G C C T G G C T G T G G C T T C T C C T G T IE)
      (HUMERP-ACCEPTOR-1566 C C T T G A C T C C C C G G G C T G T G T G C A T T T C A G A C G G G C T G T G C T G A A C A C T G C A G C T T G A A T IE)
      (HUMERP-ACCEPTOR-2264 C A G C T G A C T C C C A G A G T C C A C T C C C T G T A G G T C G G G C A G C A G G C C G T A G A A G T C T G G C A G IE)
      (HUMERP-ACCEPTOR-2578 T G C A G C G A C C T C C T G T T T T C T C C T T G G C A G A A G G A A G C C A T C T C C C C T C C A G A T G C G G C C IE)
      (HUMERPA-ACCEPTOR-1171 C C T G A C T C T C A G C C T G G C T A T C T G T T C T A G A A T G T C C T G C C T G G C T G T G G C T T C T C C T G T IE)
      (HUMERPA-ACCEPTOR-1575 C C T T G A C T C C C C G G G C T G T G T G C A T T T C A G A C G G G C T G T G C T G A A C A C T G C A G C T T G A A T IE)
      (HUMERPA-ACCEPTOR-2273 C A G C T G A C T C C C A G A G T C C A C T C C C T G T A G G T C G G G C A G C A G G C C G T A G A A G T C T G G C A G IE)
      (HUMERPA-ACCEPTOR-2587 T G C A G C G A C C T C C T G T T T T C T C C T T G G C A G A A G G A A G C C A T C T C C C C T C C A G A T G C G G C C IE)
      (HUMETN3-ACCEPTOR-391 T G A A A T G T T T T T C C T T G T G T A T T T T A A C A G G G C T G A A G A C A T T A T G G A G A A A G A C T G G A A IE)
      (HUMFABP-ACCEPTOR-2320 T T A T T T T C T C C A T T G T C T T A C C T T T T A C A G G T G T T A A T A T A G T G A A A A G G A A G C T T G C A G IE)
      (HUMFABP-ACCEPTOR-3516 A T T A T T A T T A T T A T T A T T A T T A T T A T G T A G G G G A C C T G G A G C C T T G A G G G A A A T A A A C T T IE)
      (HUMFABP-ACCEPTOR-4068 T A A A T T C T T C T G T T T G T T A A C A C C T T T C A G A C T T A T G T G T A T G A A G G A G T A G A A G C C A A A IE)
      (HUMFIXG-ACCEPTOR-9261 A A A C T A A A G A A T T A T T C T T T T A C A T T T C A G T T T T T C T T G A T C A T G A A A A C G C C A A C A A A A IE)
      (HUMFIXG-ACCEPTOR-9613 C G T T A A T T T G T C T T C T T T T A T T C T T T A T A G A C T G A A T T T T G G A A G C A G T A T G T T G G T A A G IE)
      (HUMFIXG-ACCEPTOR-13327 G C C A A T T C A A T T T C T T A A C C T A T C T C A A A G A T G G A G A T C A G T G T G A G T C C A A T C C A T G T T IE)
      (HUMFIXG-ACCEPTOR-20604 T G C T G T T A C T G T C T A T T T T G C T T C T T T T A G A T G T A A C A T G T A A C A T T A A G A A T G G C A G A T IE)
      (HUMFIXG-ACCEPTOR-23298 A G G T T A C T A A T T T T T C T T C T A T T T T T C T A G T G C C A T T T C C A T G T G G A A G A G T T T C T G T T T IE)
      (HUMFIXG-ACCEPTOR-32974 G C A G T A A G A G T C T T A A T T T T G T T T T C A C A G G T T G T T T T G A A T G G T A A A G T T G A T G C A T T C IE)
      (HUMFIXG-ACCEPTOR-33757 G T G A C T T A A A A T G A A A T T T A T T T T T A A T A G G T G A A C A T A A T A T T G A G G A G A C A G A A C A T A IE)
      (HUMFOS-ACCEPTOR-1753 C G T C G G C T T T C C C C T T C T G T T T T G T T C T A G G A C T T C T G C A C G G A C C T G G C C G T C T C C A G T IE)
      (HUMFOS-ACCEPTOR-2436 A A T G T C G G T C T T T T T T T G T G A T T A T T C T A G T T A T C T C C A G A A G A A G A A G A G A A A A G G A G A IE)
      (HUMFOS-ACCEPTOR-2658 T T A T G C T T T C C T T T A T C C C T C T G T A T A C A G G A G A C A G A C C A A C T A G A A G A T G A G A A G T C T IE)
      (HUMFVII-ACCEPTOR-136 A C A T G C C G T G G A A G C C G G G G C C T C A C A G A G T C T T C G T A A C C C A G G A G G A A G C C C A C G G C G IE)
      (HUMG0S19A-ACCEPTOR-2812 C T C G G G C T C A T T C T C T T C C T T T C T C C A C A G T T G C T G C T G A C A C G C C G A C C G C C T G C T G C T IE)
      (HUMG0S19A-ACCEPTOR-3347 A G T G C T T A A C T C T T C C T C C C T T C T C C A C A G C T T C C T A A C C A A G C G A A G C C G G C A G G T C T G IE)
      (HUMG0S19B-ACCEPTOR-2948 A C T T G G G C T T A T T C T C T C C T T T C T C C G C A G T T G C T G C T G A C A C G C C G A C C G C C T G C T G C T IE)
      (HUMG0S19B-ACCEPTOR-3484 A G T G C T T A A C T C T T C C T C C C T T C T C C A C A G C T T C C T A A C C A A G A G A G G C C G G C A G G T C T G IE)
      (HUMGAST2-ACCEPTOR-916 C C C C C A T T C T C G C C T C T C T C A C C T C C T C A G A C C C G T C C A A G A A G C A G G G A C C A T G G C T G G IE)
      (HUMGASTA-ACCEPTOR-6254 C C T T A A G C T A G T C C C T T C T C C C C T T T G C A G A C G A G A T G C A G C G A C T A T G T G T G T A T G T G C IE)
      (HUMGASTA-ACCEPTOR-6600 C C C C C A T T C T C G C C T C T C T C C C C T C C T C A G A C C C G T C C A A G A A G C A G G G A C C A T G G C T G G IE)
      (HUMGCB1-ACCEPTOR-949 C T T T T C A G T C A T T C C T C A T T C T G T C C T C A G G A A T G T C C C A A G C C T T T G A G T A G G G T A A G C IE)
      (HUMGCB1-ACCEPTOR-1590 C T C A C T C T G C T T G T A C T C C C T C C C T C C C A G G T G C C C G C C C C T G C A T C C C T A A A A G C T T C G IE)
      (HUMGCB1-ACCEPTOR-1905 G A T A C C C T T A T T C C C T G T G G A T G T C C T C A G G C C T G C T A C T G A C C C T G C A G C C A G A A C A G A IE)
      (HUMGCB1-ACCEPTOR-3009 C T A C C A T A T C T T G A T C A T C C T T T T C T G T A G G A A T C G G A T A T A A C A T C A T C C G G G T A C C C A IE)
      (HUMGCB1-ACCEPTOR-3353 T G C T T C T C T C T T C A C T A C C T T T G T C T C T A G A T A C C C C T G A T T C A C C G A G C C C T G C A G T T G IE)
      (HUMGCB1-ACCEPTOR-4081 C C G G A T C A T T C A T G A C C T T T C T C T T G C C A G G T T C C T G G A T G C C T A T G C T G A G C A C A A G T T IE)
      (HUMGCB1-ACCEPTOR-5186 G G T C C A G G A T C A G T T G C T C T T C C T T T G C A G G T A C T G A C A G A C C C A G A A G C A G C T A A A T A T IE)
      (HUMGCB1-ACCEPTOR-5810 T T T G T C T C T T T G C C T T T G T C C T T A C C C T A G A A C C T C C T G T A C C A T G T G G T C G G C T G G A C C IE)
      (HUMGCB1-ACCEPTOR-6344 G G G A C T C T G A C C A T C T G T T C C C A C A T T C A G C A A G T T C A T T C C T G A G G G C T C C C A G A G A G T IE)
      (HUMGCB1-ACCEPTOR-6555 C A C T C T C A G C T T C T C C T C C C T G C T C C C T A G C T C C T C T A A G G A T G T G C C T C T T A C C A T C A A IE)
      (HUMGFP40H-ACCEPTOR-992 T A A A G G T T C T T A T C T C T C T A T C T A C T T T A G G A A G A T C C A G C T T C C A A G T G C C A C T G C A G T IE)
      (HUMGFP40H-ACCEPTOR-1110 G G A A T C T T C A C T C T G A A A T T T C C C T T G C A G G T G A C C A G T T G T C T C T G T T T G G G C A T T C C C IE)
      (HUMGFP40H-ACCEPTOR-2431 T T C T T T G A A T A A A T C C T T A C T A T T T A C C A G G A C A A C T G C A C C A G A C C A T G C T T C A G T G A G IE)
      (HUMGFP40H-ACCEPTOR-4066 C T C T G T C C T T A T C A A C T T T C A T C C C C A C A G T A T T T T T C C T G T G A A C A G C C A T G C A A C C A A IE)
      (HUMGG-ACCEPTOR-1802 T T A T G T T G T A C C A A T C A C T G T T C T T C A C A G A T C A T T C T C A G C T T C C C A G G C A G A C C C A C T IE)
      (HUMGG-ACCEPTOR-3631 T C T T C A A T T T A A C T T T C A C A T T T C T T T C A G G A A T A A C A T T G C C A A A C G T C A C G A T G A A T T IE)
      (HUMGG-ACCEPTOR-5138 A A A C G C T A A T T T T A A C A C T T A T T T T C T T A G T T T C C C A G A A G A G G T C G C C A T T G T T G A A G A IE)
      (HUMGH-ACCEPTOR-571 T C C C T C T G T T G C C C T C T G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGH-ACCEPTOR-941 G T A G A C C T T G G T G G G C G G T C C T T C T C C T A G G A A G A A G C C T A T A T C C C A A A G G A A C A G A A G IE)
      (HUMGH-ACCEPTOR-986 C C A A A G G A A C A G A A G T A T T C A T T C C T G C A G A A C C C C C A G A C C T C C C T C T G T T T C T C A G A G IE)
      (HUMGH-ACCEPTOR-1154 C A C A G G C C A A T G C C C G T C C T T C C C C T G C A G A A C C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMGH-ACCEPTOR-1572 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A T G G C A G C C C C C G G A C T G G G IE)
      (HUMGHCSA-ACCEPTOR-5465 T C C C T C T G T T G C C C T C T G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGHCSA-ACCEPTOR-5835 G T A G A C C T T G G T G G G C G G T C C T T C T C C T A G G A A G A A G C C T A T A T C C C A A A G G A A C A G A A G IE)
      (HUMGHCSA-ACCEPTOR-6047 G C A C A G C C A A T G C C C G T C C T T C C C C T G C A G A A C C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMGHCSA-ACCEPTOR-6465 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A T G G C A G C C C C C G G A C T G G G IE)
      (HUMGHCSA-ACCEPTOR-13046 C T C C C T T C T T G C C C T C C G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGHCSA-ACCEPTOR-13504 A T G A C T C C C A G A C C T C C T T C T G C T T C T C A G A C T C T A T T C C G A C A T C C T C C A A C A T G G A G G IE)
      (HUMGHCSA-ACCEPTOR-13642 G C A C A G C C A C T G C C G G T C C T T C C C C T G C A G A A C T T A G A G C T G C T C C A C A T C T C C C T G C T G IE)
      (HUMGHCSA-ACCEPTOR-14059 G G T C T C T C C T T C T C T T G C T T C A C T T T G C A G A G G C T G G A A G A C G G C A G C C A C C T G A C T G G G IE)
      (HUMGHCSA-ACCEPTOR-27717 T C C C T C C A T T G C C C T C C G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGHCSA-ACCEPTOR-28101 G T C C T T C T T G G T G G G G G G T C C T T C T C C T A G G A A G A A A C C T A T A T C C C A A A G G A C C A G A A G IE)
      (HUMGHCSA-ACCEPTOR-28313 G C A C A G C C A C T G C C G G T C C T T C C C C T G C A G A A T C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMGHCSA-ACCEPTOR-28732 G A C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A C G G C A G C C G C C G G A C T G G G IE)
      (HUMGHCSA-ACCEPTOR-42394 C T C C C T C T G T T G C C T C C G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGHCSA-ACCEPTOR-42765 A T A G A C C T T G G T G G G C G G T C C T T C T C C T A G G A A G A A G C C T A T A T C C T G A A G G A G C A G A A G IE)
      (HUMGHCSA-ACCEPTOR-42976 G C A C A G C C A C T G C C G G T C C T T C C C C T G C A G A A C C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMGHCSA-ACCEPTOR-43393 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A T G G C A G C C C C C G G A C T G G G IE)
      (HUMGHCSA-ACCEPTOR-50539 T C C C T C C A T T G C C C T C C G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGHCSA-ACCEPTOR-50922 G T C C T T C T T G G T G G G G G G T C C T T C T C C T A G G A A G A A A C C T A T A T C C C A A A G G A C C A G A A G IE)
      (HUMGHCSA-ACCEPTOR-51135 G C A C A G C C A C T G C C G G T C C T T C C C C T G C A G A A T C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMGHCSA-ACCEPTOR-51551 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A C G G C A G C C G C C G G A C T G G G IE)
      (HUMGHN-ACCEPTOR-798 T C C C T C T G T T G C C C T C T G G T T T C T C C C C A G G C T C C C G G A C G T C C C T G C T C C T G G C T T T T G IE)
      (HUMGHN-ACCEPTOR-1166 T C A G A C C T T G G T G G G C G G T C C T T C T C C T A G G A A G A A G C C T A T A T C C C A A A G G A A C A G A A G IE)
      (HUMGHN-ACCEPTOR-1379 C A C A G C C A A T G C C C G T C C T T G C C C C T G C A G A A C C T A G A G C T G C T C C G C A T C T C C C T G C T G IE)
      (HUMGHN-ACCEPTOR-1797 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A T G G C A G C C C C C G G A C T G G G IE)
      (HUMGHVA-ACCEPTOR-741 G G C C T C T C C T T C T C T T C C T T C A C T T T G C A G A G G C T G G A A G A T G G C A G C C C C C G G A C T G G G IE)
      (HUMGPIBAA-ACCEPTOR-3033 G G G A T C C A C T C A A G G C T C C C T T G C C C A C A G G T C C T C A T G C C T C T C C T C C T C T T G C T G C T C IE)
      (HUMGRP78-ACCEPTOR-775 T G C T G A T G T C C C T C T G T C G G G T T T T T G C A G C G T C G G C G T G T T C A A G A A C G G C C G C G T G G A IE)
      (HUMGRP78-ACCEPTOR-1372 G T G T C T G A A A A C A A T A A T T C T T T A A A A T A G G T G G T T G A A A A G A A A A C T A A A C C A T A C A T T IE)
      (HUMGRP78-ACCEPTOR-2145 C A A T A C A C T T A A T T A T C T T T A T C C T T T T A G G T T A C C C A T G C A G T T G T T A C T G T A C C A G C C IE)
      (HUMGRP78-ACCEPTOR-2347 A C A A A A C T T T T C C C T T T T T C A A T C T A A T A G T A C G G C A G C T G C T A T T G C T T A T G G C C T G G A IE)
      (HUMGRP78-ACCEPTOR-2848 G A C A T C A C A G T A A C C A T G T C T T T T T T C T A G G A T C T G T T C C G G T C T A C T A T G A A G C C C G T C IE)
      (HUMGRP78-ACCEPTOR-3371 A A T T A A A A G T T A A A T A A C T T A T C C T T A C A G G T G A C C T G G T A C T G C T T C A T G T A T G T C C C C IE)
      (HUMGRP78-ACCEPTOR-4506 C T A A C A A G T T T T T C T G T A T G T A A C T T C T A G G T G A A A G A C C C C T G A C A A A A G A C A A T C A T C IE)
      (HUMGSHPXG-ACCEPTOR-968 C C G G G T T C T A G C T G C C C T T C T C T C C T G T A G G A G A A C G C C A A G A A C G A A G A G A T T C T G A A T IE)
      (HUMH19-ACCEPTOR-2224 C C C C A C A C G A C T C T C T C G T T C T C C C C A C A G C C A G G T C T C C A G C T G G G G T G G A C G T G C C C A IE)
      (HUMH19-ACCEPTOR-2449 T C T C A C T G C C C C G A C C T C T G T C T T C T A C A G A A C A C C T T A G G C T G G T G G G G C T G C G G C A A G IE)
      (HUMH19-ACCEPTOR-2643 G T G G G A C C T C A A C T C C T T C C C C A T C C A C A G A A A T G G T G C T A C C C A G C T C A A G C C T G G G C C IE)
      (HUMH19-ACCEPTOR-2846 C C C A T C C C A C C C A C G T G T C G C T A T C T C T A G G T G A A G C T A G A G G A A C C A G A C C T C A T C A G C IE)
      (HUMHBA4-ACCEPTOR-6885 C C C C A C C C C T C A C T C T G C T T C T C C C C G C A G G A T G T T C C T G T C C T T C C C C A C C A C C A A G A C IE)
      (HUMHBA4-ACCEPTOR-7232 T G G G C C G C A C T G A C C C T C T T C T C T G C A C A G C T C C T A A G C C A C T G C C T G C T G G T G A C C C T G IE)
      (HUMHBA4-ACCEPTOR-10696 C C C C A C C C C T C A C T C T G C T T C T C C C C G C A G G A T G T T C C T G T C C T T C C C C A C C A C C A A G A C IE)
      (HUMHBA4-ACCEPTOR-11050 T C G G C C C C A C T G A C C C T C T T C T C T G C A C A G C T C C T A A G C C A C T G C C T G C T G G T G A C C C T G IE)
      (HUMHBBAG-ACCEPTOR-1466 A C T G T C A A A C T G T T C T T G T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (HUMHBBAG-ACCEPTOR-2565 C A T C T T T A T T G T C T C C T T T C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C C G T T T T G IE)
      (HUMHBBGG-ACCEPTOR-2363 A C T G T C A A A C T G T T C T T G T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (HUMHIAPPA-ACCEPTOR-959 T T G A T T T C A G T G C T G G A T T A T T C T T T G C A G A A A A T T T G A G A A G C A A T G G G C A T C C T G A A G IE)
      (HUMHIAPPA-ACCEPTOR-5862 T A A C T T T T C A C A T T T G T T C C A T G T T A C C A G T C A T C A G G T G G A A A A G C G G A A A T G C A A C A C IE)
      (HUMHMG14A-ACCEPTOR-1361 G C C T C T A T T C G T G C G T C T C C G T C T C C G C A G G T C A G C T C C G C C G A A G G C G C C G C C A A G G A A IE)
      (HUMHMG14A-ACCEPTOR-1487 C T C G C T G A C T C T C C T T T T T C T T T C T C C A A G C C C A A G A G G A G A T C G G C G C G G T T G T C A G C T IE)
      (HUMHMG14A-ACCEPTOR-1599 A G G A C G C T C A G T G C T G C T T T T G C C T T T C A G A A A C C T C C T G C A A A A G T G G A A G C G A A G C C G IE)
      (HUMHMG14A-ACCEPTOR-4663 T A C T T A A A A T A T A T T C T T A T T C T A T C A T A G G A T A A A T C T T C A G A C A A A A A A G T G C A A A C A IE)
      (HUMHMG14A-ACCEPTOR-6789 C T A A A G A T C T C A A T T T C C T T T C T T T T G C A G A G T C C A G C C T C T G A T G A A G C A G G A G A G A A A IE)
      (HUMHPARS1-ACCEPTOR-2519 T T T C C A C T C C T C C T T G T C T T C T C T C T G C A G T G C C C T G G G A G C T G T C A T T G C C C T C C T G C T IE)
      (HUMHPARS1-ACCEPTOR-2888 G C A A A C T C T C T G G C T T C T C T C T C T T T G C A G A T G A C G G C T G C C C G A A G C C C C C C G A G A T T G IE)
      (HUMHPARS1-ACCEPTOR-3750 C T T T G G C T C A T T T C T T G C C T T T T G T T T C A G G A G T A T A C A C C T T A A A T G A T A A G A A G C A G T IE)
      (HUMHPARS1-ACCEPTOR-4612 G C A A A C T C T C T G G C T T C T C T C T C T T T G C A G A T G A C G G C T G C C C G A A G C C C C C C G A G A T T G IE)
      (HUMHPARS1-ACCEPTOR-5472 C T T T G G C T C A C T T C T T G C C T T T T G T T T C A G G A G T G T A C A C C T T A A A C A A T G A G A A G C A G T IE)
      (HUMHPARS1-ACCEPTOR-6470 C A C T C A C G A G T G T C T T G C T C T C C T T G A C A G T A T G T G G G A A G C C C A A G A A T C C G G C A A A C C IE)
      (HUMHPRTB-ACCEPTOR-14750 C T C A T T G A A A C A G C T A T A T T T C T T T T T C A G A T T A G T G A T G A T G A A C C A G G T T A T G A C C T T IE)
      (HUMHPRTB-ACCEPTOR-16573 T C T A T T A A A T T C C T G A T T T T A T T T C T G T A G G A C T G A A C G T C T T G C T C G A G A T G T G A T G A A IE)
      (HUMHPRTB-ACCEPTOR-27861 T A T A T A T A T A G T T T T T T T T T T T T T A A C T A G A A T G A C C A G T C A A C A G G G G A C A T A A A A G T A IE)
      (HUMHPRTB-ACCEPTOR-31587 T A C T G A T T T T C A T T T C T C T T T T T C T T C T A G A A T G T C T T G A T T G T G G A A G T A A G T T C A C A T IE)
      (HUMHPRTB-ACCEPTOR-34907 A A A G C T A T G C A A T G T C T T C T T T T T T G A A A G G A T A T A A T T G A C A C T G G C A A A A C A A T G C A G IE)
      (HUMHPRTB-ACCEPTOR-39785 A T G T T A T A T G T C A C A T T T T G T A A T T A A C A G C T T G C T G G T G A A A A G G A C C C C A C G A A G T G T IE)
      (HUMHPRTB-ACCEPTOR-40003 A T C T A A A T G A T G A A T T A T G A T T C T T T T T A G T T G T T G G A T T T G A A A T T C C A G A C A A G T T T G IE)
      (HUMHPRTB-ACCEPTOR-41424 A A A T G T G A A T T T C T G G A T T T T T T T T T A T A G C A T G T T T G T G T C A T T A G T G A A A C T G G A A A A IE)
      (HUMHSP90B-ACCEPTOR-2605 C T T T T G T A A T T A A T G A G A T T T T T A T T T T A G A T G C C T G A G G A A G T G C A C C A T G G A G A G G A G IE)
      (HUMHSP90B-ACCEPTOR-3351 G C A A A A G T A A G T T G C T G T T T G T A T T T C C A G G C C T T G G A C A A G A T T C G C T A T G A G A G C C T G IE)
      (HUMHSP90B-ACCEPTOR-3649 A C T T G T G A T T G A C T T T A A A C T T G T T G G C A G G C T G G T G C A G A C A T C T C C A T G A T T G G G C A G IE)
      (HUMHSP90B-ACCEPTOR-3995 C T G T T A C A C G C T T G T A A T T G A C T C T T C T A G G T G A G C C C A T T G G C A G G G G T A C C A A A G T G A IE)
      (HUMHSP90B-ACCEPTOR-4265 C C A A G G C T A A C T T C T G T T T T T G T T A C T T A G T T G G A G A A G G A A C G A G A G A A G G A A A T T A G T IE)
      (HUMHSP90B-ACCEPTOR-5022 A A T G T A C C A C T T A T T T T T G G T T T C T T T C A G C A C T T T T C T G T A G A A G G T C A G T T G G A A T T C IE)
      (HUMHSP90B-ACCEPTOR-5391 A C T G A G C T T T C T C A C C C T G G T T G A T G G C A G A T T T T A T C C G T G G T G T G G T T G A C T C T G A G G IE)
      (HUMHSP90B-ACCEPTOR-5710 G G A T T G T T T T T C C T C T T C C C A C C C T T C A A G C T T G G A A T C C A C G A A G A C T C C A C T A A C C G C IE)
      (HUMHSP90B-ACCEPTOR-5972 A G T C A C T G A G T T C A T T T A A T T A C C C T A C A G G T G A G A G C A A A G A G C A G G T G G C C A A C T C A G IE)
      (HUMHSP90B-ACCEPTOR-7018 T C A A T C T A A G G C T T T T G T G A T C G T C C A C A G G T G A C A A T C T C C A A T A G A C T T G T G T C T T C A IE)
      (HUMHSP90B-ACCEPTOR-7462 C A A G T C T C A C A T G G C T T A A T T T T A C T T C A G G T A T T G A T G A A G A T G A A G T G G C A G C A G A G G IE)
      (HUMHST-ACCEPTOR-3478 G C C C C G C A A T G A C C T G C G C C C C G C C C C C A G G C C T G C T G G A G C T C T C G C C C G T G G A G C G G G IE)
      (HUMHST-ACCEPTOR-4120 C A G C C C T G A C A C T G C C C T G C T T T G C T G C A G C C C T T C T T C A C C G A T G A G T G C A C G T T C A A G IE)
      (HUMIFNINI-ACCEPTOR-2785 A C C T T C T C T G C T G T T C C T C T T T T C C T A C A G G A G T A C C T C T C T C T A G A A C T G T A C G C T G T A IE)
      (HUMIFNINI-ACCEPTOR-3147 A A A T A T T T T C A T C C C T A T T T A T T T C T A C A G T G C T A C A A T G A A A A A G A A G G G T G A G A A G A G IE)
      (HUMIFNINI-ACCEPTOR-3654 C A C T T T T A T A T C C C C T T T C T C T T C T T A C A G G T C T A A A A G A T C T C C T T A A A A C C A G A G G G G IE)
      (HUMIL1B-ACCEPTOR-879 G A A G T C A C T C A T T T T C T C C T T T T T A C A C A G G T G T C T G A A G C A G C C A T G G C A G A A G T A C C T IE)
      (HUMIL1B-ACCEPTOR-1506 A A T T G A G A C A T G T C C C T G T T T T T A T T A C A G T G G C A A T G A G G A T G A C T T G T T C T T T G A A G C IE)
      (HUMIL1B-ACCEPTOR-3546 A C C A G G C T C C C T C C C T C G C T C T C T C C G C A G T G C T C C T T C C A G G A C C T G G A C C T C T G C C C T IE)
      (HUMIL1B-ACCEPTOR-4293 T A C C T A A A C A A C A T G T G C T C C A C A T T T C A G A A C C T A T C T T C T T C G A C A C A T G G G A T A A C G IE)
      (HUMIL1B-ACCEPTOR-5693 C C T A A C C A C A A G A C C C C C T T C T T T C T T C A G T G G T G T T C T C C A T G T C C T T T G T A C A A G G A G IE)
      (HUMIL1B-ACCEPTOR-6540 C A C A A A A A T T C T T C T T T C T C T T T C G T G C A G A G T G T A G A T C C C A A A A A T T A C C C A A A G A A G IE)
      (HUMIL2-ACCEPTOR-685 T C T T A A T A A C A A T G C A T T A T A C T T T C T T A G A A T T A C A A G A A T C C C A A A C T C A C C A G G A T G IE)
      (HUMIL2-ACCEPTOR-3038 A A A C T G A G C T G A T G A T A A T T A T T A T T C T A G G C C A C A G A A C T G A A A C A T C T T C A G T G T C T A IE)
      (HUMIL2-ACCEPTOR-5027 C T T T A A A A A A T T A A C A T T T T T C T T T T A T A G G G A T C T G A A A C A A C A T T C A T G T G T G A A T A T IE)
      (HUMIL2A-ACCEPTOR-1623 T C T T A A T A A C A A T G C A T T A T A C T T T C T T A G A A T T A C A A G A A T C C C A A A C T C A C C A G G A T G IE)
      (HUMIL2A-ACCEPTOR-3975 A A A C T G A G C T G A T G A T A A T T A T T A T T C T A G G C C A C A G A A C T G A A A C A T C T T C A G T G T C T A IE)
      (HUMIL2A-ACCEPTOR-5980 C T T T A A A A A A T T A A C A T T T T T C T T T T A T A G G G A T C T G A A A C A A C A T T C A T G T G T G A A T A T IE)
      (HUMIL2B-ACCEPTOR-500 T C T T A A T A A C A A T G C A T T A T A C T T T C T T A G A A T T A C A A G A A T C C C A A A C T C A C C A G G A T G IE)
      (HUMIL2B-ACCEPTOR-2852 A A A C T G A G C T G A T G A T A A T T A T T A T T C T A G G C C A C A G A A C T G A A A C A T C T T C A G T G T C T A IE)
      (HUMIL2B-ACCEPTOR-4857 C T T T A A A A A A T T A A C A T T T T T C T T T T A T A G G G A T C T G A A A C A A C A T T C A T G T G T G A A T A T IE)
      (HUMIL5-ACCEPTOR-875 A A A A A T G A T T G T A T T T C C T T T C C T C T C C A G A C T C T G A G G A T T C C T G T T C C T G T A C A T A A A IE)
      (HUMIL5-ACCEPTOR-1853 A T T T G C A T T T T A A A A A T T T T C C T C A T T T A G C A C C A A C T G T G C A C T G A A G A A A T C T T T C A G IE)
      (HUMIL5-ACCEPTOR-2088 A T A C C T A T T G T C A T T T T T C T T T T T T C A C A G A A A A A G T G T G G A G A A G A A A G A C G G A G A G T A IE)
      (HUMIL5A-ACCEPTOR-874 A A A A A T G A T T G T A T T T C C T T T C C T C T C C A G A C T C T G A G G A T T C C T G T T C C T G T A C A T A A A IE)
      (HUMIL5A-ACCEPTOR-1857 A T T T G C A T T T T A A A A A T T T T C C T C A T T T A G C A C C A A C T G T G C A C T G A A G A A A T C T T T C A G IE)
      (HUMIL5A-ACCEPTOR-2091 A T A C C T A T T G T C A T T T T T C T T T T T T C A C A G A A A A A G T G T G G A G A A G A A A G A C G G A G A G T A IE)
      (HUMINCP-ACCEPTOR-2049 G G G C G C T G T C C T G T T T T C T C C T G T G T G C A G A C C G T T G G G G G G G T G A A T T A C T T C T T C G A C IE)
      (HUMINCP-ACCEPTOR-3281 C T G A T T G G C C C T C T C T C T T C C C T T T C A C A G A A A C A G T T G T G C T C T T T C G A G A T C T A C G A A IE)
      (HUMINCPPS-ACCEPTOR-2712 T G T G A A T G T G G A G T T A T A T G T G T A C A T A C A T G T A T G T G G G G G T G G T A T G C A T A T A T G G G T IE)
      (HUMINCPPS-ACCEPTOR-4028 A A C T T G G A C A C C T G T G C C T T C C A T G A A C A G C C A G A A C T G C A G A A G A A A C A G T T G T G C T C T IE)
      (HUMIRBPG-ACCEPTOR-4936 G A C A C T G A G T A G G A C C T C C A A C T C T T A C A G A T C C C T T C C C C T G A A G T A T T T G A A G A G C T G IE)
      (HUMIRBPG-ACCEPTOR-6987 C C T G A A C A G G C T C T G C T T C C C A T C C T T C A G G T T C A A C A T C G G T G G C C C C A C A T C C T C C A T IE)
      (HUMIRBPG-ACCEPTOR-8736 C C C C A T C C T G A A G G G C C T T A T G T C T T C C A G G T G A A C G C T A T G G C T C C A A G A A G A G C A T G G IE)
      (HUMKAL2-ACCEPTOR-1745 G A T C C C C C T G A C C C A G C A C C C C C T C C G C A G G T G C C G T G C C C C T C A T C C A G T C T C G G A T T G IE)
      (HUMKAL2-ACCEPTOR-3494 T C C T C A T G C A T C C A C C C C C T T C C T C C C C A G G A A T A G C C A G G T C T G G C T G G G T C G G C A C A A IE)
      (HUMKAL2-ACCEPTOR-3894 G C C A C A G C C C A G T T T T T C T C T G A C C C A T A G T C T T G C G C C C C A G G A G T C T T C A G T G T G T G A IE)
      (HUMKAL2-ACCEPTOR-5424 C T C A C T G T G T C T C T C C T C C T T T A C C C T T A G G G T G A T T C T G G G G G T C C A C T T G T C T G T A A T IE)
      (HUMKER18-ACCEPTOR-3708 T G G A A C A A C C T C T C T C T A C A A T C C C T C C A G A T C T T C G C A A A T A C T G T G G A C A A T G C C C G C IE)
      (HUMKER18-ACCEPTOR-4128 G G G C C C C T C T G A T C A C C T C C A C T C C T A T A G G T A T G A G A C A G A G C T G G C C A T G C G C C A G T C IE)
      (HUMKER18-ACCEPTOR-4857 C C T C C T C A C T T T T G C C C C T G T C A C C T T T A G G A A G T A A A A G G C C T A C A A G C C C A G A T T G C C IE)
      (HUMKER18-ACCEPTOR-5107 G G G G C C T G A T G G A C T G T C C C C A T C C T G C A G A T T G A G G A G A G C A C C A C A G T G G T C A C C A C A IE)
      (HUMKER18-ACCEPTOR-5495 A C C C T G C C C C T C C T C T C T G T G C C C C T G C A G A A G G C C A G C T T G G A G A A C A G C C T G A G G G A G IE)
      (HUMKER18-ACCEPTOR-6098 T T A T A A C T T G G G C T T G G T C T T C T G T T A C A G T C T T G G T G A T G C C T T G G A C A G C A G C A A C T C IE)
      (HUMKEREP-ACCEPTOR-2070 C A A A T T A C C T G T G C C T T T T C C A T C C T G C A G A T T C T C A C A G C C A C A G T G G A C A A T G C C A A T IE)
      (HUMKEREP-ACCEPTOR-2715 T C T C A T A C C T T T T C T C T G G G G T C A T T C C A G G T A T G A G A C A G A G T T G A A C C T G C G C A T G A G IE)
      (HUMKEREP-ACCEPTOR-3206 T C C T G A C T G T G G A C T G T C C C T G G C T T G C A G G A G A T G A A T G C C C T G A G A G G C C A G G T G G G T IE)
      (HUMKEREP-ACCEPTOR-3451 C T G G T G T G A A T G G C A T T C T C T T T T T T G C A G A C A G A G G A G C T G A A C C G C G A G G T G G C C A C C IE)
      (HUMKEREP-ACCEPTOR-3671 T A A T C G T T G A T T C C C T T C C C T C C C T C A C A G A A A G C A T C C C T G G A G A A C A G C C T G G A G G A G IE)
      (HUMKEREP-ACCEPTOR-3986 T A A T G A T C C T G T C C T T T T C T A T T T T C A C A G C C T C T C C T C C T C C C A G T T C T C C T C T G G A T C IE)
      (HUMKEREP-ACCEPTOR-4597 G G T A A C G T C C T C T T C C C A C C T C T T C C C C A G T G A C C T C C T C C A G C C G C C A A A T C C G C A C C A IE)
      (HUMLACTA-ACCEPTOR-1512 T G T G G T A T C T C T T T C T C A T C T T T C C C T C A G T G A T C T G T A C C A T G T T T C A C A C C A G T G G T T IE)
      (HUMLACTA-ACCEPTOR-2160 T C T C A A T C C T T T C C C T G T A A C T C C T G C C A G A G T T C C T G G A T G A T G A C A T T A C T G A T G A C A IE)
      (HUMLACTA-ACCEPTOR-2735 A C T C A C C T T G T C C C C C T T C T C C A T T A T C A G G T T G G C C C A T A A A G C C C T C T G C A C T G A G A A IE)
      (HUMLYL1B-ACCEPTOR-2189 C C A C T G G C T G C C T T C T T T C C C A C A G G T G A G T A C C C C C A C G T C G G G G T C C A T G T G C C C G C C IE)
      (HUMLYL1B-ACCEPTOR-2630 A A G G A C T T A G T G A C C C A C G A C C C C T T A C A G T G T C T A C A T T G G G C C A G C A G G A C C T T T T A G IE)
      (HUMLYL1B-ACCEPTOR-3525 T G G C A C C A A C C C G G C C C T C C T T G T C C A C A G G G C A C C A G C C C C A G A A G G T G G C C C G G C G C G IE)
      (HUMMETIF1-ACCEPTOR-1065 C T C A C T G G C T T T T T T T T C T C T T T C T C G C A G G T G T C T C C T G C A C C T G C G C T G G T T C C T G C A IE)
      (HUMMETIF1-ACCEPTOR-1463 G T G A C C T C T C A T G C T C C T C T T C T T C C C C A G G C T G C T G C T C C T G C T G C C C C G T G G G C T G T A IE)
      (HUMMH6-ACCEPTOR-955 G G G C G G G T C T C A A C C C C T C C T C G C C C C C A G G C T C C C A C T C C A T G A G G T A T T T C A G C G C C G IE)
      (HUMMH6-ACCEPTOR-1451 G G G C G G G G C T G A C C G A G G G G G T G G G G C C A G G T T C T C A C A C C C T C C A G T G G A T G A T T G G C T IE)
      (HUMMH6-ACCEPTOR-2326 G T G C T T G A A T T T T C T G A C T C T T C C T T T C A G A C C C C C C C A A G A C A C A C G T G A C C C A C C A C C IE)
      (HUMMH6-ACCEPTOR-2724 A G A G A C C C T C A C C T T C A C C T C C T T T C C C A G A G C A G T C T T C C C T G C C C A C C A T C C C C A T C A IE)
      (HUMMH6-ACCEPTOR-3284 G G C C T C T C A C A G G A C A T T T T C T T C C C A C A G A T T G A A A A G G A G G G A G C T A C T C T C A G G C T G IE)
      (HUMMH6-ACCEPTOR-3562 G T G G G T T G T T G A G G G G A A C A G G G G A C A T A G C T G T G C T A T G A G G T T T C T T T G A C T T C A A T G IE)
      (HUMMH6-ACCEPTOR-3673 A T G A A T T T G T T C A T G A A T A T T T T T C T G T A G T G T G A A A C A G C T G C C C T G T G T G G G A C T G A G IE)
      (HUMMHANTLE-ACCEPTOR-1363 G G G C G G G T C T C A G C T C C T C C T C G C T C C C A G G C T C C C A C T C C A T G A G G T A T T T C T A C A C C A IE)
      (HUMMHANTLE-ACCEPTOR-1874 G G G A C C G G G C T G A C C G C G G G G G C G G G C C A G G T T C T C A C A C C A T G C A G G T G A T G T A T G G C T IE)
      (HUMMHANTLE-ACCEPTOR-2733 A T G C C T G A A T T T T C T G A C T C T T C C T G T C A G A C C C C C C C A A G A C A C A T A T G A C C C A C C A C C IE)
      (HUMMHANTLE-ACCEPTOR-3110 A G G G T C C C T C A C C T T C C C C C C T T T T C C C A G A G C C A T C T T C C C A G C C C A C C A T C C C C A T C G IE)
      (HUMMHANTLE-ACCEPTOR-3667 G G C A T C T C A C A G G A C A T T T T C T T C C C A C A G A T A G A A A A G G A G G G A G C T A C T C T C A G G C T G IE)
      (HUMMHANTLE-ACCEPTOR-3842 T G A C C A G G T C C T G T T T T T A T T C T A C T C C A G G C G G C A A C A G T G C C C A G G G C T C T G A T G T G T IE)
      (HUMMHANTLE-ACCEPTOR-4055 T G A A T T T G T T C A T G A A T A T T T T T T C T A T A G T G T G A G A C A G C T G C C T T G T G T G G G A C T G A G IE)
      (HUMMHB27B-ACCEPTOR-690 G G G C G G G T C T C A G C C C C T C C T C G C C C C C A G G C T C C C A C T C C A T G A G G T A T T T C C A C A C C T IE)
      (HUMMHB27B-ACCEPTOR-1202 D G A C G G G G C T G A C C G C G G G G G C G G G T C C A G G G T C T C A C A C C C T C C A G A A T A T G T A T G G C T IE)
      (HUMMHB27B-ACCEPTOR-2053 G C G C C T G A A T T T T C T G A C T C T T C C C A T C A G A C C C C C C A A A G A C A C A C G T G A C C C A C C A C C IE)
      (HUMMHB27B-ACCEPTOR-2421 A G G G C C C C T C A T C T T C C C T T C C T T T C C C A G A G C C G T C T T C C C A G T C C A C C G T C C C C A T C G IE)
      (HUMMHB27B-ACCEPTOR-2980 T C C C C T C A C A G G G A A A T T T T C T T C C C A C A G G T G G A A A A G G A G G G A G C T A C T C T C A G G C T G IE)
      (HUMMHB27B-ACCEPTOR-3119 T G A C C A G G T C C T G T T T T T G T T C T A C T C C A G G C A G C G A C A G T G C C C A G G G C T C T G A T G T G T IE)
      (HUMMHCD8A-ACCEPTOR-733 T T G C T C A G C C T C G C T G C T T G C C T C C T G C A G A C G C C G C C A G G C C G A G C C A G T T C C G G G T G T IE)
      (HUMMHCD8A-ACCEPTOR-1670 G C C C C C A A C C A C G C T C T G T T G C T C T T G C A G C G A A G C C C A C C A C G A C G C C A G C G C C G C G A C IE)
      (HUMMHCD8A-ACCEPTOR-1987 C C T A A A T G T C G G C G T C T T T G G T G T C G T C A G T G C A C A C G A G G G G G C T G G A C T T C G C C T G T G IE)
      (HUMMHCD8A-ACCEPTOR-2860 T C A C T T T T T C C C T T C T T T T T C C T T A T C C A G G G A A C C G A A G A C G T G T T T G C A A A T G T C C C C IE)
      (HUMMHCD8A-ACCEPTOR-5474 T A C A A T G A T G G T C G C T T T C C T C T C T T T C A G G C C T G T G G T C A A A T C G G G A G A C A A G C C C A G IE)
      (HUMMHCP42-ACCEPTOR-1945 T C C G C T G A C G C T G C T T T G G C T G T C T C C C A G A T G T G G T G G T G C T G A A C T C C A A G A G G A C C A IE)
      (HUMMHCP42-ACCEPTOR-2316 C C A C C C T C C A G C C C C C A C C T C C T C C T G C A G A C A A G C T G G T G T C T A A G A A C T A C C C G G A C C IE)
      (HUMMHCP42-ACCEPTOR-2577 G C C T G C T G A A C T C A C A C T G T T T C T C C A C A G C G C A T G A G A G C C C A G C C C G G C A C C C C T G T G IE)
      (HUMMHCP42-ACCEPTOR-2767 A A C T G A A A G T A C T C C C T C C T T T T C T G G C A G G A C G A C A A C T T A A T G C C T G C C T A T T A C A A A IE)
      (HUMMHCP42-ACCEPTOR-2970 A C A G C T G C A T T C T C A T G C T T C C T G C C G C A G T T C T T C C C C A A T C C A G G T C T C C G G A G G C T G IE)
      (HUMMHCP42-ACCEPTOR-3226 C G C T C A G C C C G C T C C T T T C A C C C T C T G C A G G A G A G C C T C G T G G C A G G C C A G T G G A G G G A C IE)
      (HUMMHCP42-ACCEPTOR-3627 G G G G C A G G A C T C C A C C C G A T C A T T C C C C A G A T T C A G C A G C G A C T G C A G G A G G A G C T A G A C IE)
      (HUMMHCP42-ACCEPTOR-3889 T G G C C A G C C T C T A A C T C C A G C C C C C T T C A G C A T C T C C G G C T A C G A C A T C C C T G A G G G C A C IE)
      (HUMMHCP42-ACCEPTOR-4089 C T C C C C A C C C A C C T G T C C A C C C G C C C G C A G A T C G C T T C C T G G A G C C A G G C A A G A A C T C C A IE)
      (HUMMHCP52-ACCEPTOR-479 T C C G C T G A C G C T G C T T T G G C T G T C T C C C A G A T G T G G T G G T G C T G A A C T C C A A G A G G A C C A IE)
      (HUMMHCP52-ACCEPTOR-851 C C A C C C T C C A G C C C C C A A C T C C T C C T G C A G A C A A G C T G G T G T C T A A G A A C T A C C C G G A C T IE)
      (HUMMHCP52-ACCEPTOR-1114 C C T G C T G G A A C T C A C A C T G T T T C T C C A C A G C G C A T G A G A G C C C A G C C C G G C A C C C C T G T G IE)
      (HUMMHCP52-ACCEPTOR-1304 A A C T G A A A G T A C T C C C T C C T T T T C T G G C A G G A C G A C A A C T T A A T G C C T G C C T A T T A C A A A IE)
      (HUMMHCP52-ACCEPTOR-1507 A C A G C T G C A T T C T C A T G C T T C C T G C C G C A G T T C T T C C C C A A T C C A G G T C T C C G G A G G C T G IE)
      (HUMMHCP52-ACCEPTOR-1763 C G C T C A G C C C G C T C C T T T C A C C C T C T G C A G G A G A G C C T C G T G G C A G G C C A G T G G A G G G A C IE)
      (HUMMHCP52-ACCEPTOR-2165 G G G G C A G G A C T C C A C C C G A T C A T T C C C C A G A T T C A G C A G C G A C T G C A G G A G G A G C T A G A C IE)
      (HUMMHCP52-ACCEPTOR-2427 T G G C C A G C C T C T A A C T C C A G C C C C C T T C A G C A T C T C T G G C T A C G A C A T C C C T G A G G G C A C IE)
      (HUMMHCP52-ACCEPTOR-2628 C T C C C C A C C C A C C T G T C C A C C C G C C C G C A G A T C G C T T C C T G G A G C C A G G C A A G A A C T C C A IE)
      (HUMMHCW1B-ACCEPTOR-882 G G G C G G G T C T C A G C C C C T C C T C G C C C C C A G G C T C C C A C T C C A T G A A G T A T T T C T T C A C A T IE)
      (HUMMHCW1B-ACCEPTOR-1398 G G A C G G G G C T G A C C A C G G G G G C G G G G C C A G G G T C T C A C A C C C T C C A G T G G A T G T G T G G C T IE)
      (HUMMHCW1B-ACCEPTOR-2261 G T G T C T G A A T T T T C T G A C T C T T C C C G T C A G A A C A C C C A A A G A C A C A C G T G A C C C A C C A T C IE)
      (HUMMHCW1B-ACCEPTOR-2658 A G G G C C C C T C A C C T T C C C C T C C T T T C C C A G A G C C G T C T T C C C A G C C C A C C A T C C C C A T C G IE)
      (HUMMHCW1B-ACCEPTOR-3217 G T C C C C T C A C A G G G C A T T T T C T T C C C A C A G G T G G A A A A G G A G G G A G C T G C T C T C A G G C T G IE)
      (HUMMHCW1B-ACCEPTOR-3357 G A C C A G G T C T T T T T T T T T G T T C T A C C C C A G C C A G C A A C A G T G C C C A G G G C T C T G A T G A G T IE)
      (HUMMHCW1B-ACCEPTOR-3569 G A A T T T G T T C A T G A C T A T T G T G T T C T G T A G C C T G A G A C A G C T G C C T G T G T G G G A C T G A G A IE)
      (HUMMHCW2B-ACCEPTOR-885 G G G C G G G T C T C A G C C C C T C C T C T C C C C C A G G C T C C C A C T C C A T G A G G T A T T T C T A C A C C G IE)
      (HUMMHCW2B-ACCEPTOR-1399 G G G A C G G G C T G A C C A C G G G G G C G G G G C C A G G G T C T C A C A C C C T C C A G A G G A T G T A C G G C T IE)
      (HUMMHCW2B-ACCEPTOR-2263 T G T C T G A A T T T T C T G A C T C T T C C C G T G C A G A A C A C C C A A A G A C A C A C G T G A C C C A C C A T C IE)
      (HUMMHCW2B-ACCEPTOR-2660 A G G G C C C C T C A C C T T C C C C T C C T T T C C C A G A G C C A T C T T C C C A G C C C A C C A T C C C C A T C G IE)
      (HUMMHCW2B-ACCEPTOR-3219 G T C C C C T C A C A G G G C A T T T T C T T C C C A C A G G T G G A A A A G G A G G G A G C T G C T C T C A G G C T G IE)
      (HUMMHCW2B-ACCEPTOR-3359 G A C C A G G T C T T T T T T T T T G T T C T A C C C C A G C C A G C A A C A G T G C C C A G G G C T C T G A T G A G T IE)
      (HUMMHCW2B-ACCEPTOR-3570 G A A T T T G T T C A T G A C T A T T G T G T T C T G T A G C C T G A G A C A G C T G C C T G T G T G G G A C T G A G A IE)
      (HUMMHDOB-ACCEPTOR-2649 T G G T T C A T G G T T T T G G T T T T G G T T T T C C A G A A G A T T T T G T G A T T C A G G C A A A G G C T G A C T IE)
      (HUMMHDOB-ACCEPTOR-3357 C A C G G T G T C T C A T T T T T C C T C C C T T C C T A G T G C A A C C A G A G G T G A C A G T G T A C C C A G A G A IE)
      (HUMMHDOB-ACCEPTOR-4124 T T T A C T A A T T T A A A G A C C T G T T T C C C A T A G G A G C T C A G T C T G A A T A T T C T T G G A G A A A G A IE)
      (HUMMHDOB-ACCEPTOR-4486 C A A T C C A T T C T T T T C T C G A T T T C T T T C C A G G A T A T G T G A G G A C G C A G A T G T C T G G T A A T G IE)
      (HUMMHDOB-ACCEPTOR-4706 C T C C T G A G A C C T T C A T C A C T G T G C C T C C A G G T C T C A A G A G C T G T T C T G C T C C C T C A G T C A IE)
      (HUMMHDRHA-ACCEPTOR-2969 A A C T C T C T T T C T C C A T T T C T T G C C T T T C A G A A G A A C A T G T G A T C A T C C A G G C C G A G T T C T IE)
      (HUMMHDRHA-ACCEPTOR-3705 A T T C T G T C A C G T C T G T C A T G T G T C C C C C A G T A C C T C C A G A G G T A A C T G T G C T C A C G A A C A IE)
      (HUMMHDRHA-ACCEPTOR-4276 T A C C A T G T A C T C T G C C T T A T C T C C C C C C A G A G T T T G A T G C T C C A A G C C C T C T C C C A G A G A IE)
      (HUMMHDRHA-ACCEPTOR-5181 T C C T T G G T A A C T A T G T G T G T C T T G C T A T A G G T G A T G G T G T T T C T T A G A G A G A A G A T C A C T IE)
      (HUMMHEA-ACCEPTOR-869 G G G C C G A T C T C A G C C C C T C C T C G C C C C C A G G C T C C C A C T C C T T G A A G T A T T T C C A C A C T T IE)
      (HUMMHEA-ACCEPTOR-1381 T G G G C G G G A C T G A C T A A G G G G C G G G G C C A G G G T C T C A C A C C C T G C A G T G G A T G C A T G G C T IE)
      (HUMMHEA-ACCEPTOR-2278 G T G C C T G A A T T T T C T G A C T C T T C C C C T C A G A G C C C C C A A A G A C A C A C G T G A C T C A C C A C C IE)
      (HUMMHEA-ACCEPTOR-2678 A G G G C C C C T T A C G T T C C C C T C T T T T C C C A G A G C C G G C T T C C C A G C C C A C C A T C C C C A T C G IE)
      (HUMMHEA-ACCEPTOR-3545 G G C C C C T C A C A G G A C A T T T T C T T C C A A C A G G T G G A A A A G G A G G G A G C T A C T C T A A G G C T G IE)
      (HUMMHEA-ACCEPTOR-3682 T G A C C A G G T C T T G T T T T T G T T C T A C C C C A G G G A G C G A C A G T G C C C A G G G G T C T G A G T C T C IE)
      (HUMMHEA-ACCEPTOR-3890 G A A T T T G T T C A T G A C T A T T T T C T T C T G T A G C C T G A G A C A G C T G C C T T G T G T G C G A C T G A G IE)
      (HUMMIS-ACCEPTOR-1185 C T C A G G C G T C C C C T G C T G T C C C G G C T G C A G T G A C C T G G G A G C C A A C A C C C T C G C T G A G G T IE)
      (HUMMIS-ACCEPTOR-1500 T C C A G C C G G G C T G A G C C C T G G T C T C C G C A G A G C C T C T G C C C C T C C C G A G A C A C C C G C T A C IE)
      (HUMMIS-ACCEPTOR-1697 C T G A G C C A G C C G C G T G C C C A C C C A C C G C A G A C T C C C G G C T G A G T A C C G C C C G G C T G C A G G IE)
      (HUMMIS-ACCEPTOR-1947 G C T C T C A A C T C C T C C A A T T G C G G G T T C C A G G C C A T C C G C G G A A C T C G A G G A G T C G C C A C C IE)
      (HUMMRP14A-ACCEPTOR-1386 T G T C C C A A C T C T T G G T T T T C C A T T A C A C A G A C A G A G T G C A A G A C G A T G A C T T G C A A A A T G IE)
      (HUMMRP14A-ACCEPTOR-3418 G C T C T C A C A G C C T T C T C T C C C C A C C C G C A G A A G G A G A A T A A G A A T G A A A A G G T C A T A G A A IE)
      (HUMMRP8A-ACCEPTOR-1988 T G G G A T T C C C C A G A A G G T T C T G T T T T T C A G G T G G G G C A A G T T C C G T G G G C A T C A T G T T G A IE)
      (HUMMRP8A-ACCEPTOR-2302 C T C T G G C T T C T T C C T C C T C A A T C T T G A C A G A A A A A G G G T G C A G A C G T C T G G T T C A A A G A G IE)
      (HUMMT2A-ACCEPTOR-1047 A C C G T T C A C T G G C T T T T T C T C T T C T A G C A G G T G T C T C C T G C A C C T G C G C C A G C T C C T G C A IE)
      (HUMMT2A-ACCEPTOR-1454 C T G A C C T C T C A A T C T C C T T T C C T C C C C A A G G C T G C T G C T C C T G C T G C C C T G T G G G C T G T G IE)
      (HUMMYC3L-ACCEPTOR-766 G G T C A G C A C G T C C C C C C T T C C C T C C C G C A G G G A G C G G A C A T G G A C T A C G A C T C G T A C C A G IE)
      (HUMMYC3L-ACCEPTOR-4242 T T T C T T C T C T T G A T C T C T T T T C T C G G A C A G A G A A T G A A G A A A T T G A T G T T G T G A C A G T A G IE)
      (HUMMYC3L-ACCEPTOR-4242 T T T C T T C T C T T G A T C T C T T T T C T C G G A C A G A G A A T G A A G A A A T T G A T G T T G T G A C A G T A G IE)
      (HUMMYCC-ACCEPTOR-4476 C T G C C T C C C G C T T T G T G T G C C C C G C T C C A G C A G C C T C C C G C G A C G A T G C C C C T C A A C G T T IE)
      (HUMMYCC-ACCEPTOR-6624 A A G G A G T G A T T T C T A T T T C C T T T C T T A A A G A G G A G G A A C A A G A A G A T G A G G A A G A A A T C G IE)
      (HUMMYCRT-ACCEPTOR-1111 C C T C C C G C T T T G T G T G C C C C G C T C C A G C A G C C T C C C G C G A C G A T G C C C C T C A A C G T T A C C IE)
      (HUMMYCRT-ACCEPTOR-3258 A A G G A G T G A T T T C T A T T T C C T T T C T T A A A G A G G A G G A A C A A G A A G A T G A G G A A G A A A T C G IE)
      (HUMMYLCA-ACCEPTOR-924 A T G C T G A C C A C T T C C C T C T T C T C T G A G C A G T G T G A C T T C A C C G A A G A C C A G A C C G C A G G T IE)
      (HUMMYLCA-ACCEPTOR-1831 A T C C T G T G T T G A C A T T C A T C T G A A T C C T A G A G T T C A A G G A G G C C T T C C A G C T G T T T G A C C IE)
      (HUMMYLCA-ACCEPTOR-2214 T G G C C T G A C A C T T C A C C T C C T T T A T G G C A G A G A T G A A T G T G A A G G T G C T G G A C T T T G A G C IE)
      (HUMMYLCA-ACCEPTOR-2481 A T T C C A A A A A T G C T T T C T T T C C C C C T G C A G G T G A G A A G A T G A C A G A G G A A G A A G T A G A G A IE)
      (HUMMYLCA-ACCEPTOR-2864 T C A A C C A T T A A T G T C T C T T C C T T C C T G C A G C G T T T G T G A G G C A T A T C C T G T C G G G G T G A C IE)
      (HUMMYLCA-ACCEPTOR-924 A T G C T G A C C A C T T C C C T C T T C T C T G A G C A G T G T G A C T T C A C C G A A G A C C A G A C C G C A G G T IE)
      (HUMMYLCA-ACCEPTOR-1831 A T C C T G T G T T G A C A T T C A T C T G A A T C C T A G A G T T C A A G G A G G C C T T C C A G C T G T T T G A C C IE)
      (HUMMYLCA-ACCEPTOR-2214 T G G C C T G A C A C T T C A C C T C C T T T A T G G C A G A G A T G A A T G T G A A G G T G C T G G A C T T T G A G C IE)
      (HUMMYLCA-ACCEPTOR-2481 A T T C C A A A A A T G C T T T C T T T C C C C C T G C A G G T G A G A A G A T G A C A G A G G A A G A A G T A G A G A IE)
      (HUMMYLCA-ACCEPTOR-3623 C C T G G C T C A T C C C A C C T T T C C T T T C C A C A G A G C T C G T C C G C A T G G T G C T G A A T G G C T G A G IE)
      (HUMOPS-ACCEPTOR-2409 T G T G C T G A C C G C C T G C T G A C T G C C T T G C A G G T G A A A T T G C C C T G T G G T C C T T G G T G G T C C IE)
      (HUMOPS-ACCEPTOR-3783 G G C A G G G T C T C C C T A C C T G C C T G T C C T C A G G T A C A T C C C C G A G G G C C T G C A G T G C T C G T G IE)
      (HUMOPS-ACCEPTOR-4065 T G G T C T G G A C C C G G G T C C C G T G T C C T G C A G G C C G C T G C C C A G C A G C A G G A G T C A G C C A C C IE)
      (HUMOPS-ACCEPTOR-5138 T G G C C C T G A C T C A A G C C T C T T G C C T T C C A G T T C C G G A A C T G C A T G C T C A C C A C C A T C T G C IE)
      (HUMOTNPI-ACCEPTOR-808 G C G T C C C G C T C A C C C C G C C C G T C C C C C G A G T G C C T C C C C T G C G G C C C C G G G G G C A A A G G C IE)
      (HUMOTNPI-ACCEPTOR-1091 G G A T T C C C C T G A C T C C A C C T C T T C C T C C A G A C G G C T G C C A C G C C G A C C C T G C C T G C G A C G IE)
      (HUMP3A-ACCEPTOR-2544 G C T G C C T C T C T G T G T C C C T T A C C T C C T C A G G G A C A G C C C T G C C A T C A A G G A A G A C A G C A C IE)
      (HUMP45C17-ACCEPTOR-3774 G A T T C C T A C A G C C T T G C C T G C T C T C T A A A G G C A A C T C T A G A C A T C G C G T C C A A C A A C C G T IE)
      (HUMP45C17-ACCEPTOR-4146 T T T C C A C C C T C A T G C C C C C T C T C C C T T C A G T T T G T C A G G A A A T C A G T A C A T T G T G T G A T A IE)
      (HUMP45C17-ACCEPTOR-5038 G G T G G A T T T A A C A T T T C T T T T T A T T T C C A G A T T T T C C C C A A C A A A A C C C T G G A A A A A T T A IE)
      (HUMP45C17-ACCEPTOR-5819 T T A A T G T C T C C C A A A C C T C A C C C A A C C C A G G A G A A A T T C C G G A G T G A C T C T A T C A C C A A C IE)
      (HUMP45C17-ACCEPTOR-6267 T A G T C A C C T C C A A C C T A C T C T G G T C T T C A G G T G A A G A A G A A G C T C T A C G A G G A G A T T G A C IE)
      (HUMP45C17-ACCEPTOR-7334 A C C C A C T T T T C C T C T T C C A C T C T G G A G C A G C A T C G G T G A G T T T G C T G T G G A C A A G G G C A C IE)
      (HUMP45C17-ACCEPTOR-7956 C C C C T G G C T G A T G C C A C T C C T T G C C A G C A G A G C G T T T C T T G A A T C C A G C G G G G A C C C A G C IE)
      (HUMPCNA-ACCEPTOR-2326 A T T T T A A A G C A T G T G T C T C C T G T C T T C T A G T A T G T C C A A A A T A C T A A A A T G C G C C G G C A A IE)
      (HUMPCNA-ACCEPTOR-2520 T C A A A A G C T A T C T G C G T T T C T T T T G G T A A G A C C A G G A G A A A G T T T C A G A C T A T G A A A T G A IE)
      (HUMPCNA-ACCEPTOR-3526 T T A A C T T T T G G A A A A T T T T G T T C T T A A T A G G A A C A G G A G T A C A G C T G T G T A G T A A A G A T G IE)
      (HUMPCNA-ACCEPTOR-5606 T T T T T C A A T G A T G A A T C T T T T G T T T T G T A G G T T A C C A T A G A G A T G A A T G A A C C A G T T C A A IE)
      (HUMPCNA-ACCEPTOR-5816 T C A G T A A T T A A C C A T C T T C C T G T C T T T C A G T T G T A G A G T A T A A A A T T G C G G A T A T G G G A C IE)
      (HUMPGAMMG-ACCEPTOR-1450 G A G G G A A A G C A G C G T G C C T G T G T C C C C C A G G A G C G T C G G T A C G C A G G C C T G A A G C C C G G G IE)
      (HUMPGAMMG-ACCEPTOR-3519 G G C T A A G G A C A C C T A T T C C T T C C G G C A T A G G G A T G T C A G A C C A G G C G A T C A T G G A G C T G A IE)
      (HUMPIM1A-ACCEPTOR-1335 A C T G A G T C C C C G T G C T T C C C C C T T T C C T A G G C A A G G A G A A G G A G C C C C T G G A G T C G C A G T IE)
      (HUMPIM1A-ACCEPTOR-1543 G G G A A C C T G A C G G A G A C C C T G G G C T T C C A G G T G G C C A T C A A A C A C G T G G A G A A G G A C C G G IE)
      (HUMPIM1A-ACCEPTOR-1687 C G C C C T A A C G C G G C C C C C T C G C C C C T G C A G C C T A A T G G C A C T C G A G T G C C C A T G G A A G T G IE)
      (HUMPIM1A-ACCEPTOR-3558 T G T T T T C T C T T C T A T T C C C T T G G C T C A C A G G G A C C C G A G T G T A T A G C C C T C C A G A G T G G A IE)
      (HUMPIM1A-ACCEPTOR-4496 T C A T A A C C T C G T C T A T C C T C C T T T C T G C A G A A T G T C A G C A T C T C A T T A G A T G G T G C T T G G IE)
      (HUMPLAPL-ACCEPTOR-452 T G A C C T G A T C T T T G C T C T C C C C C T G G C C A G T T G A G G A G G A G A A C C C G G A C T T C T G G A A C C IE)
      (HUMPLAPL-ACCEPTOR-681 A G C A A G C C T C A C A C A C T T C T G C T C C T T C A G G G A T G G G G G T G T C T A C G G T G A C A G C T G C C A IE)
      (HUMPLAPL-ACCEPTOR-987 A G A G A A G A G C T C A G A G T G T C T C T G T C C C A G A C A T A C A G T G T A G A C A A G C A T G T G C C A G A C IE)
      (HUMPLPSPC-ACCEPTOR-1326 C C T G T C T C C T T G C C T G C C C C A C C G T G T C A G G A C T A C T C C G C A G C T C C C C G G G G C C G A T T T IE)
      (HUMPLPSPC-ACCEPTOR-1830 A A G A C C A G G T G G C T C C A T G C C T T T C C C C A G G T T C T G G A G A T G A G C A T T G G G G C G C C G G A A IE)
      (HUMPLPSPC-ACCEPTOR-2176 C C C G A A T G A T C T C C A G C A T T C T G T G C C T A G C T G C T G A T C G C C T A C A A G C C A G C C C C T G G C IE)
      (HUMPLPSPC-ACCEPTOR-2621 T G G G A T A G A A A C T C A C T T C C T A C A T T C C A G A T G G A A T G C T C T C T G C A G G C C A A G C C C G C A IE)
      (HUMPNMTA-ACCEPTOR-3129 A C C A G G A C C C T C T T C C T C T G C C C T G C C C A G G T G A A G T G T C C G G A C G C A C C C T C A T C G A C A IE)
      (HUMPNMTA-ACCEPTOR-3450 C T T G A G C C C T G C C T T G T G C C T C C T G C A C A G G G A A T G C T G G C A G G A T A A G G A G C G C C A G C T IE)
      (HUMPOMC-ACCEPTOR-4445 G G G T C C C A C C A A T C T T G T T T G C T T C T G C A G A G C C T C A G C C T G C C T G G A A G A T G C C G A G A T IE)
      (HUMPOMC-ACCEPTOR-7483 C T G C C C T C A T G C C C T C G C G T C T T C C C C C A G G A G T G C A T C C G G G C C T G C A A G C C C G A C C T C IE)
      (HUMPPPA-ACCEPTOR-1721 C A C T C C A C C T C C C C T C T G C T T G C T C C T C A G A T G G C T G C C G C A C G C C T C T G C C T C T C C C T G IE)
      (HUMPPPA-ACCEPTOR-2162 T G C T T G C C C C T G C T G C C T C T T C C C T C C C A G G T A T G G G A A A A G A C A C A A A G A G G A C A C G C T IE)
      (HUMPPPA-ACCEPTOR-2425 A C A C T G C C A T G T T C T G C C C T G T C C T C A C A G G G A G C T C A G C C C G C T G G A C T T A T A A T G C C A IE)
      (HUMPRCA-ACCEPTOR-3434 C A A G G T G A G C T C C C C T C C C T C C A A A A C C A G A C T C A G T G T T C T C C A G C A G C G A G C G T G C C C IE)
      (HUMPRCA-ACCEPTOR-5063 G G A G C C T G A C G C T G C C C G C T C T C T C C G C A G C T G G C C T T C T G G T C C A A G C A C G T C G G T G A G IE)
      (HUMPRCA-ACCEPTOR-5180 G C T G A C C C C C T A C C C C G C C T T G T G T C G C A G A C G G T G A C C A G T G C T T G G T C T T G C C C T T G G IE)
      (HUMPRCA-ACCEPTOR-5420 C C A G C T G C C C G C G C C C T C C C C T G C C C G C A G A G G T G A G C T T C C T C A A T T G C T C T C T G G A C A IE)
      (HUMPRCA-ACCEPTOR-8223 C A G G C C C C T C A C C A C C T C T G C C T A C C T C A G T G A A G T T C C C T T G T G G G A G G C C C T G G A A G C IE)
      (HUMPRCA-ACCEPTOR-9239 C T G T G A T G T C A T C A T C C C A C C C C A T T C C A G G T G G T C C T G C T G G A C T C A A A G A A G A A G C T G IE)
      (HUMPRCA-ACCEPTOR-10486 C C C A C T C T G A C T G T G C C C T C T G C C C T G C A G G A G A G T A T G A C C T G C G G C G C T G G G A G A A G T IE)
      (HUMPRF1A-ACCEPTOR-3240 C C A G A G C C C A A G T G C C C C C T G T C T C T G C A G C T C C A T G G C A G C C C G T C T G C T C C T C C T G G G IE)
      (HUMPRF1A-ACCEPTOR-4965 G G C C C A G C T G A G G T C T C T C T C T T C T C G C A G T T T C C A T G T G G T A C A C A C T C C C C C G C T G C A IE)
      (HUMPRPH1-ACCEPTOR-2738 T T T T C C C A T C A T C C T G T A C T T C T T T T C T A G A T G T C A G C C A G G A A G A T G T T C C C C T C G T A A IE)
      (HUMPRPH1-ACCEPTOR-3136 G C T C A G C T C T T C T T G T T T C A A C T C A C A C A G A T G G A G G A G A C T C T G A G C A G T T C A T A G A T G IE)
      (HUMPRPH1-ACCEPTOR-4714 T A A T C T T C C T T G T T T G C T T G T C T T T T T C A G G A A G T G A A T A A G A A G A T A A C A G T G T T T C A A IE)
      (HUMPRPH2-ACCEPTOR-1848 T T T T C C C A T C A T C C T G T A C T T C T T T T C T A G A T G T C A G C C A A G A A G A C G T T C C C T T G G T A A IE)
      (HUMPRPH2-ACCEPTOR-2241 G C T C A G C T C T T C T T G T T T C A A C T C A C A C A G A T G G A G G A G A C T C T G A G C A G T T C A T A G A T G IE)
      (HUMPRPH2-ACCEPTOR-3802 C T T G C C T A T A A T C T T C C T T G T C T T T T T C A G G A A G T G A A T A A G A A G A T G A C A G T G T T T C A A IE)
      (HUMPRT1A-ACCEPTOR-209 T C C T C T C A C C A C T T T T C T T G G T C T C A C C A G G G T G C T G C C G C C C C A G G T A C A G A C C G A G A T IE)
      (HUMPSAA-ACCEPTOR-1929 G A T T C C C C T G A T C T A G C A C C C C C T C T G C A G G C G C T G C G C C C C T C A T C C T G T C T C G G A T T G IE)
      (HUMPSAA-ACCEPTOR-3726 T C C T C A T T C C T G C G T C T G C T T C C T C C C C A G C A A A A G C G T G A T C T T G C T G G G T C G G C A C A G IE)
      (HUMPSAA-ACCEPTOR-4156 C C C A C A A C A G T G T T T T T G C C T G G C C C G T A G T C T T G A C C C C A A A G A A A C T T C A G T G T G T G G IE)
      (HUMPSAA-ACCEPTOR-5669 A T C T C A C T C T C T C C C T G C T T T T A C C C T T A G G G T G A T T C T G G G G G C C C A C T T G T C T G T A A T IE)
      (HUMPSAP-ACCEPTOR-993 C A G A T G G G C T C A C G G C C A T C C C T C C T G C A G G A G C A G C G A C T G G A C C C A G A G C C A T G T G G C IE)
      (HUMPSAP-ACCEPTOR-1501 C C T A C A C A T C C A T G T C T C T T T T C T C T G C A G G C C C C A T G G G T C C A C C T G G A G A A A T G C C A T IE)
      (HUMPSAP-ACCEPTOR-2374 C C C T C C T T C T G T G T G G G G C A C T C T C C A C A G G G C T T C G A G C T C A T C T A G A T G A G G A G C T C C IE)
      (HUMPSAP-ACCEPTOR-2927 G T G G C C T G A C C C G G A C T C C T C T G C T C T C A G C C C T C A G T C T G C A G G G C T C C A T A A T G A C A G IE)
      (HUMRASH-ACCEPTOR-2012 A G G G G G T C C C T G A G C C C T G T C C T C C T G C A G G A T T C C T A C C G G A A G C A G G T G G T C A T T G A T IE)
      (HUMRASH-ACCEPTOR-2344 C G T A G C C A G C T C T C G C T T T C C A C C T C T C A G G G A G C A G A T C A A A C G G G T G A A G G A C T C G G A IE)
      (HUMRASH-ACCEPTOR-3201 T C C C T C C T G A T C C C A T C C C T C C T T T C C C A G G G A G T G G A G G A T G C C T T C T A C A C G T T G G T G IE)
      (HUMRPS14-ACCEPTOR-2108 G T T A A C C T T A T T T C T T T T C C T T C C A C T C A G A A A T G G C A C C T C G A A A G G G G A A G G A A A A G A IE)
      (HUMRPS14-ACCEPTOR-2872 G A A G A A A T G A C C C T G T G C T T T T G T C C C C A G A G A A A C C A T C T G C C G T G T G A C T G G T G G G A T IE)
      (HUMRPS14-ACCEPTOR-4137 C T C T T C T T A A C T T A A A C C T T C A T T T T C T A G G A C C A A G A C C C C T G G A C C T G G G G C C C A G T C IE)
      (HUMRPS14-ACCEPTOR-5473 G G C A A T G A C G C T T T C T C T T C C T C C C C A C A G A G G A T G T C A C C C C C A T C C C C T C T G A C A G C A IE)
      (HUMRPS17A-ACCEPTOR-463 C G T G A G T G A T C C T G T C C T C T C C A C C C G C A G G G C C G C G T T C G C A C C A A A A C C G T G A A G A A G IE)
      (HUMRPS17A-ACCEPTOR-1611 C T G T T C T C T T T G G C T G T G T G T G C T T T G T A G T T A T G T C A C G C A T C T G A T G A A G C G A A T T C A IE)
      (HUMRPS17A-ACCEPTOR-2225 G T A T T T T G A C C C T A C C T C G T T T C C T T G T A G G T C T C A G C C T T G G A T C A G G A G A T T A T T G A A IE)
      (HUMRPS17A-ACCEPTOR-3688 C T G C T C A C T G A A T C C A T T T T C T C G T T C C A G G A C T T C G G C A G T C T G T C C A A C C T T C A G G T C IE)
      (HUMSAA-ACCEPTOR-606 G C G A C T G C C T G A C T T C T C C T T T C A T T T C A G C A C C A T G A A G C T T C T C A C G G G C C T G G T T T T IE)
      (HUMSAA-ACCEPTOR-2567 T G T C C C T T C T G C C T T T C C T T T C C T T T C C A G G G G C T C G G G A C A T G T G G A G A G C C T A C T C T G IE)
      (HUMSAA-ACCEPTOR-3086 T A A T C T C C T T C T T G C C T G C C T G G A C T A C A G C A A T G C C A G A G A G A A T A T C C A G A G A C T C A C IE)
      (HUMSAA1A-ACCEPTOR-3145 A T C C T T G G T T G T G T T T C C T T G G C C C T G C A G C A G G A T G A A G C T C T C C A C T G G C A T C A T T T T IE)
      (HUMSAA1A-ACCEPTOR-5878 T A T A A T T G T T T G A T C A T T T C T T C C T T C C A G G G G C A A A A G A C A T G T G G A G A G C C T A C T C T G IE)
      (HUMSAA1A-ACCEPTOR-6290 G A T T A A T C T C C T T G C T T G C C T G G A C T A C A G C G A T G C C A G A G A G A A C G T C C A G A G A C T C A C IE)
      (HUMSAACT-ACCEPTOR-1638 C G C C T C T T C G C G G T C T C C C T G T C C T T G C A G A A A C T A G A C A C A A T G T G C G A C G A A G A C G A G IE)
      (HUMSAACT-ACCEPTOR-1885 T A A C G G G T G C G T G G T G T C T C G G C T C T G C A G G G C G T C A T G G T C G G T A T G G G T C A G A A A G A T IE)
      (HUMSAACT-ACCEPTOR-2337 A G C C A C T C A C T C T C T C C C G C G C G C G C A C A G G C A T C G T G C T G G A C T C C G G C G A C G G C G T C A IE)
      (HUMSAACT-ACCEPTOR-2578 G G G C T C C T C T C C T G C T T C T G C C C T C C G C A G C T G A G C G C G A G A T C G T G C G C G A C A T C A A G G IE)
      (HUMSAACT-ACCEPTOR-2856 T C T G C T C A C G C T C C C C G C C G C G G T C C C C A G G T A T G G A G T C G G C G G G C A T T C A C G A G A C C A IE)
      (HUMSAACT-ACCEPTOR-3116 G G T C T C C C C A C C T C A C G C G C T G T C T T G C A G A T C A T C G C C C C G C C G G A G C G C A A A T A C T C G IE)
      (HUMSHBGA-ACCEPTOR-2856 T C A G C T T T G T T T G T T T T C T C T T T C T G A T A G A G T G C C C A C G A C C C T C C G G C T G T C C A C C T C IE)
      (HUMSHBGA-ACCEPTOR-3120 T A C A C A A T C T T T C C T T C T G T G T C C T T C C A G A A C C T C C T C C T C C T T T G A G G T T C G A A C C T G IE)
      (HUMSHBGA-ACCEPTOR-3640 C C T C T G A T T T T G C T T C C C A C C T T C C T G C A G G T G G A A G T C A A G A T G G A G G G G G A C T C T G T G IE)
      (HUMSHBGA-ACCEPTOR-4029 T C C C C G T A T C T T A T C T C T G T C A C A C T C C A G C T G G T T C C T G C C C T G G A T G G C T G C C T G C G C IE)
      (HUMSHBGA-ACCEPTOR-4319 A G G C C T C A G G A T A A T C A T T T C T C C C C A C A G A C A T T C C C C A G C C T C A T G C A G A G C C C T G G G IE)
      (HUMSHBGA-ACCEPTOR-5188 T C T A C C G T C C C T T T C C C A C A C A C T C T G C A G A A G G T G G T G T T G T C T T C T G G G T C G G G G C C A IE)
      (HUMSHBGA-ACCEPTOR-5640 T A A T G C C A C C T T T G C A C T A C C T C C C T C T A G G A G A A G A C T C T T C C A C C T C T T T T T G C C T G A IE)
      (HUMSODA-ACCEPTOR-3176 A G A C A G C A A A T T C C C T A T T T T A T T T C T C A G A T T G T C A C T G C T G T T C C A A G G G C A C A C G C A IE)
      (HUMSODA-ACCEPTOR-3391 C C A C T C T A T T T G C A T T T T G T T G C A T T T C A G A G G A A C A T C A A G A A A T C A T G A A C A A C T T T G IE)
      (HUMSODA-ACCEPTOR-3793 G T G A G T C A C C T G T G A C C A C T C T T G T T T C A G G A T G A T A A G G A T G C C T T C T A T G T G G C A G A C IE)
      (HUMSODA-ACCEPTOR-4173 G G A T A G C A T G A C A C C A C T C T T C T T T T T C A G A C T G A A A T A C A G T T G G T G C A G A G T C T G G G G IE)
      (HUMSODA-ACCEPTOR-4604 A G A C A T T T G C T G C A C T T T C C T T G C T T G T A G G T T G G T T T T G C G G A T T G C C A C T G A T G A T T C IE)
      (HUMSODA-ACCEPTOR-4869 A C A G T G T C T C G T C T C T T T A T T T T A C C C C A G C T T C C A T G T A G G A A G C G G C T G T A C C G A T C C IE)
      (HUMSODA-ACCEPTOR-5127 G A T C T G G C T G A C T T A T T T T C T T G A T T C T A G G C T G A G G T T G G T T T C A G C A T G T A T C T G C T T IE)
      (HUMSODA-ACCEPTOR-6266 T G C T C T T T C T T T T C T G T T T C A C T C T C T T A G A T C A C C G G C G T A A T C A A C C C A G C G T T G G A C IE)
      (HUMSODA-ACCEPTOR-6511 G T C A T T A A G A T T G T T G A T C T G C C T T T C T A G A C G A A G A T G A G T C G A G T G A G C A G A C C T T T A IE)
      (HUMSODA-ACCEPTOR-6717 A G T A C T T C C T C T C T C C G T C T C T T T A T A T A G A G A C C T A A A C C A G A T G A G A A G T A T T A T T C A IE)
      (HUMSODA-ACCEPTOR-7572 G T T T T T A A T A T G C C A C T T T T T C T T T C T C A G G C A A C T C A T G C A G C A A T T C C A G A A C C C C G A IE)
      (HUMSPRO-ACCEPTOR-1827 G T G G C A C C G A C T G A C A C T C C T T C C T C A T A G A G T C A T G C A A G G G C C G C T G C A C T G A G G G C T IE)
      (HUMSPRO-ACCEPTOR-2022 T G G A G A C T C A C T A C C A T C C A C T C T C T G C A G T G A C T C G C G G G G A T G T G T T C A C T A T G C C G G IE)
      (HUMSPRO-ACCEPTOR-2445 C C T G C T C T C A C A C C A T C T C C T C C A C T C T A G G G C A G T A C T G C T A T G A A C T G G A C G A A A A G G IE)
      (HUMSPRO-ACCEPTOR-2841 A T A C C C C T T T T C A C T T T C C C C A C C T C T T A G G G T A R T C A G T A C T G G C G C T T T G A G G A T G G T IE)
      (HUMSPRO-ACCEPTOR-3195 C C C T C C T A A T G C C C A C C A T C C C G T C C T C A G G G A A A S A G T A C T G G G A G T A C C A G T T C C A G C IE)
      (HUMSPRO-ACCEPTOR-3807 G A C C T C T C A T T C A C C C C T T C C C T G C C A G A G C T G G T A C C A G A C A G C C C C A G T T C A T T A G C C IE)
      (HUMSPRO-ACCEPTOR-4385 T C A C G C A T C C T C T G C T T T C C T C T C T T C C A G A C A A G T A C T A C C G A G T C A A T C T T C G C A C A C IE)
      (HUMTFPB-ACCEPTOR-2160 T A A T A A T A G C T G T T T C T C T G T T G T T T A A A G G C A C T A C A A A T A C T G T G G C A G C A T A T A A T T IE)
      (HUMTFPB-ACCEPTOR-6362 T T A T G T T T C T T C C T T C T T T T C T T T C T T T A G C A C T A A G T C A G G A G A T T G G A A A A G C A A A T G IE)
      (HUMTFPB-ACCEPTOR-9259 T T C C A A C C A A G C T C A T T T C C T T T G T T T C A G C A A A C C T C G G A C A G C C A A C A A T T C A G A G T T IE)
      (HUMTFPB-ACCEPTOR-10045 A G A T G A A T T A A G A A C T C T A T C T T T T T A C A G A A A A C A G C C A A A A C A A A C A C T A A T G A G T T T IE)
      (HUMTFPB-ACCEPTOR-11925 C A A G T T G A C T A G A T G C C C T T T A T T T T T C A G A A A T A T T C T A C A T C A T T G G A G C T G T G G T A T IE)
      (HUMTHB-ACCEPTOR-883 T G T T C C A T G A C C C C C C C A C C G C C T T T A C A G T G T T C C T G G C T C C T C A G C A A G C A C G G T C G C IE)
      (HUMTHB-ACCEPTOR-1703 G T A G C C T C A C T C C C A G C C C T T G T T T T T C A G G A T G T G T T C T G G G C C A A G T A C A C A G G T G A G IE)
      (HUMTHB-ACCEPTOR-1970 C C C A A A G G T A A A C A C C T G G G T C T T T T C C A G C T T G T G A G A C A G C G A G G A C G C C T C G A G A T A IE)
      (HUMTHB-ACCEPTOR-4347 C C A A G G C T G A C C G G G G T G G G G T C T C C G C A G G T A A C T G T G C T G A G G G T C T G G G T A C G A A C T IE)
      (HUMTHB-ACCEPTOR-4549 A G C C T C C T G T T G G G C A A T T T C C T C T T C C A G A A T C A A C T C C A C T A C C C A T C C T G G G G C C G A IE)
      (HUMTHB-ACCEPTOR-7024 T C T G C T G C C T C C T T G C C C C T C A C C C A C C A G G C C A G G A T C A A G T C A C T G T A G C G A T G A C T C IE)
      (HUMTHB-ACCEPTOR-7663 C A G T C C C G G C C G G T G C C T G G G T C C C A A C A G A G G A G G C C G T G G A G G A G G A G A C A G G A G A T G IE)
      (HUMTHB-ACCEPTOR-7876 T T G C C C C T C A C T G C T T G G C T T G C T C T G C A G A C T G T G G G C T G C G A C C T C T G T T C G A G A A G A IE)
      (HUMTHB-ACCEPTOR-9160 G C T C C T A A T G C T T C C T G C T G C C C C T C C C A G G C A G G T G A T G C T T T T C C G G A A G A G T C C C C A IE)
      (HUMTHB-ACCEPTOR-9825 T T C T C C A T T T C T T T C T T G G G G T C T C T G C A G G T A C G A G C G A A A C A T T G A A A A G A T A T C C A T IE)
      (HUMTHB-ACCEPTOR-10541 T C T C A C T A G G C C C T T C T T C C T T C C C C A A A G C T T G C T C C A G G C T G G A T A C A A G G G G C G G G T IE)
      (HUMTHB-ACCEPTOR-20170 C C T G A G C A C A G A C G G C T G T T C T C T T T C A A G G T T A C A A G C C T G A T G A A G G G A A A C G A G G G G IE)
      (HUMTHB-ACCEPTOR-20387 T C T A T T G G A A A C C T C A T C T T T C T T C T T C A G A G C C C C T T T A A C A A C C G C T G G T A T C A A A T G IE)
      (HUMTHY1A-ACCEPTOR-517 C C A G T T T G A A G G A G G C A C T G C T G G T G C C A G T C T T G C A G G T C T C C C G A G G G C A G A A G G T G A IE)
      (HUMTHY1A-ACCEPTOR-1380 C C T G C C C C C G G C C C C C T T C T C T T T C T G C A G A C A A A C T G G T C A A G T G T G A G G G C A T C A G C C IE)
      (HUMTKRA-ACCEPTOR-666 G C C C T C A A A T G A C C T C A C C T T C T C T C C T A G G T G A T T C T C G G G C C G A T G T T C T C A G G A A A A IE)
      (HUMTKRA-ACCEPTOR-2330 G A C C T C A C C T G A C C C T C T C T C C T C T T G C A G C A C A G A G T T G A T G A G A C G C G T C C G T C G C T T IE)
      (HUMTKRA-ACCEPTOR-4815 C C T G C T C A C G C T C T G G C T T T C T C T T C C C A G G A A C A C C A T G G A G G C G C T G C C C G C C T G C C T IE)
      (HUMTKRA-ACCEPTOR-11871 T C A C A C T C T T T C T C C A C G T G C C C T T T C C A G T T C C C T G A C A T C A T G G A G T T C T G C G A G G C C IE)
      (HUMTKRA-ACCEPTOR-12318 A G C G C C C T C T G T C T T T C C A T G G G A G C A C A G C C A T T T G G G G C C A T C C T G A A C C T G G T G C C G IE)
      (HUMTKRA-ACCEPTOR-12537 C C T T C A C C C A T C C C C T G T C C C T G C G G C C A G G T C G A G G T G A T T G G G G G A G C A G A C A A G T A C IE)
      (HUMTNFA-ACCEPTOR-1558 G A T G T T A A C C A T T C T C C T T C T C C C C A A C A G T T C C C C A G G G A C C T C T C T C T A A T C A G C C C T IE)
      (HUMTNFA-ACCEPTOR-1791 T C A G C T T T T T C T T T T C T C T C T C C T C T T C A G G A T C A T C T T C T C G A A C C C C G A G T G A C A A G C IE)
      (HUMTNFA-ACCEPTOR-2140 A C T C T C C T C T C C C T C T C T C C C T C C C T C C A G C A A A C C C T C A A G C T G A G G G G C A G C T C C A G T IE)
      (HUMTNFAB-ACCEPTOR-1237 G T C T C T C T C T C T C T C T C T C T T T C T C T G C A G G T T C T C C C C A T G A C A C C A C C T G A A C G T C T C IE)
      (HUMTNFAB-ACCEPTOR-1431 A G A G C C C C C C T C A A C T C T G T T C T C C C C T A G G G G C T C C C T G G T G T T G G C C T C A C A C C T T C A IE)
      (HUMTNFAB-ACCEPTOR-1784 C C C A C C C C C A T C C C C T A T G G C T C T T C C T A G G A G A C C C C A G C A A G C A G A A C T C A C T G C T C T IE)
      (HUMTNFAB-ACCEPTOR-5037 G A T G T T A A C C A T T C T C C T T C T C C C C A A C A G T T C C C C A G G G A C C T C T C T C T A A T C A G C C C T IE)
      (HUMTNFAB-ACCEPTOR-5270 T C A G C T T T T T C T T T T C T C T C T C C T C T T C A G G A T C A T C T T C T C G A A C C C C G A G T G A C A A G C IE)
      (HUMTNFAB-ACCEPTOR-5619 A C T C T C C T C T C C C T C T C T C C C T C C C T C C A G C A A A C C C T C A A G C T G A G G G G C A G C T C C A G T IE)
      (HUMTNFX-ACCEPTOR-1332 G A T G T T A A C C A T T C T C C T T C T C C C C A A C A G T T C C C C A G G G A C C T C T C T C T A A T C A G C C C T IE)
      (HUMTNFX-ACCEPTOR-1565 T C A G C T T T T T C T T T T C T C T C T C C T C T T C A G G A T C A T C T T C T C G A A C C C C G A G T G A C A A G C IE)
      (HUMTNFX-ACCEPTOR-1914 A C T C T C C T C T C C C T C T C T C C C T C C C T C C A G C A A A C C C T C A A G C T G A G G G G C A G C T C C A G T IE)
      (HUMTPA-ACCEPTOR-17940 G T G A T C A A G C T G T T T T T T C T C T C C T T C C A G A A T T T A A G G G A C G C T G T G A A G C A A T C A T G G IE)
      (HUMTPA-ACCEPTOR-19737 A T C C T T C C T C C A C C T C T G G T T T C T T C G C A G G A A A T C C A T G C C C G A T T C A G A A G A G G A G C C IE)
      (HUMTPA-ACCEPTOR-22075 C T G A T G A G G C T G G C C T G T C T T T T C T C A T A G T G A T C T G C A G A G A T G A A A A A A C G C A G A T G A IE)
      (HUMTPA-ACCEPTOR-23130 A T T A G G G G C T T C C T T T T T T A T A C T T G A C A G G T T G C A G C G A G C C A A G G T G T T T C A A C G G G G IE)
      (HUMTPA-ACCEPTOR-23573 G T G A G G C A T C C A T G C C C T G C T C T C T G T C A G A T A C C A G G G C C A C G T G C T A C G A G G A C C A G G IE)
      (HUMTPA-ACCEPTOR-25978 C C C T G G C C C T T C C C T T G G C T G A T T T T T C A G A A A C C C A G A T C G A G A C T C A A A G C C C T G G T G IE)
      (HUMTPA-ACCEPTOR-28261 T G T T T C A G T T T G A G A A T T C T T T T C T T C T A G G A A A C A G T G A C T G C T A C T T T G G G A A T G G G T IE)
      (HUMTPA-ACCEPTOR-29440 A A G G A A A C C T T A A A C T C T C T T A T C A T T T A G G A A T C C T G A T G G G G A T G C C A A G C C C T G G T G IE)
      (HUMTPA-ACCEPTOR-30776 C T G A C T G C C T C C T C G T C C T T T C C T C C C C A G C C A C C T G C G G C C T G A G A C A G T A C A G C C A G C IE)
      (HUMTPA-ACCEPTOR-31083 A A A A G C A T T C T A A G G C T G T T T C T C C A C C A G G T T T C C G C C C C A C C A C C T G A C G G T G A T C T T IE)
      (HUMTPA-ACCEPTOR-31395 G C C A G C T C A C T C C T C C T T T C T C C C T C C C A G C G C T G C T G C A G C T G A A A T C G G A T T C G T C C C IE)
      (HUMTPA-ACCEPTOR-32398 T A A A A C C A T A T G A T G G T T C T C C C C T T T C A G T G T C T C C T T T C T A T T C G G A G C G G C T G A A G G IE)
      (HUMTPA-ACCEPTOR-35307 C A A A C G C C A A A C C T G C T A T C T C C T T T G C A G G G C G A T T C G G G A G G C C C C C T G G T G T G T C T G IE)
      (HUMTUBAG-ACCEPTOR-2034 T T T T A C A T T T T T C A C T T T T C C T C C C C A C A G C G T G A G T G C A T C T C C A T C C A C G T T G G C C A G IE)
      (HUMTUBAG-ACCEPTOR-2405 C C C C C T G C T C C T C C C C C A T C A T G T C T C C A G A T G A A G T T C G C A C T G G C A C C T A C C G C C A G C IE)
      (HUMTUBAG-ACCEPTOR-2858 A A C C T T T C C T C T G T C C T C T C T T T T G T A T A G G C C G A C C A G T G C A C G C G T C T C C A G G G C T T C IE)
      (HUMTUBBM-ACCEPTOR-1078 C C C G C C C G G G C C C G C C C G C G T C C C T T G T A G T T T T G G G A G G T G A T C A G C G A T G A G C A C G G C IE)
      (HUMTUBBM-ACCEPTOR-1265 T G C C T T G C T G A C G C C C T C C C G T C C C C G C A G G C G G C A A G T A C G T G C C C C G C G C C G T G C T C G IE)
      (HUMTUBBM-ACCEPTOR-1850 T G A C A A A T G A T T A G C T G T G T T C T C T C A C A G G T C A G A G T G G T G C T G G G A A C A A C T G G G C C A IE)
      (HUMUBILP-ACCEPTOR-806 A C C C T T G C C T C C C A C C C T C C G C G C G G C C A G G T G C C A G A G G A C G A G C T G G T G T C C A C G C T G IE)
      (HUMUBILP-ACCEPTOR-1158 A G G A G G A A C C C A T C G A T C T G T C T T T G G C A G A T G G G A A A C G A C T C T C G G A T T A T A G C A T C G IE)
      (HUMUBILP-ACCEPTOR-1488 C C C T G A A T C T T C C T G C C C T T C T C T C C C C A G G A T T A C G A G A G G T C C C T G A G T C G C C T G A C G IE)
      (HUMVPNP-ACCEPTOR-1688 T C C T C C C G C T C A C C C C G C C C G T C C C C G C A G T G C C T C C C C T G C G G C C C C G G G G G C A A A G G C IE)
      (HUMVPNP-ACCEPTOR-2057 G G C G C C C G T G C T C A C A C G T C C T C C C G G C A G A G A G C T G C G T G A C C G A G C C C G A G T G C C G C G IE)
      (LEMHBB-ACCEPTOR-346 C T G T C T C C T G G G T T G C T T T C A C C C C C T C A G G C T G C T G G T C G T C T A C C C A T G G A C C C A G A G IE)
      (LEMHBB-ACCEPTOR-1437 A T G T C C A T A T C T C T C G T C T C T T C C C C A C A G C T C C T G G G C A A C G T G C T G G T G G T T G T G C T G IE)
      (LEMHBE-ACCEPTOR-410 T T T T C C A T C T G C T A T G G T G C C A T C T C A C A G G C T C C T C G T T G T C T A C C C C T G G A C A C A G A G IE)
      (LEMHBE-ACCEPTOR-1474 T T T T C T T T C A T T T T G T C T T T C A C C T A A C A G C T C C T G G G A A A C G T G A T G G T G A T T A T T C T G IE)
      (LEMHBG-ACCEPTOR-364 G T T T C T A A T T G C T A T T G T C C T A T C T C A T A G A C T C C T G G T T G T C T A C C C G T G G A C C C A G A G IE)
      (LEMHBG-ACCEPTOR-1452 C A T C T C T A T T G T C T C T T T C C A C C T T C A C A G C T C C T A G G A A A T G A G C T G G T G A T T G T C T T G IE)
      (LEMHBGA-ACCEPTOR-425 G T T T C T A A T T G C T A T T G T C C T A T T T C A T A G A C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (LEMHBGA-ACCEPTOR-1498 C A T C T C T G T T G T C T C T T T C T A C C T T C A C A G C T C C T G G G A A A C G A G C T G G T G A T T G T C T T G IE)
      (MACHBA-ACCEPTOR-238 C C C C A C C C C T C A C T C T G C T T C T C C C C G C A G G A T G T T C C T G T C C T T C C C C A C C A C C A A G A C IE)
      (MACHBA-ACCEPTOR-587 T C G G C C C C A C T G A C C C T C T T C T C T G C A C A G C T C C T G A G C C A C T G C C T G C T G G T G A C T C T G IE)
      (MACHBCA2-ACCEPTOR-586 C T G T C A A A C T G C T C T T G T T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (MACHBCA2-ACCEPTOR-1693 C A T T T T T G T T G T C T C C T T T C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C T G T T T T G IE)
      (MACHBGA1-ACCEPTOR-588 C T G T C A A A C T G C T C T T G T T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (MACHBGA1-ACCEPTOR-1692 C A T T T T T G T T G T C T C C T T T C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C T G T T T T G IE)
      (MNKHBD-ACCEPTOR-475 C T G T C C C T T G G G C T G T T T T C C T A C C C T C A G G C T G C T G G T G G T C T A C C C T T G G A C C C A G A G IE)
      (MNKHBD-ACCEPTOR-1583 A T G C A T G T A T C T G C C T A C C T C T T C T C A C A G C T C C T G G G C A A T G T G C T G G T G T G T G T A C T G IE)
      (ORAHBD-ACCEPTOR-596 C T G T C C C T T G G G C T G T T T T C C T A C C C T C A G A T T A C T G G T G G T C T A C C C T T G G A C C C A G A G IE)
      (ORAHBD-ACCEPTOR-1713 T G C A T G T A T C T G C C T A C C T C T T C T C T G C A G C T C T T G G G C A A T G T G C T G G T G T G T G T G C T G IE)
      (ORAHBG1F-ACCEPTOR-391 G C T G T C A A A G T G C T C T T G T C A A T C T C A C A G G C T C C T G G T T G T C T A C C C A T G G A C C C A G A G IE)
      (ORAHBG1F-ACCEPTOR-1486 C A T C T T T G T T G T C T C C T T T C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C C G T T T T G IE)
      (ORAHBG2F-ACCEPTOR-392 C T G T C A A A C T G C T C T T A T T C A A T C T C A C A G G C T C C T G C T T G T C T A C C C A T G G A C C C A G A G IE)
      (ORAHBG2F-ACCEPTOR-1492 C A T C T T T G T T T T C T C C T T T C A T C T C A A C A G C T C C T G G G A A A T G T G C T G G T G A C C G T T T T G IE)
      (ORAIGECA-ACCEPTOR-583 C A A C C C T C A T G A C C A C C A G C T C T C C C C C A G T C T G C T C C A G G G A C T T C A C C C C A C C C A C C G IE)
      (ORAIGECA-ACCEPTOR-990 G G C C T C A C A C A G C C T T C C G G T G T A C C A C A G A T T C C A A C C C G A G A G G G T T G A G C G C C T A C C IE)
      (ORAIGECA-ACCEPTOR-1393 A G C C T G G G C T G A C C C C A C G T C T G G C C A C A G G C C C G C G T G C T G C C C C G G A A G T C T A T G C G T IE)
      (TARHBB-ACCEPTOR-1686 C T G T C C T G T G G G T T C C T C T C A C C C C C T C A G G C T G C T G G T C G T C T A C C C A T G G A C C C A G A G IE)
      (TARHBB-ACCEPTOR-2748 A T G T T T A A A C C T C G C G T T T C C T C C C C G C A G C T C T T G G G C A A T G T G C T G G T G T G T G T G C T G IE)
      (TARHBD-ACCEPTOR-594 C T G T C C T G T G G G T T C C T C T C A C C C T C T C A G G T T G C T G G T C G T C T A C C C A T G G A C C C A G A G IE)
      (TARHBD-ACCEPTOR-1884 C A T A T G T A T C T T T T T A C C T T T T C C C A A C A G C T C C T G G G C A A C G T G C T G G T G T G T G T G C T G IE)
      (AGMKPNRSB-NEG-1 C A A A A G A A C A A A G C T G G A G G C A T C A C G C T A C C T G A C T T C A A A C T A T A C T A C A A G G C T A C A N)
      (AGMORS12A-NEG-181 A G G G A G G T G T C T G A T T G G T C C A G C T T A G T C C A T G T C C C T A C C C T G A A C A G G G G C A T G G G G N)
      (AGMORS9A-NEG-481 T G G T C A A T T C T G A A T T C T C T C C A C A T T A T T A T T A T T A T T T T T T G A G A C A G T C T T G C T C T G N)
      (AGMRSKPNI-NEG-1141 A G G G C A T G G T G A A A A A G G A A A T A T C T T C C G T T C A A A A C T G G A A A T A A G C T T T C T G A G A A A N)
      (ATRINS-NEG-841 G G C C C C C A C C T G G T G G A A G C C C T C T A C C T G G T G T G C G G G G A G C G A G G T T T C T T C T A C G C A N)
      (BABA1AT-NEG-181 C C A A C A G C A C C A A T A T C T T C T T C T C C C C A G T G A G C A T C G C T A C A G C C T T T G C A A T G C T C T N)
      (BABAPOE-NEG-1201 T T C T C C C G C C T C A G C C T C C C G A G T A G C T G G G A C T A C A G G C G C C C G C C A C C A T G C C C G G C T N)
      (BABBMYHA-NEG-301 G A C C T G C A G C A C C G G C T G G A C G A G G C C G A G C A G A T C G C C C T C A A G G G C G G C A A G A A G C A G N)
      (BABT1GL-NEG-61 C C G T G A G C C G A A A T C G C G C C A C T G C A C T C A C C G C A C C C G G C C A A T T T T T G T G T T T T T A G T N)
      (CHPAZGLO-NEG-1 G A G C T C T G C A G G C T G A A G A T G T C G C A G C T G T C A G C G G G A T G G G G G C A C G C T T G C T G A C G C N)
      (CHPCD4A-NEG-961 G G A C C C T A A G C T C C A G A T G G G C A A G A A G C T C C C G C T C C A C C T C A C C C T G C C C C A G G C C T T N)
      (CHPCLA108-NEG-841 C A C C T G C C A T G T G C A G C A T G A G G G T C T G C C C A A G C C C C T C A C C C T G A G A T G G G A G C C G T C N)
      (CHPGGGLOG-NEG-961 A A A C A T A C A T T G C C A A G G C T A T T C C T A T G T C A T C T G G A C A C A T A T A A A A T G C T G C T A A T G N)
      (CHPHBBC-NEG-1321 G A G T G T C A T G A T T T T C A T G G A G G A A G T T A A T A T T C A T C C T C T A A G T A T A C T C A G A C T A G G N)
      (CHPHBBPCH-NEG-301 A T A T T C C T A A G T A A A A C A G A T A A C T G C C T C T C A A C T A T A T C A A G T A G A C T A A A A T A T T G T N)
      (CHPHBBPCH-NEG-4861 A C A G C T A A A A T C C T T G C C T G T G A A T G A A A A G A A G G A A A T T T A T T G A C A G A A C A G C A A A T G N)
      (CHPHPA2-NEG-1 G A A C T G T T G C T C T C T C C T T T C C G T C T C A G A A C C A G A G G C A A A G G C C C A G C C T C T T C T G C T N)
      (CHPHPA3-NEG-2041 C T A T G A A A C A G G G A A G C T G A A C T T T G A A T C C A G G C C T G G T T G A T A G A A A C T C A G A G C T C T N)
      (CHPINVOL-NEG-1 A T G T C C C A G C A A C A C A C A C T G C C A G T G A C C C T C T C C C C T G C C C T C A G T C A G G A G C T C C T C N)
      (CHPMHCBAA-NEG-841 T A C A C C T G C C A T G T G C A G C A T G A G G G T C T G C C C A A G C C C C T C A C C C T G A G A T G G G A G C C G N)
      (CHPP44-NEG-481 A T T C A G G A T T A T G A A G T T T T T C G A T G C G A A G A T T C A C T G G A C G A A A G A A A G A T A A A A G G G N)
      (CHPRGITX-NEG-1441 G C C C G G C T C G C T G G C G T G G A G C C G G G G T G G A A T G C G A G T G C C T A G T G G G C C A C T T T T G G T N)
      (CHPRSA-NEG-2161 A G C C C A G C T G T T T G T C T C C C A T T T T C T C T A C T T C T A A A A T A C A T T T C T T C A C T A A G T G A G N)
      (CHPRSALPI-NEG-481 A T A T C T T C G T T T A A A A A C T A G A C A G A A T C A T T C T C T G A A A C A A C G T A A T G A T T T G T G C G T N)
      (GCRHBBA1-NEG-61 C C C A C C G T G C T G C T G G G A C C T G C A G G T G T A G A G A G G G G G G C C C T G A C G C G C A G A C C C A G T N)
      (GCRRSAGAB-NEG-121 A G G G C A C T G T G G T A G G C A C C T A T A G T C C C A G C T A C T T G G G A G G C T G A G G C A A G A G A A T T G N)
      (GIBHBGGL-NEG-3301 C A A C A T A C A G G G T T C A T G G T G G C A A G A A G A T A G C A A G A T T T A A A T T A T G G C C A G T G A C T A N)
      (GIBHBGGL-NEG-7861 G T T C T A A T C A T T T C A C C A T T T T T G T T A T T C G T T T T A A A A C A T C T A T C T G G A G G C A G G A C A N)
      (GIBIL2LTR-NEG-241 A C A T C T T C A G T G T C T A G A A G A A G A A C T C A A A C C T C T G G A G G A A G T G C T A A A T T T A G C T C A N)
      (GORHBBPG-NEG-181 T A A A T G T G T T T C C T G C A T A C A G T C A A A G T T G C C A C T T C T T T T T C T T C A T A T C A T C G A T C T N)
      (GORHBBPG-NEG-4741 G C T G T A A T T A T A T T G A G G T G A T G G A T A A A G A A C T G A A G T T G A T G G A A A C A A T G A A G T T A A N)
      (GORHBPSBD-NEG-2281 A A T A T C T T T C G T T G G C T T C C A G G T T A C A G A A A A A T A A T T T G T A A C A A A G T T T A A A G G T C A N)
      (GORRGITX-NEG-1 G T C A A C A A G T A C C G T A A G G G A A A G T T G A A A A G A A C T T T G A A G A G A G A G T T C A A G A G G G C G N)
      (HUM18BPD-NEG-61 A A A G C A G G A A A C C T G T G G T A T G A A G C C A G A C C C C C G A G T G A A G A C T A C T A C T A C T A C T A C N)
      (HUM3ALPH-NEG-1 G A A T T C T C A G T A G C T T C T T T G T G T G T G T G T A C T C A A C T C A C A G A G T T G A A C C T T C C T T T A N)
      (HUM4COLA-NEG-1021 C T C G A C G G T G A T G G G G G G C A A C T C G G C G G G G G A G C T G T G C G T C T T C C C C T T C A C T T T C C T N)
      (HUM4F2HG1-NEG-1441 A G C C C C G G C T G G G T A C G C A C C C G C T G G G C A C T G C T G C T G C T C T T C T G G C T C G G C T G G C T C N)
      (HUM5FDX-NEG-2041 G C G C T C T G C T T G C C A A T G T C T T T A T A G G T C A C C C G G A A G G C A C G C G G A A C C T C G G C G C G G N)
      (HUM7B2-NEG-901 T A A A A A T T A A A A T G T G A A T G T C A A C A A T A A A A A G C A A G A C T A T G A A A G G C T C A G A T T T C T N)
      (HUM7SKP41-NEG-541 A T G C C A G G T T A A A G A G A A A A T G A G A G G A G A G G A G G C C A G G G A G G G T T G A A T T T A G T G T G C N)
      (HUM8KER1-NEG-61 C C T A C A A G G T G T C C A C C T C T G G C C C C C G G G C C T T C A G C A G C C G C T C C T A C A C G A G T G G G C N)
      (HUMA1ACMB-NEG-421 T T G G A A T C C A C C A G C T A C A T C C A G C T C C C T G A G G C A G G T A A T C C A T G A T G T T T T A C A T C C N)
      (HUMA1AR2-NEG-3601 A G G G G G C T G A A T C C T C A G T T T A A G G G C C T G G A C C T G G G A G C T T A T G G A A G A G C A A G G G G C N)
      (HUMA1ATP-NEG-301 C A T T C A G C C A G C T C A G G G G A A G G A C A G G G G C C C T G A A G C C A G G G G A T G G A G C T G C A G G G A N)
      (HUMA1ATP-NEG-4861 G T G C C T A G C C A T G G G A A T T C T C C A T C T G T T T T G C T A C A T T G A A C C C A G A T G C C A T T C T A A N)
      (HUMA1ATP-NEG-9421 A G A G A C C C T T T G A A G T C A A G G A C A C C G A G G A A G A G G A C T T C C A C G T G G A C C A G G T G A C C A N)
      (HUMA1ATR-NEG-781 T A A G A A G C T G T C C A G C T G G G T G C T G C T G A T G A A A T A C C T G G G C A A T G C C A C C G C C A T C T T N)
      (HUMA1GLY2-NEG-1501 G A G T A A A C T T T T G C T G G G C T C C A A G T G A C C G C C C A T A G T T T A T T A T A A A G G T G A C T G C A C N)
      (HUMA1GP01-NEG-301 G C G G G A G G C C T C T C T A G G A A A T C T G T G G A C T C A C A C G T T T A C T A A T G T T G C T G C A G C C C C N)
      (HUMA1MICR-NEG-1081 G A G C T G C T G C G C T T C T C C A A C T G A C A A C T G G C C G G T C T G C A A G T C A G A G G A T G G C C A G T G N)
      (HUMA2M-NEG-4441 T T G C A G C A A A G A T C T T G G A A A T G C T T G A A G A C C A C A A G G C T G A A A A G T G C T T T G C T G G A G N)
      (HUMA2PIBB-NEG-421 T T G G T C A G G C T G G T C T T G A A C T C C T G A C C T C A G T G A T C T G C C T G C C T C G G C C T C C C A A A G N)
      (HUMA2PIG3-NEG-541 G G A G G C C A C G G A G G G G A A G A T T C A G G A A T T C C T C T C T G G G C T G C C G G A A G A C A C C G T G T T N)
      (HUMAACT-NEG-481 T A A A A G A C G G A A G A T A C A A T A A T A C T T T C C T T A C A G G G T T C T G A G A C T A C T A A G A G A A C T N)
      (HUMABL1B-NEG-1621 A G T A G C C A A A G A C C A T C A G C G T T T C C T T T A T G T G T G A G A A T T G A A A T G A C T A G C A T T A T T N)
      (HUMABLA-NEG-2701 A G T A A C G C C T C C C C C C A G G C T G G T G A A A A A G A A T G A G G A A G C T G C T G A T G A G G T C T T C A A N)
      (HUMABLLA-NEG-1 G C T A A T A A A A A C A A G C A C T A T T G T T C A A C T T T T A G G T G T G T G T A C T T T G G A G C C A C C A T T N)
      (HUMACBPA2-NEG-1 G A A T A A A A G T G C A T G C C T T A T A A A A A A A A C A C T T A T G T T T C C A C T A T A C T G T A G T C T A T T N)
      (HUMACCYBA-NEG-2521 C C T T C C T T C C T G G G T G A G T G G A G A C T G T C T C C C G G C T C T G C C T G A C A T G A G G G T T A C C C C N)
      (HUMACCYBB-NEG-3481 C C C C A A C T T G A G A T G T A T G A A G G C T T T T G G T C T C C C T G G G A G T G G G T G G A G G C A G C C A G G N)
      (HUMACHRA7-NEG-901 A G T G T T T T C A T A T T G C T T C T C C C T T T A G T T C T G C T G T C T C C C T G A A G A G T G A A C C C T C T T N)
      (HUMACHRG4-NEG-1 T A G G T C C T C C T G C T C T C C A T A T C T C G C C A G T G G G G T T T G A T A G A G A A C T C A G A A G C G T G G N)
      (HUMACHRM2-NEG-1681 G C C A T T G C A C T T T A T A G T C T G A T T A C A A A A C G T G C A A T T C A G G A G C C C A G C A G T G A C A C A N)
      (HUMACROS-NEG-1 C A G G C A G T G C A G G A G T A T G G T T G A G A T G C T A C C A A C T G C C A T T C T G C T G G T C T T G G C A G T N)
      (HUMACTASK-NEG-1021 G A T G T A C C C T G G G A T C G C T G A C C G C A T G C A G A A A G A G A T C A C C G C G C T G G C A C C C A G C A C N)
      (HUMACTCA2-NEG-1381 T T A T T T C T G T A G C T G A A C G T G A A A T T G T C C G T G A C A T T A A A G A G A A G C T G T G C T A T G T C G N)
      (HUMACTGA-NEG-2641 T T T G C C C C T G G C A A A T G C A C A C A C C T C A T G C T A G C C T C A C G A A A C T G G A A T A A G C C T T C G N)
      (HUMACTGP1-NEG-481 G G C A T G G A G A A G A T C T G G C A C C A C A C C C T A C A A C A A G C T G C A T G T G T T C C T G G A G G A G C A N)
      (HUMACTSM7-NEG-61 C T C C A C T T A A G G A C C A T G G C C T G T G T C T C T T T T C C A G G G A T G G A G T C T G C T G G C A T C C A T N)
      (HUMADAG-NEG-4441 G C C C C G C G C C T A C T G A G T G C T C A G T G A A T G G A A G C A G C T T T G T A C G C C A G C G T T A T G G T G N)
      (HUMADAG-NEG-9001 T G A C A A A A C C A A G A T C T T G G G G T T C T T G G G G A A A C T G A C A T G C T G A T T G G T T T T T G T A C A N)
      (HUMADAG-NEG-13561 C T G T C T C T A C T A A A A G T A C A A A A A T T A G C C G G G C A T G G T G G T G G G C G C C T G T A A T C C C A G N)
      (HUMADAG-NEG-18121 G G C T G T T T C C T T T G G G C T A T C C A T G T C C A C C T A C A C T G C C C T T T T T A A T C C T T A C A A T T T N)
      (HUMADAG-NEG-22681 T A T A A T C C C A G C T A C T T G A G A G G C T G A G G C A G G A G A A T C A C T T G A A C C A G G G A G G T G A A G N)
      (HUMADAG-NEG-27241 A T T A C A G G C G T G A G C C A C T G C G C C T G G C C T C C A T C C T C A T C C T G A A G A T G C A A G A A C T T C N)
      (HUMADAG-NEG-31801 A G G A A A A A G A G G A A G G G A G G G A G G G A G G A A G G A A G G A A A G A A G G A A G G A A G G G A G A G A G A N)
      (HUMADAG-NEG-36361 G T T C T A G A A G C C T G G G C G A A G T C C G G C T A A T T G T G G A C T T G G G G A A A A T A A G G C C C A A C C N)
      (HUMADH1CA-NEG-121 G A G T T A A A G A A A C C C T T T T C C A T T G A G G A G G T G G A G G T T G C A C C T C C T A A G G C C C A T G A A N)
      (HUMADH21C-NEG-541 G C T G T G G A T T C T C G A C T G G T T A T G G G T C T G C A G T T A A C G T T G C C A A G G T C A C C C C A G G C T N)
      (HUMADH2C1-NEG-841 G A A A T G A C T G A T G G A G G T G T G G A T T T T T C G T T T G A A G T C A T C G G T C G G C T T G A C A C C A T G N)
      (HUMADH2E2-NEG-1 T G T T T G A T T T T C T A G G T A A T C A A A T G C A A A G C A G C T G T G C T A T G G G A G G T A A A G A A A C C C N)
      (HUMADH3G1-NEG-841 G G C T G A C T T T A T G G C T A A G A A G T T T T C A C T G G A T G C A T T A A T A A C A A A T A T T T T A C C T T T N)
      (HUMADH4C1-NEG-1501 A A C T A G A T T G G C C A T A T G T T T A T A A T T T T T T T A G A T T G G G T A A T G A A T A C A T G G A G T T T C N)
      (HUMADHIG-NEG-241 T T A G T G G C A A C C T G G T G A C C C C C C T T C C T G T G A T T T T A G G C C A T G A G G C A G C C G G C A T C G N)
      (HUMADPRT01-NEG-61 T C G G G C T T C C G G A G C T T T G G C G G C A G C T A G G G G A G G A T G G C G G A G T C T T C G G A T A A G C T C N)
      (HUMADRA-NEG-961 C G C C G A G C G G C C T C C A G G G C C C C G C A G A C C C G A G C G C G G T C C C C G G G G C A A A G G C A A G G C N)
      (HUMADRA2R-NEG-2581 G C T C A T C T C C A T C G A G A A G A A G G G C G G C G G C G G C G G C C C G C A G C C G G C C G A G C C G C G C T G N)
      (HUMADRBR-NEG-1861 G C C C A T A T T C T T A T G A A A A T G T G G A C T T T T G G C A A C T T C T G G T G C G A G T T T T G G A C T T C C N)
      (HUMADRBRA-NEG-2941 T C C C C C A C T C C T C T T A T T T G C T C A C A C G G G G T A T T T T A G G C A G G G A T T T G A G G A G C A G C T N)
      (HUMAE1-NEG-2101 A T G A T G T T T G C C T C C G C C C T G C C T G C T C T G C T G G T C T T C A T C C T C A T A T T C C T G G A G T C T N)
      (HUMAFLP2-NEG-61 A A A A A T A A T A A T A A A T A A A T A A A T T T T A A A A A C C C T G A A T G C C A C G G A A G C C G C C A T G G C N)
      (HUMAFP-NEG-4141 G G T T C A A G G T A A T G T T A C A G A T C G C T G A T T T A T T C T T G T A A A T T C A A A G G T A T G T C T T T T N)
      (HUMAFP-NEG-8701 T A T A T A T A T T C A G A G T T T A T T T G A T T G C T G T T T G G T T A A A T A A C A C G T T A A A G C A T A T T G N)
      (HUMAFP-NEG-13261 A T T G T T T A A T A G A A G C A G T T C T T C A G T T G C A A A G G T T C T T T G C A G T A G A A T T T T C T C A G C N)
      (HUMAFP-NEG-17821 G A G G T A T G T T T C A C A G T A T G A T A A G A A T G T T G C C T G T T C T G G C A A G C T T T T T C T A T T G C T N)
      (HUMAFP1-NEG-241 A C A A G T C A T C T C T C T G A A T T T T T T G T A C T T T G A G A G T A T T T G T T A T A T T T G C A A G A T G A A N)
      (HUMAG1-NEG-2101 T A C T C T C C T T T C T T G G G G G T A T C A T T T C T T G G G G T T G T A T A A A A A T A T A A T T T T A T A A T G N)
      (HUMAGG-NEG-541 A G A A C C A C C T A C T T C T T G G G G A G G T A G G T C T G C T T C C C T T C A A C T C A G G A T A C A A C T G C T N)
      (HUMAGP1A-NEG-421 G A T G A G A A G A A C T G G G G G C T G T C T G T C T A T G C T G A C A A G C C A G A G A C G A C C A A G G A G C A A N)
      (HUMAICEB-NEG-2641 G C C C A T T C C T G C T C A C C T G C T G G G G A A C A T G T G G G C G C A G A C C T G G T C C A A C A T C T A T G A N)
      (HUMAK1-NEG-1801 C C T G G G T G C T T A G C C C G T A A C C C A A C T C C A T C C T A G A C C C C T G T C C T C T G T G A G G C C T C C N)
      (HUMAK1-NEG-6361 T C C C C A G G G C A G G G A A G G C C T A A T T G G T C C A T G G C C G T G T C C T C G G G A C C C A G G A C A G C A N)
      (HUMAK1-NEG-10921 C T G G C C T G A G G A C C C G G C G C T G A G T G G C G G G G C C C C T G C T C C G A G G G G C T C A T G T T C A G G N)
      (HUMALBAF1-NEG-301 A C A T G T G T A G C T G A T G A G T C A G C T G A A A A T T G T G A C A A A T C A C T T C A T A C C C T T T T T G G A N)
      (HUMALBGC-NEG-241 C A G A A A G A C A A G T C T G G T A T T T C C T T T C A G G A C T C C C T T G A G T C A T T A A A A A A A A T C T T C N)
      (HUMALBGC-NEG-4801 G T A C T G T T T A T C T T T T T A T G A C T G A C T T A T T T C C C T T A G C A T A G T G C A T T C A A A G T C C A A N)
      (HUMALBGC-NEG-9361 C T T A T G A G A A A T A G T A T T T G C C T A G T G T T T T C A T A T A A A A T A T C G C A T G A T A A T A C C A T T N)
      (HUMALBGC-NEG-13921 T T G T C A A G A A A G A T A G G A G A G G A G A G A T A A A A T A G T T G A T G G G G T G G A G A G G T C T A T A T T N)
      (HUMALBGC-NEG-18481 T G C C A T T T T A C A A A T A A G A C T T A T A T T T G T C C T T T T G T T T T T C A G C C T A C C A T G A G A A T A N)
      (HUMALDA1-NEG-661 G A A G T C C A T A A A G C C C A C A A G T C A T T T T C A T G A T G G A C A G A A A A A T G T G T G T G C T T T C T C N)
      (HUMALDAR-NEG-1081 A G G C C T G G G G C G G G A A G A A G G A G A A C C T G A A G G C T G C G C A G G A G G A G T A T G T C A A G C G A G N)
      (HUMALDB1-NEG-2761 A A A A A A A A A A T A G C T G G G C A T G G T G G C A G G C G C C T G T A G T T T C A G C T G C T T G G T G T C T G A N)
      (HUMALDB1-NEG-7321 A G T T T G A G A C C A G A C T G A G C A A C A C A G T G G G A C C T T G T C T C T A C T A A A A A T C A A A A A C A T N)
      (HUMALDB2-NEG-1681 C A C C A G C C G G G T A A A C A A T T T C A A A G G G C C A A T A A T A A C A T G C T A T A G A G A G A T T C A A A A N)
      (HUMALDC-NEG-61 T T T A C C A G A G G G A G C C A G G G C T G C A G C T C A T C T G T T T G C G G A T C A A G A A C C C G A G C T G T G N)
      (HUMALDC01-NEG-361 A T G A G A A G T C A A A A A A T A A T A A C T G G C C T T A G T G G C A G A A G C A G C T G C T G C A T A C A C T T A N)
      (HUMALDCG-NEG-1441 C A A C C T C T T C T G T T C T A T C C C T C T T C A G C T C T C C C A G C T G A A C C T C A G C T T T C C A A T C C C N)
      (HUMALDH03-NEG-1 T G T T T T C T A G G A A G A T G T G G A C A A G G C A G T G A A G G C C G C C C G G G C C G C C T T C C A G C T G G G N)
      (HUMALDH2-NEG-1201 G A A T C A T G C A A G C T T C C T C C C T C A G C C A T T G A T G G A A A G T T C A G C A A G A T C A G C A A C A A A N)
      (HUMALDOA-NEG-4501 T C T T C C A T G A G A C A C T C T A C C A G A A G G C G G A T G A T G G G C G T C C C T T C C C C C A A G T T A T C A N)
      (HUMALDOAP-NEG-661 A C A A G A A G G A T G G A G C T G A C T T C A C C A A G T G G C A T T G T G T T C T G A A G A T T G G G G A A C A C A N)
      (HUMALDOBG-NEG-1 T T A T G A G C C A A T C A G A G G T G T T G A A T A A A C A C C T C C C T A C T A G G T C A A G G T A G A A A G G G G N)
      (HUMALIPOA-NEG-781 C C G A C T G A G C A A A G G C C T G G G G T G C A G G A G T G C T A C C A T G G T A A T G G A C A G A G T T A T C G A N)
      (HUMALIPOA-NEG-5341 A C A C C A C A C T C G C A T A G T C G G A C C C C A G A A T A C T A C C C A A A T G C T G G C T T G A T C A T G A A C N)
      (HUMALIPOA-NEG-9901 G G T G T C A G G T G G G A G T A C T G C A A C C T G A C G C A A T G C T C A G A C G C A G A A G G G A C T G C C G T C N)
      (HUMALLFU-NEG-61 C T T C G C G G A G G C G T G G A A G G C G C A G T T C C C G G A C T C A G A G C C C C C G C G C A T G G A G C T G C G N)
      (HUMALP5-NEG-781 T G C C T C C T T T C A C A C T C C T C T T G G G G C T C G T G A C A T T A C G A A C C C T A A C C C G G G C C C T G C N)
      (HUMALPHA-NEG-181 A C T A T A C C C A A A A T C C C C A C C C T T C C C T G G G G A C A C C T G G T C C A C C C T A A G C T G C C T T T C N)
      (HUMALPHB-NEG-241 A A A C T G G G G C C T G A G A C G C C C C T G G C C A T G G A C C G C T T C C C A T A C C T G G C T C T G T C C A A G N)
      (HUMALPHLB-NEG-901 A C G G C G C A C C C C A G A C T A C T T C C T A T A A A T T T C T C C T G G G A A A C C T G C C T T T G T A T G T G G N)
      (HUMALPI-NEG-3901 T C A C A G C C A C T C A G A T G C T T C C T G C C C C C C A G T G C C C A T T C C A G G T C A C C A G A T C C A A G G N)
      (HUMALPL01-NEG-721 C C G C G C C C T G G T T C C C C A G G G C C C C A G C G G A C G T G G T C C A T C C C C T T C T G C A T C C T C C G C N)
      (HUMALPP-NEG-1981 T T T G C T T C A G T C C T T G A A T C A C C T G T G G G A C T T G A G G A C T C G G G A T C T T C A G G A C G C C T G N)
      (HUMALPPB-NEG-781 T G C A G G A A T G G C T G G C G A A G C A C C A G G G T G C C C G G T A C G T G T G G A A C C G C A C T G A G C T C A N)
      (HUMALPPD-NEG-841 C C A G A C C A T T G G C T T G A G T G C A G C C G C C C G C T T T A A C C A G T G C A A C A C G A C A C G C G G C A A N)
      (HUMALPSAT-NEG-541 C C C T A T T T G T G C A G T T T C C A G T T G G A G A T T T C A A T C A C T T T G A G A C C A A A T G T A C A A A A G N)
      (HUMALUAGP-NEG-181 G C A T T T T G G A T T G T T T C T T T C T T T T T T T T T G G T T T T T G T T T T T G C T T T T G T T T T T G T T T T N)
      (HUMAMD-NEG-601 T G A A G C C T T C T C A C C A A G G G T A C C C A C A C C G G A A T T T C C A G G A A G A A A T A G A G T T T C T T A N)
      (HUMAMIPEP-NEG-3361 G G C C G C C C T G T A C C C T C T T T C A C C T T T C C C T A A A G A C C C T A A A T C T G A G G A A T C A A C A G G N)
      (HUMAMY107-NEG-1 T A A C T T T C A G G C T G T A C A A A A T G G C A G T T G G A T T T A T G C T T G C T C A T C C T T A T G G A T T T A N)
      (HUMAMY2A-NEG-361 T G G G T T G A T A T T G C T C T T G A A T G T G A G C G A T A T T T A G C T C C G A A G G G A T T T G G A G G G G T T N)
      (HUMAMYA1-NEG-541 C T G G G A G C G C T C T T T G G A T C C C A T C C C T C A G G C T G G C C A G A G T C C C T G G C A G C T G A G G G A N)
      (HUMAMYA3-NEG-721 A T T C G C A A G T G G A C T G G A G A G A A G A T G T C T T A C T T A A A G T A A A T A A A T A C A A C T T T T C C C N)
      (HUMAMYB-NEG-2041 T T T C A G A C A T G C A G T C A G A A A A T A G A T T T A C T A C A T C C T T A T T A A T G A T A C C A T T A T T G G N)
      (HUMANDREC-NEG-1681 A A G A A G G C C A G T T G T A T G G A C C G T G T G G T G G T G G T G G G G G T G G T G G C G G C G G C G G C G G C G N)
      (HUMANFA-NEG-2581 T T C A G G C C G A T A T T C C T T G T C G T T T T A C T C T T T G T C A G A G G A A A G A A T G C T G A G T T T T T C N)
      (HUMANK-NEG-1981 G T G C A A G G T G T G A C G C C C C T T C A C C T G G C C G C C C A G G A G G G C C A C G C A G A G A T G G T G G C T N)
      (HUMANP70-NEG-361 A A T C C A G G T G C A A A A C G A A T T C T A G A G C T T G A C C A G T T T A A G G G G C A G C A G G G A C A A A A A N)
      (HUMANT1-NEG-2881 T T C A A A A A A A A A A T C T A G G A A G T G C A A A C C T T T T T T T T T T C T C C T G T C C T C T T C C C T T C T N)
      (HUMANT61K-NEG-1681 A A G C C C A T C C T A G A G A A G C T G A C C C A G G A C C A G G A T G T G G A C G T C A A A T A C T T T G C C C A G N)
      (HUMANTCD2-NEG-661 G G A G G C A G C C T C T T G A T G G T C T T T G T G G C A C T G C T C G T T T T C T A T A T C A C C A A A A G G A A A N)
      (HUMANTCE-NEG-841 T A C A G A T C A G G G G A A A A T C T G A A C C T C T C C T G C C A T G C A G C C T C T A A C C C A C C T G C A C A G N)
      (HUMANTLAA-NEG-481 T T A G A A G A T A A A G G T C A A G T A C T A A A T A T T C A G A T G A G A A G A A C A T T G C A T A A A G C A T T T N)
      (HUMANTNC-NEG-2401 C T T G T T C C A A T T T G A C A A A A C C C A C T G T T C T T G T A T T G T A T T G C C A G G G G G G A G C T A T C A N)
      (HUMANTP53-NEG-121 A G G T C G G C G A G A A T C C T G A C T C T G C A C C C T C C T C C C C A A C T C C A T T T C C T T T G C T T C C T C N)
      (HUMAPA-NEG-841 T G C T T C T G C T A T A T T T G T G A T A T A G G A A T T A A G A G G A T A C A C A C G T T T G T T T C T T C G T G C N)
      (HUMAPA4R-NEG-2761 A A G A A T C G A T G G G G G A T G C T T C A T G T G A A C G T G G G A G T T C A G C T G C T T C T C T T G C C T A A G N)
      (HUMAPB03-NEG-1441 G C T G A T A A A G A C A T A C C T G A G A C T G G G T A A T T A C A A A A G A A A G G T T T A T T G G A C T C A C A G N)
      (HUMAPB09-NEG-1 A A G C T T A T A G G C T G G T G G A G A G A G A A C T C A G A C G A A A A A T A T A A T A T G A T T T C T C T A C C C N)
      (HUMAPB13-NEG-1 A A C A G G C A T T C C A C A G G C T T T T T C T G G G A A C C C T T A C T T G A T A G T G C T C T A G G A A A C A C T N)
      (HUMAPB18-NEG-601 A A T T T G C T C C T A A T T C A G T G T C C A T G T T T C T G A G C C T C C A G A C C A T C G C T A T G A G C T T C C N)
      (HUMAPB21-NEG-2941 T T C A T G G C A G G C T C T A A G A G G A G A G C C T C C T C C A G G G A G G A A A G G A C T T T G G C T T T C T A G N)
      (HUMAPB21-NEG-7501 T C A C A T T A G A T G C A A A T G C T G A C A T A G G G A A T G G A A C C A C C T C A G C A A A C G A A G C A G G T A N)
      (HUMAPB21-NEG-12061 T C A T C T A A A T C A T A G G C A A G C T C A G C C A T A G G C A G G G T A T A T T T T C A G A G A G G A C T G G T T N)
      (HUMAPB48A-NEG-2041 G A C C A A C A T A T C C A G G T T T T A A T G G A T A A A T T A G T A G A G T T G G C C C A C C A A T A C A A G T T G N)
      (HUMAPBM-NEG-3841 T G G G T T C C A A A T T A A T A G T T G T A A G T A T G A G T C T G C C A G T C A A T A A A T A C A T G G A T A T A A N)
      (HUMAPC3G5-NEG-481 C C G C A G A A C T C C T C T G T G C C C T C T C C T C A C C A G A C C T T G T T C C T C C C A G T T G C T C C C A C A N)
      (HUMAPLA-NEG-1261 A C A G G C C T T C C C C T C T T C G T G G G C A G C G T G A G G A A C C C C A A C C C C A G T G C A C C G C G G G A G N)
      (HUMAPOA4-NEG-61 G T G G T C C T G A C C C T G G C C C T G G T G G C T G T C G C C G G A G C C A G G G C T G A G G T C A G T G C T G A C N)
      (HUMAPOA4A-NEG-3241 C T C T C C C T C C C T G A G C T G G A G C A A C A G C A G G A A C A G C A T C A G G A G C A G C A G C A G G A G C A G N)
      (HUMAPOA4C-NEG-2761 G T C A A G A T T G A C C A G A C C G T G G A G G A G C T G C G C C G C A G C C T G G C T C C C T A T G C T C A G G A C N)
      (HUMAPOAI1-NEG-721 A C C T T G G C C G T G C T C T T C C T G A C G G G T A G G T G T C C C C T A A C C T A G G A G C C A A C C A T C G G G N)
      (HUMAPOAI1-NEG-5281 C C A G T A G T C T T T C A G G G A A C T G A A G C C A T C G G T C A C C C A G C C C C T A A A T C A G T C A G G G G A N)
      (HUMAPOAIA-NEG-1 A A G C T T C T G A G A T T C C C C C A T G T G C T G A C T G G G A C A A A C T C T A C C C C C C A A A A G A A A A G A N)
      (HUMAPOAIT-NEG-661 T C C C C T C C C A C C C T C A G G G A G C C A G G C T C G G C A T T T C T G G C A G C A A G A T G A A C C C C C C C A N)
      (HUMAPOB-NEG-1321 A A T T T T G C T G G A G A A G C C A C A C T C C A A C G C A T A T A T T C C C T C T G G G A G C A C A G T A C G A A A N)
      (HUMAPOB10-NEG-301 C A G A A T G A G C A A G T G A A G A A C T T T G T G G C T T C C C A T A T T G C C A A T A T C T T G A A C T C A G A A N)
      (HUMAPOB2-NEG-3061 C C A G T G A A G T C C A A A T T C C G G A T T T T G A T G T T G A C C T C G G A A C A A T C C T C A G A G T T A A T G N)
      (HUMAPOB2-NEG-7621 T A G A G C A A G G G T T C A C T G T T C C T G A A A T C A A G A C C A T C C T T G G G A C C A T G C C T G C C T T T G N)
      (HUMAPOB2-NEG-12181 C T T C A A A G C T G A G A A G A A A T C T G C A G A A C A A T G C T G A G T G G G T T T A T C A A G G G G C C A T T A N)
      (HUMAPOB26-NEG-2881 A G G C A G T C C T G G T C A G T T T G C A A G C A A G T C T T T C C T G G C C T G A A T T A C T G C A C C T C A G G C N)
      (HUMAPOB4A-NEG-241 A A A A T A G C T A T T G C T A A T A T T A T T G A T G A A A T C A T T G A A A A A T T A A A A A G T C T T G A T G A G N)
      (HUMAPOBA-NEG-4141 G T T C T A G A C C T C T C C A C G A A T G T C T A C A G C A A C T T G T A C A A C T G G T C C G C C T C C T A C A G T N)
      (HUMAPOBA-NEG-8701 G T C A A G A T A A A C A A T C A G C T T A C C C T G G A T A G C A A C A C T A A A T A C T T C C A C A A A T T G A A C N)
      (HUMAPOBA-NEG-13261 G G C T G G A C A G T G A A A T A T T A T G A A C T T G A A G A A A A G A T A G T C A G T C T G A T C A A G A A C C T G N)
      (HUMAPOBB-NEG-3541 G G C A C C A A T G T A G A T A C C A A A A A A A T G A C T T C C A A T T T C C C T G T G G A T C T C T C C G A T T A T N)
      (HUMAPOBB-NEG-8101 A T T C C T C T A G C G A G A A T C A C C C T G C C A G A C T T C C G T T T A C C A G A A A T C G C A A T T C C A G A A N)
      (HUMAPOBB-NEG-12661 A T G A G G G A G G T A G G G A C G G T A C T G T C C C A G G T A T A T T C G A A A G T C C A T A A T G G T T C A G A A N)
      (HUMAPOBF-NEG-1081 A A G G C G A C A C T A A G G A T T G G C C A A G A T G G A A T A T C T A C C A G T G C A A C G A C C A A C T T G A A G N)
      (HUMAPOBF-NEG-5641 C A C A G G C A T T C C A T C A C A A A T C C T T T G G C T G T G C T T T G T G A G T T T A T C A G T C A G A G C A T C N)
      (HUMAPOBG-NEG-121 A C T G A G A C A C A G G A A G G G C C G C G C C A G A G C A C T G A A G A C G C T T G G G G A A G G G A A C C C A C C N)
      (HUMAPOC2-NEG-2521 G A C A G A G C C G A G A C T C C A T C T C A A A A A A T A C G A A A A C A A A A A T C A G C C G G G T G G T G G C G G N)
      (HUMAPOC2G-NEG-3001 A C G A G A A G A C A T A C C T G C C C G C T G T A G A T G A G A A A C T C A G G T A G C A C C T G C C C C T G G A G A N)
      (HUMAPOCIA-NEG-2221 T G G A G A G G C T G A C A A C A T C C C T C T G G T C A C A C A G C T A G A T C T C A A G G T G C T C A G A C T T C A N)
      (HUMAPOCIB-NEG-1441 G T A T C C T C C C C A T T C T A A C C A C A T G A T C C C C A A G G A T C T C C T T A T C T A T C C C C G G G A T C C N)
      (HUMAPOCII-NEG-121 A A T A A C A C C C T A T T G T G G G C T T G C G G A G A A T G G G G G A C T T C A A G G C G T G T C A G T T T C A G G N)
      (HUMAPOCIP-NEG-301 A A G G C T C A G G A G G A G G G A G A T C A A C A T C A A C C T G C C C C G C C C C C T C C C C A G C C T G A T A A A N)
      (HUMAPOE3-NEG-1 C G C A G C G G A G G T G A A G G A C G T C C T T C C C C A G G A G C C G A C T G G C C A A T C A C A G G C A G G A A G N)
      (HUMAPOE4-NEG-3301 G G T C T C T G C T G G T T C T A G C T T C C T C T T C C C A T T T C T G A C T C C T G G C T T T A G C T C T C T G G A N)
      (HUMAPRT-NEG-421 T C G A T G G C G C C T A G G A G T C C A T G A A A T A C G G T A C A G G C T T C C G G C G A C G G A T G C C C C G C C N)
      (HUMAPRTA-NEG-1981 G T G G G C C T C C T A T T C C C T G G A G T A C G G G A A G G T A A G A G G G C T G G G G T G G C C G G A G G A A G G N)
      (HUMARA-NEG-1441 G C C G C T T C C T C A T C C T G G C A C A C T C T C T T C A C A G C C G A A G A A G G C C A G T T G T A T G G A C C G N)
      (HUMARAF1R-NEG-1381 T G G C C G A C A C A C G C T T C G A C A T G G T C C A G C T C A T C G A C G T G G C C C G G C A G A C T G C C C A G G N)
      (HUMARB-NEG-3541 G A A T G G T G T T G T A T G C C T T T A A A T C T G T G A T G A T C C T C A T A T G G C C C A G T G T C A A G T T G T N)
      (HUMARC6-NEG-61 G T A C C G C A T G C A C A A G T C C C G G A T G T A C A G C C A G T G T G T C C G A A T G A G G C A C C T C T C T C A N)
      (HUMAREPAP-NEG-61 G A T A G A G C A G T T T T G A A A C A C T C T T T T T G T G G A A A A T G C A A G T G G A T A T T T G G A T A G C T T N)
      (HUMAREPBV-NEG-61 G A C A G A G C A G T T T T G A A A C A G T C T T T C T G T G G A A T C T G C A A G T G G A T A T T T G G A T A G C T T N)
      (HUMARF1A-NEG-301 G C C G C A G C G G C G C A G C T G A T A G C A G G A A C A G G A T C A A G T C T T C C A T A C C A G G G A C C A G G C N)
      (HUMARGL-NEG-241 G T C C C T T T C A A A T T G T G A A G A A T C C A A G G T C T G T G G G A A A A G C A A G C G A G C A G C T G G C T G N)
      (HUMARMA-NEG-961 C A C T G A G T T G A T T T T A G C A G A G A A A C G T G G T G A C C T G A C A A G A G A G A A T G T G A A C C A G T G N)
      (HUMARP450-NEG-2521 C T C A A A C T T C T A A G G G G T A C T C C T C T C A T C C C C T T A T C C T T C T C C C T C G A C A T T T T C T C C N)
      (HUMARSBX-NEG-421 C G G C C T C G C A A G C C C A C G G C C C G C T G G G G G T G C C G T C C C G C G C C G G G G C G G A G C A G G C C C N)
      (HUMAS08-NEG-721 G T C A T C G A A G G G A A G G G T G G G G G G C A G C T G C G G T G G G G A G C T A T A A A A A T G A C A A T T A A A N)
      (HUMASA-NEG-61 C C A A T C C C A G A C G C T A T G T C C A G C A A A G G C T C C G T G G T T C T G G C C T A C A G T G G C G G C C T G N)
      (HUMASFB-NEG-1021 C A G A A G G G C G T G A A G A A C C G G G A G C T C A T C C A C A T C T C T G A C T G G C T G C C A A C A C T C G T G N)
      (HUMASGPR1-NEG-661 C A G C T G C T A C T G G T T C T C T C G C T C C G G G A A G G C C T G G G C T G A C G C C G A C A A C T A C T G C C G N)
      (HUMASL1A-NEG-961 C G G T G T G C C G G G C T C C T G A T G A C C C T C A A G G G A C T T C C C A G C A C C T A C A A C A A A G A C T T A N)
      (HUMASP-NEG-541 C G T C T G C C C C T G C A G C T G G A T G A T G C T G T T C G G C C T G A G C A A G A A G G A G A A G A G G A A G G A N)
      (HUMAT3X1-NEG-1 G A T C A C A C T A T C T C C A C T T G C C C A G C C C T G T G G A A G A T T A G C G G C C A T G T A T T C C A A T G T N)
      (HUMATCCD2-NEG-1261 C T C C A T C A C A C C A G T A A G G A G A A G C A A T A T A A G T G T G A T T G C A A G A A T G G T A G A G G A C C G N)
      (HUMATCT4-NEG-1561 C G T C C T C C C T A C A A T T T G C C A T T G T T T C T C C T G G G T T A G G C C C C G G C T T C A C T G G T T G A G N)
      (HUMATH3U5-NEG-181 T G T T C A G C A T C T A T G A T G T A C C A G G A A G G C A A G T T C C G T T A T C G G C G C G T G G C T G A A G G C N)
      (HUMATP-NEG-1981 T C G G C A G G T G G G C A A C A A G A C C G A G T G T G C T C T G C T A G G C T T T G T C A C A G A T C T G A A G C A N)
      (HUMATP1A2-NEG-2101 G G G A G T C C T A G C C T G A G A G G C T G G G G G T C C A T T T T G A G G T T A G A G A G G G G C A G T A G A G C A N)
      (HUMATP1A2-NEG-6661 A T G G A G G C C C C A G C C C C T C T C T T C C C T G A C T C T C C G G C T C T C C C T C C C T C A G G C T G G C C G N)
      (HUMATP1A2-NEG-11221 C A G G G T A T T G A C T G A G G G C A G C C T G A C T C C A T G G G A A A T G T A T C T C C C T T C C C C A G G G A G N)
      (HUMATP1A2-NEG-15781 T G T A C C C T T C C A T T C T G A T T T G A A G C A T A A T C T G G C A C T C C T A T C T T G A A G A C C T A G T T G N)
      (HUMATP1A2-NEG-20341 T G T G G C C G T C T T C C C T C C A G G G A G C C A T T G T G G C C G T G A C G G G T G A C G G G G T G A A C G A C T N)
      (HUMATP1A2-NEG-24901 G G C A G A C A G G T G G G A G A T G G A G G T A G G G C T G G C T G G A G G A A G G A A A C A A C A A A G G A A G T G N)
      (HUMATPA2-NEG-781 G T C T T T G C T T T T C T C T G T A T T A T A T C A A A C A T T G G G A A A T T C A G C C T C T C C A G G C G A T G G N)
      (HUMATPAR-NEG-3241 G G T G T T G C T C T T A G G A T G T A T C C C C T C A A A C C T A C C T G G T G G T T C T G T G C C T T C C C C T A C N)
      (HUMATPB-NEG-841 T T A A C T G T G T C T C G T G C A C G G A A A A T C C A G C G T T T C T T G T C T C A G C C A T T C C A G G T G G C T N)
      (HUMATPCAPM-NEG-661 G T C A C A A T C T C T G A T T C C T T G C A G A T G G A T G T A G T G A A T G C T T T C C A G A G T G G A A G T T C C N)
      (HUMATPSY1-NEG-1 A T G C C T C C C A A A G T G C A G G G A T T A C A G G T G T A A G C C T A C C A C A C C C A G C C A A A A T C C T A T N)
      (HUMATPSY1-NEG-4561 A T C A A C A A T G T C G C C A A A G C C C A T G G T G G T T A C T C T G T G T T T G C T G G T G T T G G T G A G A G G N)
      (HUMATPSYB-NEG-841 T T A T T T T A T A T A T T T A T T T T A T T T T T T T A G A G A G T C T C A C T C T G T C G C C C A A G C T G G A G T N)
      (HUMATPSYB-NEG-5401 G T T C A G A G G T A A G A G G G A A G G C T T G A G A G G A C C T G G T T C A T C T G G C C T T T C T T C G G A T G A N)
      (HUMATPSYB-NEG-9961 G T A T T T A A T T T T A G T T T T A G A G A C A C G G T G T C T G G C T G T G T T G C C A A G A C T G G T C T C T A A N)
      (HUMB100DI-NEG-121 C T C C A G G G A G G A A A G G A C T T T G G C T T T C T A G C A G A T A A T C T T C C T T G C T A C T T G G A A G T C N)
      (HUMB2M2-NEG-1201 T G T G A G T G G C A T G A A G A A G G T G T A T G G C C C C A C C T A T G G C C T A T T T A C T G A C C C T C T A C A N)
      (HUMBARR-NEG-361 G A G C G T C T G C A G A C G G T C A C C A A C T A C T T C A T C A C T T C A C T G G C C T G T G C T G A T C T G G T C N)
      (HUMBAT2A-NEG-2761 G C C G A A A G C T G C C C G C G A G T C G G A G T G G A G C A G G C C C C C C A C C A C C A C G C A G A G A G A G T C N)
      (HUMBAT2B3-NEG-1 T C T A G A A T C C T G C T T T T A T C C C A G C A T C T T T G C T T T C T A T G T T G C T C A G T C G C C C T A T G T N)
      (HUMBAT2B4-NEG-1441 T A G C A C C A G C A G T G G C A G C T T C G A A G C C A G C C C A G T G G A A C C A C A A C T G C C C T C A A A A G A N)
      (HUMBAT2B4-NEG-6001 C T T C C G C A C C C A G C G C G T C G A C C T T T A C C A G C A G G C C T C C C C A C C A G A T G C C C T G C G C T G N)
      (HUMBAT3B1-NEG-421 T G G G G C T G C G G A C T T T C T C G T C G T G C C C C A C A A A A G T A A A G C T T G G G G A C C T G G G G G G A G N)
      (HUMBAT3B2-NEG-4141 T G C T C T A T G G C C C T T C C T C A T C A G G G G A C C G T T T C C C C C C T C T T C C T T C A C A G T A T T T A A N)
      (HUMBCI2-NEG-241 C A C C A C C C A A C C C A C C A T C C A A C C C A C C C A A C C A A C T A C C C A G C T C C C A A C A G A T T C T C C N)
      (HUMBCL2A-NEG-1 G C G C C C G C C C C T C C G C G C C G C C T G C C C G C C C G C C C G C C G C G C T C C C G C C C G C C G C T C T C C N)
      (HUMBCL2A-NEG-4561 C T G T G G T A T G A A G C C A G A C C T C C C C G G C G G G C C T C A G G G A A C A G A A T G A T C A G A C C T T T G N)
      (HUMBCL2C-NEG-3061 G G G G C T T T C T C A T G G C T G T C C T T C A G G G T C T T C C T G A A A T G C A G T G G T G C T T A C G C T C C A N)
      (HUMBCL3AA-NEG-1381 G A G G G G G A T G G G G G G G C A G A T C T T G G A C T C A T G A G G A G G G G C C C C C C T G C C C A G A G G G G T N)
      (HUMBCR-NEG-1801 C C A C C A T C G T G G G C G T C C G C A A G A C C G G G C A G A T C T G G C C C A A C G A T G A C G A G G G C G C C T N)
      (HUMBCR22I-NEG-1681 C T G G T G T G G A G G G A C T C C C T C C A G T C A C T T T C A G A C C T C A C T C C C C A T G C T G C T C C C A C A N)
      (HUMBCRD-NEG-301 G C G C G C C G A G C G C C C C G C T C C G C C T C A C C T G C C A C C A G G G A G T G G G C G G G C A T T G T T C G C N)
      (HUMBCRR-NEG-1261 A G G C A G C C T T C G A C G T C A A T A A C A A G G A T G T G T C G G T G A T G A T G A G C G A G A T G G A C G T G A N)
      (HUMBDGALA-NEG-1441 A C A T A A C A G G G A A A G C T G G A G C C A C T C T G G A C C T T C T G G T A G A G A A C A T G G G A C G T G T G A N)
      (HUMBGAL-NEG-781 A G A T G C T T T C C T A A G C C A G A G G A A G T G T G A G C C C A A A G G A C C C T T G A T C A A T T C T G A A T T N)
      (HUMBGPG-NEG-1021 C A C A G C C T T T G T G T C C A A G C A G G A G G G C A G C G A G G T A G T G A A G A G A C C C A G G C G C T A C C T N)
      (HUMBHA05-NEG-61 C A C C G G G G C T T G C T G T T G G A T A C A T C T C G C C A T T A C C T G C C A C T C T C T A G C A T C C T G G A C N)
      (HUMBHAA-NEG-1261 G T G G G G A G A A T A T G T G G A C A A C A C A A A C C T G G T C C C C A G G C T C T G G C C C A G A G C A G G G G C N)
      (HUMBLAST1-NEG-661 G T C T G C C T C A G T C C A C C C T G T A C C C T G G C C C G G T C C T T T G G A G T A G A A T G G A T T G C A A G T N)
      (HUMBMP1A-NEG-2161 C T C G G G G A C G C C C C C A C C A G C T C A A A T T C C G A G T G C A G A A A A G A A A C C G G A C C C C C C A G T N)
      (HUMBMP3A-NEG-1021 C T T T T C C A G A G C C T T A T A T C T T G G T A T A T G C C A A T G A T G C C G C C A T T T C T G A G C C A G A A A N)
      (HUMBN51-NEG-1261 G G C G C C T G T G C C C A C G C T G C T G C C T G C T C C A G A C A T T T T G T T C T T G A A T C T G T G A G A C C C N)
      (HUMBPGM3-NEG-661 A A G G G A T A C T T T G A T A A T T A A G G C C A G A G G C C C A T T A G T T G A G A A A G T C A C A G A T A T A T T N)
      (HUMBRAFA-NEG-601 G T A T A T G C A T T T G G A A T T G T T C T G T A T G A A T T G A T G A C T G G A C A G T T A C C T T A T T C A A A C N)
      (HUMBSF2-NEG-4141 T G C T G G C T A G C A T G T G G A G G A G C C A A A G C T C A A T A A G A A G G G G C C T A G A A T G A A A C C C T T N)
      (HUMBURKA-NEG-1141 C A A C C C G C C C T G A T C C T T T T A A G A A G T T G G C G A T T T G G C T T T T T G A A A A G C A A T A A T A C A N)
      (HUMC1A1-NEG-3901 A T G G C C T A C A T G G G T G T G G G T G C T G C A A T T T C C G C T N C G G C A G A C A G T T G G G A A C G A T A C N)
      (HUMC1A2-NEG-661 A C C T G G T C C T C C T G G C C C C C C T G G T C T C G G T G G G A A C T T T G C T G C T C A G T A T G A T G G A A A N)
      (HUMC1A2-NEG-5221 C A A A G T T G T C C T C T T C T T C A G A T T C A G C A T T T G T T C T T T G C C A G T C T C A T T T T C A T C T T C N)
      (HUMC1INH-NEG-481 G G C T C T C A G C C C T T C T G T T T T C A A G G C C A T C A T G G A G A A A C T G G A G A T G T C C A A G T T C C A N)
      (HUMC1INHI-NEG-121 G T C T G C C C T C C G A T A C C C G C C T T G T C C T C C T C A A T G C T A T C T A C C T G A G T G C C A A G T G G A N)
      (HUMC1R-NEG-1801 G A C A A C G A T A C C T T C T A C G A C C T G G G C T T G A T G G G C T A T G T C A G T G G C T T C G G G G T C A T G N)
      (HUMC1RX-NEG-1201 A A T G G T G A C T T C C G T T A C A C C A C C A C A A T G G G A G T G A A C A C C T A C A A G G C C C G T A T C C A G N)
      (HUMC1SAB-NEG-841 C G G T T G G A G A A A G G G T T C C A A G T G G T G G T G A C C T T G C G G A G A G A A G A T T T T G A T G T G G A A N)
      (HUMC21PLA-NEG-121 A A A A T G T C T G C T C A G T T A A A A A A A A A A A A A G T A G T A G T G C C A C C C A G T T T C A G G C A G A A A N)
      (HUMC3-NEG-3481 A T G G C C C T C A C G G C C T T T G T T C T C A T C T C G C T G C A G G A G G C T A A A G A T A T T T G C G A G G A G N)
      (HUMC3A1R-NEG-2941 G G T G C A A T C G G C A G T C C A G G A C C T G C A G G C C C C A G A G G A C C T G T T G G A C C C A G T G G A C C T N)
      (HUMC45B2B-NEG-1021 T A A T A T A C A A A A T C A T A T A T A T A T A T A T G T T C T T G T T T T T T G A G A C A G A G T C T C A C A C T G N)
      (HUMC4A1-NEG-2761 G G A T C C C G A G G A G A C C C T G G G A C C C C A G G A G T G C C T G G A A A G G A C G G G C A G G C A G G A C A G N)
      (HUMC4A2-NEG-3721 A C T T A A A G G A C A A A C A G G C T T T C C A G G G C T G A C T G G G C C T C C A G G G T C G C A G G G A G A G C T N)
      (HUMC4BP-NEG-241 G G A G T T G G C T G G A G T C A T C C T C T C C C A C A A T G T G A A A T T G T C A A G T G T A A G C C T C C T C C A N)
      (HUMC5A2B-NEG-181 A T T G T T T T A T T A G G G C A A T T T G T C T C A A T A A A A G C C C A G G A A G A A G A C G A G G A T G A A G G A N)
      (HUMC5B-NEG-3241 A C T T T C A C A G T G T A C G A A T A C C A C A G A C C A G A T A A A C A G T G T A C C A T G T T T T A T A G C A C T N)
      (HUMC6AI-NEG-301 T A C A A T G C T C A T A A C A T A A A A A A T C A A A C A T A A C A T C A A A T A A A A T A T A T G A T T C T G A T A N)
      (HUMC7A-NEG-1861 G T T G G G G A A A T G C A T T G T C A G A A A A T T G C C T G T G T T C T A C C T G T A C T G A T G G A T G G C A T A N)
      (HUMC8B-NEG-241 T G T G C A C A G A C A G G A A G G T G T G T A A A C C G C A G A C T T C T T T G C A A T G G G G A C A A T G A C T G T N)
      (HUMC8GA-NEG-241 C C A C C A C A C T G C A T G T G G C T C C C C A G G G C A C A G C C A T G G C T G T C A G T A C C T T C C G A A A G C N)
      (HUMC9M-NEG-841 T T A C C A A C T A T T T T T G T C A T A T T C T T C A A A G A A G G A A A A A A T G T T T C T G C A T G T G A A A G G N)
      (HUMCA1XIA-NEG-3421 G A G A G A A A G G T G C T C C T G G A G A A A A A G G T C C C C A A G G G C C T G C A G G G A G A G A T G G A G T T C N)
      (HUMCA2VR-NEG-361 A G G G G T G C T C C T G G C A A T C G T G G T T T T C C A G G C T C T G A T G G T T T A C C T G G G C C A A A G G G T N)
      (HUMCAATP3-NEG-61 G A A A C C T T G A A A A G A T C A A G C T G A A T G T T C C T T T T C A T C T G T C G C T G T T G A T C T T C A T C T N)
      (HUMCACY-NEG-3481 C A T C A G A G A A G A T G A C T A A T T G A A T C A T T G T C C A T C A T C T G G A T T A G T G T T T T A A G G C A G N)
      (HUMCAIII1-NEG-181 A A G C A A C T T T T A A G T G A G G C T G C A A G A G C C G C C G G G A T G T A G A T T T T A G T T C G T G G C C A A N)
      (HUMCAL-NEG-301 G G A C A G C C C C A G A T C T A A G C G G T G C G G T A A T C T G A G T A C T T G C A T G C T G G G C A C A T A C A C N)
      (HUMCALC1-NEG-1561 G T T A C C T A T T G T G C A T C T T T T T A A A T A C T T G A T T A T G T A A C C A T A A A T C T G A C A G C A T G T N)
      (HUMCALLA-NEG-2161 T C A G G A T T A T T G G G A C T T T G C A G A A C T C T G C A G A G T T T T C A G A A G C C T T T C A C T G C C G C A N)
      (HUMCALLA14-NEG-61 T G T C A A T G G G A A T A T G G A A A A T G C T G T G G G G A G G C T T T A T G T G G A A G C A G C A T T T G C T G G N)
      (HUMCAM-NEG-121 T G G T G A T G G C A C T A T A A C A A C A A A G G A A C T T G G G A C T G T A A T G A G A T C T C T T G G G C A G A A N)
      (HUMCAMA-NEG-841 C C C T T G G A G C C T C T G C C C T C C T C C A G C C C G G A T G G C C T C T C C T T C A T T T T G G T T T G T T T C N)
      (HUMCANPR-NEG-841 A C C T C T A C C A G A T C A T C C T C A A G G C G C T G G A G C G G G G C T C C C T G C T G G G C T G C T C C A T A G N)
      (HUMCAPG-NEG-1261 C C T G G T G C G A G A A G A C T T T G T G C T G A C A G C A G C T C A T T G C T G G G G A A G G T G A G G A G C T A A N)
      (HUMCARM-NEG-661 C T T G C A C A T A C C T A T G C T T C A A G A A A T C C C A A C A T G A A G A A A G G A G A C G A G T G T A A A A A C N)
      (HUMCARN-NEG-1561 G G C C C T A G T A G C A G C C A T A C A G G A G C T G G G G A A G G G G G C C T C T G G G G C T G A C C A G G C G A C N)
      (HUMCATF-NEG-721 T T A C C T A A T T A G A A A A A A A A T C T A G T C A A A C A A T T A T A A T A A T G G G G A A G T C A T A T A C A A N)
      (HUMCATG12-NEG-241 G A T T C T C C T G T G C T A G A T G T G C A A A T G C A A G C T A G T G G C T T C A A A A T A G A G A A T C C C A C T N)
      (HUMCATR-NEG-1081 C A A C A T G C C A C C T G G C A T T G A G G C C A G T C C T G A C A A A A T G C T T C A G G G C C G C C T T T T T G C N)
      (HUMCBP-NEG-1321 C A T T A A T T T T G T G C A T T C T T T G G T A A T T T T T T T T G T T T T T T G T A A C T A C A A A G C T T T G C T N)
      (HUMCCG1-NEG-1621 G G A T G C T C A G G C C A T G C C C C G G C T G T T G G A A C C T C C T G T T T T G A C A C T T G A T C C C A A T G A N)
      (HUMCCK2-NEG-361 C G C A C C T G G G C G C C C T G C T G G C A A G A T A C A T C C A G C A G G C C C G G A A A G G T A A G A A T G C T G N)
      (HUMCD1A-NEG-1261 A G C A G C A G G G C A C T C A G C G A G G G G A C A T C T T G C C C A G T G C T G A T G G G A C A T G G T A T C T C C N)
      (HUMCD1B1-NEG-241 A G C T C T G C C A G T A A G A A G T T G C A T C T C C C A G T G A A A T G C T G C T G C T G C C A T T T C A A C T G T N)
      (HUMCD20-NEG-721 G G C A T C G T T G A G A A T G A A T G G A A A A G A A C G T G C T C C A G A C C C A A A T C T A A C A T A G T T C T C N)
      (HUMCD2A-NEG-121 C C T G G G G T G C C T T G G G T C A G G A C A T C A A C T T G G A C A T T C C T A G T T T T C A A A T G A G T G A T G N)
      (HUMCD7-NEG-241 G G G T G G G G T G C T G A G C G G C C T C C A G T G T C T G A G G A C T C A T T T A A G A G A A G G A A A A A G G G T N)
      (HUMCDW44A-NEG-1261 T G G G A C A C T T A A C A G A T G C A A T G T G C T A C T G A T T G T T T C A T T G C G A A T C T T T T T T A G C A T N)
      (HUMCEAB-NEG-121 C T T T T A C A A A T C A G G G A A T C A A G G A T C A T A G A A G C C A C G T G C A C T T G T C C A A G T C A A C A T N)
      (HUMCEAE-NEG-61 C A G G T G T T G A C A A G A A C C C T G G A G G G A G G A G A G C A G G G A A A G G T C A G A A A G G G A A G A C C C N)
      (HUMCEALV-NEG-721 C C C T C A C T C T A T T C A A T G T C A C A A G A A A T G A C G C A A G A G C C T A T G T A T G T G G A A T C C A G A N)
      (HUMCENPBR-NEG-901 A C C T C G G G C C T G C G G C A T G T G C A G C T G G C C T T C T T C C C T C C C G G C A C C G T G C A T C C G C T G N)
      (HUMCERP-NEG-121 G A A A A G A A A C T T A T T T C T G T T G A C A C G G A A C A T T C C A A T A T C T A T C T T C A A A A T G G C C C A N)
      (HUMCERPS-NEG-1381 T C C C T G G A A C A T A C C A A A C C C T A G A A A T G T T T C C A A G A A C A C C T G G A A T T T G G T T A C T C C N)
      (HUMCETP2-NEG-661 A T T G A T C A G T C C A T T G A C T T C G A G A T C G A C T C T G C C A T T G A C C T C C A G A T C A A C A C A C A G N)
      (HUMCETP6-NEG-481 G C A A A C C T C T C C C T G G C C C C T T G G A G T C A G G C A C A G G G C G G G G T G T T G G T G G G G A A A T G T N)
      (HUMCFTRM-NEG-2281 A C T C C C T T A C A A A T G A A T G G C A T C G A A G A G G A T T C T G A T G A G C C T T T A G A G A G A A G G C T G N)
      (HUMCFVII-NEG-661 C A A A C C C C G C C C T T G C T C C G G A C A C C C C C A T C C A C C A G G A G G G T T T T C T G G C G G C T C C T G N)
      (HUMCFVII-NEG-5221 C A C A G G A C A C C T C A C A G A G G T C A C C T C A C A C G G G G C A C A C T T C A C A C T C A G G T C A C C T C A N)
      (HUMCFVII-NEG-9781 G T C G T C C T C A C G G T T A C T C T T T G A G G T G G G A T C T T T G C C T G A T C T T T G C A A A A T C A G G A G N)
      (HUMCFXI03-NEG-421 G C T A G T A T T T T T T T T T T T T T T T G T A T T T T T T A T A G A G A C A G G G T C T T G C C A T G T T G C C C A N)
      (HUMCFXI14-NEG-481 G T T T T T G A T C A C G C T T C T A T G G A G T C C A A G A A T T A C C A T A A G G C A A T G T T T C T G A A G A T T N)
      (HUMCFXII3-NEG-3061 T T C C C T C T G G G C G C C G G G C T G C A A A G G C C A A C T A G G A C G C T G G C C C C G C G C T C C G G G C T A N)
      (HUMCG1A1B-NEG-121 C T C T A C T A A A A A T A T A A A A A T T A G C T G G G C G T G G T A G T G C A T G G C T G T C A T C C C A G T T A C N)
      (HUMCG1PA1-NEG-1501 C C T G G T C C C C C T G G C C C T G C T G G C G A G A A A G G A T C C C C T G G T G C T G A T G G T C C T G C T G G T N)
      (HUMCG2A1-NEG-1 G G T G A A C C T G G A C G A G A G G T G A G C A G T G A G A C C C C C T G G G G T G G C C C T G A T T G G G G A G A G N)
      (HUMCG2A1-NEG-4561 A C A T A G G A G G G C C C G A G C A G G A A T T C G G T G T G G A C A T A G G G C C G G T C T G C T T C T T G T A A A N)
      (HUMCG4A11-NEG-961 T C G C T G T G G A T C G G C T A C T C T T T T G T G A T G C A C A C C A G C G C T G G T G C A G A A G G C T C T G G C N)
      (HUMCG5B-NEG-1261 G G G A A G G G T C T C T G G G T C T T T G T G G G T G G T G T G C C A C G T G G G A T G G G A A G G C C G G G G C T C N)
      (HUMCGB-NEG-181 C A T C T G T G C C G G C T A C T G C C C C A C C A T G A C C C G C G T G C T G C A G G G G G T C C T G C C G G C C C T N)
      (HUMCGPRA-NEG-1981 T G G C A A A A C A C T G C T C A G A G A C G A G A G C C T G A A T A T C T T T C A A A A C C T C A A T C G T C G A C A N)
      (HUMCH15M-NEG-121 C C T A A G A A A A A T G T G T T T T C A T G T A C A G T A A G T C A T T G T C T T C A C T T G G C T G C C A C C T C C N)
      (HUMCHEBG2-NEG-1 T T T A C A G A A T C A G G T T T A T T T G T T T C A T A A T T T G T A G A A T T A T C A A G C A T C A T A T T T T A G N)
      (HUMCHEF-NEG-181 A C A A A G A A T G G A A A A G T C A G A G G G A T G A A C T T G A C A G T T T T T G G T G G C A C G G T A A C A G C C N)
      (HUMCHRA-NEG-121 C G G G C A A G T C A C T G C G C T C C C T G T G A A C A G C C C T A T G A A T A A A G G G G A T A C C G A G G T G A T N)
      (HUMCHROMB-NEG-421 G G C A G G A G C C C C A G G G G A G G A G G A C A T C C A A G G C C C A A C A A A G G C A G A C A C A G A G A A A T G N)
      (HUMCINHA-NEG-541 T C T G G G A A G A A G C T G T A A A A A T G G G C T A T T A T A T A T T G G G G G T G G G G T A G A G G G A T G T A T N)
      (HUMCINHP-NEG-121 G G A G A T G A A G A A G A G A G T C G A G G A C C T C C A T G T A G G T G C C A C G G T G G C C C C C A G C A G C A G N)
      (HUMCIX-NEG-2521 T T G A A G T T G C C T A G A C C A G A G G A C A T A A G T A T C A T G T C T C C T T T A A C T A G C A T A C C C C G A N)
      (HUMCKBBA-NEG-481 C C A T C G A G A A G C T C G C G G T G G A A G C C C T G T C C A G C C T G G A C G G C G A C C T G G C G G G C C G A T N)
      (HUMCKMM1-NEG-1921 T C C C C G C A C A G C G A A A T C T C C C A G T G G C A C C G A G G G G G C G A G G G T T A A G T G G G G G G G A G G N)
      (HUMCKMT-NEG-1321 T G G G C A T G G T G G C T G G A G A T G A G G A G A C C T A T G A G G T A G G G G G T C C C C A G A G T C T C C C T G N)
      (HUMCKMT-NEG-5881 T G A T A G T C A A T A C C A G G G A C C A G G A A G G T C G T G A C C A G T C C T G G A G G C C C C A G G C T G T A C N)
      (HUMCMOSAA-NEG-121 A C C T G A G G T C G G G A G T T C G A G A C C A G C C T G A C C A A C A T G G T G A A A C C C C A T C T T T A C T A A N)
      (HUMCMYBB-NEG-901 A A G G C T C C A T A T A T C C A T T C A G A A T G T C T C A A C A C A A G A A G T T G C T T G T A G T A A A A T G T A N)
      (HUMCN2-NEG-841 C C A T A T A T G G A C G T T C C C A A A A T C C T G T C C A G C C C A T C G G C C C A C A A A C C C C A A A A G C G T N)
      (HUMCN4GEL-NEG-2521 T C A G G T T G T C T G A A G T C A C T G C A C A G T G C A T C T C A G C C C A C A T A G T G A T G G T T C C C C T G T N)
      (HUMCNPG3-NEG-121 G A G A T T T G A T G C C A A G C T G G C C A T C G T G G G C A T T G C C T T C T C C T G G A T C T G G G T A A G G G T N)
      (HUMCNR-NEG-2101 T T A A G T G C T A G T T G T G A T T T T A T A C A T A A A G G C C A G A A G C T G T C T G A G G C A A T C A T G A T T N)
      (HUMCNRAB-NEG-1741 C A C C C G A G G A G C T G G A G G G G T C G G C C A A G C T G A C T G T A A A T T T C A C A G T C T C T C T G A A G A N)
      (HUMCOL11A2-NEG-1861 A C A G G C C C G G T G G G T C C T G C A G G C C C A G C A G G G A A A C C T G G C C C T G A T G G T C T G A G G G G G N)
      (HUMCOL1A07-NEG-1 G G G A G C A G G G A G A T G G A T T G G T A T T G G T A T G G T C A C A C C T G A G G G T C C T G C A C C T G C T A G N)
      (HUMCOL1A18-NEG-241 T G C T G T G T T G C T G T C T T T T T C C C T C T C T C T C A C G A A A G G T T T C C C A G G G C A G C C A G G G G C N)
      (HUMCOL1A25-NEG-121 C T G G C C T T C C T G G A C A G C A G G G G G C T C C T G G G A T T C C T G G G T T T C C A G G T A A G T G A T T T T N)
      (HUMCOL1A39-NEG-361 G G G G A A A A C A T A A G A C C A T T T A T T A G T A G G T G A G T C G A G C A T C T G T A G G A A C A A A T G C A A N)
      (HUMCOL2A1-NEG-961 C C G G G T G A A C G T G G A G A G A C T G G G C C C C C C G G A C C A G C G G G A T T T G C T G G G C C T C C T G G T N)
      (HUMCOL3A1A-NEG-661 A T C A A A G A C C T A T A A A T G T A T T T G C C C C T C T T T C A A A T A T G A C A C A A A A A T T A C T G C T T A N)
      (HUMCOL4A1-NEG-961 C C G G A A A A C C A G G A C C C A G A G G C A A A C C C G G A A A A G A T G G T G A C A A A G G G G A A A A A G G G A N)
      (HUMCOL4A2-NEG-2581 G G G C C C C C T G G G G A A A G G G G C C T C C C T G G A G A A G T C C T G G G A G C T C A G C C C G G G C C A C G G N)
      (HUMCOL4A6-NEG-301 C A G A G G G G C C T C C C G G A C C T C C G G G G C T C C A A G G T G T T C C T G G A C C A A A G G G G G A A G C A G N)
      (HUMCOLA1C-NEG-1141 C A T C G C A T G G A C C G C A G G A G G G C A G A T T C G G A C C A C T A G G C C T G A A A T G A C A T T T C A C T A N)
      (HUMCOLA2I-NEG-841 T A C T T G G A G T G G G T A C A T T C T G A A A A G T A A T A T A A G T G T C T C A A T T C A C T T T C T A G T C A T N)
      (HUMCOLII2-NEG-781 T G G G C T G C A T C C T G C T G G A T C G G A G A C G T G G G A G A T A C T C C C T C G A G A A A G G A A G A A G A C N)
      (HUMCOLTHA-NEG-481 C C T G A C G G T G C C C C C G G G G A G C G G G G T G G C C C T G G A G A G A G A G G A C C A C G G G G G A C C C C A N)
      (HUMCOX4A-NEG-301 C T T T G C T G A G A T G A A C A G G G G C T C G A A C G A G T G G A A G A C G G T T G T G G G C G G T G C C A T G T T N)
      (HUMCP21OH-NEG-1981 G A G C C T A G A C A C C C C T G G G T T G T A G G G G A G A G G C T G G G G T G G A G G G A G A G G C T C C T T C C C N)
      (HUMCP21OHA-NEG-2521 T G C G T C C T G C G G A C A A G C A A A A G G C T C C T T C C C A G C A A C C T G G C C A G G G C G G T G G C C A C C N)
      (HUMCP21OHC-NEG-3061 G A C G G T C T G G G A G A G G C C A C A T G A G T T C T G G C C T G G T A T G T G G G G G G C C G G G G G C C T G C C N)
      (HUMCPA4-NEG-601 T A T C T T G G C T T A T A G A T G G C C G T C T T C T T C C C G T G T C T C T A C A C A C C G T C T T C C T T C T G T N)
      (HUMCR1-NEG-241 G A A T G C C G C C C T G G T T A T T C C G G A A G A C C G T T T T C T A T C A T C T G C C T A A A A A A C T C A G T C N)
      (HUMCR1-NEG-4801 A C A G C T C C A G A A G T T G A A A A T G C A A T T A G A G T A C C A G G A A A C A G G A G T T T C T T T T C C C T C N)
      (HUMCR1L04-NEG-1 A A C A T T C C T T A T T T T T T G C C T C T A G A T A C C G A C T C A T T G G T T C C T C G T C T G C C A C A T G C A N)
      (HUMCR1R-NEG-2581 T C A T T G G G G A G A G C A C C A T C C G C T G C A C A A G T G A C C C T C A T G G G A A T G G G G T T T G G A G C A N)
      (HUMCR1RS-NEG-1681 G A G T T G G C A G C A A C A T C T C T T G G T T T A A G A G T T C C A G C A C A G C G A T A G T A C T T T C T A G C C N)
      (HUMCRBP2-NEG-421 G A T G G A C C T T G G A A A A A G G C A C C A T G G A T G G G C C T T G G T T C T G T T C T A A A G C T T C T C T T C N)
      (HUMCREB-NEG-2101 A A G C A A A G T G A T A T A T A T T T G T T T A T G A A A T G T T A C A T G T A G A A A A A T A C T G A T T T T A A A N)
      (HUMCRPG-NEG-781 A A T G A G A T T C T C A T A T T T T G G T C T A A G G A T A T A G G A T A C A G T T T T A C A G T G G G T G G G T C T N)
      (HUMCRPGP-NEG-481 A C C T G A C C T G T G A A C A T A G C C T T T T T T T C T T A T G C C A T G A G G A C T A G A T A A T G A A T C C T C N)
      (HUMCRYABA-NEG-3301 G T C A T A G T C T C C T T G G A T G G A G T C A T T T T T T T T T T T T T T T A A T T T C A G C A G C A G T C C T A T N)
      (HUMCRYGA1-NEG-181 C C A G C T G A C T G T C T A C T G T C A C C T T A T T T C T A C C T C A G A T C A C C T T C T A C G A G G A C C G A G N)
      (HUMCRYGBC-NEG-3781 G T T G A G G G G G C T G T G A C C C A T G A T C A T G C C A T T G C A C T C C A G C C T A G G T G A C A G A G G G A G N)
      (HUMCRYGBC-NEG-8341 C A C G T T G G G A G G T C G A G G C A G G C A G A T C A C T T G A G C C C A G C A G T G T A A G G T T C T T G T A T C N)
      (HUMCRYGBC-NEG-12901 A G G G G G A A G C G T G G G T G G G G A A T G C C A C C T T A A G C T G G T G C C A G C A T A C A C C A T A C T T T A N)
      (HUMCRYGBC-NEG-17461 T G T C T A A T A G C G G A G T A A C A T G T C C T C A C T G C G G A G T G C C A G G C C A G C A T C T G A A T G T C A N)
      (HUMCRYGBC-NEG-22021 C C T A A G T A G C T G G G G C T A C A G G C G C G C A C C A C C A T G C C T G A C T A A T T T T T T C A C T T T T T T N)
      (HUMCRYGQ6-NEG-361 T T T C C T G T G T G T T C C A T G C A G T A A T G T A T C C T C T G T T C C T T T C A G C C T C C T T G G A A G G G C N)
      (HUMCS3-NEG-361 G A G G A G C T T C C A A A T T A T C C A T T A G C A C A A G C C C G T C A G T G G C C C C A T G C A T A A A T G T A C N)
      (HUMCS5-NEG-2161 C T T C T A T A A T A T T A T G G G G T G G A A G G T G G T G G T A T G G A G C A A G G G G T A G G T G G G A A G A C G N)
      (HUMCSF1G1-NEG-361 A C T A G G A A G A C G C G C G A A C G G G G C T G G C C G G C C G G C G G G T G G G G G A G G G G A G G C G G G G G A N)
      (HUMCSFGM-NEG-1 G C T G G A G G A T G T G G C T G C A G A G C C T G C T G C T C T T G G G C A C T G T G G C C T G C A G C A T C T C T G N)
      (HUMCSFM-NEG-181 A G C C A C C T T T G C C T T T G C T G G A C T T C A A C A A C C T C A A T G G G G A A G A C C A A G A C A T T C T G A N)
      (HUMCSIST-NEG-2221 C T C C A C C T C C G G C G G C T C C T C C T A G G A A A C C A G C T C G T G G G C C G G G A A C G G G G G A G A G A A N)
      (HUMCSPB-NEG-61 G C A G A G G C A G T G G G G G T G G G C A G C A T T T A C A G A A A A T C T G T G A T G A G A C A C C A C A A A A C C N)
      (HUMCSPCP-NEG-1261 C T G G T G C G G T A C C A G T G C A C A G A G G G G T T T G T C C A G C G C C A C A T G C C C A C C A T C C G G T G C N)
      (HUMCSYNA-NEG-2461 C T C T G T T C A G T G T A A A T A G T T A C T C C A G T G C C A A C A A T C C T A G T G C T T T C C T T T T T T A A A N)
      (HUMCTHD-NEG-1801 C T A G A G G C C T G A G G A T G A G C T G G A A G G A G T G A G A G G G G A C A A A A C C C A C C T T G T T G G A G C N)
      (HUMCTSE-NEG-661 G A T G G C T C A G A A C C T G G T G G A C T T G C C G A T G T T T T C T G T C T A C A T G A G C A G T A A C C C A G A N)
      (HUMCY4ARO-NEG-541 C T G G A C A G G T T G G A G G A G G T G A C C A A T G A A T C G G G C T A T G T G G A C G T G T T G A C C C T T C T G N)
      (HUMCYAR03-NEG-301 G T C T G T T C A T A A T C G A A G A C A T A C T T T T T A A A T C G A G G C T G G A G T T T T T T G G A G T T A A G A N)
      (HUMCYAR10-NEG-1381 A G A T C A G T A A A G A A C G T G G T C A G A G T A G A A C C C C T G A A G T A T T T T T T A A T C C T A C C T C A A N)
      (HUMCYC1-NEG-961 A G C T G G C A T A T C G G C C G C C C A A G T G A C C C T G T C C A G T G T C T G C T T G C C A T C C T G C C A G A A N)
      (HUMCYC1A-NEG-4381 T A T C T A G G A G G G T C A C A G A G A C A T G A C C C A G C A C C G G C C C A G T G A C C T G G T G C A G G A C T C N)
      (HUMCYCB-NEG-181 C T G C T G C A A C C T C C A A G C C C G G A C T G A G G C C A A G A A C A G C T C T T G G G G A C A T T G G T A A C A N)
      (HUMCYCPS3-NEG-1081 C C A G C C T G G G T G A C A G A G C G A G A C T C C A T C T C A A A A A A A A A A A A C A A A A A A A A A A A A A A A N)
      (HUMCYCPSE-NEG-541 C A T A C A C C A G A A T T C A G A T C A T G A A T G A C T G A C A G A A T A T T C T G T T G G G C A G T C C T G A C T N)
      (HUMCYCPSJ-NEG-361 G G A G A T C G A G A C C A T C C T G G C T A A C A C G G T T A A A T C C C G T C T C T A C T A A A A A T A T A A A A A N)
      (HUMCYES1-NEG-1501 G C A A A A T T T C C A A T C A A A T G G A C A G C T C C T G A A G C T G C A C T G T A T G G T C G G T T T A C A A T A N)
      (HUMCYP145-NEG-301 A C G T G C T G C A G A T C C G A A T T G G C T C C A C A C C C G T G G T G G T G C T G A G C G G C C T G G A C A C C A N)
      (HUMCYP2A4-NEG-1 G C T A C C A C C A T G C T G G C C T C A G G G A T G C T T C T G G T G G C C T T G C T G G T C T G C C T G A C T G T A N)
      (HUMCYP2BA-NEG-2761 C C T A C T G T T T C C C T C T A T C A A A A A G C C T C C T T G G C G C A G G T T C C C T G A G C T G T G G G A T T C N)
      (HUMCYP345-NEG-1381 G T A T C G G G G A A G T C C T G G C C A A G T G G G A G A T C T T C C T C T T C C T G G C C A T C C T G C T A C A G C N)
      (HUMCYP450-NEG-2761 T T C T G G A G G C A G T A C C A G C A T G G A T G C A G C A T C T G C T T C C G G T G C G G G C C T C A G G A A C C T N)
      (HUMCYP450-NEG-7321 G C T G G C T C T G T G A G G G T G C T G A C T G G C T T C A G C A A G T T A G A A C T A G C C A A A C C A G G A C C C N)
      (HUMCYP45C-NEG-3781 A A C T T G G C T T G G G A G T C T G C A T C C A A C A C T T T C T G G C T G T G T G A C C T T G G G C A A G T T A C T N)
      (HUMCYP4A2-NEG-781 T C A A C C A G A G G T T C C T G T G G T T C C T G C A G A A A A C A G T C C A G G A G C A C T A T C A G G A C T T T G N)
      (HUMCYPAX-NEG-421 C A T T G A G G A C C G T G T T C A A G A G G A A G C T C A C T G C C T T G T G G A G G A G T T G A G A A A A A C C A A N)
      (HUMCYPB1-NEG-1141 A G C C G C T A A T C C A G G A G A G G G G A G G G T G G A C A G G A G A C A C T T T G G A T T G G G A C T G C A G G G N)
      (HUMCYPBX1-NEG-541 G A T A A A A G G A T T T G G G C T G A A C A G G G T G G A G G G A G C A T T G G A A T G G C A C T C A G G G C A A A G N)
      (HUMCYPBX3-NEG-241 C C T G G C C A C C A G C T T C C C T C T G C C T G A C C C C A G G C C A C C T G T C T T C T C T C C C A C G T G C A C N)
      (HUMCYPD-NEG-361 A A C C A T G A C C A G A A G C T A T G G G T C A A C C C A T C T G A G T T C C T A C C T G A A C G G T T T C T C A C C N)
      (HUMCYPHLP-NEG-421 G C T G A G G A T G A A G A A T G G A A G A G A T T A C G A T C A T T G C T G T C T C C A A C C T T C A C C A G T G G A N)
      (HUMCYPIIE-NEG-3001 G G T A A G A G A A A T A G T G T T G A T T T T A G G G A G A A T A A C T C A G C A A T T G G A T C T G G T A T G T G T N)
      (HUMCYPIIE-NEG-7561 C A C C T T C C T C A T C G G C T G C G C G C C C T G C A A C G T C A T A G C C G A C A T C C T C T T C C G C A A G C A N)
      (HUMCYPIIE-NEG-12121 C T G A A A T T T G T C C C A T T C A T A T C T T G G C A G A G A A G C T C C A T G A A G A A A T T G A C A G G G T G A N)
      (HUMCYPMP-NEG-181 A C T C T G T A T T T T G G C C T G A A A C C C A T A G T G G T G C T G C A T G G A T A T G A A G C A G T G A A G G A A N)
      (HUMCYPMPC-NEG-1 C T C T C T T T T A T G C T T C T C T T T T C A C T C T G G A G A C A G A G C T G T A G G A G A A G G A A G C T C C C T N)
      (HUMCYPNO-NEG-961 A A T C A A T T A T C T T T A T T T T T G C T G G C T A T G A A A C C A C G A G C A G T G T T C T C T C C T T C A T T A N)
      (HUMCYPSCC-NEG-1501 A A A T C C A A C A C C T C A G C G A T G T G G G C A C C A C A T T C A A C C T C A T T C T G A T G C C T G A A A A G C N)
      (HUMCYPX1-NEG-4201 G T T C A G C C T T T G A C C T T G G A A G T G C C A G A G T G C C C C T A A G C T T C T G C C C C C T C A G A A C A G N)
      (HUMCYPX4-NEG-2101 T T T T A G A A C A T T T T C A T C A C C C C T A A A A G A A A C C C T G C A C C C A T T A G C A G T C C C T C C A C A N)
      (HUMD2A-NEG-841 C C A C T C C T C T T C G G A C T C A A T A A C G C A G A C C A G A A C G A G T G C A T C A T T G C C A A C C C G G C C N)
      (HUMDAFA-NEG-1561 A G A G T G A T T C C T T T C C T A A A A G T G T A A G A A A G C A T A G A G A T T T G T T C G T A T T T A G A A T G G N)
      (HUMDB1A-NEG-121 C G C A A C T T G G G C C T G G G C A A G A A G T C G C T G G A G C A G T G G G T G A C C G A G G A G G C C G C C T G C N)
      (HUMDBH01-NEG-1321 C G A C G C A G A C C C C A T C C C A C T G G G G A C T G G G C C A G A C A G C C T G T G A G G C A G T C A G C T G G T N)
      (HUMDBHRA-NEG-1321 T C C A G G A G A T C C G C A T G T T G A A G A A G G T C G T G T C G G T C C A T C C G G G A G A T G T G C T C A T C A N)
      (HUMDBLPRO-NEG-181 G A A G C A A A T C C C C G G A G A G G C A A G A T G A G G T T C A G A A G G A A T G C G G C T T C C T T C C C T G G G N)
      (HUMDBLTP-NEG-1081 T A T G C A T C A G A T T G C A A T A A A T G G C T A T A T T G G A A A C T T A A A T G A A C T G G G C A A G A T G A T N)
      (HUMDBPA-NEG-1381 G A T G A C C A T T C A G A A A T A A A G C A A A A A G C A G G C C A C A T A C C T T A A C C A A C A C C A A A G A A A N)
      (HUMDBPC-NEG-2821 G C C A T G G A A A A G C A C C A G A A G C G G G C C A A A G A T G A A A A T G G A G C T G T T T G T G C A A C A G A C N)
      (HUMDBPG-NEG-1141 G G A T T T A A A A T A T T A T G T T G A A T T G G C T T C T C A C T C T T T T T C C C C T T T T A C T T A G A A C A T N)
      (HUMDCC-NEG-1561 G T G G C C A C A C A G C C T G A G T T G C A A G T T C C A G G G C C A G T A G A A A A C C T G C A A G C T G T A T C T N)
      (HUMDEF1AA-NEG-121 A T T C T C C T G G T G G C C C T G C A G G C C C A G G C T G A G C C A C T C C A G G C A A G A G C T G A T G A G G T T N)
      (HUMDES-NEG-2641 T G A C G C C C T C A A G G G C A C T G T G A G T C C C T G C C C A C C T G G G C C A G G C C C T G C C C C T T C T C T N)
      (HUMDES-NEG-7201 G G G G T T G G G G T C T G C T A G G G C T C T G C C A A T G T G G C C C C A G A T G G A C T C C C A G C C C C T G G T N)
      (HUMDHPRA-NEG-421 C A T C G A C C A T C T C C A G C C A T C T G G C T A C C A A G C A T C T C A A G G A A G G A G G C C T C C T G A C C T N)
      (HUMDLDH-NEG-1021 T A G A A G A G C T G G G A A T T G A A C T A G A T C C C A G A G G T A G A A T T C C A G T C A A T A C C A G A T T T C N)
      (HUMDMDA-NEG-1201 A C C T C A A A T T G A A C G A T T A A A A A T T C A A A G C A T A G C C C T G A A A G A G A A A G G A C A A G G A C C N)
      (HUMDMDHI41-NEG-481 T T C A G C A C A T C T G G A C T C T T T A A C T T C T T A A A G A T C A G G T T C T G A A G G G T G A T G G A A A T T N)
      (HUMDMHSP-NEG-1741 C A A C C T G C T T G A C A A G T T T G A A C T C A C A G G C A T A C C T C C T G C A C C C C G A G G T G T T C C T C A N)
      (HUMDMP-NEG-3481 A T T G G C T T A G T C C G A C C T G G T A C T G C T C T G G A G T T G C T G G A A G C C C A A G C A G C T A C T G G C N)
      (HUMDNFA-NEG-2101 G T C A G C T T C A T G A A T G C T G T G C T C T G C G T A C G C A C A C A C T T G G G C A G C T G A A G C C C T G C C N)
      (HUMDONT01-NEG-481 T C T T C A T T A T G A T C T C C A T A T T G G A C A A A T G A A C T G A A C A G A G A T A A A A A T T C C C C A T C A N)
      (HUMDRD2A-NEG-841 G T G G A G G C T G C C C G G C G A G C C C A G G A G C T G G A G A T G G A G A T G C T C T C C A G C A C C A G C C C A N)
      (HUMDUG-NEG-2941 A G A A A T A A T C A G A A A A G C A A C A T C A C A G T C C T T G G T T A T C T T G G A T G A A C T A G G A A G A G G N)
      (HUMDYS-NEG-3841 A G C G A A A G T G A A A C T C C T T A C T G A G T C T G T A A A T A G T G T C A T A G C T C A A G C T C C A C C T G T N)
      (HUMDYS-NEG-8401 A A A A G A G C T G A T G A A A C A A T G G C A A G A C C T C C A A G G T G A A A T T G A A G C T C A C A C A G A T G T N)
      (HUMDYS-NEG-12961 C T G G T A G G A A A A A G C T T T A C T C T T T C A T G C C A T T T T A T T T C T T T T T G A T T T T T A A A T C A T N)
      (HUMDYSIN7-NEG-3541 T C A T G C A T T G A A C C A A A A C T C A G G C C G T A A G G A A A G G C T T T G A A G G G G C A G T G G T A A C T T N)
      (HUMDYZ1-NEG-3301 T C A A T T C T A T T C C A T T C G A T T T A G T T C G A T T C T A T T C A C T T C C A T T C C A T T C G A T T C C A G N)
      (HUMEAR2-NEG-1381 G T G G C C G A C C A G G T G G C G C T G C T G C G C A T G A G C T G G A G C G A G C T C T T C G T G C T G A A C G C G N)
      (HUMEB2CR2-NEG-1141 C G A A T G G T A T C T G G G C A G A A A G A T C G A T A T A C C T A T A A C G A C A C T G T G A T A T T T G C T T G C N)
      (HUMEBUR04-NEG-241 A T C C C C A G A T C C T A A G A G G C C G A A T G G T A T C T G G G C A G A A A G A T C G A T A T A C C T A T A A C G N)
      (HUMEBVR-NEG-841 A T T G C T G G A C A G G G A G T T G C T T G G A C C A A A A T G C C A G T A T G T G A A G A A A T T T T T T G C C C A N)
      (HUMEDF-NEG-841 C A G C T T G G T T C T C C T G G G C A A G A A G A A G A A G A A A G A A G A G G A G G G G G A A G G G A A A A A G A A N)
      (HUMEDHB17-NEG-3541 G G A G T G G G G G C G G T G C G T C C T C C G G C C G G C A G C G G T G G C C A C A G C T C T C C T C C C G C C G C C N)
      (HUMEF1A-NEG-1561 A A A C T A C C C C T A A A A G C C A A A A T G G G A A A G G A A A A G A C T C A T A T C A A C A T T G T C G T C A T T N)
      (HUMEF1AB-NEG-481 C A T G A A G C T T T G A G T G A A G C T C T T C C T G G G G A C A A T G T G G G C T T C A A T G T C A A G A A T G T G N)
      (HUMEF2AB-NEG-721 G A G G G C C A G T T G G G G C C T G C C G A G C G G G C C A A G A A A G T A G A G G A C A T G A T G A A G A A G C T G N)
      (HUMEGFAA-NEG-421 T G G C C C G G G C C T C G G C T C C G A G A G G A A G A G G A G C C C G C C T G G G C G C C G A G G A G A G C G G G C N)
      (HUMEGFRBB3-NEG-1201 C T C A A T G G A G A C C C C T G G C A C A A G A T C C C T G C C C T G G A C C C A G A G A A G C T C A A T G T C T T C N)
      (HUMEGFRER-NEG-901 T G C T T T A A A A T A T C C T G C A A A T G T A G C A G T T G A T C C A G T A G A A A G G T T T A T A T T T T G G T C N)
      (HUMEGFRN-NEG-4381 T A C T G T A T C A A G T C A T G G C A G G T A C A G T A G G A T A A G C C A C T C T G T C C C T T C C T G G G C A A A N)
      (HUMEGR2A-NEG-421 G G G T C A C T T C C C C A G C T T C A A C C A C A G C C T C A T C C A G C G T C A C C T C T G C C T C C C C C A A C C N)
      (HUMEL01-NEG-901 G G C A T C G C A G G C G T T G G G A C T C C A G C T G C A G C T G C A G C T G C A G C A G C A G C C G C T A A G G C A N)
      (HUMELA301-NEG-1 T C T A G A A G G G C T G A G A C C A T G C A T T T T T C A C A G C T G T A T C C C C T A G A A C A G T G C C T G A T A N)
      (HUMELAM1A-NEG-1141 C C T G T G A G G A A G G C T T C A T G T T G C A G G G A C C A G C C C A G G T T G A A T G C A C C A C T C A A G G G C N)
      (HUMELANA-NEG-1261 G C T C A G G T G C C C G G G T G C C C G C C C T G T A G G G G G A T C A G A G C A T C C T G G G G G A G G G C C C A G N)
      (HUMELI-NEG-721 T G T G G A G A C A T G G C T G G A T T C C G C C A A A G A A A T A A A A A A G C A G G T T C G T G G T G T C C C T T G N)
      (HUMELIA-NEG-2641 C T G C C A T A G T C A G A C T T C A G A C T T T C A A G A T T A T T C T A A A T C A C C A G A A A A T T A A T T T C A N)
      (HUMEN1-NEG-1201 G A A C G T C T G G C T A A A T A C A A T C A G C T C A T G A G A A T T G A G G A A G A G C T G G G G G A T G A A G C T N)
      (HUMENKB1-NEG-1081 C T C C A C G T C T G T C T G T C T G T G G A T C A G T G T G T T T T G A G T C T G A C A G T C T A C C T G G C T G G T N)
      (HUMENKPH1-NEG-1141 G C G A G C C C G T G G T G A C C T G G G T G T C T C A G C T G T T C C T G G A C A T G A C T G A A G T C C T G C C C T N)
      (HUMENKPH2-NEG-3781 G C G G G C T G A G T C C G A A A A G A G A G T C A G C A A A G G G A G A T A A G G G T G A G G C C A T T T T A T A A G N)
      (HUMENOG-NEG-121 G G A A C C C C A C A G T G G A G G T G G A T C T C T A T A C T G C C A A A G G T C T T T T C C G G G C T G C A G T G C N)
      (HUMEP-NEG-2461 A C C A C T C G G T C C T A G C C T C C A G A C A C C C C A C A A T A C T C C T C T G A G C C T G A G G C C A G G C A G N)
      (HUMEPISIB2-NEG-1081 G G T G A G C T G G G A G T T C A G G T G G G C T G C T C A C A G C C T C C T T C A G A G G C C C C A C C A A T T T C T N)
      (HUMER141-NEG-121 A A A C A T C A A C T C C T G A C C T A A C C G C T T G T G G A T T C C A G A C A T T G T A T G A G G A A G A C T T C T N)
      (HUMER41-NEG-3661 G T G T T G C T C C A G T A C G T T G A T G A C C T T T T G C T G G G A C A C C C C A C G G C A G T C G G G T G G C C A N)
      (HUMER41-NEG-8221 C T A T C G C T C T A T C T C A C A A A G A G A C T A A A A A A G T G A G G A C G A G A G T A A G A A C T C C C A C T A N)
      (HUMERB2R-NEG-2521 T C C C G C C T T C T G G G C A T C T G C C T G A C A T C C A C G G T G C A G C T G G T G A C A C A G C T T A T G C C C N)
      (HUMERBC-NEG-421 C C A A T C A C A G G A G A A G G A G G A G G T G G A G G A G G A G G G C T G C T T G A G G A A G T A T A A G A A T G A N)
      (HUMERG11-NEG-181 C C A A A G G C G G G A A G A T G G T G G G C A G C C C A G A C A C C G T T G G G A T G A A C T A C G G C A G C T A C A N)
      (HUMERG2-NEG-1321 C T A T G A C A A G A A C A T C A T G A C C A A G G T C C A T G G G A A G C G C T A C G C C T A C A A G T T C G A C T T N)
      (HUMERMTV2-NEG-301 C C T A A T A A A T A C A A A G G G C T G T A G A A G C T C A G G G C C C T T G T T C C C T A G A A G A A A G G A G C C N)
      (HUMERPA-NEG-1021 G G T G G G G T G T G C A C A C G G C A G C A G G A T T G A A T G A A G G C C A G G G A G G C A G C A C C T G A G T G C N)
      (HUMERSP1A-NEG-241 T T T T G T A G G A C T A A C A T C C G C C A C A A A A T T A A A A A T T A T G G T T T A G G A G T C A T G C A G A T A N)
      (HUMERSP2B-NEG-781 A C A G A A G A A G C G A G C C A C G C C C C C A G C G C A C G C C C T G C G A G G G G A A C A A G G G A A C C T T T C N)
      (HUMERV34A-NEG-2521 A G A G G T T G G T T C T T A T C C C T T G G A G G A T T T A A A A C C T T A G T A C A A A T A G T C C T A G C C A T A N)
      (HUMERVKA-NEG-2161 G A G A T T C T G G C A A A A T C G T C T C T C T C A C C C T C T C A A T T T T T A C A A T T T A A G A C T T G G T G G N)
      (HUMERVKA-NEG-6721 C A T C A G T A G A T T C A C T T A T C A C A T G G T A A G C G G G A T G T C A C T C A G G C C A C G G G T A A A T T A N)
      (HUMERVKA2-NEG-901 T A A G G G A A C T C A G A G G C T G G C G G G A T C C T C C A T A T G C T G A A C G C T G G T T C C C C G G G T C C C N)
      (HUMERYA-NEG-661 T A T T T T A T T T A A T T G T T C T A T T T T A T C A T T A G T T A T T G T T T G T T A A T C T C T T G C T G T A C C N)
      (HUMESTR-NEG-2161 T C C C A C A C G G T T C A G A T A A T C C C T G C T G C A T T T T A C C C T C A T C A T G C A C C A C T T T A G C C A N)
      (HUMET-NEG-301 G G A G C T C C A G A A A C A G C A G T C T T A G G C G C T G A G C T C A G C G C G G T G G G T G A G A A C G G C G G G N)
      (HUMETN1-NEG-181 A A A G T C G G A G C T G T T T A C C C C C A C T C T A A T A G G G G T T C A A T A T A A A A A G C C G G C A G A G A G N)
      (HUMETS1A-NEG-481 T T G G G G A C A T C T T A T G G G A A C A T C T A G A G A T C C T G C A G A A A G A G G A T G T G A A A C C A T A T C N)
      (HUMETS2PR-NEG-901 G A T C G G G G C T T C C C G G G A G C A G C G C G A T C A G C A C C A C G A C T C G G G G A C A C A G C C A G G G C C N)
      (HUMEXCI5R-NEG-1321 C C A A C T A G T T T T G A T T T T A C A T G C T C A T A G G C T G A A G G G A C T T G C C T T G T C T C A G A T G A G N)
      (HUMF13A05-NEG-121 G G G G T A A T T T T T T A T G G A G A G G T C A A T G A C A T C A A G A C C A G A A G C T G G A G C T A T G G T C A G N)
      (HUMF13A15-NEG-1981 A G A A A C T A T A A A A T C T C T G T A G A T A T T T T C T C A T A A A T A A T C T T A T G A A C C A T T A T G G T G N)
      (HUMF8L1B-NEG-2041 A A A G A G A A T A A A A T A C C T A G G A A T C C A A C T T A C A A G G G A T G T G A A G G A C C T C T T C A A G G A N)
      (HUMFABP-NEG-661 A A T T G C T G T T G T G A A A A A G G G A A A G G T C A T G G T C T C A T T T C C C A G A T G T T A T T T G A T A T A N)
      (HUMFABPL-NEG-61 T A C C A A C T G C A G A G C C A G G A A A A C T T T G A A G C C T T C A T G A A G G C A A T C G G T C T G C C G G A A N)
      (HUMFAPYSY-NEG-541 A T T C A C T G A A A A G A G G T A C A A A T C T A T T G T C A A G T A C A A G A C A G C T T T C T A C T C C T T C T A N)
      (HUMFAV-NEG-3961 C A G A C A A A C C T C T C T C C A G A A C T C A G C C A T A T G A C T C T C T C T C C A G A A C T C A G T C A G A C A N)
      (HUMFBPA-NEG-421 T G C T C C C C C A A C T T G G G G C C C T G G A T C C A G C A G G T G G A T C A G A G C T G G C G C A A A G A G C G G N)
      (HUMFBRAA-NEG-1 A A T C C T T T C T T T C A G C T G G A G T G T C C T C A G G A G C C A G C C C C A C C C T T A G A A A A G A T G T T T N)
      (HUMFBRB3-NEG-1 A T G A A G A T C A G G C C C T T C T T C C C A C A G C A A T A G T C C C C A A T A C G T A G A T T T T T G C T C T T C N)
      (HUMFBRG-NEG-2641 T T T A G T T T T T A T T T A A T A T T C T A T A C T T G A G T G A A A G T A A T T T T T A A T G T G T T T T C C C C A N)
      (HUMFBRG-NEG-7201 A T G C T T C A A A G G C T T C T A G G C C C A T C C C G G G A A G T G T T A A T G A G C T G T G G A C T G G T T C A C N)
      (HUMFBRGAB-NEG-1081 T A C C G A T G C T A A A G G A T C C A T G T T A C A A T A A T G G C A T T A T T T G G A A A T C C C A G T G G T A T T N)
      (HUMFCERA-NEG-121 G C T G A G T G G A C T G C G T T G T C A G G G A G T G A G T G C T C C A T C A T C G G G A G A A T C C A A G C A G G A N)
      (HUMFCGRB-NEG-61 C T G C T A C T T C T A G T T T C A G C T G G C A T G C G G A C T G A A G A T C T C C C A A A G G C T G T G G T G T T C N)
      (HUMFCRHA-NEG-661 C C T G G A G G G G A A T C T G G T C A C C C T G A G C T G T G A A A C A A A G T T G C T C T T G C A G A G G C C T G G N)
      (HUMFERG2-NEG-1 G G A T C C C T A G T A T A A C A C A T T C A G T G T T C C C C N T T T C A G C C C N T T T C A G T C T T A C T A C T T N)
      (HUMFERHX-NEG-481 A G G A G A G A A A T T A A A A T T T A T T A T T T T A A G G T T C T T A A T A T A C A A A C T A G T A T A T T A T C A N)
      (HUMFERP1-NEG-961 C T T C G A T T T G T A C C A T T C C T T C A A A T A A A G A A A T T T G G T A C C A A A A A A A A A A A G A A A G A A N)
      (HUMFESFPS-NEG-2101 C C A C A C C C C T T C C T C A A G T G C A G A G C C C A G C C T T G C C A T G G A C C C A C A G C G G C C C C T G G T N)
      (HUMFESFPS-NEG-6661 G C T C T C C C T G C T T C A G G A G C G G T T G G G G G C C T G T G G C C T G G A G G A G G A G G C A C C A G C T T G N)
      (HUMFESFPS-NEG-11221 C T C T T T G T C C T T T G G G C C C T T G G T G G A G A A C A G T G C A T C C T T C A G A A C A G T G C A T C T T A A N)
      (HUMFESFUR-NEG-3481 G A T G G C C G C A G G G G C A G G G C T C A G G C T G T G G G C G C C T G A G G C T T C A G C T G G G G C A G G C T T N)
      (HUMFGFB-NEG-181 G G G G G A C C C G G C G C G G C C G C G C G C T G C C G G G C G G G A G G C T G G G G G G C C G G G G C G G G G C C G N)
      (HUMFGFG1-NEG-901 G G G C C G G G G G A C G G C G G C T C C C C G C G C G G C T C C A G C G G C T C G G G G A T C C C G G C C G G G C C C N)
      (HUMFGRINT-NEG-421 A A G G G G A T C C T C C A T G G T G G G A G G A A T G G G C T T G A A G T T G T G T G T C C T A A G C T G T G G A G A N)
      (HUMFIBEDA-NEG-2641 G G G C C A T T G C T T A T T T T T C C A T A C A A A A G T A A A A T A A A T C A T A A T G G C C A A T A A G C C A A T N)
      (HUMFIGRD-NEG-361 T C A A G G C C A A C A A C A A T G A C A G C G G G G A G T A C A C G T G C C A G A C T G G C C A G A C C A G C C T C A N)
      (HUMFIL-NEG-841 G G C A T T G G G C A C G G A C A A G C T T C A T C T G C A G T C A G A G A C A G T G G A C A C C G A G G G T A C A G T N)
      (HUMFIXA-NEG-781 A T G G A T T G T A A C T G C T G C C C A C T G T G T T G A A A C T G G T G T T A A A A T T A C A G T T G T C G C A G G N)
      (HUMFIXG-NEG-3661 A C C A A A G C T T T T C A T G G A T T A G G A A A A A A T C A T T T T G T C T C T A T G T C A A A C A T C T T G G A G N)
      (HUMFIXG-NEG-8221 G G T A T T T G T G T A T C T A A A C A T A G A A A A G G T A C A G T G A A A A T A C A G T A T T A T A A C C T T A T G N)
      (HUMFIXG-NEG-12781 T G A C A T G T T T T C T A T T G T C T T G A A C C A T T A C T G C A T A T G A T A C A T C A A A G T T A A G T G A C A N)
      (HUMFIXG-NEG-17341 T G A C A T C C A C C C A G A G C T A A T C A C C A C C A T G C T G G A A A A A G A C A C A G G T G A A G C T G A G A A N)
      (HUMFIXG-NEG-21901 A A T T G T C T G T G G T T T A A G A A C A C C T T T A A G C A G T T T T C C G C C C T G G G T G G G C C A G G T G T T N)
      (HUMFIXG-NEG-26461 T A G T T A T T G T A C C T G T T G T C T T T T T G C T G T C A A G C C T A G C T A A G A T C A T T T G G A A T G T T C N)
      (HUMFIXG-NEG-31021 A A C A G G T C T C A A A C T T A A T T A T G T A A A G A A T A T T C T G G A G A G C T T C C T T T T A C C C A G T C C N)
      (HUMFIXG-NEG-35581 C T A A G T T G T C C T T T T C T G G T T T C G T G T T C A C C A T G G A A C A T T T T G A T T A T A G T T A A T C C T N)
      (HUMFIXG6-NEG-1 A A A G C T C A C A T T T C C A G A A A C A T T C C A T T T C T G C C A G C A C C T A G A A G C C A A T A T T T T G C C N)
      (HUMFLA1A-NEG-961 G A C C A A G G A G A G T C A G G A G A C C C T C C A C A A A T T T G C A T C A A A A C C C G C G A G C G A G T T T G T N)
      (HUMFMSCPO-NEG-61 G G A G A A G A G A G A A G A G G A A G A G G A A G A G G A A G A G A G G A A G C G G A G G G A A C T G C G G C C A G G N)
      (HUMFMSD-NEG-661 G A T C A T C G A G A G C T A T G A G G G C A A C A G T T A T A C T T T C A T C G A C C C C A C G C A G C T G C C T T A N)
      (HUMFN-NEG-3241 G T G T T G G G C A A C A A A T G A T C T T T G A G G A A C A T G G T T T T A G G C G G A C C A C A C C G C C C A C A A N)
      (HUMFN3A-NEG-661 T G A G G G C T T A C C T T C T C C C A C T T C T A A T G C T A C T C T A C T A C T C A G T G A C A T T T T A A A G C T N)
      (HUMFNI-NEG-121 G G A C C A G G A C C A A C A A A A A C T A A A A C T G C A G G T C C A G A T C A A A C A G A A A T G A C T A T T G A A N)
      (HUMFNMC-NEG-3481 C A C T G G A G T G C T C A C A G T C T C C T G G G A G A G G A G C A C C A C C C C A G A C A T T A C T G G T T A T A G N)
      (HUMFNRA-NEG-361 T T G A C A G C A A A G G C T C T C G G C T C C T G G A G T C C T C A C T G T C C A G C T C A G A G G G A G A G G A G C N)
      (HUMFNRAS-NEG-601 A C T G G C C G T G T G G T T T T A G G T G G A C C A G G A A G C T A T T T C T G G C A A G G C C A G A T C C T G T C T N)
      (HUMFNRB-NEG-1081 G A G T G A A A A T A A T A T T C A G A C A A T T T T T G C A G T T A C T G A A G A A T T T C A G C C T G T T T A C A A N)
      (HUMFOLA1-NEG-541 C C T G G G C G G G A C G C G C C A G G C C G A C T C C C G G C G A G A G G A T G G G G C C A G A C T T G C G G T C T G N)
      (HUMFOLLI1-NEG-2041 C T T C G C T A G C C A C C T C G C T C T C C C T G C C C T G C C A C C G C T C A C T G C T C A C T C A C C C A C C T C N)
      (HUMFOLMES-NEG-721 T G T T T T T A T T C C C C A C T A C T C T T C T C T C T A T C A G A T A C C A T T T A T G A G A C A T T C T T G C T A N)
      (HUMFOS-NEG-1501 C A G C G C A G A C G T C A G G G A T A T T T A T A A C A A A C C C C C T T T C A A G C A A G T G A T G C T G A A G G G N)
      (HUMFOS-NEG-6061 C C A G C C T G G G T G A C A C A G C A A A A C C C T A T C T C A A A A A A A A A A A A A A A A A A A A G G A A C C C A N)
      (HUMFSH3-NEG-1021 G C T A T T A C T A C C A A G C C T G T T A G T T A A G G G C A A A G G C A A G A A A T T G T A A T T T G G G G C T G T N)
      (HUMFUMA-NEG-841 C T C A G T G G A G C C A T G A A T A C T A G C T C C T G C A G T C T G A T G A A G A T A G C A A A T G A T A T T C G A N)
      (HUMFUR1-NEG-3901 T G G T G T C C T G A C C A C C C T C C C C T C T C T T G C A C C C G C C T C T C C C G T C A G G G C C C A A G T C C C N)
      (HUMFVA-NEG-3001 C C A G A A T G C C T C A C G T G C T T G G G G A G A A A G C A C C C C T C T T G C C A A C A A G C C T G G A A A G C A N)
      (HUMFVII-NEG-721 T G T T G T T G G T G A A T G G A G C T C A G T T G T G T G G G G G G A C C C T G A T C A A C A C C A T C T G G G T G G N)
      (HUMFVIII-NEG-2821 A A G A A A C T T G A T T T C A A A G T T T C T A G T A C A T C A A A T A A T C T G A T T T C A A C A A T T C C A T C A N)
      (HUMFVIII-NEG-7381 T G C A T C C A A T T T A A C T T A A C T C T T A C C T A T T T T C T G C A G C T G C T C C C A G A T T A C T C C T T C N)
      (HUMFVIIIB-NEG-121 G C T C T C C A C C T G C T T C T T T C T G T G C C T T T T G C G A T T C T G C T T T A G T G C C A C C A G A A G A T A N)
      (HUMFVIIIB-NEG-4681 A T T C C C T A C G G A A A C T A G C A A T G G G T C T C C T G G C C A T C T G G A T C T C G T G G A A G G G A G C C T N)
      (HUMFVIIIC-NEG-121 G A G A A G A A T T A A C C T T T T G C T T C T C C A G T T G A A C A T T T G T A G C A A T A A G T C A T G C A A A T A N)
      (HUMFVIIIC-NEG-4681 T T G C C C A A A A C A T C T G G C A A A G T T G A A T T G C T T C C A A A A G T T C A C A T T T A T C A G A A G G A C N)
      (HUMFX-NEG-241 C C T G A C A G C A T C A C A T G G A A G C C A T A T G A T G C A G C C G A C C T G G A C C C C A C C G A G A A C C C C N)
      (HUMFXIIIA-NEG-181 C A G G G C G T G G T G C C C C G G G G C G T C A A C C T G C A A G A G T T T C T T A A T G T C A C G A G C G T T C A C N)
      (HUMFXIIIB-NEG-841 G G A A G A G G G A A T C C C A T C A A A G T C A G C C G T G T G G G G T C T G C A A T G G T G A A T G C C A A A G A T N)
      (HUMFXIIIC-NEG-1561 A G G A A T G T G C A C A T C T C C T C C T C T T A T T A A A C A T G G A G T C A T T A T T A G T T C A A C A G T A G A N)
      (HUMG0S19A-NEG-2341 G G T A T G A G A A T C T A G G C A G G G G C A G G G G A G T T A C A G T C C C T T T T A C A G A T A G A A A A A C A G N)
      (HUMG0S19B-NEG-2821 G A C A G A A A C A A A G A G A C A T T T C T C T G C A A A A C C C C C C A A A T G C C T T G C A G T C A C T T G G T C N)
      (HUMG3PD-NEG-481 G A C A A C A G C C T C A A G A T C A T C A G C A A T G C C T C C T G C A C C A C C A A C T G C T T A G C A C C C C T G N)
      (HUMG3PDP-NEG-1 T A C C A C T G C T G G T G A G C T G A A A G T T T C A T A T T C A T A A A T G T C A C A G T G T A G T G G T T A A G G N)
      (HUMG6PA-NEG-781 A T T T T G T C A T G C T G G G A G G A A T G T T T T C G G G T C A T A C G G A G T G T G C T G G A G A A G T G A T T G N)
      (HUMG6PDA-NEG-601 T C T A C C G C A T C G A C C A C T A C C T G G G C A A G G A G A T G G T G C A G A A C C T C A T G G T G C T G A G A T N)
      (HUMGA7331-NEG-241 G C T G G G C T C G G G C A T G G C G G T C G A C T G C T C C A C G C T G A C C T C C A A G T G T C T G C T G C T C A A N)
      (HUMGAA-NEG-781 A A C A G G C G C T A C G A G G T G C C C T T G G A G A C C C C G C G T G T C C A C A G C C G G G C A C C G T C C C C A N)
      (HUMGALAB-NEG-901 C C C A G G T T A C C C G C G G A A A T T T A T G C T G T C C G G T C A C C G T G A C A A T G C A G C T G A G G A A C C N)
      (HUMGAPJR-NEG-961 G C G A A G C C C T C C T C C T T C T C C C C T G C C G G T G C A C A G G C C T C T G C C T G C T G G G G A T T A C T C N)
      (HUMGASTA-NEG-1681 G T C A C C G T G T C C T G C T C T A G A T G A G A G T G G T T A T T C A C A A C G G T T A T T C A G C C G T C A G T T N)
      (HUMGASTA-NEG-6241 G G G A C A G C C T C A C C C T T A A G C T A G T C C C T T C T C C C C T T T G C A G A C G A G A T G C A G C G A C T A N)
      (HUMGBR-NEG-2521 G G T A G C G G G A T A A G T C A C T G T T T T C T T T A T T T C T T T A A A A A A A A A A A A A G T T C T G T T G C A N)
      (HUMGCB-NEG-2281 T G T G A A C A T G C G C T G T G T G C T G C T T G C T T T G G A A A C T N G C C T G G G T C C A G G C C T A G G G T G N)
      (HUMGCB1-NEG-4201 C T T C C A G T G C C T G G G C T T C A C C C C T G A A C A T C A G C G A G A C T T C A T T G C C C G T G A C C T A G G N)
      (HUMGCB2-NEG-1141 T C A T A G T C C T T T G G T A G C C T T C C A G T A A G C T G G T G G T A G A C T T T T A G T A G G T G C T C A A T A N)
      (HUMGCB2-NEG-5701 C T G T A C C A A C A A C G A G G A G C A C G G G G G C C T C T G G A A G T C A T G A G A G T A G A A A A A C C A G T C N)
      (HUMGCBPRC-NEG-1501 G C C A C T T C A G C A A G T T C A T T C C T G A G G G C T C C C A G A G A G T G G G G C T G G T T G C C A G T C A G A N)
      (HUMGCRA-NEG-3721 T C C A T G T T T G T A A A A C T A C A C A T C C C T A A T G T G T G C C A T A G A G T T T A A C A C A A G T C C T G T N)
      (HUMGCRB-NEG-3481 T T T T T T A T C A C A G T A A T T T T A A A A T G T G T A A A A A T T A A A A C C A G T G A C T C C T G T T T A A A A N)
      (HUMGCSFR1-NEG-61 A A G C T G A T G G C C C T G C A G C T G C T G C T G T G G C A C A G T G C A C T C T G G A C A G T G C A G G A A G C C N)
      (HUMGDHA-NEG-181 T T C C C C A A G G C A A A G C C T T A T G A A G G A A G C A T C T T G G A G G C C G A C T G T G A C A T A C T G A T C N)
      (HUMGDHR-NEG-841 C T T C C A T G G G A T T G A A A A T T T C A T C A A T G A A G C T T C T T A C A T G A G C A T T T T A G G A A T G A C N)
      (HUMGELS3-NEG-121 G C C C A T T T A G T G T G C A C A C A G C T A G C G C C T G C C G T A T G T C A G G C C T G G T G C T G G G T C T C C N)
      (HUMGENX-NEG-2341 G G G A G C A C A G T G G A C C A T C A G G G A G T G A G C T G G T A C C A C T G G A A G G G C T T C G A G T T C T C G N)
      (HUMGFAP-NEG-2941 G C T G C T G C T G C T A A T C T T C A G G G C A C T G C T G C T G C C T T T A G T C G C T G A G G A A A A A T A A A G N)
      (HUMGFB-NEG-2701 A A A G A T G C A T A G A A A G A G T A T A A T G T T T T A A A A C A T A A G G C A T T C A T C T G C C A T T T T T C A N)
      (HUMGFI-NEG-1 C C T G A T T A A T G A C A G T C G T G G A A T C G T G G G A G T C A A T G C A C T T C T G T C C C A C C C C A C T C C N)
      (HUMGFIA1-NEG-841 G G T G G A G G A G G C T T T C A T A T T C G T G C C A T G A C C C C T C A A G G C G G G C C A T T C G T G T G C A C C N)
      (HUMGFIA2-NEG-3961 T G G G G C T T G G C C T G G C T G C C C C G C T C A C G C C A C T T C T C T C C C G C C C C C A G A C A C C A A T G G N)
      (HUMGFIAB5-NEG-421 G A A C A C C T A C C A A A A A A T A A G T T T G A T A A C A T T T A A A A G A T G G G C G T T T C C C C C A A T G A A N)
      (HUMGFIBPA-NEG-1441 A C A T C C C A A C G C A T G C T C C T G G A G C T C A C A G C C T T C T G T G G T G T C A T T T C T G A A A C A A G G N)
      (HUMGFIIM-NEG-121 T G T G C C T G C T C A C C T T C A C C A G C T C T G C C A C G G C T G G A C C G G A G A C G C T C T G C G G G G C T G N)
      (HUMGFP40H-NEG-1201 A C C T T G G A T T T T T T T G G T T T G T T T T T A A G T A A A A A T A A G T T G C T T T A T T T A A T A T T T A A T N)
      (HUMGFRIL-NEG-1441 G C G C C A A A G C A A A G G G G A C A T A A A C A C C A G G A A C A A C G G G G A G A G A G C C T C C T G T G A A A G N)
      (HUMGG-NEG-1021 T A C T A T T T T T T T G C A C A T A G G T T T C T A G T T G T A G A A A T A C T G T G T C A A A G G G C C T G A A T G N)
      (HUMGG-NEG-5581 T G G G A A A T G T T A C A T C A T T C A C A T A T T G T C A C A T T A A A A A T T G C T A T G T T G A A A T T T C A G N)
      (HUMGGTA-NEG-661 C G C A G A G C C A T G A A G A A G A A G T T A G T G G T G C T G G G C C T G C T G G C C G T G G T C C T G G T G C T G N)
      (HUMGGTX-NEG-1981 C T C C A A G G T C C G C T C C C C G G T C A G C G G G A T C C T G T T C A A T A A T G A A A T G G A C G A C T T C A G N)
      (HUMGHCSA-NEG-2041 C T C T G A T C T C A A G G A A G A A A G A A C A G A G C T G C A G G T G A G A A G T G T G C G C C T C A A A T C A C C N)
      (HUMGHCSA-NEG-6601 T G C T C T A C T G C T T C A G G A A G G A C A T G G A C A A G G T C G A G A C A T T C C T G C G C A T C G T G C A G T N)
      (HUMGHCSA-NEG-11161 G A A A G A A A G A G A A A G A A A G A A A G A A A G A A A G A A A G A A A G A A A G A A A G A A A G A A A G A A A G A N)
      (HUMGHCSA-NEG-15721 A A C C C C C T A A T T A A T C T T C T T T A G A A G T T C T G A T T C T T A T G T G C C A T A A T G A A T T T T T T T N)
      (HUMGHCSA-NEG-20281 G T A T C C C C A C T G C C T T G T A T G T G G T G A A A C C A A A G G G T T A C T T T T A C A C T T A A T C T A T A G N)
      (HUMGHCSA-NEG-24841 T C G A T G A C A C C C C T C T T G G A T C C T C C T A C A G G C C T G C C T G G A G A A C A G C T C A C A G C A C A G N)
      (HUMGHCSA-NEG-29401 A T G G G C T A T T A A G T G C A G A G G C A A A A A A G T C C C C A A C A G G T G A G G A A A C A A T G G C A T A G A N)
      (HUMGHCSA-NEG-33961 G A A A A G A A A A A A A A G A A T C A A T G A G A A G G G G C T G C C T G C C T G A C C A C T G G T T G T G T G G A T N)
      (HUMGHCSA-NEG-38521 G G A G A C A A A G T C A G T C T C A C T C C T T C G C C C A G G G T G G A G T G C A G T G G C G C G A T C T C G G C T N)
      (HUMGHCSA-NEG-43081 T T C G C C A A C A G C C T G G T G T A T G G C G C C T C G G A C A G C A A C G T C T A T C G C C A C C T G A A G G A C N)
      (HUMGHCSA-NEG-47641 C T A C A T G C T C T T A A A C T C A G G G T G G G A G A A G A T T T C A C C A C T A C A G A G G G T G T T C T T T C C N)
      (HUMGHCSA-NEG-52201 G G G A A G A A A T G A A A A C A A G A T G G G C T A T T A A G T G C A G A G A C A A A A A C T C C C C A A C A G G T G N)
      (HUMGHCSA-NEG-56761 A A T C A A T G A G A A G G G G C T G C C T G C C T G A C C A C T G G T T G T G T G G A T C C T T C G G G A A G G A A A N)
      (HUMGHCSA-NEG-61321 A A G G T T A C C T T G A A C A A T G A C A G C A A T G T C T T T G C T G A C A G A G C C C A G C T G G T T A G T G G C N)
      (HUMGHCSA-NEG-65881 T A A T T T A A A A C T C A G A A G A A A G C C T A C A T C A A A G G G A A G T A G A A G T G G G C C C G G C T C A C T N)
      (HUMGHR-NEG-841 A T G G C T C T T A A T T A T T A T C T T T G G A A T A T T T G G G C T A A C A G T G A T G C T A T T T G T A T T C T T N)
      (HUMGHRA06-NEG-1 A T A C C T G T A G T G T T C A T T G G C A T T G A G T T G T T G A C T C T T T G G C C A A T A T G G C G T T T A T A T N)
      (HUMGHV-NEG-1861 G G G C A G A T C T T C A A T C A G T C C T A C A G C A A G T T T G A C A C A A A A T C G C A C A A C G A T G A C G C A N)
      (HUMGIAA-NEG-901 T T G A G G A G A A G A T C A C A C A C A G T C C C C T G A C C A T C T G C T T C C C T G A G T A C A C A G G G G C C A N)
      (HUMGIP2A5-NEG-1 C C C C C C A T C C C C A G C T A C C T G A A C G A C C T G G A G C G T A T T G C A C A G A G T G A C T A C A T C C C C N)
      (HUMGIR-NEG-121 G G G A T G G G C T G C A C C G T G A G C G C C G A G G A C A A G G C G G C G G C C G A G C G C T C T A A G A T G A T C N)
      (HUMGKAS-NEG-1441 C T T A C T C T T T T T T T C C C C C C T T C T T A A A C C A C C A G T G G T T C A T T T T T A A G G T T T T T T C A T N)
      (HUMGLA-NEG-3721 C A G A T G G C T G G A A G G A C C T C T T T C G A A A C T T T G T T T A A T T C C A T T A A T C T G T G T A T T C T T N)
      (HUMGLA-NEG-8281 C A T T T C T T T C C C T T A T T T T A C C C A T T G T T T T C T C A T A C A G G T T A T A A G C A C A T G T C C T T G N)
      (HUMGLAA-NEG-421 A A T G G A T A G A C C A G C A C T C A G A C C A C T A T T T T C A G T A T C T G T T T T T C T T A A C T C A G G G C C N)
      (HUMGLCB-NEG-661 C T G G A C T G C A G C G G T C T G T A C T T C T G T A C A C G A C A C C C A C C A C C T A C A T C G A T G A C A T C A N)
      (HUMGLI-NEG-901 T G C T C C A G G G A G C T G A G G C C C T T C A A A G C C C A G T A C A T G C T G G T G G T T C A C A T G C G C A G A N)
      (HUMGLNRS-NEG-361 G A A G G C T T A T G T G G A T G A T A C T C C T G C T G A A C A G A T G A A A G C A G A A C G T G A G C A G A G G A T N)
      (HUMGLTH1-NEG-241 C G C A G C G G G G T C G C A G G G C G C G G C G G G T T C C A G C G C G G G G A T G G C G C T G T C C G C G G A G G A N)
      (HUMGLUCG2-NEG-1621 C T G T A A G A C T T C C T A C T T A T T A T T G T T A C C A T A C T T T C C T T T A A A T T T T A G T G G A A A T T T N)
      (HUMGLUCG2-NEG-6181 T T A T G C A T A G A A A G T A G C T G A A G A A A T C A A A A A A T C A G G A A A A G G A C A T A G A T T T G T C T G N)
      (HUMGLUD1-NEG-721 C G C T G A T A C C T A T G C C A G C A C C A T A G G G C A C T A T G A T A T T A A T G C A C A C G C C T G T G T T A C N)
      (HUMGLUTRN-NEG-1021 C C C A G C A G C T G T C T G G C A T C A A C G C T G T C T T C T A T T A C T C C A C G A G C A T C T T C G A G A A G G N)
      (HUMGLYCA4-NEG-181 G C T T T G T G A G A T A A A A C T C T C C T T T T C C T T A C C A T A C C A C T T T G A C A C G C T T C A A G G A T A N)
      (HUMGLYPL-NEG-1081 A A G G A A C T G T G T T T G A T G C C T T C C C G G A T C A G G T G G C C A T C C A G C T G A A T G A T A C T C A C C N)
      (HUMGLYSA-NEG-2761 A G C A G G C C A C G C T C A G G C C C G G C A T G C G G G C C A C C A A G T T C T G G A A A C C A C G T G G T G T C C N)
      (HUMGMCSFG-NEG-2821 G C A C A C T G A C C C T G A T A C A G G C A T G G C A G A A G A A T G G G A A T A T T T T A T A C T G A C A G A A A T N)
      (HUMGNAI1-NEG-1201 A C C A G G G A A T G G C A G C A G C A T G C A G A A T C T T A G C A C T C T T T A G C A C A A T A T T T T G T A T T A N)
      (HUMGNAS6-NEG-1 C T A G A G T T C C C T G A T T C C T A A A A T T A T T T A T C T T A A A T C C T G T T T G C C C T A A C C T T C T T A N)
      (HUMGNAZ-NEG-961 A C C A A G G A G A T C T A C T C C C A C T T C A C C T G C G C C A C C G A C A C C A G T A A C A T C C A G T T T G T C N)
      (HUMGNPAS-NEG-61 A A G G A C A A G C A G G T C T A C C G G G C C A C G C A C C G C C T G C T G C T G C T G G G T G C T G G A G A A T C T N)
      (HUMGP-NEG-1321 G C C C C C A C T G T G G A G A T A A G A A G G G G A T G G A A T G G G G G A A G A G G A G G A G C A G G A G G C C C T N)
      (HUMGP3A-NEG-1921 G C A C C T T T A A G A A A G A A T G T G T G G A G T G T A A G A A G T T T G A C C G G G A G C C C T A C A T G A C C G N)
      (HUMGPBPS-NEG-961 A G T G T C A C A A G A A A T G A A A C A G G A C C C T A T C A A T G T G A A A T A C G G G A C C G A T A T G G T G G C N)
      (HUMGPIBA-NEG-1561 T T C T A T G T C T T G G G T C T C T T C T G G C T G C T C T T T G C C T C T G T G G T C C T C A T C C T G C T G C T G N)
      (HUMGPIBAA-NEG-3661 A C T C G C T G T A T A C A A T A C C A A A G G G C T T T T T T G G G T C C C A C C T C C T G C C T T T T G C T T T T C N)
      (HUMGPMSS-NEG-1501 G A A A G T G C C G A G A T C C T G C A G G C T G T G C C G T C C G G T G A G G G G G A T G C A T T T G A G C T G A C T N)
      (HUMGPP3A04-NEG-421 T G A C A T G C T G G A G T C T A G A A C C T C C C A A A C T C A T T T G G T G T T G A G A A T T G C C T G A G G T G C N)
      (HUMGPP3A07-NEG-1381 A T G T A C G G G G T A A A C T C T T A G C T A T T G G G A A G T G G T A G G G C C T G C A G G A G G T A G A G A G T C N)
      (HUMGPP3A08-NEG-3721 G C C C A G C T A A T T T T T G A A A A C A G G G T C T T T C T A T G T T G C C C A G G C T G G T C T C A A A C T C C T N)
      (HUMGPP3A11-NEG-961 T T T T A G A G A G A G T T T G G A A G G A A G T G T T A T C A G A A T G A T T A G G G G A G A G C A A G A G A T C A G N)
      (HUMGPP3A17-NEG-1081 G C A T T T T T T T G A G G C A A T G A T G T C A A G A A A T A A A G A A T T T A A A T T T T A G G A C T T T A C A G C N)
      (HUMGPP3A21-NEG-2521 T T G A C A T A C A T C C A A C A T T A A A A G C C A C C C C C A A A T G C C C A A G A A A A A A A G A A A G A C T T A N)
      (HUMGPPSB1-NEG-241 C A A T T T G C C C C A G A A T C T T A C C G G C T A C A T C T G G T A C A A A G G G C A A A T G A G G G A C C T C T A N)
      (HUMGPPSBB-NEG-1021 A G A A A T G A A A C A G G A C C C T A T C A A T G T G A A A T A C G G G A C C G A T A T G G T G G C A T C C G C A G T N)
      (HUMGRFCIG-NEG-1501 A A A C C C G C C T C C C A G G T T T A A G C G A T T C T C A T G C C T C A G C C T C C C A G T A G C T G G G A T T A G N)
      (HUMGRP78-NEG-421 T T C G C G A G T G T G A G A G G G A A G C G C C G C G G C C T G T A T T T C T A G A C C T G C C C T T C G C C T G G T N)
      (HUMGRP78-NEG-4981 C A A A G C T A A G A A G A A G G A A C T G G A A G A A A T T G T T C A A C C A A T T A T C A G C A A A C T C T A T G G N)
      (HUMGSA1R-NEG-661 C G C C G C A A G T G G A T C C A G T G C T T C A A C G A T G T G A C T G C C A T C A T C T T C G T G G T G G C C A G C N)
      (HUMGSHPXG-NEG-1081 C G A G A A G T G C G A G G T G A A C G G T G C G G G G G C G C A C C C T C T C T T C G C C T T C C T G C G G G A G G C N)
      (HUMGSTC-NEG-421 G C C A A G C T T G C C T T G A T C C A A G A G A A A A C A A A A A A T C G C T A C T T C C C T G C C T T T G A A A A A N)
      (HUMGSTPI-NEG-301 G A C C T C C G C T G C A A A T A C A T C T C C C T C A T C T A C A C C A A C T A T G A G G C G G G C A A G G A T G A C N)
      (HUMGSTPIG-NEG-1381 A G G G G A C C C A G G A C G T C C C C A G T G C C G T T A G C G G C T T T C A G G G G G C C C G G A G C G C C T C G G N)
      (HUMGTLPA-NEG-1621 A T A T C A C A C G G G C C T T T G A A G G G C A G G C A C A C G G T G C A G A T A G A T C T G G A A A G G A C G G C G N)
      (HUMGTPBPA-NEG-1081 C A C T A C T G C T A C C C T C A T T T C A C C T G C G C T G T G G A C A C T G A G A A C A T C C G C C G T G T G T T C N)
      (HUMGYPA06-NEG-421 A T T C A C G A T A T T T A A G A C A T A A T A T G T G T G T G T G T A T T T A T G A T G C T G T C A C T G T C T C T G N)
      (HUMGYPC-NEG-421 G G C A G A T A A T G C T A T G A T A C A T T T T T T G T A G G T G G T G C C A T T T G A C T G C A T T T A G C C A A C N)
      (HUMGYPCDC-NEG-421 C T A A G G A C T T G G G C A G T G G T G G C T G T G G C C A T T T T T T C T C T C C C T C A G A G G T G G T T T T G A N)
      (HUMH-NEG-3061 A A A T G C C A T A C C C A T G G G A G A G A A G A A G G A T G T G T A T A A G G C G G G T G A G C A A G T G A C T T A N)
      (HUMH1FNC1-NEG-1 G T C C T G T G C C T G T G T T A C T T G C T A C A G T T A G A A A C A A A C T T C A T G C C C A A A C C A A G G A A C N)
      (HUMH38-NEG-661 C C A A A T G G T G A C T A C T C A C C T T T A A G G A T T A A A C A C A G A A C T G G A G A T G A A A T C A C G T A C N)
      (HUMHA44G-NEG-2701 G C G G G C C C T G C C G G A C T T T A G T G C T T T A G G G G T T A A T T T C G G G C T G A C A G G G A C G G A G C C N)
      (HUMHAPRA-NEG-481 A T T G A A A C A C A G A G C A C C A G C T C T G A G G A A C T C G T C C C A A G C C C C C C A T C T C C A C T T C C T N)
      (HUMHBA1-NEG-841 C T G A G A G G A C C A T C A T T G T G T C C A T G T G G G C C A A G A T C T C C A C G C A G G C C G A C A C C A T C G N)
      (HUMHBA3-NEG-1021 G G G G A C C A T G G G G A G G G C A C A G T G G G G A G G G G A G A G T G A G G A A G G G A C A G T G A G G A G G G G N)
      (HUMHBA4-NEG-2041 G T G A G C C A C C A C A C C C A G C C C C C G C A A C T G T T T A C A T G G A T A A T T A A C A A G C T T T T T G T C N)
      (HUMHBA4-NEG-6601 A G C G C C G C C C G G C C G G G C G T G C C C C C G C G C C C C A A G C A T A A A C C C T G G C G C G C T C G C G G C N)
      (HUMHBA4-NEG-11161 A A G T T C C T G G C T T C T G T G A G C A C C G T G C T G A C C T C C A A A T A C C G T T A A G C T G G A G C C T C G N)
      (HUMHBARSA-NEG-1081 T A T T T C A T C A G G A A G A A T G G A G G T C T G A C C T A A A G G T A G A A A T A T G T C A A A T G T A C A G C A N)
      (HUMHBB-NEG-1201 A A G G G G T G G A C T C C A G A G A C T C T C C C T C C C A T T C C C G A G C A G G G T T T G C T T A T T T A T G C A N)
      (HUMHBB-NEG-5761 G G T G T G G T G G C A C G C G T C T A T A A T C C C A G C T A C T C A G G A G G C T G A G G C A G G A G A A T C A C T N)
      (HUMHBB-NEG-10321 T A G A T G G T C C T G A G G A A A A G T T T A T A G C T T G T C T A T T T C T C T C T C T A A C A T A G T T G T C A G N)
      (HUMHBB-NEG-14881 A C T G G G G C C T A T C A G A G G G T G G A G G G T G A G A G A A G G A G A G G A T C A G G A A A A A T C A C T A A T N)
      (HUMHBB-NEG-19441 T G G A G A A C A G G G G G C C A G A A C T T C G G C A G T A A A G A A T A A A A G G C C A G A C A G A G A G G C A G C N)
      (HUMHBB-NEG-24001 T G A G A G A T G A A G A T C C A G T T T C A T T C T C C T A C A T G T A G C T T G C C A G C T A T C C C G A C T C A T N)
      (HUMHBB-NEG-28561 T G G C T C G C T T T T G G T G T C C A T T T G T G T G G A A T G T C A T T T T C C A C C C C T T T A C C T T A A G T T N)
      (HUMHBB-NEG-33121 G C C G C C T A A C A C T T T G A G C A G A T A T A A G C C T T A C A C A G G A T T A T G A A G T C T G A A A G G A T T N)
      (HUMHBB-NEG-37681 T T C A A A T C A T A A A G G A C C C A C T T C A A A T G C C A T C A C T C A C T A C C A T T T C A C A A T T C G C A C N)
      (HUMHBB-NEG-42241 T A A G A C C C A A A T A A T A A G C C T G C G C C C T T C T C T C T A A C T T T G A T T T C T C C T A T T T T T A C T N)
      (HUMHBB-NEG-46801 G T G A G T T G G C A T A G C A A G T A A G A G A A G G A T A G G A C A C A A T G G G A G G T G C A G G G C T G C C A G N)
      (HUMHBB-NEG-51361 C A C T G T G T G T C A A A A T C T A G A A C C T T A T C T C C T A C C T G C T C T G A A A C C A A C A G C A A G T T G N)
      (HUMHBB-NEG-55921 C A T A T A T A G A C T A C A T G C T A G T T A A G T A C A T A G A G G A T G T G T G T G T A T A G A T A T A T G T T A N)
      (HUMHBB-NEG-60481 C T A G G C T C C A G A T A G C C A T A G A A G A A C C A A A C A C T T T C T G C G T G T G T G A G A A T A A T C A G A N)
      (HUMHBB-NEG-65041 A A A A A A G A A A A C A A T G A A C A A A T G A A A G G T G A A C C A T G A A A T G G C A T A T T T G C A A A C C A A N)
      (HUMHBB-NEG-69601 T G C C C A C A C A A T A A T A A T G G G A G A C T T T A A C A C C C C A C T G T C A A C A T T A G A C A G A T C A A C N)
      (HUMHBB32-NEG-121 T G T T C C T G C C T T A A C T G A T G A C A T T G T C T T G T G A A A G T C C T T C T C C T G G C T C A T C C T G G C N)
      (HUMHBBAG-NEG-1441 T T C T C A G G A T T T G T G G C A C C T T C T G A C T G T C A A A C T G T T C T T G T C A A T C T C A C A G G C T C C N)
      (HUMHBBGG-NEG-481 A T C T C A C A G A T C C C C T A T C T T A A A G A G A C C C T A A T T T G G G T T C A C C T C A G T C T C T A T A A T N)
      (HUMHBBRT-NEG-1141 G T T C G A T T C T G C T T C A A T T T G T C C C T A T C T A T T A A T C A C C A C T C T T A C T G C C C A G T C A G G N)
      (HUMHBEG-NEG-721 A G A T T T T G G G A A A A A G T A A T C T G C T T A T G T G C A C A A A A T G G A T T C A A G T T T G C A G A T A A A N)
      (HUMHBEG-NEG-5281 T T C C T A T T C T T C C A C A T C C T C T C C A G C A C C T T T T G T T T C C T G A C T T T T T A A T A A T T G C C A N)
      (HUMHBEG-NEG-9841 T G A G C A A T C T G C T T C T T T C A G A G G G T G T G T G C G T T C T C T C A G C T T T C T T G A A T T T A T T T C N)
      (HUMHBGF1-NEG-601 C A T G G C T G A A G G G G A A A T C A C C A C C T T C A C A G C C C T G A C C G A G A A G T T T A A T C T G C C T C C N)
      (HUMHBVINT-NEG-61 T T G T G T A T G G T G T G A G G T A G G G C T T G A G G T T T A T G T T T T G T T T A T G G G T G T A C A G T T G T T N)
      (HUMHCKA-NEG-61 A G A C G A T G A C G A C G A T G G C T C T G A G G G G A C C T C A G G G G C T G C C G A G C T G G G G G G G C G C T C N)
      (HUMHCR-NEG-661 C C C A T C T T A A T C C C G A G A G T C C G G A G G G C T G T G C T A C C C C A A G A A G A G G A A G G A T C A G G G N)
      (HUMHELB-NEG-2461 A G G G A G T T G A C A G A G G T G T G A G C T G G A C T T T A A G A A G C T G C A C A T A A G A T G C T A G T A T G A N)
      (HUMHER2A-NEG-3301 T C T A C C A G G A G T G G C G G T G G G G A C C T G A C A C T A G G G C T G G A G C C C T C T G A A G A G G A G G C C N)
      (HUMHEXB01-NEG-481 T G G A G G A A A T T C T C G A G G T G A C C T G G A C A G G G C G G G C T G G G C G A G G A C G C T C C C G G G G C C N)
      (HUMHF10-NEG-241 A A G G T G A A A A A G G A G G A G G A A G A A G A A G A A A A C T T C C C A G G T C A G G C A T C C A G C C A A C A A N)
      (HUMHGMCOA-NEG-181 T T G C C C T T G A G A T C T A T T T T C C T T C T C A A T A T G T T G A T C A A G C A G A G T T G G A A A A A T A T G N)
      (HUMHIAPPA-NEG-1861 C T T A G A G T A G T T A A A A T T T T C A A A C T G A G A T T T T A A A A C T G T A A T T T A T T T A A A G G G T T A N)
      (HUMHIAPPA-NEG-6421 T A T T C T T G A C A T G A G A A A A T C A G T A A T T G G A C C A G G C G C G G T G G C T C T T G C C T G T A A T C C N)
      (HUMHIS4A2-NEG-301 T T G G G G C A T T A C A C G T T T C A T A A G A C A A T G G T G C A A T A C T C C G A A A T T T T T T A A C G A A A A N)
      (HUMHISH3C-NEG-781 C T T A A G A A T C C A C T A T G A T G G G A A A C A T T T C A T T C T C A A A A A A A A A A A A A A A A T T T C T C T N)
      (HUMHK1A-NEG-3421 A T T T T G T T T T G C T T T T T C T G A C T C C A G T G G G G C A A G A T T T T C C T T T T T T A T A C A C A T A A T N)
      (HUMHKB3R-NEG-121 A G G G C C A A C G T G C T G C G G G C T C T G C T G T T G A A A C A C A G C C A C C C A A G T G A T G A G A A G G A C N)
      (HUMHKR42-NEG-181 C G G A C C C A C A C G G G C G A G A A G C C C T T C G C G T G T G G C G C C T G C G G C A A G G C C T T C G G C C A G N)
      (HUMHLA1EA-NEG-121 C G G G G A G C C C C G C T T C A T C T C T G T G G G C T A C G T G G A C G A C A C C C A G T T C G T G C G C T T C G A N)
      (HUMHLA1PS-NEG-3061 A T C G T T G C T G G C A T G G T T C T A C T T G T A G C T G T G G T C A C T G G A G C T G T G G T C A G C T G C T G T N)
      (HUMHLAB13-NEG-901 T C T T C C C A G T C C A C C G T C C C C A T C G T G G G C A T T G T T G C T G G C C T G G C T G T C C T A G C A G T T N)
      (HUMHLACW2-NEG-781 A G A T A C A C G T G C C A T G T G C A G C A C G A G G G G C T G C C G G A G C C C C T C A C C C T G A G A T G G G A G N)
      (HUMHLADP4-NEG-721 C A G T C T G A T T C T G C C C G G A G T A A G A C A T T G A C G G G A G C T G G G G G C T T C G T G C T G G G G C T C N)
      (HUMHLADPB-NEG-4201 C A T G T C C C T A C A A A G G A C A T G A A C T C A T C C T T T T T T A T G G C T G C A C A G T A T T C C A T G G T G N)
      (HUMHLADPB-NEG-8761 C A G T T C A T T C G T C T T T T T C C T T C A G G A A G T C T G G G T G T A A A G G G A T G G A G A G A G G T G A G G N)
      (HUMHLADPB-NEG-13321 C C C C T C T T T C A A T G T C A G C C T T C A G G C A A G T G G G G A A A G A G C A T T G C T T G G C T C C A T T G C N)
      (HUMHLADZA-NEG-721 A G C A G G T T T T A C C A G T C C A C A G A C T A C C C G A G A A C C A C C T G G G G A G C A T G C T G A A A A C A C N)
      (HUMHLADZA-NEG-5281 A C A C A T T C T A A A T A T G T G G C C T A G A A G A T T T T G G T C T A C T T T T C T G T G A A C A A A A T T T A A N)
      (HUMHLASBA-NEG-601 A A A A G T G C T A T C T T A G T G T G T A A A A G G T C A T T C A G T G G C A T G A C T T A G A G G G A T T A G A G T N)
      (HUMHLASBA-NEG-5161 A G T C C C G T A G T T C C T T C T C A C T C T G A T G C A T T T A T C A T T C T A A A C C C A G A C T T T C A C A T A N)
      (HUMHLASBA-NEG-9721 C T C T T A A A A C A T C T C C T A C A G T T T T A A A T T T C A C A T T T A C T A C T T T A A T T C A T C T G G G A T N)
      (HUMHLASBA-NEG-14281 A A C T A A A T C A A G A A G A A A T C T C T G T C A A T G G A A G A A A T T A A G T T T G T A A T T T T A A A A A T C N)
      (HUMHLDPWB-NEG-61 C A G G T T T C T G C G G C C C C C C G G A C A G T G G C T C T G A C G G C G T T A C T G A T G G T G C T G C T C A C A N)
      (HUMHLS2R-NEG-1201 A C A A A A A T G G C A A C A T G G C A G G C A T C T C A G A C C A A A G G A T C G C C A T C G A C C T G T T C A A G C N)
      (HUMHMG14A-NEG-61 C C A T G C T G T G C A A C A T A G T G A A A C C C C C T C T C T A C A A A A A A T A C A A A A G T T A G C T G G G C A N)
      (HUMHMG14A-NEG-4621 G G G G A A A A A G T A A A A C A A A A T G T A A A T A A G G A G T A A A G C A T G T A C T T A A A A T A T A T T C T T N)
      (HUMHMG17-NEG-301 A A A T G G A G A T G C C A A A A C A G A C C A G G C A C A G A A A G C T G A A G G T G C T G G A G A T G C C A A G T G N)
      (HUMHMG17G-NEG-3661 T A A A A A A C A T C A A A A A A C A A T T C C C T T T G C T T C C A T G A A T T A T G G T T A G T G C C T G G T T T T N)
      (HUMHMG17P-NEG-1081 T T G T G A A A A G T T G T T A A A A A C A A G C T A A A T G T G A A C T T A A C C C T C A C T C T A A G C T T T C C C N)
      (HUMHMGCOA-NEG-2101 G T G G T A A C T A T T G T A C T G A C A A G A A A C C T G C T G C T A T A A A T T G G A T A G A G G G A A G A G G A A N)
      (HUMHMGIB-NEG-721 C C T T C C C C A G G C C C A C C A T C A C C A C C G C C T C T G G C C G C C A C C C C C A T C T T C C A C C T G T G C N)
      (HUMHMGYB-NEG-1561 A C C A G C G C C A A A T G T T C A T C C T C A T T G C C T C C T G T T C T G C C C A C G A T C C C C T C C C C C A A G N)
      (HUMHMPFK-NEG-901 T G T C T T G G G G C A T G T G C A G A G G G G T G G G A C G C C A T C A G C C T T T G A C A G A A T T C T G G G C A G N)
      (HUMHODB2-NEG-301 A T G T C A A T G T G A A A G G T A T G G T A G G C T G G G G A G G A G A T G C A G C A A G G T G G G G A A T T A A G G N)
      (HUMHOM4-NEG-841 A T C A A G A T C T G G T T C C A G A A C C G G A G G A T G A A G T G G A A A A A A G A T C A T A A G C T G C C C A A C N)
      (HUMHOXB-NEG-541 A G G A T T T T A G T T C T G A G C A G G G C A G G A C T G C G C C C C A G G A C C A G A A A G C C A G T A T C C A G A N)
      (HUMHP2FS-NEG-1021 A G T C T T G C T G T C C T G G C A C T G C T C T A A G G G C T T T A T A C T T A T T T G C T C A C T T A G T C C T C A N)
      (HUMHPA1B-NEG-601 A A C T C A A A C A G A A G G T G T C T G T T A A T G A G A G A G T G A T G C C C A T C T G C C T A C C A T C C A A G G N)
      (HUMHPA2BR-NEG-1261 G C T G G A A G A G G G C A A A G T G G A C G G G A G T G G A C A G G A G T G G A T G C G A T A A G A T G T G G T T T G N)
      (HUMHPARS1-NEG-241 T C T A A T T T A A G A A C A A C T A A C C C T T T T T A A T G A A T A A A T C A A C C T T G T A T T G A G T T G C T A N)
      (HUMHPARS1-NEG-4801 C A T G A T G G G T G G T G C T G A G G T G A T T C G C C A G A A A G T T C G T T G C T C T C C T T G G A G C C A G G A N)
      (HUMHPARS1-NEG-9361 C A T T G T A C T C C A G C C T G G G C A A C A G G A G T G A A A C T C T G T C T C A A A A A A A A C A A A A A A C A A N)
      (HUMHPARS2-NEG-2401 C C T A T G T A C C T T T C T A T C C C T C T C T G A A G C T T C T G C A G A A T T C C C A G C A A G A C A G A G C T T N)
      (HUMHPARS2-NEG-6961 T A A G C C T T C A A T A C C A C C A A T C A C C A A T G T G C C T T C T T C T C A T G C G A A A A T A C G G C C C C T N)
      (HUMHPBA-NEG-901 A G C A G A A C G C T A A G T A T G T A A C G A A C C C T T C A T G A A G C A G T T G A T A G G T A G G C T T A A A C A N)
      (HUMHPP16C-NEG-541 T G A A G G G G G A A G C C C C T T A T A A A A C C A T C A G C T C T C G T G A G A A C T C A C T C A C T A T C A C A A N)
      (HUMHPRT9-NEG-121 A A T T A T C A A T G T T C T A G T T C T G T G G C C A T C T G C T T A G T A G A G C T T T T T G C A T G T A T C T T C N)
      (HUMHPRTB-NEG-3601 A G T G G C A T G A T C T C G G C T C A G T G C A A C C T C T G C C T C C C G G G T T C A A G C G A T T C T C C T A C C N)
      (HUMHPRTB-NEG-8161 C C T T T A C T C A G T T T A C A A T C T A G G C A G T A G A A T G T A A T C A C T G C T T T A A A C T T G A T A C T G N)
      (HUMHPRTB-NEG-12721 T C A T A G T A C A T T T T C A C A T C A C A G G T A C C A T A T C A G T G T T A T T A A A T A T T T T G T A T G C C A N)
      (HUMHPRTB-NEG-17281 A C T T T T G A T C C A C A G T C T G C C T G T G T C A C A C A A T T G A A A T G C A T C A C A A C A T T G A C A C T G N)
      (HUMHPRTB-NEG-21841 T C A T A A A A C T A T A A C T C T T T A T C T T T A A T T A G A A A T G T T T T T T T T T T T G A G A C A A G G T C T N)
      (HUMHPRTB-NEG-26401 C T T G A A T G T A T C T T T G T A T A C T T G T C A A G T G T T T T T G T A G C A A T T G A T T C C C A G A A G T G G N)
      (HUMHPRTB-NEG-30961 T T C T T A T A A C T A G C A T A A G A A C A G A T A G G A C T T T C T C G A T T T T G A G G G G T A A T T A T T A G A N)
      (HUMHPRTB-NEG-35521 T C T C A T T T T C G T T T C A T C T C T C A A C A A C T C T G G G G T G G C A T T A T T A T T C C C A C T T T T C A G N)
      (HUMHPRTB-NEG-40081 A C T A T A A T G A A T A C T T C A G G G A T T T G A A T G T A A G T A A T T G C T T C T T T T T C T C A C T C A T T T N)
      (HUMHPRTB-NEG-44641 T C T C A G C T A A T T T T T A A T T T A T T T T T T T A G A G A T A C G G T C C C A C T C T G T T T C C C A G G C T G N)
      (HUMHPRTB-NEG-49201 C A C T A G A A A G A T A G G A C A C T G G A G G G T G G G A A G C C C T A G C A G T T T C T T C C A G G G T G G G C T N)
      (HUMHPRTB-NEG-53761 C C G G A G T G G G G A G A T C A G A T G G G G C T C T G T G T A T C A T G C A A A G G A C T T T G C A T T C T G T T C N)
      (HUMHPS12-NEG-1621 A G C T C C A G G C T A T T T T T G T G C T T A G T T A C T G G T T T T C T C C A T T G C A T T G T T A G G C A T G G T N)
      (HUMHRGA-NEG-481 A G T G A T T G A C T T T A A C T G C A C C A C A A G T T C T G T C T C T T C A G C A C T G G C C A A T A C C A A A G A N)
      (HUMHSC70-NEG-1021 T T T C T T T T T T T C A G C A A C C A T G T C C A A G G G A C C T G C A G T T G G T A T T G A T C T T G G C A C C A C N)
      (HUMHSDB-NEG-121 G G A C C A G A A T T G A G A G A G G A A T T T T C T A A A C T C C A G A A C A A G A C C A A G C T G A C A G T G C T G N)
      (HUMHSP27P-NEG-601 T T G A A C T G G G G A A G C G A A G G T G G C A G T G A G C T G A G A T T G C G C C A T T A C A C T C C A G C C T G G N)
      (HUMHSP70D-NEG-1441 A G A A G G C T C T G C G C G A C G C C A A G C T G G A C A A G G C C C A G A T T C A C G A C C T G G T C C T G G T C G N)
      (HUMHSP90-NEG-1 C T C C G G C G C A G T G T T G G G A C T G T C T G G G T A T C G G A A A G C A A G C C T A C G T T G C T C A C T A T T N)
      (HUMHSP90B-NEG-1981 C C A T C T T T C T T G G G T T T G G T C C T G T T C T G T A A T T T T G T G C T G T G A A A G G G T C G T G G T G G A N)
      (HUMHSP90B-NEG-6541 C A G G C T G G A G T G C A G T G G C A C G A T C T C T G C T C A T T G C A A G C T C C G C C T C C T G G G T T C A C G N)
      (HUMHSPGC-NEG-2821 G A T T G A A G T G G C T G G A A A G A G T G A T G C C T G G G G A A G G A G A T G G A G T T A T G A G G G T A C T G T N)
      (HUMHST-NEG-3961 G C A C C A G C T G T T G T G G G C T G G C C A T G T C C C C T T C T C A C C C T G T G T G G G T C T T G A C A C C T T N)
      (HUMHTA1-NEG-241 C T C A G T G A C A C C T G C C C A C G T T T C A T C T T G G G T C T T C T T G A T G C A G G A A A G G C A C A T C T C N)
      (HUMHTV1A-NEG-121 C A T T A A A A C A T T T A T A T C T A T A A A T T T G A A A A C T A A T C A G T A T T T T T T A A A G T A T A A A A C N)
      (HUMHTV3A-NEG-841 C T A G C C T A G A A C A T C C C A C C A A T A T C T C C A C C C A C T T A A G G A G A A A A G G C T A T C A A G G G T N)
      (HUMHXM-NEG-1321 C A C T G A G G G G C C T T C T G A C A T G A G T C T G C C T G G C C C C A C C T C C T A G T T C C T C A T A A T A A A N)
      (HUMIAIG4-NEG-421 C C T C T A T C C G T A T T A G G T C T T T G A G A G C T G G A T G C A C C A T T G G C T C C T G T T T G A A A T G A G N)
      (HUMICAM1-NEG-481 C C C C G G G C C A A C C T C A C C G T G G T G C T G C T C C G T G G G G A G A A G G A G C T G A A A C G G G A G C C A N)
      (HUMICAM1A-NEG-1981 C C C A C C A T G A G G A C A T A C A A C T G G G A A A T A C T G A A A C T T G C T G C C T A T T G G G T A T G C T G A N)
      (HUMIDB-NEG-241 A G A A G C C G G A A G T G G T G A A G A C G C A C C T G C G G G A C A T G A T C A T C C T A C C C G A G A T G G T G G N)
      (HUMIFNA01-NEG-421 A A C C T A G A G G C C A A G G T T C A A G T T T A C C C A T C T C C A G T A G C C T A G C A A T A T T T G C A A C A T N)
      (HUMIFNA04-NEG-961 C A G A C A T G A T T T C G G A T T C C C C G A G G A G G A G T T T G A T G G C C A C C A G T T C C A G A A G A C T C A N)
      (HUMIFNAA-NEG-1621 A A C A A A T A C A A T T C T G C T C T C T T G T G T A T T T G A T T T T T G T A T G A A A A A A A C T A A A A A T G G N)
      (HUMIFNAD-NEG-841 G C T T T C A T G A A T T C T G T C A T T T C A A A G A C T C T C A C C C C T G C T A T A A C T A T G A C C A T G C T G N)
      (HUMIFNAGS-NEG-721 T A G T A A A A A C A C C A C T T A C T A A A T A G C T G A T T T G C T A A A G C A G A C C T C A T T C C A T T T A A G N)
      (HUMIFNAGS-NEG-5281 G A C T A T T A T T C C C T A C T T T T G G G A A T A G T A A A T T G T C T G A T T C C T A C A A A C T G T G T G A A T N)
      (HUMIFNAGS-NEG-9841 A T A T T A C T T G G T A A T A C T A A A G C A A T G A T G A A T T A T G T G C A T G G A G T C A T T A A T C T T C T G N)
      (HUMIFNAII-NEG-61 A C T G A A A G T A C A G A G A A A T G T T C A G A A A A T G A A A A C C A T G T G T T T C C T A T T A A A A G C C A T N)
      (HUMIFNAPS-NEG-721 C T G A A C T T C A T C T G C A G C T G G A A T G C C T G G A G T C T T G C T T A G G G C A G A C A A A A A G A G A G G N)
      (HUMIFNATC-NEG-661 C A T C T C T G T C C T C C A T G A G A T G A T C C A G C A G A C C T T C A A T C T C T T C A G C A C A A A G G A C T C N)
      (HUMIFNB2-NEG-361 G G A T G C T T C C A A T C T G G A T T C A A T G A G G A G A C T T G C C T G G T G A A A A T C A T C A C T G G T C T T N)
      (HUMIFNB3-NEG-1081 C T G T C C T G A A C T C G A T G A A T C A G C T C G G T C A G G C G T G C T T A A C G G T T C T C T C C G C T T T T G N)
      (HUMIFNB3-NEG-5641 G G G G T G G G G G C T G A G A C C C C A G A A G G C C C C T T C T C C C A C A G G A A A G G G G A A G C C A G A C C C N)
      (HUMIFNB3-NEG-10201 A C T T A G C A T T T C A T A A C A G G C G C A G G T T C A C T G A G A A G A T A T T T A A A C T C T G A A A C G A G G N)
      (HUMIFNF-NEG-601 T T A A G G A G G A A G G A A T G A A A C C T G T T T C A A C A T G G A A A T G A T C T G T A T T G A C T A A T A C A C N)
      (HUMIFNG-NEG-4321 G C T G A C T C C A C A A C C A G G A G T C T T T T C A C T A T A T A A T T T C A A G A A T T C T A T A G A A G T A G A N)
      (HUMIFNINI-NEG-1201 T A G C T C A A T G C C A A C A C T T T T T T T T T C T T T T T C T T T G C A T T T A A C A T T G T C T T G G A G C T G N)
      (HUMIFNN-NEG-601 C C T C A T T G A T T A A T A C A T C A T C T C A C A C T T T C A T G A G T T C T T C C A T T T C A A A G A C T C A C T N)
      (HUMIFNRG-NEG-1561 A C A G T T T T C T G C T T T A A T T T C A T G A A A A G A T T A T G A T C T C A G A A A T T G T A T C T T A G T T G G N)
      (HUMIGB7-NEG-1381 T C T C C C C A T A T G C A A T T T G C T T A A T G T A A C C T C T T C T T T T G C C A T G T T T C C A T T C T G C C A N)
      (HUMIGCB4-NEG-61 T C G G C A A C C C C C G C A A G T C C A A G C T C A T C T G C C A G G C C A C G G G T T T C A G T C C C C G G C A G A N)
      (HUMIGCC4-NEG-781 A G G A C C C T G C C C C T G A C C T A A G C C C A C C C C A A A G G C C A A A C T C T C C A C T C C C T C A G C T C G N)
      (HUMIGCC8-NEG-481 A C C C C G T C G T G C C C T G A C A C T G C G C C T G C A C C C G T G T T C C C C A C A G G G A G C C G C C C C T T C N)
      (HUMIGCD2-NEG-121 T G G A C C A T C G C G G A T A G A C A A G A A C C G A G G G G C C T C T G C G C C C T G G G C C C A G C T C T G T C C N)
      (HUMIGCD6-NEG-901 C C T A G G G G C A T G G C C C A G T G T C T C T G C T C C T G A G T G C C C A C C G T G C A G C A C T T G C A G G G G N)
      (HUMIGCD7-NEG-1921 G C A C A T G C C C C G G A C A G T T C T G A G T G A G C A G T G G C A T G G C C G T T T G T C C C T G A G A G A G C C N)
      (HUMIGCH5-NEG-241 G T G A A C A C T T C T G G G T T T G C C C C C G C A C G C C C C C C T C C A C A G C C C A G G A G C A C C A C G T T C N)
      (HUMIGF27-NEG-1 G A C A A C T T C C C C A G A T A C C C C G T G G G C A A G T T C T T C C A A T A T G A C A C C T G G A A G C A G T C C N)
      (HUMIGF2AP-NEG-421 G G A G G G G G T C C T G C A G G G C G G G G G G C T G G G A A G G T G G G G A G A G G C T G C C G A G A G C C A C C C N)
      (HUMIGFII5-NEG-121 C G G G G T C A C G T G C T C G C C A A G G A G C T C G A G G C G T T C A G G G A G G C C A A A C G T C A C C G T C C C N)
      (HUMIGFIIR-NEG-2281 G G C A C A C C C T A T A A C A A T G A A A G A C A C A C A C C G A G A G C T A C G C T C A T C A C C T T T C T C T G T N)
      (HUMIGFIIR-NEG-6841 T G C G G A A A G G A T A A G A C C A A G T C T G T T T C T T C C A C C A T C T T C T T C C A C T G T G A C C C T C T G N)
      (HUMIGGFCRA-NEG-1 C C C A A A T G T C T C A G A A T G T A T G T C C C A G A A A C C T G T G G C T G C T T C A A C C A T T G A C A G T T T N)
      (HUMIGGRLA-NEG-841 A G G G A A A A G C C C A T G A T C T T C A A G C A G G G A A G C C C C A G T G A G T A G C T G C A T T C C T A G A A A N)
      (HUMIGHAB-NEG-121 C A G A G C C A G C A A G A T G G G G G C T C A G T G A C A C C C G C A G G G A C A G G A G G A T T T T G T G G G G G C N)
      (HUMIGHAE2-NEG-781 T T G T C C A C C G C C T C T A C C A C G C A G G A G G G T G A G C T G G C C T C C A C A C A A A G C G A G C T C A C C N)
      (HUMIGHAJ-NEG-541 G A T G G T G G G A C A T C A A A C T G C G C T G C C T C C G T G A A A G G C A G A T T C A C C A T C T C A A G A G A T N)
      (HUMIGHBC-NEG-481 T G G G G A T C A T C T A T G C T G G T G A C T C T G A G A C C A G A T A C A C C C C G T C C T T C C G A G G C C A G G N)
      (HUMIGHBU-NEG-301 A G C C T A C A T G G A G C T G A G C A G C C T G A G A T C T G A G G A C A C G G C C G T G T A T T A C T G T G C G A G N)
      (HUMIGHCH-NEG-121 G G A A T T G T C T C A G G G G A G C G G C C T C C T C C A G A G G T T A G A G C A C A G G C C C A G C T A A T A G G A N)
      (HUMIGHHSG4-NEG-601 C C T T T T C T T T T C T A C C A C A T G G C C A G G C A T G A A T T T T C C A A A T T T T T T A T G C T C T G C T T C N)
      (HUMIGHVA-NEG-481 A C A C C T T C A A C A G C T A C T A T A T G C A C T G G G T G C G A C A G G C C C C T G G A C A A G G G C T T G A G T N)
      (HUMIGHVAQ-NEG-61 G A G C T G A G C A G C C T G A G A T C T G A G G A C A C G G C C G T G T A T T A C T G T G C G A C C G C A A C T G G A N)
      (HUMIGHVH-NEG-481 C A C C G C C T A C C T G C A G T G G A G C A G C C T G A A G G C C T C G G A C A C C G C C A T G T A T T A C T G T G C N)
      (HUMIGHVQ-NEG-61 A G C T G G A T T T T C C T T G T T G C T A T T T T A A A A G G T G T C C A G T G T G A G G T G C G A C T G G T G G A G N)
      (HUMIGHVV2-NEG-841 G A A A G A A A C G A G G A A G A C G G G T T T T C G T C T A T A G T T G A A G C T T T T A C T A G G A T C T T G C C T N)
      (HUMIGJ2-NEG-181 A T A G A T G T G G A A G T T A A T A G C T T T T A A T T T T A A C C T T G T T A G T A A G A A T G T T T T T A A A A A N)
      (HUMIGJHI-NEG-61 C T C A A T T T T G T A G A A A A A T T T G T A T T T C T T T G T G A T A A T G A C T T T A G T G T T G T A T T T T T T N)
      (HUMIGKAG-NEG-481 T T G C A T T G T G G T C T C C C A T C A A G A C T C A G C G G C A C T C G A T C T G G G A C A G A C C T C A C T C T C N)
      (HUMIGKAR-NEG-181 T T C A G T G G C A G T G G G T C T G G G A C A G A C T T C A C T C T C A C C A T C A G C A G A C T G G A G C C T G A A N)
      (HUMIGKC1-NEG-1681 A G G A G T T T G G T A A A G A T T G G T A A A T G A G G G C A T T T A A G A T T T G C C A T G G G T T G C A A A A G T N)
      (HUMIGKCB-NEG-1081 T T G A A A T C T G G A A C T G C C T C T G T T G T G T G C C T G C T G A A T A A C T T C T A T C C C A G A G A G G C C N)
      (HUMIGKP1-NEG-1441 A A T A T C T C A A A G A A T A A G C C A C T C T T G A A A T T C C A A G T A G G A T T A T T T T T C T A A A T A T A G N)
      (HUMIGKPC-NEG-61 A A G A C T T T T T A T A G G C T G G T C A C A C C C G G A G C A G G A G T C A G C C C C A G T C A G G A C A C A G C A N)
      (HUMIGKREC-NEG-1 G A G C T C A T T T T T T A A A A A T C C A A T T T G T A C A T T A G A C T A A A C G T G A A A T T A T C T C T T A T T N)
      (HUMIGKVAB-NEG-1261 T C C T T T A C A G A C A G C T A G T G T G G T G G C C A C T C A G T T T T A G C A T C T C T G C T C T A T T T G G C C N)
      (HUMIGKVI1-NEG-541 T T C A G G G A A A T T C T C T T A C T A C A T G A T T A A T T G T G T G G A C C A T T T G T G T T T A T G C T T C C A N)
      (HUMIGKVI3-NEG-421 T G G G T T G G G G A C A G A T T T C A T G C T G A A A T C A G G A G G A T G G A T G C T G A G G A T G T T G G G G T T N)
      (HUMIGKVI5-NEG-2101 C A A G A A G C C A A A G C A G T G A A G G T T G C A G A G A A T T T T C T T A C T A A A A T G C C A A G G A T T C A T N)
      (HUMIGKVJ2-NEG-961 G A C A A A T T T G T G C T A C C C T G G T C T T A C C T G G G A C A C C T G G G G A C A C T G A A C T G G T G C T G A N)
      (HUMIGKVM-NEG-421 C C C T C T C C T G C A G G G C C A G T C A G A G T G T T A G C A G C A G C T A C T T A A C C T G G T A T C A G C A G A N)
      (HUMIGKVS-NEG-421 C T G G T G T T T T T T C C T C A A G C C T T C T G T T T A C T T A T G G G A A G C T A C T A T G G T G G C T G C T T A N)
      (HUMIGKVW-NEG-841 A A A G A A G A G A G A T A A G T C C A G C T G A G G A G T C T G T G T T A T G G G A T A A T C G G A A T T T G T A C A N)
      (HUMIGLAM1-NEG-121 G C G G C C C C A G G A C A G A A G G T C A C C A T C T C C T G C T C T G G A A G C A G C T C C A A C A T T G G G A A T N)
      (HUMIGLC2A-NEG-361 G T C A C G C A T G A A G G G A G C A C C G T G G A G A A G A C A G T G G C C C C T A C A G A A T G T T C A T A G G T T N)
      (HUMIGLPAV-NEG-301 G C A A C C A G T G G T C A C C C C T T T T C T C T C T C T C T C T G T G T C C C T T G G G A T G A G C C C T T C T C T N)
      (HUMIGLV71-NEG-721 T C A T A A G A G G A A C C A A G A C A T A A A C C T C C C T C G G C C C T T G T G A T G T G G A G A T T G T G T G A T N)
      (HUMIGMUD-NEG-721 G G C A C A C A C A T G G A T A T G T G C A C A C A T G G A C A C A T A C A T G T G C A G G A C A T G C A C A C A C A C N)
      (HUMIGMUD-NEG-5281 T T G T A A C T T G A C A A G A A G T T A T C T G C T T C C A A A G T A C A A T G A T G G G G C A G G C A T A G G A T G N)
      (HUMIGMUTDM-NEG-361 G G A T G T G G A G A G C A G T G T C C C A A G G C T G C A C A G G C A G A G T G G C C A T G G C C A T G G C C A C A A N)
      (HUMIGVKA2-NEG-601 C A T A T G T T G A A A A A T G A T C A A A T C A G G A T A T T T A G G A T G T G C A T C A G C T C A T G T A T T T A C N)
      (HUMIGVKW1-NEG-841 G A C T C C A C T G T C C C T G T C C A T C A C C C C C G G A G A G C C G G C C T C C A T C T C C T G C A G G T C T A G N)
      (HUMIHRP-NEG-541 C C A G T G C C G C C T G G A A A A G C T G C A G C T G G A G T A T T G C A G C C T C T C G G C T G C C A G C T G C G A N)
      (HUMIIP-NEG-61 T G C C C C T G C T G C G A T G A C C C T G T C G C C A C T T C T G C T G T T C C T G C C A C C G C T G C T G C T G C T N)
      (HUMIL1AG-NEG-421 G G C T T A A A C T C C A A C T G G G A A C C C A A A A C A T T C A T T T G C T A A G A G T C T G G T G T T C T A C C A N)
      (HUMIL1AG-NEG-4981 T C C T G G G T T C A T G C C A T T C T C C T G C C T C A G C C T C C C G A G T A A G C T G G G A A T A C A G G C A C C N)
      (HUMIL1AG-NEG-9541 A G G A G A G G A A T A G G T T T G G G A A A T A A A T C C T G C T G A C A T T G G A A A C C C C A A G G A A G C C T C N)
      (HUMIL1B-NEG-2161 C T G A G A T T C C A G C A T C C T G C A A C C T C C A G T T C T G A A A T A T T T T C A G T T G T A G C T A A G G G C N)
      (HUMIL1B-NEG-6721 T G G G A G G G A C C A A A G G C G G C C A G G A T A T A A C T G A C T T C A C C A T G C A A T T T G T G T C T T C C T N)
      (HUMIL1BX-NEG-901 G A T C G T G C C A C T G C A C T C C A G C C T G G G C G A C A G A G T G A G A C T C T G T C T C A A A A A A A A A A A N)
      (HUMIL1BX-NEG-5461 G C T G G A A A C C A A A G C A A T C A T C T C T T T A G T G G A A A C T A T T C T T A A A G A A G A T C T T G A T G G N)
      (HUMIL1P-NEG-301 G A A G A A G A G A C G G T T G A G T T T A A G C C A A T C C A T C A C T G A T G A T G A C C T G G A G G C C A T C G C N)
      (HUMIL1RA-NEG-2821 T C T T T G G A G G A A C A G C T C C C T A G T G G C T T C C T C C G T C T G C A A T G T C C C T T G C A C A G C C C A N)
      (HUMIL2-NEG-2401 T G A A A T A T T A T A T A T A A T A T A G A A T C A A G A G G C C T G T C C A A A A G T C C T C C C A A A G T A T T A N)
      (HUMIL2A-NEG-1261 G A C T G G T A A A G T C T T T G A A A A T A T G T G T A A T A T G T A A A A C A T T T T G A C A C C C C C A T A A T A N)
      (HUMIL2A-NEG-5821 A T C A T T T G G T A T C A T A A C A A A A T A C G C A A T T T T G G C A T T C A T T T T G A T C A T T T C A A G A A A N)
      (HUMIL2B-NEG-3241 A A T G G A C A A G C C T C A T C C C A A A C T C C A T C A C C T T T C A T A T T A A C A C A A A A C T G G G A G T G A N)
      (HUMIL2R-NEG-1 G A G C T C T G T G A C G A T G A C C C G C C A G A G A T C C C A C A C G C C A C A T T C A A A G C C A T G G C C T A C N)
      (HUMIL2R6-NEG-1 C C C C A A A G C A A G T G T C A G A A A G A G G G A A C C C A G G A C C A G G A C C A A G C A C G G T C C C C A G G C N)
      (HUMIL2RA-NEG-2161 T G G A T G T G G T G G C A T A C G C C T G T A G T C C T A G C C A C T C A G G A G G C T G A G G C A G G A G G A T T G N)
      (HUMIL2RBC-NEG-1681 C T G G G C A G G G G G A G T T C A G G G C C C T T A A T G C T C G C C T G C C C C T G A A C A C T G A T G C C T A C T N)
      (HUMIL2RX6-NEG-1 C C T C A C C A C C A C C A C G T G T C T C C C A C C A G C C T C T G A G C T T C T C A T T C A C A G A G A C A C C C T N)
      (HUMIL4-NEG-301 T A C A G C C A C C A T G A G A A G G A C A C T C G C T G C C T G G G T G C G A C T G C A C A G C A G T T C C A C A G G N)
      (HUMIL5A-NEG-481 A A T T G A C T G G G G A C G C A G T C T T G T A C T A T G C A C T T T C T T T G C C A A A G G C A A A C G C A G A A C N)
      (HUMIL6-NEG-1021 C C A G T A G T G T C G G G A G C A A G T T C A G C A A A A C T C A A A C C T T T C A G G G T T G T G G A A T C T T G C N)
      (HUMIL71-NEG-61 C C T C C C C A C C T C C C A C T C T A G G T T C C A G T C A A A T G G A A A T A T G T G G C T T T T C T C A C T C C A N)
      (HUMIL7A-NEG-361 G A C T A C G C C C G C C T C C C G C A G A C C A T G T T C C A T G T T T C T T T T A G G T A T A T C T T T G G A C T T N)
      (HUMIMP-NEG-181 C T G C A G A C C A G G T G G A C C T G A C T T C T G C T C T G A C C A A G A A A A T C A C T C T T A A G A C C C C A C N)
      (HUMINCP-NEG-3121 G G A G C C T T G G G A G G G G C A A T G G A A C A G T C A C T A T T C A T T C T A G T T C A G C A C T C T G G G A C T N)
      (HUMINCPPS-NEG-3181 G C C C C A G C T C A C C C A A C A C C A G C T T C T C T A A G A A C C C A G G A T T T C T T G T G A G G T C T C T G T N)
      (HUMINHA-NEG-1 G A A G G A C T G G G G A A G A C T G G A T G A G A A G G G T A G A A G A G G G T G G G T G T G G G A T G G G G A G G G N)
      (HUMINHBA-NEG-541 A G A T A G A G G A T G A C A T T G G A A G G A G G G C A G A A A T G A A T G A A C T T A T G G A G C A G A C C T C G G N)
      (HUMINHBB2-NEG-301 A G C G G C T G G C A T A C C T T C C C A C T C A C G G A G G C C A T C C A G G C C T T G T T T G A G C G G G G C G A G N)
      (HUMINIFI-NEG-481 A T T G G T G G C A G A A G A G G A A G A T T T C T G A A G A G T G C A G C T G C C T G A A C C G A G C C C T G C C G A N)
      (HUMINS02-NEG-181 T C T T T A C T A A A A C T A C A A A A T T A G C T G G G T G T G G T G G C A C A T G C C T G T A A T C C C A G A T A T N)
      (HUMINSPR-NEG-61 C C T C A C T C C C A C T C T C C C A C C C C C A C C A C C T T G G C C C A T C C A T G G C G G C A T C T T G G G C C A N)
      (HUMINSR-NEG-541 A A C C T G A T G A A C A T C A C C C G G G G T T C T G T C C G C A T C G A G A A G A A C A A T G A G C T C T G T T A C N)
      (HUMINSR2-NEG-1 T T G C T C T G C A G G T G C G C C T C C T G G G A G T G G T G T C C A A G G G C C A G C C C A C G C T G G T G G T G A N)
      (HUMINSRA-NEG-4201 T T C G C T T T C C T C T G G T T T G A A A G C C T C T G G A A A A C T C A G G A T T C T C A C G A C T C T A C C A T G N)
      (HUMINSRC-NEG-2101 A C A G G A A C C A T G A T G C T G G C A T C T G C T C A G C T T C T G A G G A A G C C T C A A G A A A C T T T C A A T N)
      (HUMINSRC-NEG-6661 T A G G C T C C A G C A G G C T G G C T C A G G C T T C A T T C C A T G G T C C T C T G T T G G T T C C T A G T A G C A N)
      (HUMINSRD-NEG-3601 A T G C C T T G A T A T A G G T A T A G G C A T A T T T A A G T T T A T T A T G A A T T T T G C T G A T A T A G G A T G N)
      (HUMINT1G-NEG-601 C C G C G G C A C A G A G C C A G G G G C C A A C C C T A C C C A G C T C C C A C G C T C T G G G A T C C G T C T G C C N)
      (HUMINT2-NEG-481 G G C G C G C T G C G G A G C G G A G C C G C G G C T C G A C G G C G G T G C G C T G G C G G C G A G T G T A T G C A G N)
      (HUMINT2-NEG-5041 G G C T T T G A G A A G G G T G G A C A G A G G C T C C T A G C C C C A C C A G G G A T G C T T A G C C A A G C A G T C N)
      (HUMINT2-NEG-9601 G G T G G C C A C C G C C A G A G C T C C T G G C G A C A T C T T G G C G T G G C A G C C T C T T G A C T C T G A C T C N)
      (HUMINV2-NEG-121 A G G A G C A A A T G A A A C A G C C A A C T C C A C T G C C T C C C C C A T G C C A G A A G G T G C C T G T C G A G C N)
      (HUMIR3EBA-NEG-121 G G G A G C A G G A G G A G A A G A T G C G G A G G C A G G A G G A G A T G A T G T G G G A G T A G G A G G A G A A G A N)
      (HUMIRBP-NEG-3481 C T G G A C A C A C G C C C A G G T T G T A G G T G A A C G C T A T G G C T C C A A G A A G A G C A T G G T C A T T C T N)
      (HUMIRBPG-NEG-3781 G G C G C T T T G T C T G G G A G G C G G T T A C T G A A G C A G G C A T G A A G G A G G G A G C A G G G A G A G T G G N)
      (HUMIRBPG-NEG-8341 G G C T C A C G T T G C A T T C C T G T T G G A C A G T G C T G T C C T G G A G A G T T G T T C T T A T A C A T C A C A N)
      (HUMIRBPM-NEG-3241 A G G T T C A A C A T C G G T G G C C C C A C A T C C T C C A T T C C C A T C T T G T G C T C C T A C T T C T T T G A T N)
      (HUMIRGT-NEG-1681 C A G G C A G G G G T G G G A G A G C C A G C T C T C T C T A C C C G G C C C A G A G A C C C C T T C C T T T C C T C T N)
      (HUMIRRA-NEG-1861 G C G A C C T C T A C C T C A A T G A C T A C T G C C A C C G C G G C T T G C G G C T G C C C A C C A G C A A C A A C G N)
      (HUMISG1-NEG-241 A C C T T T G T T G G T T G T A A A T C T G T C T T A C C A A T G G T G G T T T G T T C C C T C C T G A A C A G T T T T N)
      (HUMITF1-NEG-601 C A C C A G C A C G A G C G T A T G G G C T A C C A G C T G C A T G G A G C A G A G G T G A A C G G T G G G C T C C C A N)
      (HUMITI2-NEG-481 G C T C T T T A T G C A C A G G C C A G A G C A A A A G G C A A G A C G G C T G G C T T G G T G A G G A G C A G C G C T N)
      (HUMJNLTRA-NEG-121 T T T T A G A C A T T A C A C C A A A A G C A C A T G C C G T A A A A G A A A A A A T A G A T A A A T T G G T G G A T T N)
      (HUMJUNA-NEG-3301 G A A G T C A A A C A T T T C A A A G T T T G G A T T G C A T C A A G T G G C A T G T G C T G T G A C C A T T T A T A A N)
      (HUMKADA-NEG-601 T T C G T C A C T A T C T C C T C T C C A C T G G C C A C G C A G A T C C C T C A G G C G G T G G G G G C G G C G T A C N)
      (HUMKAL2-NEG-1741 G T C T G A T C C C C C T G A C C C A G C A C C C C C T C C G C A G G T G C C G T G C C C C T C A T C C A G T C T C G G N)
      (HUMKALA-NEG-181 C A C A A C T T G T T T G A C G A C G A A A A C A C A G C C C A G T T T G T T C A T G T C A G T G A G A G C T T C C C A N)
      (HUMKER18-NEG-1381 G G T T G A A T T G T A A A T G C T C A G G A T T T G T T T A A T T A A G G A T G C A G G A A A G G T G A T A T A C C G N)
      (HUMKER18-NEG-5941 A G T A T T G T C C C T A G C T G T A C T T A G T A T G C A A A T G A A G T T T G G C C T T G A G T T T C C C T T T T C N)
      (HUMKER19-NEG-541 C G T G G A G G C C G A C A T C A A C G G C C T G C G C A G G G T G C T G G A T G A G C T G A C C C T G G C C A G G A C N)
      (HUMKER56K-NEG-1201 G A A T G C T T A G T G C C C T C A C T T C T T C T C T C T C T C T C T A T A C C A T C T G A G C A C C C A T T G C T C N)
      (HUMKER654-NEG-1441 C C G T G G T C A G C A G C A G C A C G A C T T C C G C C T C C G C A G G T G G C T A T G G A G G A G G T T A C G G C G N)
      (HUMKER672-NEG-2401 T T C T C C T T C T A C C A C T C A G C T G T A T G G A A T G G G G G T A A C C C T A C A G G T A A A G G G C G A G T G N)
      (HUMKER7R-NEG-601 G A A G A T G A A A T T A A C C G C C G C A C A G C T G C T G A G A A T G A G T T T G T G G T C C T G A A G A A G G A T N)
      (HUMKERC4-NEG-961 G A C A T C G A G A T C G C C A C C T A C C G C A A A C T G C T G G A G G G C G A G G A G T A C A G A A T G T C T G G A N)
      (HUMKEREP-NEG-3721 C C T G G A G G A G A C C A A A G G T C G C T A C T G C A T G C A G C T G G C C C A G A T C C A G G A G A T G A T T G G N)
      (HUMKEREP9-NEG-241 C T A C A A G C A C T G A A G C T G T G C C G C C A G C T C T C A G T C C C A C A G C T C T C A G G C C C C T C T C T G N)
      (HUMKERMII-NEG-181 G G C C T C G G C G C C T C G C G G C C G C G C G T G G C C G T G C G C T C T G C C T A T G G G G G C C C G G T G G G C N)
      (HUMKERP2-NEG-1381 A G G T G G C C A C C A A C A G C G A G C T G G T G C A G A G C G G C A A G A G C G A G A T T T C G G A G C T C T G G C N)
      (HUMKITCR-NEG-1021 A T T G T T G A A T A T G A A G C A T T C C C C A A A C C T G A A C A C C A G C A G T G G A T C T A T A T G A A C A G A N)
      (HUMKRASP-NEG-541 G G C A G T G G C G G C G G C G A A G G T G G C G G C G G C T C G G C C A G T A C T C C C G G C C C C C G C C A T T T C N)
      (HUMKTEP2A-NEG-1441 G T G A G G T T T G T T T C T A C C A G T T A T T C C G G A G T A A C C A G A T A A A G A G A T G C C C T C T G T T T C N)
      (HUMKUP-NEG-1021 A A A T A T A A A T C G G A G G G G A A G T G C T T C T C T G T T T T G G G A T T T T G T A A A T C T T C T C A G G T T N)
      (HUMLACF-NEG-541 A A T C A T G C C G T G G T G T C T C G G A T G G A T A A G G T G G A A C G C C T G A A A C A G G T G C T G C T C C A C N)
      (HUMLAM1B-NEG-121 G G G C T T C T C C A G T T G C T A G C T T T C A G T T T C T T A G C C C T G T G C A G A G C C C G A G T G C G C G C T N)
      (HUMLAM1B-NEG-4681 G A A G C A G T T G C T A A T G A A G T A T T G A A A A T G G A G A T G C C T A G C A C C C C A C A G C A G T T A C A G N)
      (HUMLAMAR-NEG-1081 G A G C T G C A G C A G T C G C G C A T C C G C A T C G A C A G C C T C T C T G C C C A G C T C A G C C A G C T C C A G N)
      (HUMLAMB2-NEG-961 T G A C A A T A G C C C T G T G C T G C A G G A A T G G G T A A C T G C C A C T G A C A T C A G A G T A A C T C T T A A N)
      (HUMLAMC-NEG-181 C C A G C T C C A C T C C G C T G T C G C C C A C C C G C A T C A C C C G G C T G C A G G A G A A G G A G G A C C T G C N)
      (HUMLAMP1A-NEG-841 T G T G G A C A A G T A C A A C G T G A G C G G C A C C A A C G G G A C C T G C C T G C T G G C C A G C A T G G G G C T N)
      (HUMLAP-NEG-1141 A A G A A T G C T T A C A A T A A A C T C T C C T C C A G G G T C T T C C T G G A T C A C A A C G C C C T C C C C G A C N)
      (HUMLAPA-NEG-2881 A C T A A A T A T C T C A A C T T C A C G G C C T C A G A G A A T A C C A G T C G G G T C A T G C A G C A T C A A T A T N)
      (HUMLC3-NEG-901 G G A C A T T C G A A C A G A G T T C A A G A A G C A T T A T G G C T A T T C C C T A T A T T C A G C A A T T A A A T C N)
      (HUMLCA-NEG-2521 G G A G C T G G A G G A C A C A G C A C A T T G G A A A T C A A G A A G A A A A T A A A A G T A A A A A C A G G A A T T N)
      (HUMLCAR-NEG-2161 T T G A A C T C T C T G A G A T A A A C G G A G A T G C A G G G T C A A A C T A C A T A A A T G C C A G C T A T A T T G N)
      (HUMLCAT1-NEG-721 C G G C T G T C T A C A C T T G C T C T A T T T C C T G C T G C G C C A G C C C C A G G C C T G G A A G G A C C G C T T N)
      (HUMLCATG-NEG-3841 C T G A C C T T A A G T C A T C T G C C T G C C T C G G C C T C C C A A A G T G C T A G G A T T A C A G G T G T G A G C N)
      (HUMLCK-NEG-181 A T C C T G C T G A C G G A A A T T G T C A C C C A C G G C C G C A T C C C T T A C C C A G G G A T G A C C A A C C C G N)
      (HUMLCK2-NEG-841 T C A G A A T C T G A A A C T T T G T A G C T G C A T C T C C T C T A T C T T C T C A G G G G T A T G A G T C C A A C G N)
      (HUMLD78R-NEG-1 A A G G A C A C G G G C A G C A G A C A G T G G T C A G T C C T T T C T T G G C T C T G C T G A C A C T C G A G C C C A N)
      (HUMLDHA7-NEG-361 A T A T T T T A A G A T G G A C T G G G A A A A A C A T C A A C T C C T G A A G T T A G A A A T A A G A A T G G T T T G N)
      (HUMLDHB1-NEG-2461 T T C C T T A C A G C C T G C A C T C T G A T G T T G G C A C A G G C T G T A T A T C A T G C A G A C C A T T T T C T T N)
      (HUMLDHBR-NEG-121 A A G A T C A C T G T A G T G G G T G T T G G A C A A G T T G G T A T G G C G T G T G C T A T C A G C A T T C T G G G A N)
      (HUMLDL100-NEG-1381 T C C C C G A G C C C T C A G C A C A G C A G C T G C G A G A G A T C T T C A A C A T G G C G A G G G A T C A G C G C A N)
      (HUMLDL100-NEG-5941 T G G C A T T T A C T T T C T C T C A T G A T T A C A A A G G C T C C A C A A G T C A T C A T C T C G T G T C T A G G A N)
      (HUMLDL100-NEG-10501 T G G A A T T T A A G T A T G A T T T C A A T T C T T C A A T G C T G T A C T C T A C C G C T A A A G G A G C A G T T G N)
      (HUMLDLR01-NEG-241 G C T A T T G G A G G A T C T T G A A A G G C T G T T G T T A T C C T T C T G T G G A C A A C A A C A G C A A A A T G T N)
      (HUMLDLR18-NEG-1621 A G A C C C C A T C T C T T A A A A A A T G A A T T T G G C C A G A C A C A G G T G C C T C A C G C C T G T A A T C C C N)
      (HUMLDLRRL-NEG-2641 G A T A C T G C T C A A T G G C A C A G A C C G G A A G A T T G T G T A T G A A G G T C C T G A G C T G A A C C A C G C N)
      (HUMLDLRRL-NEG-7201 A G G C A C C T C T C C G G G C A C C C C C A A T C G C A T C T T C T T C A G C G A C A T C C A C T T T G G G A A C A T N)
      (HUMLDLRRL-NEG-11761 T G A C T G C G G G G A C G G C T C T G A C G A G G A G G A C T G C A G C A T C G A C C C C A A G C T G A C C A G C T G N)
      (HUMLECGBB-NEG-61 A G G T G T G C A T C A C C T T T G A C C A G G C T G A C C T G A C C A T C A A G C T G C C A G A C G G A C A T G A A T N)
      (HUMLGTPA-NEG-1261 T C A G C T T C T T T G A A A T T G G G C C A G G C C C G A T C C C C T G G T T C A T G G T G G C T G A G T T T T T C A N)
      (HUMLHRH-NEG-961 T C C A T C T T C T G C A G G G T T A G T G A T A C A G A T G C T A G C T T T T T C A C T A A A G A G G T C T T T T A G N)
      (HUMLIDNA-NEG-2701 T A C C T G G G A C T A C A G T C A T G C A C C A C C A C A T C C A G C T A A T T T T T T A T A C A G A T G G G G T T T N)
      (HUMLIPCR-NEG-1261 A T T A T A A C T C T G T A T A A T A G A G A T A A G T C C A T T T T T T A A A A A T G T T T T C C C C A A A C C A T A N)
      (HUMLKHA4-NEG-61 G C C T C T C C G G C T T C C G T C T G C C G G A C C A A G C A C C T G C A C C T G C G C T G C A G C G T C G A C T T T N)
      (HUMLMWOS1-NEG-301 T A T C T C A A A A C T A T T C T G C A T G G T G C T G T A A T G G T G G A T A C A T G A C A T G T T A T G T T T G C C N)
      (HUMLMYC2-NEG-901 G A G A A A A G A C A G C T C C G A T G C C G G C A G C A G C A G T T G C A G A A A A G A A T T G C A T A C C T C A G T N)
      (HUMLOX5-NEG-61 T C A C C G T G G C C A C T G G C A G C C A G T G G T T C G C C G G C A C T G A C G A C T A C A T C T A C C T C A G C C N)
      (HUMLOX5A-NEG-2161 T T C C T C C G A G G C C A G T A C C T T T C C A T T T A T T C T T T G A T C T T C A G G G A A C T G C A T A G A T T G N)
      (HUMLPHAA-NEG-1861 T G A G A G C C T C T G A G C G C T T C T T G C A C T T C A T G C T G G G C T G G T T T G C A C A C C C C G T C T T T G N)
      (HUMLPL-NEG-181 A G C A A A G C C C T G C T C G T G C T G A C T C T G G C C G T G T G G C T C C A G A G T C T G A C C G C C T C C C G C N)
      (HUMLPLR-NEG-361 T G G A C G G T A A C A G G A A T G T A T G A G A G T T G G G T G C C A A A A C T T G T G G C C G C C C T G T A C A A G N)
      (HUMLSZH-NEG-841 C C A T T C T C C T G C C T C A G C C T C C C G A G T A G C T G G G A T T A C G G G C G C C C G C C A C C A C G C C C G N)
      (HUMLYL1A-NEG-841 G A C C A A G C C G C A G C T C T G G C C G C A G G C C C C A C C C C T C C C G G G C C T C G C A A A C G G C C G G T G N)
      (HUMLYL1B-NEG-4081 A A G G A C C A G T G A A G A C G T C A G G G G C A A G G T C T C G G G G G T C C G G A A G G G T G A T C A T C G A C C N)
      (HUMLYRE-NEG-1801 T A T G T C T C C A G A T G A T T G A G C A A A T G G G C T C C C A G C T C A A G G G T C C C G G G T T T G A G T C C A N)
      (HUMM6PR-NEG-1861 A G T A T T T C T A A A C A T G T C G C A C T T T C T C C A C A G G C A T G T G G T T T T G A C C T T T T T T T C A A T N)
      (HUMMAC1A-NEG-4021 C C T G T G G G T G A A G A G A G A G G G A A A C A C A G C A G C A T C T C T C C A C T G A A A G A A G T G G G A C T T N)
      (HUMMAP2A-NEG-421 G A A G C A G G G T A C A G C A C T C T C G C A C A G A G T T A T C C A T C A G A T T T A C C T G A A G A A C C C A G T N)
      (HUMMBP17K-NEG-361 G C C A G A G A C C A G G A T T T G G C T A C G G A G G C A G A G C G T C C G A C T A T A A A T C G G C T C A C A A G G N)
      (HUMMBPA-NEG-661 A A T G C C T G C G G A G T T G T G C A C G T A G T A G G G T C A G G C C A C G G C A G C C T A C C G G C A A T T T C C N)
      (HUMMCAF-NEG-661 A A C A T T C C A A T G C A T T G C T A A A A T A T T A T T G T G G A A A T G A A T A T T T T G T A A C T A T T A C A C N)
      (HUMMCM-NEG-481 A G T T G C C T T T G A T C T G G C G A C A C A T C G T G G C T A T G A T T C A G A C A A C C C T C G A C T T C G T G G N)
      (HUMMCR-NEG-781 G A G A A A A G C C C G T C T G T T T G C A G C C C T C T G A A C A T G A C A T C T T C G G T T T G C A G C C C T G C T N)
      (HUMMCR-NEG-5341 G C T T A C T T A C A A A A G C A G C T T T T A G T T C A G A C T T A G T T T T T A T A A A A T G A G A A T T C T G A C N)
      (HUMMDNCF-NEG-1141 A T G T T A T A G T A A A T T T A T T T T A T T T T A G A T A T T A A A T G A T G T T T T A T T A G A T A A A T T T C A N)
      (HUMMDR1-NEG-2401 A T C C A G T C T A A T A A G A A A A A G A T C A A C T C G T A G G A G T G T C C G T G G A T C A C A A G C C C A A G A N)
      (HUMMDR1A07-NEG-781 T G A C A A A A T T G G A A T G T T C T T T C A G T C A A T G G C A A C A T T T T T C A C T G G G T T T A T A G T A G G N)
      (HUMMDR3-NEG-301 G A A A C T T C T C C T T T C C A G T G A A C T T T T C C T T G T C G C T G C T A A A T C C A G G C A A A A T T C T G G N)
      (HUMMDRA3-NEG-961 G G A G A T A A G G G G A C T C A G C T C T C A G G A G G T C A A A A A C A G A G G A T T G C T A T T G C C C G A G C C N)
      (HUMME491-NEG-601 G T G G A G A A G A T T G G G G G C T G G C T G A G G A A A A A T G T G C T G G T G G T A G C T G C A G C A G C C C T T N)
      (HUMMEDA-NEG-2761 T G C T G T C A A T C A A C C A A A C T T A C T G A G A A G G G A G G C C C C G A T C T G C T G T C A A T C A T C A A A N)
      (HUMMEHR-NEG-361 A C T G G C G G A A T G A A T T T G A C T G G A A G A A G C A G G T G G A G A T T C T C A A C A G A T A C C C T C A C T N)
      (HUMMET2AB-NEG-61 C T G C A A A T G C A A A G A G T G C A A A T G C A C C T C C T G C A A G A A A A G C T G C T G C T C C T G C T G C C C N)
      (HUMMETIA-NEG-1921 A C A G T G C A T G C C A T C C T G A A C T A A G T G T C C T C T G G G G C T G G G G A C A G A G C T T G G G C C A G G N)
      (HUMMETIF-NEG-1681 C T A C A T T C C T T T T C C T G T G A A A T A T G T G A G T G A T A A T T A A A C A C T T T A G A C C T G A T T C T G N)
      (HUMMETPOA-NEG-901 A T G T T T T A C C T G A G T T C A G A G A T T C T T A C C C C A T T A A G T A T G T C C A T G C C T T T G A A A G C A N)
      (HUMMFD8A-NEG-181 A A T C C T A A T G T G A T T T A G T A A A C A T T A G C T A A A G T T T C T C A T T C C T C C A T G T G A G G G C A T N)
      (HUMMG2-NEG-541 C T G G A G G T G G G C A G G A A G G A C C G A G G T C T A A A G C T G G A G G T G G C T G C T C A G A G T C C C A G C N)
      (HUMMGA2PS-NEG-1861 T G T T A C T T T C C T C T T C T G T G A T T T C T C T A C T C A T T T T T T T T T T C A G G A C A C A G T G G T G G C N)
      (HUMMGI2-NEG-901 C A A G A G G T T T C T G A G T G T G A G G A T T G C T C T G G A G T G G A A T G G C C C T C A C A G G T A G G A G T G N)
      (HUMMGPH-NEG-61 C T G G A G C C T C A T A A G T T C C A G A A T A A G A C C A A C G G C A T C A C C C C T C G G C G C T G G C T G G T T N)
      (HUMMGSA-NEG-1 C C C G C C T G C T G A G C C C C A T G G C C C G C G C T G C T C T C T C C G C C G C C C C C A G C A A T C C C C G G C N)
      (HUMMH-NEG-3541 C A G A G T C C A T G T G T T T C T T G T G C T G A T T T G T T G C A G G G G A G G A G A A T A G G T G G G G C T G T G N)
      (HUMMH6-NEG-1201 C T G A C A G A A T G A A C C T G C A G A C C C T G C G C G G C T A C T A C A A C C A G A G C G A G G C C A G T G A G T N)
      (HUMMHA2-NEG-1321 C G A C G G C A A G G A T T A C A T C G C C C T G A A A G A G G A C C T G C G C T C T T G G A C C G C G G C G G A C A T N)
      (HUMMHA3-NEG-1501 C T T T G G C A C C G G C G A C G G C C T T G G G C C C G T G A C T T T T C C T C T C A G G C C T T G T T C T C T G C T N)
      (HUMMHADX2-NEG-1201 C T C C C T A A G C C G G G G G C C T T G A G T C T T G C A G A G C C A G C C C T C C A C C C C A T C C C A T C C C A C N)
      (HUMMHANTLE-NEG-3181 G C T G G C C T G G T T C T A C T T G T A G C T G T G G T C A C T G G A G C T G T G G T C G C T G C T G T A A T G T G G N)
      (HUMMHAW-NEG-1201 A C G G G A A G G A G A C G C T G C A G C G C G C G G G T A C C A G G G G C C A C G G G G C G C C T A C C T G A T C G C N)
      (HUMMHAWB-NEG-721 T G G C A G C G G G A T G G G G A G G A C C A G A C C C A G G A C A C G G A G C T T G T G G A G A C C A G G C C T G C A N)
      (HUMMHB17W-NEG-1681 A C C A C C C C G T C T C T G A C C A T G A G G C C A C C C T G A G G T G C T G G G C C C T G G G C T T C T A C C C T G N)
      (HUMMHB27B-NEG-1201 G D G A C G G G G C T G A C C G C G G G G G C G G G T C C A G G G T C T C A C A C C C T C C A G A A T A T G T A T G G C N)
      (HUMMHB39W-NEG-1 G G C T C C C A C T C C A T G A G G T A T T T C T A C A C C T C C G T G T C C C G G C C C G G C C G C G G G G A G C C C N)
      (HUMMHB7A-NEG-1261 G T C C A C T G T G A C C C C T G T T C C C A T G C T G A C C T G T G T T T C C T C C C C A G T C A T C T T T C T T G T N)
      (HUMMHBC-NEG-1921 C A G A A G C G G C A A A A G C A G G T A C C C G C T C A C G C C C G A G A C T T T C A C A T C A A C C T C T T T C A A N)
      (HUMMHBIA-NEG-541 C C G T C T T C C C A G C C C A C C A T C C C C A T C G T G G G C A T C A A T G C T G G C C T G G T T C T C T T T G C A N)
      (HUMMHBW4-NEG-61 G C T G G G C C C T G G G C T T C T A C C C T G C G G A G A T C A C A C T G A C C T G G C A G C G G G A T G G C G A G G N)
      (HUMMHC1-NEG-4321 A A T A G A T G G G G C T G T G C C T A G T G G G T G C T C A G G C C A G T A T G G A C T T T A T G T G G T C A C T G C N)
      (HUMMHC4A-NEG-2761 C G C T G T G T C T C T G A A G G T G G T G G C T C G A G G G T C C T T C G A A T T C C C T G T G G G A G A T G C G G T N)
      (HUMMHCA1A-NEG-601 G A G A C G C T G C A G C G C A C G G A C C C C C C C A A G A C A C A T A T G A C C C A C C A C C C C A T C T C T G A C N)
      (HUMMHCACA-NEG-181 T G G A C G A C A C G C A G T T C G T G C G G T T C G A C A G C G A C G C C G C G A G T C C A A G A G G G G A G C C G C N)
      (HUMMHCAG-NEG-1 A T G C G G G T C A C G G C G C C C C G A A C C C T C C T C C T G C T G C T C T G G G G G G C A G T G G C C C T G A C C N)
      (HUMMHCAI-NEG-1 A T G G C C G T C A T G G C G C C C C G A A C C C T C G T C C T G C T A C T C T C G G G G G C T C T G G C C C T G A C C N)
      (HUMMHCAR4-NEG-241 C C G G A G T A T T G G G A C C G G A A C A C A C A G A T C T G C A A G G C C C A A G C A C G G A C T G A A C G A G A G N)
      (HUMMHCB44A-NEG-361 A G G A T G T A C G G C T G C G A C G T G G G G C C G G A C G G G C G C C T C C T C C G C G G G T A T G A C C A G G A C N)
      (HUMMHCBWC-NEG-121 C G C G G G G A G C C C C G C T T C A T C A C C G T G G G C T A C G T G G A C G A C A C G C T G T T C G T G A G G T T C N)
      (HUMMHCC6A-NEG-2401 T C T G A A T G C A T T T G T A T G T C T C C A G A A G A A G A C T G T A G C C A T C A T T C A G A A G A T C T C T G T N)
      (HUMMHCCWB-NEG-241 T G C G C G G C T A C T A C A A C C A G A G C G A G G C C G G G T C T C A C A C C C T C C A G A G G A T G T A T G G C T N)
      (HUMMHCD8A-NEG-3781 A T G A A A G C C T A C A A C G C A C G T T A C T T G C T T T A T A G A T T T T T T T T A A T T T T A A G T T T T A T G N)
      (HUMMHCGE1-NEG-61 G G A A C C C T G A A G A T A T C C T C T T C T C T G T C C T G T C A C T C T A T G G G A C T T A C G G C T C T T T G T N)
      (HUMMHCGE2-NEG-3301 G G A C T A C C T T A C C C G T A C C C T C C C T C C C T C C C A T C A T G G C T G A G T C C A G G G T T T A G G C T T N)
      (HUMMHCP41-NEG-541 G A T C C A G C T G T G G C T A T C C A G C C C C T T C C T G G G G A C T T T G G A C T T T G A G G G G G G G C A T G C N)
      (HUMMHCP42-NEG-4501 C T C C A G C G G C T G G G T G G T G A A G G A C C C T G G C T C T T C T C T C G G G G C G A C C C C T C A G T G C T C N)
      (HUMMHCP52-NEG-781 T A T C T G G T G G G A G A A A G C T G G G G T T G G G G A G G C C G A A G A A G G T C A G G C C C T C A G C T G C C T N)
      (HUMMHCW1B-NEG-241 A A T A T T A C C T G A G G T A A G G T A A G G C A A A G A G T G G G A G G C A G G G A G T C C A G T T C A G G G A C G N)
      (HUMMHCW1C-NEG-781 G G A G A T G G A A C C T T C C A G A A G T G G G C A G C T G T G A T G G T G C C T T C T G G A G A A G A G C A G A G A N)
      (HUMMHCW2B-NEG-3721 A G C A T A A T G T G A G G A G G T G G A G A G A C C A G C C C A C C C C C G T G T C C A C C G T G A C C C C T G T C C N)
      (HUMMHCW3-NEG-2761 A G C T G C T C T C A G G C T G C G T G T A A G T G A T G G C G G T G G G C G T G T G G A G G A G C T C A C C C A C C C N)
      (HUMMHDBW1-NEG-1 G C C T G C T G C T C T G G C C C C T G G T C C T G T C C T G T T C T C C A G C A T G G T G T G T C T G A G G C T C C C N)
      (HUMMHDC3B-NEG-2461 A C A C A A C T A C C A G T T G G A G C T C C G C A C G A C C T T G C A G C G G C G A G G T G A G C G G C G T C G C C C N)
      (HUMMHDC3B-NEG-7021 A T G T G G A G C C A G A A C C A C G G C T T A A A T G T T A G A C A C T A G G A T G A T G C C C A C T T T G T G C C A N)
      (HUMMHDCB-NEG-2041 C A G A T A C A T C T A T A A C C G A G A G G A G T A C G C A C G C T T C G A C A G C G A C G T G G G G G T G T A T C G N)
      (HUMMHDCB-NEG-6601 A T C T G C A T C A A G C T G A A G T T C T G T G T C C T C A C G A G C T G A T T T C A C C T T T G C A C A G A T C T T N)
      (HUMMHDOAG1-NEG-61 A G G G T T C C T T T T T C C C A G G A A C C C T T C C A A T A A T A C A A C G G C T C C T T C C T T T C T T T C C C T N)
      (HUMMHDOB-NEG-4261 A A A G G T A A T G A G C C T G T G A G G A G T G C C C T G C C A C C T G T C C C A G A C C T T C C C C A C T C C C A C N)
      (HUMMHDPBF-NEG-61 T A C A T C T A C A A C C G G G A G G A G C T C G T G C G C T T C G A C A G C G A C G T G G G G G A G T T C C G G G C G N)
      (HUMMHDQA1-NEG-661 T T C C T A A G A C C C C T T T C A C T A T T A A G A G A A T T A A A A A T T A T A G C T G T T C C T C C T T C A G G A N)
      (HUMMHDQAR-NEG-1 G G T G A A G A C A T T G T G G C T G A C C A C G T T G C C T C T T G T G G T G T A A A C T T G T A C C A G T T T T A C N)
      (HUMMHDQAW-NEG-301 C G C T C C A A C T C T A C C G C T G C T A C C A A T G A G G T T C C T G A G G T C A C A G T G T T T T C C A A G T C T N)
      (HUMMHDQBC-NEG-841 T G A T G C C T G C T T G T C C C T G C C C A G A A T T C C C A G C T G C C T G T G T C A G C T T G T C C C C C T G A G N)
      (HUMMHDQBR-NEG-601 G G A A T G G T G A C T G G A C T T T C C A G A T C C T G G T G A T G C T G G A A A T G A C T C C C C A G C G T G G A G N)
      (HUMMHDQOB-NEG-1 A G G A T T T C G T G T A C C A G T T T A A G G C C A T G T G C T A C T T C A C C A A C G G G A C G G A G C G C G T G C N)
      (HUMMHDR2A-NEG-61 A C G G A G C G G G T G C G G T T C C T G C A C A G A G A C A T C T A T A A C C A A G A G G A G G A C T T G C G C T T C N)
      (HUMMHDR3-NEG-1441 T T G T A A T C T G A G A A G A G G A G A A G T A T A G G G A C C T T T C C T G A C A T G A G G G G A G T C C A A T C T N)
      (HUMMHDRA2-NEG-241 C C T C C A G A G G T A A C T G T G C T C A C G A A C A G C C C T G T G G A A C T G A G A G A G C C C A A C G T C C T C N)
      (HUMMHDRB-NEG-901 C T C T G C C T G T G C A C G G C C A G C T G C A T C T A C T C A G G C C C C A A G G G G T T T C T G T T T C T A T T C N)
      (HUMMHDRB3-NEG-661 A A C T C C A C A G T C C C C C G C T G C G G G A A C C A T G G A C A A A A C T G C T T C A C T C T A C T A A A A A G T N)
      (HUMMHDRB4A-NEG-781 G C G G C C T G A C G C T G A G T A C T G G A A C A G C C A G A A G G A C C T C C T G G A G C G G A G G C G G G C C G A N)
      (HUMMHDRBC-NEG-661 G C C A A G T G G A G C A C C C A A G C C T G A C G A G C C C T C T C A C A G T G G A A T G G A G A G C A C G G T C T G N)
      (HUMMHDRBK-NEG-1321 A G C T T C T C C A T G C A C A G G C G A G G T G A G C A A G G C G G G T G G G G G A G G G G A G T A G G G T C C C T G N)
      (HUMMHDRBS-NEG-601 A G T G G A G T C G G G G G C T T T G T G C T G G G C C T G C T C T T C C T T G G G G C C G G G T T G T T C A T C T A C N)
      (HUMMHDRBX-NEG-61 A C G G A G C G A G T C T G G A A C C T G A T C A G A T A C A T C T A T A A C C A A G A G G A G T A C G C G C G C T A C N)
      (HUMMHDRC2-NEG-841 G A T G A A G A T G A G A T G T T C T A T G T G G A T C T G G A C A A G A A G G A G A C C G T C T G G C A T C T G G A G N)
      (HUMMHDRCD-NEG-601 T T T A C A C C T G C C A A G T G G A G C A C C C A A G C G T G A C G A G C C C T C T C A C A G T G G A A T G G A G A G N)
      (HUMMHDRGB-NEG-121 C T G G G G A C A C C C G A C C A C G T T T C C T G T G G C A G C C T A A G A G G G A G T G T C A T T T C T T C A A T G N)
      (HUMMHDRHA-NEG-781 A A A T T T G G T T T A G A G G G T C A A A A C T G A G T T G T G T A T T G A T G A A T A G C A C G G T C C T G C T A C N)
      (HUMMHDRHA-NEG-5341 C C C C A A G T G T G G T T A T G C C T C C T C G A T T G C T C C G T A C T C T A A C A T C T A G C T G G C T T C C C T N)
      (HUMMHDRO2-NEG-2461 C A G C C G G G T T G G C C T A A G G G A C T T A G T G C C G G G C G G A A A G G G G A C T T T G G G T T G G G G A T T N)
      (HUMMHDRP1-NEG-481 A T T T T T G T A T T T A G T G G C A G G T T T C G C A T G T T A G T A G G G T G G T C T T C T T G A C C T G A C C T T N)
      (HUMMHDRR2-NEG-121 T A A A T C C T C T C G C T G C G T G G T G A G A A A A C T G A T G C C T N G A G T C T G T G A C C T G C C T N G G A C N)
      (HUMMHDRS1-NEG-241 A A A A T A C A A A A A T T A G C C N N N G G G A G G C C G A G A T T A C A A T G A G C T G A G A T C A C A C C A C C A N)
      (HUMMHDRS2-NEG-2461 A T T A T T G G G A C C A T C T T C A T C A T C A A G G G A G T G C G C A A A A G C A A T G C A G C A G A A C G C A G G N)
      (HUMMHDRW1-NEG-2581 G A T C T A C T G T C T A A T A T C T T A A G G G C T T A G T A T T T T T C T C A G T G A C T T T G T G G G T T C T T T N)
      (HUMMHDRWA-NEG-901 G C T T T C C T G C T T G G C A G T T A T T C T T C C A C A A G A G A G G G C T T T C T C A G G A C C T G G T T G C T A N)
      (HUMMHDXAR2-NEG-1 A T G A T G T G C A G G C A C T A A G T A G G C A C T C A G G A A A T A A C A G A C G T G T G A C G T T C T G C C T T T N)
      (HUMMHEA-NEG-2041 T C C A G C T T T T C T C A G T C A C T C A G C A T C C A C A C A G G C C A G G A C C A G A A A T C C C T T T T C A C C N)
      (HUMMHHLA-NEG-241 G G A T G G A A A C G G C T T T A C C G G G A G T T A C A C A G G G G C C G G C C G G C G G G G G C G A A G G A C T C G N)
      (HUMMHM71-NEG-181 A T A G A G C A G G A G G G T C C G G A G T A T T G G G A C G G G G A G A C A C G G A A A G T G A A G G C C C A C T C A N)
      (HUMMHSBA-NEG-61 T A G A C C A A C A G G G G A G T T T A T G T T T G A A T T T G A T G A A G A T G A G A T G T T C T A T G T G G A T C T N)
      (HUMMHSBB1-NEG-1561 G T C A A A A T T A A G C A T A A C T G G C G G A A A C C C A G A G G T C T T A A C A G T A G G G T T C G T A G A A G G N)
      (HUMMHSXA-NEG-1 G A G A T T T C T T C T T A G G T T T G G A T C T A T T C G C T G G G G T C C A G T G T G G A G G T G G T A G G G G A G N)
      (HUMMHSXA-NEG-4561 T C A A C A T A T G C G A G G T T T G T G C A G A C G C A C A G A C C C T C T G G G G A G T A T A T G T T T G A A T T T N)
      (HUMMHTRP-NEG-661 T A T G A G G C C A C C C T G A G G T G C T G G G C C C T G G G C T T C T A C C C T G C G G A G A T C A T A C T G A C C N)
      (HUMMIFA-NEG-181 C G G A C C A G C T C A T G G C C T T C G G C G G C T C C A G C G A G C C G T G C G C G C T C T G C A G C C T G C A C A N)
      (HUMMK562B-NEG-1 G A G C A G C A G A A G A A G T G T T T C A G A A G C T T C T C C C T G A C A T C C G T G G A G C T G C A G A T G C T G N)
      (HUMMLC2A-NEG-1021 C C A A C G C C A C C A G C C A T G G G A G T G T G C T C A G G A G T C G C G G G G C A G A C G T G A C A T C T G T C C N)
      (HUMMLCAC-NEG-601 G G A A A A C A A A G C A A T C T G G A C G G T T C A A G A C T G A G C A A C T C C C T G A A T T T T T A T A C A T C T N)
      (HUMMMTVPOL-NEG-421 C A T T T C T G C A G A G G T T G C A A A C G C A G A T T C A G A C C T C T A C T C C T T T T C A T T A T T T G G G A A N)
      (HUMMPO-NEG-301 A C G C C C C A G C C C T C T G A A G G T G C T G C T C C A G C T G T C C T G G G G G A G G T G G A C A C C T C G T T G N)
      (HUMMPO1-NEG-1681 C G C A C C A T C A C C G G G A T G T G C A A C A A C A G G T G C G G C T G G C T G G G G G T G G C T G C A G G A A C C N)
      (HUMMPOA-NEG-1321 A C A G C T T A A A A G C C A T C C T T C C C A A A G C C T T G C C T C T G T C T G G A C A C C C A G G T C C A T A T C N)
      (HUMMPRCI-NEG-601 T A C T T T G A G T G G A G G A C C A C T G C A G C C T G C A A G A A A G A C A T A T T T A A A G C A A A T A A G G A G N)
      (HUMMPRCI-NEG-5161 G G T T A T G A G G C T T A T G A T G A G A G T G A G G A T G A T G C C T C C G A T A C C A A C C C T G A T T T C T A C N)
      (HUMMRCOX2-NEG-481 C T C T T C A A T A C C T T T G G T T T T G G G A A G A T C T C A G G A A C G G C C T G C C T C A C C G T C T A T G G T N)
      (HUMMRNAEN-NEG-1681 C C C C C T T C T T T A G T G C C C A G C A G T C C A A C T C A T T G A A C T A T G G G G G C A T C G G C A T G G T C A N)
      (HUMMRP14A-NEG-1561 A T C T G C A A A A T T T T C T C A A G G T A G G G C T G G A C T C T G G C A G G T C T G A C C C A G C C T C A C C G C N)
      (HUMMRP8A-NEG-1381 C T G G T T G A G A A A C A G A G A C T G T A G C A A C T C T G G C A G G G A G A A G C T G T C T C T G A T G G C C T G N)
      (HUMMSOD-NEG-61 T C T G G G C T C C A G G C A G A A G C A C A G C C T C C C C G A C C T G C C C T A C G A C T A C G G C G C C C T G G A N)
      (HUMMT2A-NEG-121 C G C A C A C G G G G G G C A C A G C G C C T C C C T C G C G A G C C G G T G C G A A A G G G G C C G C C T G C G G T G N)
      (HUMMTLMC2-NEG-781 T T A C C A C C A T A G T T G G C C C A A A A G C A G C C A C C G A T T A A G A A A G C G T T T A A G C T C A A C A G C N)
      (HUMMUC18B-NEG-61 T C C T C G C G T C G C G G G T G T G C C C G G A G A G G C T G A G C A G C C T G C G C C T G A G C T G G T G G A G G T N)
      (HUMMUCC-NEG-121 C A C C C A C C G G C A C A C A G A C C C C A A C A A C G A C A C C C A T C A G C A C C A C C A C C A C G G T G A C C C N)
      (HUMMXB-NEG-1741 A C C A A A C T G T T C A G A G C A C G A T T G A A G A C A T A A A A G T G A A A C A C A C A G C A A A G G C A G A A A N)
      (HUMMYC3L-NEG-3301 T C G G A C T T C T G T G T G G A G G C T G C A A A A T G T G T G G A G C A G G A G G A G A C T T T T C T C C C A A T T N)
      (HUMMYCAWT-NEG-1 G C C C A G C T C A G C T C A G T T C A G T T C A G C C C T G T T C A G C A C A G C A C A T C A G A G C C C T G C G A T N)
      (HUMMYCBL1-NEG-1 C C A G T C C G C T C A G C C C A G C C C A A G C C C A G C C C A G C G C C A A C C C A G C T C G G C T T A A C C C A G N)
      (HUMMYCBLK-NEG-781 G G A C A C T T C C C C G C C G C T G C C A G G A C C C G C T T C T C T G A A A G G C T C T C C T T G C A G C T G C C T N)
      (HUMMYCC-NEG-2761 G C G G G G A G G C T A T T C T G C C C A T T T G G G G A C A C T T C C C C G C C G C T G C C A G G A C C C G C T T C T N)
      (HUMMYCC-NEG-7321 G T C T T G A G A C T G A A A G A T T T A G C C A T A A T G T A A A C T G C C T C A A A T T G G A C T T T G G G C A T A N)
      (HUMMYCE1-NEG-421 C T G G C T C C C C T C C T G C C T C G A G A A G G G C A G G G C T T C T C A G A G G C T T G G C G G G A A A A A G A A N)
      (HUMMYCF1-NEG-1081 T G G G G G T T G C T T T G C G G T G G C A G A A A G C C C C T T G C A T C C T G A G C T C C T T G G A G T A G G G A C N)
      (HUMMYCG2-NEG-1501 T C C T G C T T T A T T G T T G G T T A A T T T G C T C T C T G G G T T T T G G G G G G C T G G G G G T T G C T T T G C N)
      (HUMMYCH-NEG-901 C T T T C G A G A T T T C T G C C T T A T G A A T A T A T T C A C G C T G A C T C C C G G C C G G T C G G A C A T T C C N)
      (HUMMYCL-NEG-1681 G T A T A C G T G G C A A T G C G T T G C T G G G T T A T T T T A A T C A T T C T A G G C A T C G T T T T C C T C C T T N)
      (HUMMYCL2A-NEG-2341 A C C T T T G G C T T C T C A G C A G G C A G C T G A C T G A G G A G A C T T G G G G T C T T C C T G G C T C A C T A T N)
      (HUMMYCLYA-NEG-781 T C A C G C A G C C G C T A G C G C C C A G G C G C C T C T C G C C T T C T C C T T C A G G T G G C G C A A A A C T T T N)
      (HUMMYCNH-NEG-1 C T C G A G T T T G A C T C G C T A C A G C C C T G C T T C T A C C C G G A C G A A G A T G A C T T C T A C T T C G G C N)
      (HUMMYCST-NEG-1 A G C T C G G C C C A G C T T G G C T C A G C C C G A C A C A G C C T G C T C A G C C C A G T T C A G C T C G G C T C A N)
      (HUMMYCTR-NEG-2041 T A T T C T G C C C A T T T G G G G A C A C T T C C C C G C C G C T G C C A G G A C C C G C T T C T C T G A A A G G C T N)
      (HUMMYH1R-NEG-1621 A C A C T G A A T G C T G A G A T C A G G A G C A G G A A T G A T G C C A T T A G G C T C A A G A A G A A G A T G G A G N)
      (HUMMYHC-NEG-1381 T A T G A A A A G T T G T T C T T G T G G A T G G T C A C T C G C A T T A A C C A G C A A C T G G A T A C G A A G C T T N)
      (HUMMYHC-NEG-5941 A T A T G C A A A A T G T A T A T T T T C T T G A T T C C T G A C C A T T G A T A C T T A A T G T C C A T G T G A C T C N)
      (HUMMYHC04-NEG-1 T T G C T T T A T G G A G A A A G C T G A A C C C A C C T C C T G G T G C C C A C C C C T C C C C A G G C G A A G A A C N)
      (HUMMYHC08-NEG-421 T C T C A C T T C G G G G G A A A A A T A A C T G A G G T A A G G G C C A T G G C A G G G T G G G A G A G G C G G T G T N)
      (HUMMYHC10-NEG-1561 G C A G A G G A G C T G A A G A A G G A G C A G G A C A C C A G C G C C C A C C T G G A G C G C A T G A A G A A G A A C N)
      (HUMMYHC5-NEG-1141 G A C C T G C A G C A C C G G C T G G A C G A A G C C G A G C A G A T C G C C C T C A A G G G C G G C A A G A A G C A G N)
      (HUMMYLCA-NEG-3181 T G G G A A C C T C A C C A G C C T G T A T A C C A G T C T T G C T T T A G G G T G A C C T T C T G G C C C T G G A G C N)
      (HUMMYOHP-NEG-901 A C T T C T G C T C A G G T G G A A T T G A A C A A G A A G C G G G A G G C T G A G T T T C A G A A A C T G C G C A G G N)
      (HUMMYONM-NEG-1501 C C T C G A G A A G G C A A A G C A G A C T C T G G A G A A C G A G C G G G G G G A G C T G G C C A A C G A G G T G A A N)
      (HUMMYP-NEG-961 C C G G G C C T C C T T C G T C A C T G G C G T C A A C T G C G A G A C C A G C T G C G T T C A G C A G C C G C C C T G N)
      (HUMNAKATP1-NEG-721 C C C A G G A G G G G T G G A C C C A C A G C C C A G G G A G G C C G A A A G C G C G G G C G G G C A G G C A G A G G C N)
      (HUMNAKATP1-NEG-5281 T G C C T A G T A C A G C C T G T T A C T A T G C A G C T A A T C A G G G A G A T A A T C C T T G T A A A C C A G T A A N)
      (HUMNAKATP2-NEG-2161 A C C C T T A A G T G G T G G T T G A A A A G G A A A A T A C C A G T T C C T T T T T A A A A A T T C T G A C C A A A A N)
      (HUMNAKATP2-NEG-6721 A G C G A G A T G A A G A T A A G G A T A A A G T T G G A A A T G T G G A G T A T T T T G G A C T G G G C A A C T C C C N)
      (HUMNAKATPA-NEG-3061 C T A A T A A T T G C C A G A G T A C A G T G C T C T T G T T G A T C A T G T A T T C A G T C A A G T T A A A A C A A T N)
      (HUMNARIA-NEG-3841 C C T C T C C G G C A G A A G G G A A C T G C C T G G G C T C C C T T G T G C G T G G G T G A A G C C G C T G C T G G G N)
      (HUMNCAM-NEG-121 C T C A A A T A C A A A G C T G A G T G G A G A G C A G T T G G T G A A G A A G T A T G G C A T T C C A A G T G G T A T N)
      (HUMNCAMB-NEG-661 G G G G C C A T C G T G G G C A T C C T C A T C T T C G T C C T G C T C C T G G T G G T T G T G G A C A T C A C C T G C N)
      (HUMNEBB-NEG-241 G C C A A C T A C A G G A A C G T G A T C C A T A C C T A C A A C A T G C T T C C T G A T G C C A T G A G C T T T G A A N)
      (HUMNFH3-NEG-1 G A A G C C A T T C A G C A G C T G G A C G C T G A G C T G A G G A A C A C C A A G T G G G A G A T G G C C G C C C A G N)
      (HUMNFLG-NEG-1861 T T C T T T A T G T G T A A A A T C T T C T A C A A C A T T T C T G T T T A A A C A T C T C C A T C T T C T G G G G A G N)
      (HUMNFM-NEG-1921 G G C C G C T C G C T A G A G C A C G C G C G C C G C A G A C C T A G G G T A T T T G C G G A T C A G C G T C C T C G C N)
      (HUMNGFB-NEG-241 T C T G T G C C A G C T T C T T A T C C T A T A G A G G A G A A A G C T C A A A G A T G A A A T G A A T C T C C T T C T N)
      (HUMNGFB-NEG-4801 G A T A T A T T T G A G A C A T T T T C A A G T C T T A A T G A A A C A T T C T G C C T G T G A T A C A A A T C T C C A N)
      (HUMNGFB-NEG-9361 T T T A A A A A G C G G C G A C T C C G T T C A C C C C G T G T G C T G T T T A G C A C C C A G C C T C C C C G T G A A N)
      (HUMNGFBA1-NEG-2341 G C C T T G C C A A G G T C C T C C C T C T G C A G C T G C C A G A A G C A G G A G T C C C A A G T G A C A G G A C C T N)
      (HUMNGFBA2-NEG-4021 G G A A G G C T G T G A G A A G A G C C T G A C C T G C C G A C A C G C T C C C T C C C C C T G C C C C T T C T A C A C N)
      (HUMNGFR-NEG-2821 T T T T T T C C T G A G C T T G G C C A G A A G G G G G C C A T G A G G C C T C A G T G G A C T T T C C A C C C C C T C N)
      (HUMNID-NEG-3541 C A G T A T C C T T T T G C T G T G A C G A G C T A C G G G A A G A A T C T G T A T T T C A C A G A C T G G A A G A T G N)
      (HUMNMCY1A-NEG-661 A C C A A G G C T G T C A C C A C A T T C A C C A T C A C T G T G C G T C C C A A G A A C G C A G C C C T G G G T C C C N)
      (HUMNMYC-NEG-1561 C A C C C C C G G T A T T A A A A C G A A C G G G G C G G A A A G A A G C C C T C A G T C G C C G G C C G G G A G G C G N)
      (HUMNMYC-NEG-6121 A G A C T G G A A G T T C A T A C C T A A G T A C T G T A A T A A T A C C T C A A T G T T T G A G G A G C A T G T T T T N)
      (HUMNMYCA-NEG-1 T T C A G C A G G A G G G C T T G G T G G C G A T T A G G G G G C T A G G G A A A A G C A G A A G T G G G G C T G T A A N)
      (HUMNMYCA-NEG-4561 G G G G T G A A A G G G A C T C T C T G G C C C A G G T C A G G G G A G G G A A A G A C A T C C C C G A G A A G A T T C N)
      (HUMNOXF-NEG-361 G A T T C A G C T T C G A G G G A A C C A G C T G A T A G A C T A T A A G A T C C T G G G G C T C C A G T T C A A G C T N)
      (HUMNPY4-NEG-241 C C T C A A T G A A A A A T C T A T T A C A A T A G T G A G G A T T A T T T T C G T T A A A C T T A T T A T T A A C A A N)
      (HUMNRNPEP-NEG-1141 G C C A T T T C T A T G T C C T T T A T A T G C A T C A A A T A C T G T T C T G G A G C A G A G G C A C C T T T A G A T N)
      (HUMNTSXPH-NEG-1081 A G G A A A G C T T G A C C C T G G T G G G T C T C G G T G A C T T C T A T C A C G A T G T C C T A G T T T C T C C G C N)
      (HUMOAS06-NEG-181 T A C C A G C A A C T C T G C A T C T A C T G G A C A A A G T A T T A T G A C T T T A A A A A C C C C A T T A T T G A A N)
      (HUMOAT01-NEG-1 A G G G T T C A A G G G C A T G G G G T C C C G C A G C T G T G G C T G G G G C A G A G C T G G G G C T G G T C C C T C N)
      (HUMOCS1-NEG-1 G C G G G C C G G A G C A C G G G C A C C C A G C A T G G G G G T A C T G C T C A C A C A G A G G A C G C T G C T C A G N)
      (HUMODC-NEG-241 C A T C T G A G G T G G T T A A A A G C T C T C C C T C G T G T C A C C C C C T T T T A T G C A G T C A A A T G T A A T N)
      (HUMOPS-NEG-181 T C T G G G G G G G T C A G A A C C C A G A G T C A T C C A G C T G G A G C C C T G A G T G G C T G A G C T C A G G C C N)
      (HUMOPS-NEG-4741 A C C T C C G A G G G G T A A A C A G T T G G G T A A A C A G T C T C T G A A G T C A G C T C T G C C A T T T T C T A G N)
      (HUMOTNPI-NEG-481 A T C C A G A A C T G C C C C C T G G G A G G C A A G A G G G C C G C G C C G G A C C T C G A C G T G C G C A A G G T G N)
      (HUMP120PC-NEG-2101 C C G A A G G G A T C A G G G A G C C A A A G G T G A C T G G G A A G C T A A A G C A A C G A T C A C C T A A A T T A C N)
      (HUMP15095-NEG-4021 A G C T G G G A C T A C A G G C A C A C G C C A C C T C G C C C G G C C C G A T C T T T C T A A A A T A C A G T T C T G N)
      (HUMP3A-NEG-2461 T A A G A G T A A A A C T C A G C A G G G A C C C T T G C C C C A C A C T C A G G A A T G G A A G A G G C A A T G C C T N)
      (HUMP42LA-NEG-2161 A T G C C C C C A T G G A G G A C T G T G T G A T C T C C A T C C T G G G A A G G G G G C T C A T T C A C A G A G A G A N)
      (HUMP45C17-NEG-301 C A A T A T G A A A T T A G T G C A C C T T G A A A A A G A A C A C A A T A A G A G C A A T T T T T A G G G A A C A A G N)
      (HUMP45C17-NEG-4861 C G C C C T C C T C C C T T G T T T A G A A T T G T C T T C G T C G T C A T G A T A A A C C C G T T C T G T G T C C C C N)
      (HUMP45C21-NEG-901 C A G C A G C T C A G C C T C C C C C C G C T G G G G A G C G A A A G T T T C T T G G T C T C A G C T T C A T T T C C G N)
      (HUMP47-NEG-721 G A C A G T G G G T T C T T C T G T G A A G A G A A T T C C A G T G A T G A T G A T G T G A T T C T G A A A G A A G A A N)
      (HUMP53A-NEG-1 G G G A G A A A A C G T T A G G G T G T G G A T A T T A C G G A A A G C C T T C C T A A A A A A T G A C A T T T A A C T N)
      (HUMP68-NEG-1081 T G C T G G C C A G T T C T T C C C G G A G G C A G C G C A G G T G G C C T A T C A G A T G T G G G A A C T T A G T G C N)
      (HUMPA2I-NEG-541 A T T T A T G G T A A A A C A T T A T T C A C C A T C T T C T G T A T T T C T T T C T A A G G G T G C T C G T G G T T T N)
      (HUMPAC-NEG-541 G G G A C A G G A C T C C T G G G T C T G A G G G A G G A G G G C C A A G G A A C C A G G T G G G G T C C A G C C C A C N)
      (HUMPAI2-NEG-181 C T A C A T G G G C T C C A G G G G C A G C A C C G A A G A C C A G A T G G C C A A G G T G C T T C A G T T T A A T G A N)
      (HUMPAI2A4-NEG-121 T A T T T A C T G G A A A G T G T C A A T A A G C T G T T T G G T G A G A A G T C T G C G A G C T T C C G G G A A G T A N)
      (HUMPAIA-NEG-661 C T A G C G G G C A G C T C G A G G A A G T G A A A C T T A C A C G T T G G T C T C C T G T T T C C T T A C C A A G C T N)
      (HUMPAIA-NEG-5221 G A A G G C T T G A G G C C T G G A G T T T G A G A C C A G C C T G G C C A A C A T A A C A A G A C C T C A T C T C T T N)
      (HUMPAIA-NEG-9781 C C G T C C C T A T T C T G G C C A C T T G A T T C G G G G G A C A C C T G G T A G G G G A T G G G G A A A G G T G G G N)
      (HUMPAIA-NEG-14341 T A C T C C C A C T C C C C A T T C T T C A A A C C C A G C T C A A G T T C C A G T T C C T C C A C C T A G G A C T T C N)
      (HUMPAIB1-NEG-61 C A G C T C A G C A G C C G C C G C C A G A G C A G G A C G A A C C G C C A A T C G C A A G G C A C C T C T G A G A A C N)
      (HUMPAIR1-NEG-1081 A T G G A C A G A C C C T T C C T C T T T G T G G T C C G G C A C A A C C C C A C A G G A A C A G T C C T T T T C A T G N)
      (HUMPALC-NEG-2281 T G C C T A A T G A A C A C T T T G G G G C A C C T A C T G T G T G C A A G G C T G G G G G C T G T C A A G C T C A G T N)
      (HUMPALC-NEG-6841 T G G G A A G A A T G T T T C C A G C T C C A G A A T G C T A A A T C T C T A A G T C T G T G G T T G G C A G C C A C T N)
      (HUMPALD-NEG-3841 G A G A G C T G C A T G G G C T C A C A A C T G A G G A G G A A T T T G T A G A A G G G A T A T A C A A A G T G G A A A N)
      (HUMPALF1-NEG-781 G G G T A C C C A G C A T C T A T T T T T A A T A T A A T T A A T T C A A A C T T C A A A A A G A A T G A A G T T C C A N)
      (HUMPAP4-NEG-781 G A C A A G T A C A T G A C T A T A T C A G G A T T T C A A A T T G A G G A A A C C A T T G A C C G C G A G A C T T C T N)
      (HUMPAPA-NEG-2401 T A A G A A A G G A A G T A T A G G C T A G G C A C A G T G G C T C A C A C C T G T A A T C C T T G C A T T T T G G A A N)
      (HUMPBG2-NEG-841 G T G G C T T T A T T C T C T T T G C T C C A G A T G G T C C A G A C C T C C C C A G A A T T T A C C C T T C A T T C A N)
      (HUMPBGDR2-NEG-1 C A C A C A G C C T A C T T T C C A A G C G G A G C C A T G T C T G G T A A C G G C A A T G C G G C T G C A A C G G C G N)
      (HUMPC125-NEG-3181 T T C A G C T C A C T G C A A A C G C C G C C T C C T G G G T T C A A G C A G T T C T C C T A C C T C A G C C A C C C A N)
      (HUMPC2A-NEG-481 C T G A T C A A T A C T G G G C A A G C T G A T G G C A C T C C T G G C C T T G A T T T G A A T G T G G C T G A A G C C N)
      (HUMPC64-NEG-1801 G T T C T G C C C A G G A A T G A T G A T T G G G G C T A T T G T T A T A T T T T A A T A C T T G G G T A A A T A G G A N)
      (HUMPCNA-NEG-301 G G C T G A G G C A G G A G A C T C A C T T G A A C C T G G G A G G C G G A G G T T G C A A T G A G C T G A G A T C G C N)
      (HUMPCNA-NEG-4861 T T T T T T T C T T T T G C T G T T T T T C T T T G T T T T T G A G A C A G G G C T T G C T C T G T G C C A C C C A G G N)
      (HUMPDGA1-NEG-481 C G G C C G C T G C C C G G C C C C G G C G A G C G G A G G G C G G A G C G C G G C G C C G G A G C C G A G G G C C G C N)
      (HUMPDGFA1-NEG-841 A C C C C C T A C C C G G C G G C C C A G G A G G C T C C C C G C G C T G C G G G C G C G C A C T C C C T G T T T C T C N)
      (HUMPDGFARA-NEG-61 C A C G C T C T T T A C T C C A T G T G T G G G A C A T T C A T T G C G G A A T A A C A T C G G A G G A G A A G T T T C N)
      (HUMPDGFARA-NEG-4621 C T T A C C C C A A A G A G A A A G A G T T T G A A A C T C G A G A C C A T A A A G A T A T T C T T T A G T G G A G G C N)
      (HUMPDGFB1-NEG-1381 G C C T C C T G C C A C C C C T T C C T C C C C A C A C T C C A C T C T G A T T C A C C T C T T C C T C T G G T T C C T N)
      (HUMPDGFR-NEG-721 T T T T C T G G T A T C T T T G A G G A C A G A A G C T A C A T C T G C A A A A C C A C C A T T G G G G A C A G G G A G N)
      (HUMPDGFR-NEG-5281 C A C C T A G G T T T A C A A A T A T T T T T A G G A C T C A C G T T A A C T C A C A T T T A T A C A G C A G A A A T G N)
      (HUMPDGFRA-NEG-4441 G T C T T A A T C C A T C C A C C A G A G T C T A G A A G G C C A G A C G G G C C C C G C A T C T G T G A T G A G A A T N)
      (HUMPDGFRAA-NEG-3421 G A G G G G T T C C T T C C A C T T C T G G G G C C A C C T C T G G A T C C C G T T C A G A A A A C C A C T T T A T T G N)
      (HUMPDHA-NEG-1141 T A C C A C A T C T A C T C C A G C G A C C C A C C T T T T G A A G T T C G T G G T G C C A A T C A G T G G A T C A A G N)
      (HUMPDHE1B-NEG-301 A A A G C A G A T C A G C T G T A T A A A C A G A A A A T T A T T C G T G G T T T C T G T C A C T T G T G T G A T G G T N)
      (HUMPEP7-NEG-1 T T G C C C T C A G C A T C A C C A T G A A C G G A G A G G C C A T C G C C T G C G C T G A G G G C T G C C A G G C C A N)
      (HUMPEPC1-NEG-901 C C T G G C A T C G A G T C G G T A G A T G C C A G G A A T G C T G T T A A A C A T T C T A T A G T A C A C A G G A T G N)
      (HUMPEPD-NEG-421 C C T G A C G T C A C A G A A G C C C T C T G T C C T C C T C A C T T T G C G T G G C G T C A A C A C G G A C A G C G G N)
      (HUMPFKM23-NEG-1621 T G A T G A G C T C T G C A T C C C A T T T G T G G T C A T T C C T G C T A C A G T C T C C A A C A A T G T C C C T G G N)
      (HUMPGAMMG-NEG-2221 C T G G G C T T G C A G C T G G G C T C C C A C T G A A G A G C A A G G G C T G A C A A A T G G G C C C G G G A T G C A N)
      (HUMPGK1-NEG-181 C G C T T C C T C G T C C G C C C C T A A G T C G G G A A G G T T C C T T G C G G T T C G C G G C G T G C C G G A C G T N)
      (HUMPGK2P-NEG-361 T T A G T T C A C T C A A C T T A T G G A G T A G A A T G A A A A A A A C T G T A A A G C C A A T T T T C A T T A C T A N)
      (HUMPGKA09-NEG-241 C A G A T T G T G T G G A A T G G T C C T G T G G G G G T A T T T G A A T G G G A A G C T T T T G C C C G G G G A A C C N)
      (HUMPGKPX-NEG-961 A A C T C T G G G A A C A A G G T T A A A G T G A G C C C G C C A A A A T A G A A G C T T T C C G A G C T T C A C T T T N)
      (HUMPGRR-NEG-1681 C G C C G C C G C C G G G G C G G C C C C C G C G C T C T A C C C T G C A C T C G G C C T C A A C G G G C T C C C G C A N)
      (HUMPHH-NEG-541 C A T G A G C T T T C A C G A G A T A A G A A G A A A G A C A C A G T G C C C T G G T T C C C A A G A A C C A T T C A A N)
      (HUMPIGF2A-NEG-301 G A G G T G G G C G G C A G C G T C G C C G G C T T C C A G A C A C C A A T G G G A A T C C C A A T G G G G A A G T C G N)
      (HUMPIM1A-NEG-1741 G A A G T G G T C C T G C T G A A G A A G G T G A G C T C G G G T T T C T C C G G C G T C A T T A G G C T C C T G G A C N)
      (HUMPIP-NEG-241 C A T T A G C A G C A T C C C T C T A C A A G G T G C A T T T A A C T A T A A G T A T A C T G C C T G C C T A T G T G A N)
      (HUMPKB-NEG-1741 C T A T C C C A A G T C T A T G T C C A A G G A A G C T G T G G C C A T C T G C A A A G G G C T G A T G A C C A A A C A N)
      (HUMPKCAMD-NEG-781 T G A T G G T G T T G G A A G A T G T G T T G G T A A C T A T G A T A A T C G T G G G A G T T T C G G C G A A C T G G C N)
      (HUMPKCB1A-NEG-1321 C C T G C C T G G G A A G C C G C C C T T C C T G A C C C A G C T C C A C T C C T G C T T C C A G A C C A T G G A C C G N)
      (HUMPKCB2A-NEG-1321 C C T G C C T G G G A A G C C G C C C T T C C T G A C C C A G C T C C A C T C C T G C T T C C A G A C C A T G G A C C G N)
      (HUMPKLR-NEG-1441 C T C G G G C A G C A G T C A T T G C T G T C A C C C G C T C T G C C C A G G C T G C C C G C C A G G T C C A C T T A T N)
      (HUMPLA2A1-NEG-1561 T G G A T T A C A G G C A T G A G C C A C C G T G C C C G G C C T T A T C A C A T T T A T T A T T T A T T G T T T T T C N)
      (HUMPLAKO-NEG-1861 G G C T C A A C A C C A T T C C C C T G T T T G T G C A G C T C C T G T A C T C G T C G G T G G A G A A C A T C C A G C N)
      (HUMPLAP2A-NEG-481 G G T A A C A A G G G G A G G G G C C A G G A C A C A G T T T T T C C T G A T T T A A A C C C A G G C A G C C T G G A T N)
      (HUMPLASTA-NEG-1561 G A G A A A C T C A A C A A T G C A A A A T A T G C C A T C T C T A T G G C C C G A A A A A T T G G A G C A A G A G T G N)
      (HUMPLG2B-NEG-181 C C A T G G G A G A G T G G C C A T C G T G G T G G G C G C C C C G C G G A C C C T G G G C C C C A G C C A G G A G G A N)
      (HUMPLP1-NEG-301 G A G G A G A A G G G G A G G A G G A G A G G A G G A G G A A A G C A G G C C T G T C C C T T T A A G G G G G T T G G C N)
      (HUMPLP6-NEG-421 G A C A T A T T G A T G T G G C A A A G C C C A A A T A T T G T T C A C T T C C C T G A G G A A A A C T C A G T G C T A N)
      (HUMPLPA-NEG-2041 T T T A T T A C T T A T T T G G G G T T G C A T C A G A A A T G T C T G G A G A A T A A T T C T T T G A T T A T G A C T N)
      (HUMPLPSPC-NEG-1801 T G G G T A C C A C T G G C T G A G T A G G A A A G G G G A A G A C C A G G T G G C T C C A T G C C T T T C C C C A G G N)
      (HUMPMG3BA-NEG-3001 C A A C C C A G C T A T G G T T C T C T C G C A A G G G A A G T C C T T G C A A G C T A A T T C T T T G A C C T G T T G N)
      (HUMPMGR-NEG-1621 C G G G C G G G T C T G G A A A A A A A T T A C T G C C G T A A C C C T G A T G G T G A T G T A G G T G G T C C C T G G N)
      (HUMPMPCA-NEG-1141 C A A C A A A G C A A A A G C C C A G G A T G G T G C A G C C A T G G A A A T G C A G C C A T T G A A G A G T G A A G A N)
      (HUMPNMTA-NEG-421 A C C T C T A A A A C T A A C C T G C C T C T C A G T T C T G A A T C C A G A C A G A A T C A A T C C T C A G C T G T G N)
      (HUMPNU-NEG-721 A G A A T G T C G T G T G C T G C A G A A G C T G G G A G C A G A C G C T G T T G G C A T G A G T A C A G T A C C A G A N)
      (HUMPOLBA-NEG-781 A A A A C G C G C C A T G C A T T G G G T A G C T A T T A C A G T G C A C A T T T T T G T G C A G G A A G C T A C C C C N)
      (HUMPOLDNAA-NEG-3481 A C A T G T T G C C C T C T G G A T A A A T T C T C A A G G A G G C A G A A A G G T G A A A G C T G G A G A T A C T G T N)
      (HUMPOLP-NEG-2341 T C G C T T T T A C A C C C T G A T C C C C C A C G A C T T T G G G A T G A A G A A G C C T C C G C T C C T G A A C A A N)
      (HUMPOMC-NEG-421 C G G A G A C C C A A C G C C A T C C A T A A T T A A G T T C T T C C T G A G G G C G A G C G G C C A G G T G C G C C T N)
      (HUMPOMC-NEG-4981 T T T T A A G A A G C T C A T A T C A C T T G C C A T T T T C A T T C C A T A T T T C T T A C C C T T T T A T C T A C T N)
      (HUMPOMC3-NEG-241 C T C C C C T A A A C C A G G C C C T T G G A G A G C A G G C C C C A G G G G A G C A G T G C A A C T C A C C T T C A C N)
      (HUMPOVRA-NEG-541 T C A G A C C T G G G C G G G A T G C C C A A T A C G A G C C A G G T G C C A G G G T T C C T G T C T G G C A C A G T C N)
      (HUMPP12R-NEG-1261 T G A A G G A G G A C G G T T A A C T T G T A T A T T C C A C C A T T C A C A T T T G A T G T A C A T G T G T A G G G A N)
      (HUMPPARP1-NEG-181 G A C G A T G A G G T G A C A G T C A C G G A G G A T A A G A T C A A T G C C C T C A T T A A A G C A G C C G G T G T A N)
      (HUMPPH1-NEG-61 T A A T A C A A A C A G A A A T C A G A C C T T T A A G A G T T G A G A G T A A G T A G G A G A G T T A G G A C T T G T N)
      (HUMPPOL-NEG-1081 G C C T A T T A C T G C A C T G G G G A C G T C A C T G C C T G G A C C A A G T G T A T G G T C A A G A C A C A G A C A N)
      (HUMPPPA-NEG-1561 G T C C G T G C C T T C A G A G C A G T G T C T A G G A G G T G G A G T G G C C A G C T T G G A G T G G C C C T T T G C N)
      (HUMPPS-NEG-1561 A T A A G C A T T G C C T G G T T A C T G T G G A G A A G G G C T C C T A C T A T C C T G G T T C T G G A A T T G C T C N)
      (HUMPRA403-NEG-1 T G C T C T C C C A G G T C T A C C C T G A A C T G C A G A T C A C C A A T G T G G T A G A A G C C A A C C A A C C A G N)
      (HUMPRB1-NEG-601 A A A G C C A C A A G G A C C A C C C C C A C A A G G A G G C A A C C A G C C T C A A G G T C C C C C A C C T C C T C C N)
      (HUMPRC1-NEG-61 C A G A G G T G G G C T T C G G G C A G A A C A A G C C G T G C T G A G C T A G G A C C A G G A G T G C T A G T G C C A N)
      (HUMPRC7-NEG-961 T G A A T A G A A T C T T A A C T C C T A G A G C A A C T C T G T G G G G T G G G G A G G A G C A G A T C C A A G T T T N)
      (HUMPRCA-NEG-4321 C A G G G C A G G A G A C C C T C T G G C C T G C A C C C T C T C T T G C C C T C A G C C T C C A C C T C C T T G A C T N)
      (HUMPRCA-NEG-8881 G T G G G A C C A C A G C C A G G A C G G C C C T T C A A G A T A G G G G C T G A G G G A G G C C A A G G G G A A C A T N)
      (HUMPRCM-NEG-1681 G G G T G G G G A G G A G C A G A T C C A A G T T T T G C G G G G T C T A A A G C T G T G T G T G T T G A G G G G G A T N)
      (HUMPRF1A-NEG-3601 A A A G T C A G C T C C A C T G A A G C T G T G G C C C G G G A T G C G G C T C G T A G C A T C C G C A A C G A C T G G N)
      (HUMPRL1-NEG-61 C T T C A T T T A A C T C A A C T A T A G A A T T A T T A G G C T G G T G C G C A A G T G A C T G C A G T T T T T A C C N)
      (HUMPRLA-NEG-241 C C C T T G C C A C C C C C G A A G A C A A G G A G C A A G C C C A A C A G A T G A A T C A A A A A G A C T T T C T G A N)
      (HUMPRLR-NEG-1861 A A C A G A G A G A G A A C A G C G G C A A G C C C A A G A A G C C C G G G A C T C C T G A G A A C A A T A A G G A G T N)
      (HUMPROD1-NEG-1741 T G G C C C C T G A G T A T G C C A A A G C C G C T G G G A A G C T G A A G G C A G A A G G T T C C G A G A T C A G G T N)
      (HUMPROD4-NEG-721 G T C A G G G T G T C C C C C A T G C C T G G A A G A G G A G C T G G T G C T G C C A G C C C T G G G C C C G G C A C A N)
      (HUMPROSA-NEG-1021 G T T T C A G T G T G C C T T C C C T T G A A C C T T G A C A C A A A G T A T G A A T T A C T T T A C T T G G C G G A G N)
      (HUMPRP-NEG-1 C G G C G C C G C G A G C T T C T C C T C T C C T C A C G A C C G A G G C A G A G C A G T C A T T A T G G C G A A C C T N)
      (HUMPRP0A-NEG-2161 T G A A G T G T C T A A T G C A T T A A C T T T T G T A A G G T A C T G A A T A C T T A A T A T G T G G G A A A C C C T N)
      (HUMPRPC4B-NEG-541 C A A A T A G A A T T C A G C T G T T C A G A A G G A T T T T T C T T A A T T G G C T C A A C C A C T A G T C G T T G T N)
      (HUMPRPG-NEG-421 G G A C C A C C C C C A C A A G G A G G C A A C C A G C C T C A A G G T C C C C C A C C T C C T C C A G G A A A G C C A N)
      (HUMPRPH1-NEG-4081 A A T G T A C A G A G C T A A A T A G T A A G A G C C T A A C T C A T C T T T C C T C C C T T C T A T C C T T C T C A A N)
      (HUMPRPH2-NEG-3661 G C A A T G G C A T A G A A A G T G T G A A C A A A G A A A A T G A T A T T A A G G A G G G G G G C T G T A G A A G G G N)
      (HUMPS12-NEG-1321 T G G C T G C C A C A A T A G A G A C A C T G A G A A A A A G A A C A G G T T G A T A C C T T C A T G A A A T T C A A G N)
      (HUMPS2G3-NEG-421 G T G A T T A G T C C C A G A G C T C G G C T G C C A C C T C C A C C G G A C A C C T C A G A C A C G C T T C T G C A G N)
      (HUMPSAA-NEG-2521 C T G T C T C A C C T G T G C C T T C T C C C T A C T G A A C A C A C G C A C G G G A T G G G C C T G G G G G G A C C C N)
      (HUMPSAA1-NEG-1 C C C C T A G A T G A A G T C T C C A T G A G C T A C A A G G G C C T G G T G T A T C C A G G T G A T C T A G T A A T T N)
      (HUMPSAP-NEG-2401 C A G G G C T T C G A G C T C A T C T A G A T G A G G A G C T C C A A G C C A C A C T C C A C G A C T T T A G A C A T C N)
      (HUMPSBGA-NEG-781 G C A G G A T C C T A C A C C T T A C A C A T C A T A A A G G G A G A T G A T G G G A C T A G A G G A G T A A C T G G A N)
      (HUMPSG3A-NEG-481 G G T G A T A G G A C T A G A G G A G T A A C T G G A T A T T T C A C C T T C A A C T T A T A C C T G A A G C T G C C C N)
      (HUMPSPBA-NEG-601 C T C C G A G C A G C A A T T C C C C A T T C C T C T C C C C T A T T G C T G G C T C T G C A G G G C T C T G A T C A A N)
      (HUMPTCAA-NEG-481 G T G G C C G T G A A G A T G C T G A A A G A G A A C G C C T C C C C G A G T G A G C T T C G A G A C C T G C T G T C A N)
      (HUMPTH2-NEG-841 C T C T C T T C T A C C T T A A A A T G T A A A A C A A A A A T G T A A T G A T C A T A A G T C T A A A T A A A T G A A N)
      (HUMPTHL2-NEG-1 T G C A G T T G A A G C C C A T G A G G C C C A A G A A T G T T C A T G T T C C C A G G A A G G T C A C A A C C T A G T N)
      (HUMPTHLHA-NEG-1381 T A A A T T A T G T T T T A A A C A C A T G C C T T A A A T T T G T T T A A T T A A A T T T A A C T C T G G T T T C T A N)
      (HUMPTPASE-NEG-1801 A T A T T T T A T A A G T A T C T A T T T A A T C T T T T G T A G T T A A C T G T A C T T T T T A A G A G C T C A A T T N)
      (HUMPUMP1-NEG-661 G C A A C T C A T G A A C T T G G C C A T T C T T T G G G T A T G G G A C A T T C C T C T G A T C C T A A T G C A G T G N)
      (HUMPYGM09-NEG-1 C C T C C C C C T A C C C C A G G T G G C C A T C C A G C T C A A T G A C A C C C A C C C C T C C C T G G C C A T C C C N)
      (HUMPYHBASA-NEG-2641 A G A A A G C C A A A A T G T T T G T T T T T T T A A G A T T C T G A A A T G T G T T G T G A C A A C A A T G A C C T A N)
      (HUMPZP-NEG-1741 C A T T C T C A C A T C T G T T C T C T A A C T T T A A C T G A A G T T T T C T A A T T C T C T C C A G C T T G A A A G N)
      (HUMRA3A-NEG-1 G A A T T C A A T A A G T A T T C T G T A T T C T T T G T T T G A G A A T C C C A C C T C T T T G T C C A A G T A A G C N)
      (HUMRAF19-NEG-721 C A C G T C C C C G A G G C T G C C T G T C T T C T A G T T G A C T T T G C A C C T G T C T T C A G G C T G C C A G G G N)
      (HUMRAFR-NEG-2521 T G C A G C G C C A G A C A T T T T G C A C A T A A G G C A C C A A A C A G C C C A G G A C T G C C G A G A C T C T G G N)
      (HUMRAG1-NEG-4141 G C T T G A T G T C T A A A A A T A T A T T T C A T G T C T T A C T G A A A C A T T T T G C C A G A C T T T C T C C A A N)
      (HUMRAP2-NEG-181 G G C A C C G A G C A G T T C G C G T C C A T G C G G G A C C T G T A C A T C A A G A A C G G C C A G G G C T T C A T C N)
      (HUMRASAA-NEG-481 A C A C A G C G A G G C C T C A A G A C A G T G T T T G A C G A A G C G A T C C G A G C A G T C C T C T G C C C G C C T N)
      (HUMRASFA2-NEG-1321 A G T C A C T G G G T C T C T G C C C A G G G T C C A A G G G G G T G A G A C C A C A G G C A C C A G G C C T C C T G G N)
      (HUMRASH-NEG-601 G G C C G C G C G C C C T C C T C G C C C C C A G G C G G C A G C A A T A C G C G C G G C G C G G G C C G G G G G C G C N)
      (HUMRASH-NEG-5161 G G G A C G C C A C A C T C G C C C T T C T C T C C A G G G G A C G C C A C A C T C G C C C T T C T C T C C A G G G G A N)
      (HUMRASK25-NEG-361 C T A A T T T A A A A A T T T T A A A A T T T A A T T C C A T T A G A A A A C A A A A C T G A C T T T T A A G A A C A A N)
      (HUMRASN2-NEG-1 G A T T C T T A C A G A A A A C A A G T G G T T A T A G A T G G T G A A A C C T G T T T G T T G G A C A T A C T G G A T N)
      (HUMRASR2-NEG-1621 G C C T G C C T C T G C C G G G A A C A C C C T G A C T T C C C T G C C T G C C C A C T C C T G G T T A T C T A A G G C N)
      (HUMRASSK2-NEG-1381 C C C G G G A G C C T C G G G C C C G G C G C C C T C A C A C C C G G G G G C G T C T G G G A G G A G G C G G C C G C G N)
      (HUMRB1RA-NEG-3061 T G C T G T G C T T T A T G G A T A G T A A G A A T G G C C C T A G A G T G G G A G T C C T G A T A A C C C A G G C C T N)
      (HUMRBP1-NEG-421 C T C G C T C T G T G A G G C C A C G G T C T T C C C G C C A G G T T G A C T C G A G C C T C C T G C C A G A G C C A C N)
      (HUMRBS-NEG-2221 A T G A G A G A C A G G C A T T T G G A C C A A A T T A T G A T G T G T T C C A T G T A T G G C A T A T G C A A A G T G N)
      (HUMRBSA-NEG-1381 A T A C T G A A A A G A G T G A A G G A T A T A G G A T A C A T C T T T A A A G A G A A A T T T G C T A A A G C T G T G N)
      (HUMRCC1B-NEG-361 C G G C C C T G G T A T C C A T T C C G G A G G A T G T T G T G C A G G C T G A G G C T G G G G G C A T G C A C A C C G N)
      (HUMRCYP3-NEG-1081 G T T T T A C C C A A T A A G G C A C C A C C C A C C T A T G A T A C T G T G C T A C A G A T G G A G T A T C T T G A C N)
      (HUMREN02-NEG-121 G G C C A G G A T C T T C C T C A A G A G A A T G C C C T C A A T C C G A G A A A G C C T G A A G G A A C G A G G T G T N)
      (HUMRENA3-NEG-361 A A G G G A G T G G C T T C C T C T C T G C C T C T G T G C C C A C T G A C A T G T A G G G G A G A G G G G A A G A T G N)
      (HUMRENA4-NEG-2461 C C C A G T A T G T C G T G A A G T G T A A C G A G G G C C C T A C A C T C C C C G A C A T C T C T T T C C A C C T G G N)
      (HUMRENT1-NEG-601 G A G A G A G C C C C A G A C T G A G G G A A G C A T G G A T G G A T G G A G A A G G A T G C C T C G C T G G G G A C T N)
      (HUMRENT2-NEG-4321 A G T A T G T T C T G C A T G C T T C C C A A C G A C A G C T C C G A G C C T G G C T G T C T G T C C C A C A T T C C T N)
      (HUMREPA-NEG-1141 G C T T G T T A C A A C A T C A A G A T A G A T G G A A T T G G A A G G A T G C T A C C A G G A G A G T A C T T A C A T N)
      (HUMREPAL1-NEG-2821 G T T C A C G T T T G A A A C A C T C T T T T T G C A G G A T C T A C A A G T G G A T A T T T G G A C C A C T C T G T G N)
      (HUMREPHY2-NEG-481 A A A T A A C A A C A A C A G T C T G T A A A C C A C T G G A T A G G T T T T A A T A A A T T A A C C C A A G T A A A G N)
      (HUMRETPON-NEG-1261 T C C T C T G G T G C C A A C T G C A G C A C G C T A G G G G T G G T C A C C T C A G C C G A G G A C A C C T C G G G G N)
      (HUMRETREC-NEG-1321 C C G C C T C T C A T C C A G G A A A T G T T G G A G A A C T C A G A G G G C C T G G A C A C T C T G A G C G G A C A G N)
      (HUMRFPA-NEG-841 C G C C T T G A G G A G C T A G A C T T G G C C A T C T A C A A T A G C A T C A A T G G T G C C A T C A C C C A G T T C N)
      (HUMRGE-NEG-1801 C C G C C C G T C G C T A C T A C C G A T T G G A T G G T T T A G T G A G G C C C T C G G A T C G G C C C C G C C G G G N)
      (HUMRGLTIB-NEG-721 T G C G C T C T C C G C T G C G G G C G C C C G G G G C G C G C A A C C C C A C C C C G C T G G C T C C G T G C C G T G N)
      (HUMRGM-NEG-4441 T T C G C C A A G C G T T G G A T T G T T C A C C C A C T A A T A G G G A A C G T G A G C T G G G T T T A G A C C G T C N)
      (HUMRGNTS-NEG-1981 A T C T C A C C G A T C C G C C T T T T C G T T C T T T C T T T T T A T T C T C T T T A G A C G G A G T T T C A C T C T N)
      (HUMRGNTSA-NEG-2161 C T G T C T C T C T C C C C T C C C T C C C T C C T T G G C G C C T T C T C G G C T C G C C G C C G C C G C C G C C T C N)
      (HUMRGRSAL-NEG-1981 T T T C G T G C T T T C T T G C T T T C C C G T T T T C T T G C T T T C T T T C T T T C T T T C G T T T C T T T C A T G N)
      (HUMRGRSALU-NEG-1981 C A G G G A G G C A C C C C C A C G C C T G G C T T G G C T G A T G T T T G T G T T T T T A G T A G G C A C G C C G T G N)
      (HUMRHOC9-NEG-121 A A C T A T A T T G C G G A C A T T G A G G T G G A C G G C A A G C A G G T G G A G C T G G C T C T G T G G G A C A C A N)
      (HUMRIBIR-NEG-1681 G C A A G A A G A G C C T G G A G A C T G A A C A C A A G G C C T T G A C C A G T G A G A T T G C A C T G C T G C A G T N)
      (HUMRISDAD-NEG-3721 C A A A A A G A G C T T T C C T T C T C C A G G A A T A C T G A A C A T G G G A G C T C T T G A A A T A T G T A G T A T N)
      (HUMRNP70K-NEG-1141 A G G G G C T G C C G C A G C C G C C G C G A G C C T C C G G A C A G A C G C C A G A G C G A G G A G G C G C T A C G C N)
      (HUMRNPA2A-NEG-1201 C A T G C T C A C T G T T C T C C C C A T C C T T G T C C T T C C C A T G T T C A T T A A T T C A T A T T G C C C C G C N)
      (HUMRNPLA-NEG-181 T A T A T T A A A G G C T T C C C A A C T G A T G C A A C T C T T G A T G A C A T A A A A G A A T G G T T A G A A G A T N)
      (HUMROSMCF-NEG-121 A G G A A G G G G T G A C A G T G C T T A T A A A C G A A G A C A A A G A G T T G G C T G A G C T G C G A G G T C T G G N)
      (HUMRPHO2A-NEG-1861 G T A T T T C A C A T A T T A C A A T T T G T C A C A T T G T T G G T G T G C A C T T T G T G G G T T C T T C C T G C A N)
      (HUMRPS14-NEG-3421 A A A G T G T A A T T T A A A C T A G G G T C T A A A T G A T A A G T C C G G A G T C C T T C C A G T G A A A T A A G G N)
      (HUMRPS17A-NEG-1561 T A T A T A T C C A C A T G T G C T C A G T A C C A G G T G G G A G T T G A T T T G T C T T C T C A C T G T T C T C T T N)
      (HUMRPS6A-NEG-601 A T T G C T C T G A A G C A A C A G C G T A C C A A G A A A A A T A A A G A A G A G G C T G C A G A A T A T G C T A A A N)
      (HUMRSA6-NEG-961 C A C A T A C C T G C A T C A T T T T C A T C C T T T C T T T C A G C A A C T G A C C C T C T C A A C T G G A T G T A G N)
      (HUMRSALPI-NEG-181 G A T C A A A A C T T T G C T T C T A T A A A G G A A A A G A C G G T A A C T G G A A T T T C G C G A A C T T T A G A G N)
      (HUMRSCNTF-NEG-61 G A C A G A G C A G A T T T G A A A C A C T C T A T T T G T G C T A T T T G C A A G T G T A G A T T T C A A G C G C T T N)
      (HUMRSCNTT-NEG-121 T G A G G T T A A A G G T N G A A A A G G A A A T A T C T T C G T A T A A A A A C T A G A C A G A A T G A T T C T C A G N)
      (HUMRSH3-NEG-1621 A A A G A G T C C A G G A C C A G A T G G A T T C A C A G C C A A A T T C T A C C A G A G G T A C A A G G T G G A A C T N)
      (HUMRSKP08-NEG-61 A C A T A T G G C T A G C C A G C T T T C C A C C A C C A T T T A T T A A A T A G G G A A T C C T T T C C C C A T T G C N)
      (HUMRSKPA2-NEG-121 A G C C G G G C A G A G A C A C A A C A A A A A A A A G A A T T T T A G A C C A A T A T C C T T G A T G A A C A T T G A N)
      (HUMRSKPNA-NEG-2341 A G T T A G T G G G T G C A G C G C A G C A G C A T G G C A C A T G T A T A C A T A T G T A A C T A A C T T G C A C A A N)
      (HUMRSLINE-NEG-2161 C A A A A A A A G G C A G G G G T T G C A A T C C T A G T C T C T G A T A A A A C A G A C T T T A A A C C A A C A A A G N)
      (HUMRSO5C-NEG-361 A T G G G G A C A C A G C C A A A C T A T G T C A G T A A T C A C G G T C G A G A C T A T C T G C A A T T T A G T G A A N)
      (HUMRSP1GPB-NEG-181 C T C T A G G A T G T C C T T G G C A A G G G A A G C T G C A G A G A A A A C A T A C C T T G G G C G G C A A A G T A A N)
      (HUMRSSA1B-NEG-601 T A G A A T C T G C A A A T G G A T A T T T G G A G C T A T T T C A G G C C C A T G G T G A A A A A G A A A G T A T C T N)
      (HUMRTVLH2-NEG-121 C T T A A C T G A T G A C A T T C C A C C A C A A A A G A A G T G A A A A T G G C C G G T C C T T G C C T T A A G T G A N)
      (HUMRTVLH2-NEG-4681 A A T T C A G G C C T G T C C T T A G A A T G C T A C A G G G T A C A G C C C A T T T G A G C T C C T G T A T A G A T A N)
      (HUMRUN1C2-NEG-241 T C C C G T G C C C T G G G A G C G G G T T C A G G A C C G C G G A T C G G A A G T G A G A A T C C C A G C T G T G T G N)
      (HUMRYR-NEG-1081 C C C A A G C G G G A T G T G G A G G G C A T G G G C C C C C C T G A G A T C A A G T A C G G G G A G T C A C T G T G C N)
      (HUMRYR-NEG-5641 A C C C T G C T G G T G A T G G G C A T C T T T G G C G A T G A G G A T G T G A A A C A G A T C T T G A A G A T G A T T N)
      (HUMRYR-NEG-10201 A A G A G G G C A G G G A A G G T G G T G T C C G A G G A G G A G C A G C T G G C C C T G G A G G C C A A G G C G G A G N)
      (HUMRYR-NEG-14761 G T C C G G G C T G G C G G A G G C A T T G G G G A C G A G A T C G A G G A C C C C G C G G G T G A C G A A T A C G A G N)
      (HUMS71AA-NEG-3301 T C A A A T G C T C G C A T C C T G C A G T A T C A G A G T T T A C T G T T A G A T T G G C C T C G T T T A A C T T T C N)
      (HUMSAA-NEG-2821 G A G T T A G A G G C T G T G G T C C C T C C T C T T C T T G C C C T C T C T C T G C C T C T G T G C T C A G T G T G A N)
      (HUMSAA1A-NEG-3901 A A G C A G A G C A G G A T T A A C C C A G G C A G T C T T G C T C T G C A G A A C T T G C T C T T A A T C A A G G T A N)
      (HUMSAACT-NEG-301 T C C C G A G C G C C C A G G G C G C T C A G A G T G G A C A T G G T T G G G G A G G C C T T T G G G A C A G G T G C G N)
      (HUMSAP1-NEG-121 G C G T C C G A C T G C G G G G C A G T G A A G C A C T G C C T G C A G A C C G T T T G G A A C A A G C C A A C A G T G N)
      (HUMSATA-NEG-361 T C T G C A A G T G G A C A T T T G A A G C A C T T T G A G G C C T A T T G T T G A A A A G G A A A C A T C T T C A T A N)
      (HUMSATA7A-NEG-2461 A A G C C T T C G T T G G A A A C G G G A A T A T C T T C C C C T T G A A A C T A G A C A G A A G C A T T C T C A G A A N)
      (HUMSATAR2-NEG-181 A A G C A T T C T C A G A A A C T T A T T T G A G A T G T G T G T A C T C A A C T A A G A G A A T T G A A C C A C C G T N)
      (HUMSATAX-NEG-1441 T C T G A G A A A G T T C T T C A T G A T G A A T G C A T T T A A C T C G C A G A G A T G A A C C T G C C T T T G A G A N)
      (HUMSATM29B-NEG-181 C T G T G C A A T G C C C A A A C T G T C C C T G T G A G T T G A A T G C C C C T G G C A G G A T G C G T G T C C A C T N)
      (HUMSATOD-NEG-841 A T G C A G C A C C T T C A G G T C T T G A G C T C T A T G C A G G G A G G T A A G C C A C G G A A G T C A C A A G C A N)
      (HUMSB3B2-NEG-121 G G G G G A G T T C C G G G C G G T G A C G G A G C T G G G G C G G C C T G A T G A G G A C T A C T G G A A C A G C C A N)
      (HUMSBLA-NEG-961 A G G A A C A A A G A A G T G A C T T G G G A A G T A C T A G A A G G A G A G G T G G A A A A A G A A G C A C T G A A G N)
      (HUMSECP1-NEG-181 C T G A C A T G C T T T C A T C T A G T T T C C T C G C T T C C T T C C T T T T C T G C A G T T T T C G C T T C A C A G N)
      (HUMSERDHY-NEG-241 G G T G G G C C A A G C A A G G C T G T G C A C A T T T T G T C T G C T C C T C G G C G G G C A A C G C A G G C A T G G N)
      (HUMSGLT1-NEG-1141 A C T G C G A G G C C T G A T G C T A T C A G T C A T G C T G G C C T C C C T C A T G A G C T C C C T G A C C T C C A T N)
      (HUMSHBG-NEG-1021 G G A C T C A C A G C T G C C C C C A G A G C C C A G G C A A T G G C A C T G A C G C T T C C C A T T A A A G C T C C A N)
      (HUMSHBGA-NEG-4501 C A T T G C C T G T A T T C A G T G G A G C C T G G A G C A A T G A G G A A G A G G G A G T C C A A C A T G T C A A T A N)
      (HUMSIGMG3-NEG-301 A C A C C A A T T T A T T G T A T A T T T T C A T A C G G C T A G A A G A G C A A A T T T T G A T T G T T C C C A G C A N)
      (HUMSIGMG4-NEG-961 A C C C A C A C A C A C C A A T T G C A G G C A C T G G A A C A T G A C C A G A A G T A G G C A A A C A C T A G T A A G N)
      (HUMSISG1-NEG-841 G C A G G T A G G T C C A A G C T G C C C C G T C C A A A C A T C C T C T T C C T T G T C T G G A G C C T G G A G G A G N)
      (HUMSISG1-NEG-5401 A G G C A A C C A G C T A G G A G G A G G A G A C T C G G A C C C A G C T T G C A G C T G A A G G G C G C T G G C T G C N)
      (HUMSISM-NEG-241 C G G C G A G C G G G C G G G C A G A C G G A C C G A C G G A C T C G C G C C G C G T C C A C C T G T C G G C C G G G C N)
      (HUMSISPDG-NEG-2581 T T C A C C T C T T C C T C T G G T T C C T T T C A T C T C T C T A C C T C C A C C C T G C A T T T T C C T C T T G T C N)
      (HUMSLIPG-NEG-961 A T G A C C T T T G G G C T T T G T G G A C A G C T A C T G A G G T A A G G G T C T C T C C C C C T C A A A A G T G G T N)
      (HUMSLK-NEG-841 A G A T G C T G A G C G A C A G C T A T T G T C C T T T G G A A A C C C A A G A G G T A C C T T T C T T A T C C G C G A N)
      (HUMSMCK-NEG-1021 G A A A A A G G A G G C A A T A T G A A A C G A G T A T T T G A G C G A T T C T G T C G T G G A C T A A A A G A A G T A N)
      (HUMSNRNP1-NEG-301 T T T T T T G A C A G G G C C T G G C T C T G T T A C T C A G G C T G G A G T C A G T G G C A T G A T C T C T G C T C A N)
      (HUMSNRNP3-NEG-3901 G G A A G A C A A A G T G A G A T C C T T T C T C A A A A A A A A A A A A A A A C T T T G G G T G G A A G G T G G G G T N)
      (HUMSNRNP9-NEG-121 A A T T G A A G C T T T T T C A G A G C A G A G C A A A G A C C T C C C T G C A G C T T T C T T G G C A C C A G A A T A N)
      (HUMSNU1P2A-NEG-301 C T A G G A G G G C T C G C C G G G T G C G G C G G G G A A G T G A C C G T G C G T G T A A A G G G T G A G G C G T A C N)
      (HUMSODA-NEG-1801 T A A A T A A T T T T A A G A A A G C T G G T T C A C A A G G T G C C A C A T T T G A T G A A A G C A A A A T A C A G T N)
      (HUMSODA-NEG-6361 A G C T G A G C C C G G C A G A T A C T A T G T T G C A T C A G C T T T C A C G C T T G C A G T T A A T A T C A T T G C N)
      (HUMSODG5-NEG-181 T G G G C A A A G G T G G A A A T G A A G A A A G T A C A A A G A C A G G A A A C G C T G G A A G T C G T T T G G C T T N)
      (HUMSP18A-NEG-361 G A C A C G C T G C T G G G C C G C A T G C T G C C C C A G C T G G T C T G C C G C C T C G T C C T C C G G T G C T C C N)
      (HUMSPARC07-NEG-1 T T T G G A A C C T A G A C A T C C C C C C T T G C C T G G A C T C T G A G C T G A C C G A A T T C C C C C T G C G C A N)
      (HUMSPBAA-NEG-3061 A C A C A C A C A C C C T G T C C A C A A A G G G C C T A G G A A A C T A C G T G C C C T T C A G C C A T G C A C C C G N)
      (HUMSPBAA-NEG-7621 T G T T C T T T C C C G G A A G A G C T G G G T G T G G G G A G C T G A G G G G G C C C A G G C C T C A G C C C T G G T N)
      (HUMSPIA04-NEG-61 G A G G A G C T A C G C C A C C T G T G G G A C C T G C T G T T A G A G C T G A C C C T G G A G A A G G G T G A C C A G N)
      (HUMSPM1-NEG-181 G A A G G C C A G G A C G C C A T C A C A G A C C A G G C A G A C A T C A G G G C G A G A T G G A G T G C T C A C C T C N)
      (HUMSPR1B-NEG-181 G C C C T G C C A C C C C A A G G T G C C T G A G C C C T G C C A C C C C A A A G T G C C T G A G C C C T G C C A G C C N)
      (HUMSPRO-NEG-1321 T G T T A A T C C T A T T T T A T T G A A A A T G A A C T A A G A C T C A G A G A G A T A A A G C T G T T G C C C A A T N)
      (HUMSPROTR-NEG-541 T T A C T T G C A C T T G T A A A C C A G G T T G G C A A G G A G A A A A G T G T G A A T T T G A C A T A A A T G A A T N)
      (HUMSPTA1A-NEG-1861 G G C C T G T T A G C C C G G C G G G A T G C C C T A C G T G A A A A G G C T G C C A C T A G A C G T A G A T T G C T G N)
      (HUMSPTA1A-NEG-6421 C A G C T G C A G A A A G A C C A T G A G G A C T T C T T G G C C T C C C T G G C T A G G G C T C A A G C A G A C T T T N)
      (HUMSRC2B-NEG-61 A T C A A G T C A G A C G T G T G G T C C T T T G G G A T C C T G C T C A C T G A G C T C A T C A C C A A G G G C C G A N)
      (HUMSRTR2A-NEG-61 T G G C A G C C G C G G G A C T G T C G C G T C G G C G C C C G A C G C G G A G T C A G C A G G G G C G A A A A G C G G N)
      (HUMSTATHG2-NEG-1 A A G C T T T A C T T T C T T C T T T A C C T T C A T A C C C C T A T T C T C T T G G T C T G T G T A A G G T G T T G A N)
      (HUMSTATHG2-NEG-4561 C A A A G C A C T C A C A T T T T T T A T C T C A G T C C C T G T A G G T C A G A A G A T A A C C A C C A T G T C A C T N)
      (HUMSTROMR-NEG-661 T A C A A C A G G G A C C A A T T T A T T T C T C G T T G C T G C T C A T G A A A T T G G C C A C T C C C T G G G T C T N)
      (HUMSTS-NEG-3361 C T T T T G T G G A C T T G T C T G A C C A C C T T C T A T T T G C C C A G A G T T T G C T C A A T T C C A A G A C A G N)
      (HUMSTSB-NEG-1021 A G C G G A A C A C T G A G A C T C C G T T C C T G C T T G T C T T G T C C T A C C T C C A C G T G C A C A C A G C C C N)
      (HUMSTSXG2-NEG-2461 A T G C C T A T T T G T G T C T A G A A C C A G T T A T T T A A C C T G T A A A A T G T C A A T A G C A A A T G A A G G N)
      (HUMSYN25A-NEG-1 G G G G G A A G A G A T A A A A G C A A A C A G G T C T G G G A G G C A G T T C T G T T G C C A C T C T C T C T C C T G N)
      (HUMSYNPR-NEG-61 A T C T T C G C C T T T G C C A C A T G C G G C A G C T A C A G T G G G G A G C T C C A G C T G A G C G T G G A T T G T N)
      (HUMT1418-NEG-2161 A G G G T G G T T T T T C T T T T A A C C A G T T G A G A C G G G C A A A A G C T T G A T T G C C C T T T A A C C G C C N)
      (HUMT28E-NEG-121 G G C C A G A T C G T G C C A T A G C A C T C C A C T T T G G G T G A T A G A G G G A G A C T C T G T C T C A A A A A A N)
      (HUMTACEB-NEG-241 T C G T C C C T T C C C T C C C C G A C A G G T C A C A T A A C A G C T G C A T C A T T G A C C G C A C A G C G C C A T N)
      (HUMTACEC-NEG-2341 A G A G A C T G G G A T G G G A A C A C T G G T G G G C A G C T G A G G A C A C A C C C C A C A C C C C A G C C C A C C N)
      (HUMTBB14P-NEG-1441 A C T T C A T C T C T G A G A T C A G C A G T A C C A G G A T C C C A C C A C A G A A G A G G A A G A G G A T T T C A G N)
      (HUMTBB46P-NEG-421 A T G G A C T C T G T T C G C T C A G G T C C T T T T G G C C A G A T C T T T A C A C C A G A C A A C T T T G T A T T T N)
      (HUMTBB5-NEG-3241 A T C A A A T A A A A C A G G G A T T C T A A A A T G C T A T T A G A A T T G T G A G G C T C A G G G T G G G C A C G G N)
      (HUMTBB5-NEG-7801 G A G C A G T T C A C G G C C A T G T T C C G G C G C A A G G C C T T C T T G C A C T G G T A C A C G G G C G A G G G C N)
      (HUMTBBM40-NEG-841 G C C C G G A C C C C A G A G G C C G G T C C T G T A T T T G T T C C T G G A T G G A A G G A G A A T A A G A A C G G G N)
      (HUMTBG-NEG-301 T C A T C T C T T A T A G A T T A A C T T C C T T C C A A A A T G T C A C C A T T C C T G T A C C T G G T T C T C T T G N)
      (HUMTCAJA-NEG-61 G G C A G G A A G T G C T G T G G A A T A A C A A T G C C A G A C T C A T G T T T G G A G A T G G A A C T C A G C T G G N)
      (HUMTCAXB-NEG-1321 G G T T C T C T T G G G C T C T A G G T C C T G G A G A A T G T T G T G A G G G G T T T A T T T T T T T T T A A T A G T N)
      (HUMTCAXN-NEG-61 G C C C A G A A G A T A A C T C A A A C C C A A C C A G G A A T G T T C G T G C A G G A A A A G G A G G C T G T G A C T N)
      (HUMTCAYD-NEG-1 G A A T T C A T G T C T T A C G G T C A A G G G C T A G A G A A A G G A T T T C T G C A T C A C T T T C T T C C T G T A N)
      (HUMTCAYJ-NEG-181 A G A G T G A A A C C T C C T T C C A C C T G A C G G A A C C C T C A G C C C A T A T G A G C G A C G C G G C T G A G T N)
      (HUMTCAYS-NEG-121 A T T C A A A C A G C G C C T C A G A C T A C T T C A T T T G G T A C A A A C A A G A A T C T G G A A A A G G T C C T C N)
      (HUMTCBA-NEG-2161 A G T T T G C A C C T G T C C C C A C C C T C C A C T C A G C T G T C C T G C A G C A A A C A C T C C A C C C T C C A C N)
      (HUMTCBCC-NEG-1981 T G A T G G G G G C A G G G G A T G G A A C A T C A C A C A T G G G C A T A A A G G A A T C T C A G A G C C A G A G C A N)
      (HUMTCBCE-NEG-1621 G A G A A A G G A T T C C A G A G G C T A G C T C C A A A A C C A T C C C A G G T C A T T C T T C A T C C T C A C C C A N)
      (HUMTCBJC-NEG-721 G A T T T T C A C C T T G A C C C C T G T C A C T G T G T G A A C A C T G A A G C T T T C T T T G G A C A A G G C A C C N)
      (HUMTCBJD-NEG-361 T T C C A A G G A G G G A C C T C T C T G C C C C C C A C C A T T A C C A T C A C T G T G A C T T T C C C C A A G C C C N)
      (HUMTCBV81-NEG-541 T G A T G C G G G G A C T G G A G T T G C T C A T T T A C T T T A A C A A C A A C G T T C C G A T A G A T G A T T C A G N)
      (HUMTCBVD-NEG-1 G G T C A C A A C T C T C C C C A G A G A A G G T G G T G T G A G G C C A T C A C G G A A G A T G C T G C T G C T T C T N)
      (HUMTCBVW2-NEG-301 T C A T T C A G T A T T A T A A T G G A G A A G A G A G A G C A A A A G G A A A C A T T C T T G A A C G A T T C T C C G N)
      (HUMTCBXF-NEG-541 T T C T G G C A G A A C C C C C G C A A C C A C T T C C G C T G T C A A G T C C A G T T C T A C G G G C T C T C G G A G N)
      (HUMTCBYB-NEG-61 T C T G G G C A T A G G A G T G T A T C C T G G T A C C A A C A G A C C C C A G G A C A G G G C C T T C A G T T C C T C N)
      (HUMTCBYM-NEG-181 A T T C A T T A C T C A G T T G G T G C T G G T A T C A C T G A C C A A G G A G A A G T C C C C A A T G G C T A C A A T N)
      (HUMTCBYX-NEG-1 A G C T T C A T T C C T G C C T C T T G T C T G G C T C A G C A C A T A T T G G T C A T A A A A C A T A T T C T G G T T N)
      (HUMTCBZE-NEG-241 C A G G A T A T G A A C C A T G A A T A C A T G T A C T G G T A T C G A C A A G A C C C A G G C A T G G G C T G A G G C N)
      (HUMTCDXA-NEG-1 A G A G G C A G A G C T G C C C C T G A G T G A G C C A T G C A G A G G A T C T C C T C C C T C A T C C A T C T C T C T N)
      (HUMTCGCF-NEG-121 T T A T T A A G A T A C A T T G G C A A G A A A A G A A G A G C A A C A C G A T T C T G G G A T C C C A G G A G G G G A N)
      (HUMTCGXH-NEG-601 G A C T A A C G A C A C A T A C A T G A A A T T T A G C T G G T T A A C G G T G C C A G A A G A G T C A C T G G A C A A N)
      (HUMTCOBI-NEG-1261 A A T A A T G A C A G A A C C T A C T G G G A A C T T C T G A G T G G A G G C G A A C C A C T G A G C C A A G G A G C T N)
      (HUMTCR3G1-NEG-961 T A C C T A C A G C A A C A A C A A C T A G C A A C A A G T A A C A A C T G G C T A C G A T C C T A A C A A C T A A T G N)
      (HUMTCRAC-NEG-1441 T T T T T T G A G A T G G A G T T T T G C T C T T G T T G C C C A G G C T G G A G T G C A A T G G T G C A T C T T G G C N)
      (HUMTCRAI2-NEG-61 T C A G T G C C C T T C T A T C A T C A A T G G G A T G G T C T G A T T A A G G C C T G G C T C C C A C T G G C T A C C N)
      (HUMTCRAJ3-NEG-301 G T G A T G C A G G C C T A A T T C A T A A A G G A A G C A C T G C C A G C T C T T T A T T C A G T G C T T T G C C A A N)
      (HUMTCRB11-NEG-1 G G A C A G G A T G T A G C T C T C A G G T G T G A T C C A A T T T C G G G T C A T G T A T C C C T T T A T T G G T A C N)
      (HUMTCRB22-NEG-241 A C A A A A T C A A G A G G T C A C T A A T T G A T A T A T C T A T T T T G A G T T G C C T T T G A G A C T T C C A C G N)
      (HUMTCRDA-NEG-1741 A A G G G A G G A A C A G A A A T G A G A C C C C T A T C T T T C C C T A T A A A A A C A A C A T T T T T A C T G T C T N)
      (HUMTCRDA4-NEG-661 A G G G C A C A G A T G T T A C A G C T C A G G C C C C A G G G C C A G C T C C A G G C T A G T T A C C T G T G A G G C N)
      (HUMTCRGAA-NEG-1 T A T T A C T G T G C C A C C T G G A A G G A T T A T T A T A A G A A A C T C T T T G G C A G T G G A A C A A C A C T T N)
      (HUMTCRGE-NEG-121 G G A A G G A G G G G T A A T G G G G T A C A A A A A T G A T G A A T T T C T T T G T C C C A A T C C A C T T T T A C C N)
      (HUMTCRT3D-NEG-1081 G A C T G G C C A T G G G A G C A C A G C T T C C T G C A C T A C T C C T T T T A G G C C T G A T G G C C T C T G G A A N)
      (HUMTCSM-NEG-241 T G T G T G C C A A C C C A G A G A A G A A A T G G G T T C G G G A G T A C A T C A A C T C T T T G G A G A T G A G C T N)
      (HUMTDTA-NEG-781 A A G A C T T C T G A G A A G T G G T T C A G G A T G G G T T T C A G A A C T C T G A G T A A A G T A A G G T C G G A C N)
      (HUMTF-NEG-1261 G A T G G A G G G T T T G T C T A C A T A G C G G G C A A G T G T G G T C T G G T G C C T G T C T T G G C A G A A A A C N)
      (HUMTFA01-NEG-1321 C T G G C C T T T G C T T G G G C T T C T A G A C A C C T T T C A C T G C A C T C A C T G T C T T C T C C C C C T C C T N)
      (HUMTFAA-NEG-2881 C C C T G A T G A A G G C A C C T T G G G G C T T C C C T G C C G C A T C C T C T C C C C T C A G G A A G G G G A C T G N)
      (HUMTFP-NEG-61 A G C C C C A C G G G C G C C A C G G A A C C C G C T C G A T C T C G C C G C C A A C T G G T A G A C A T G G A G A C C N)
      (HUMTFPB-NEG-421 C T T C C A A G G C G C C C T C C C T T T C C T G C C A T A G A C C T G C A A C C C A C C T A A G C T G C A C G T C G G N)
      (HUMTFPB-NEG-4981 T G T A A A T G C A A A C C A T C T A A T A G T C A G C G A G A C C C T A T A G C C C T G C T G C T T A A T G G G G G C N)
      (HUMTFPB-NEG-9541 C C A A T T C A A A A A T A G C A G A A C A G A G T T G T T G A G A A G G T G A T G G A G T A G A A G G G G G A G C G C N)
      (HUMTFPC-NEG-241 T C A A C T A A T T T C A A G A C A A T T T T G G A G T G G G A A C C C A A A C C C G T C A A T C A A G T C T A C A C T N)
      (HUMTFRR-NEG-1741 G A A T C C C A G C A G T T T C T T T C T G T T T T T G C G A G G A C A C A G A T T A T C C T T A T T T G G G T A C C A N)
      (HUMTFRRA-NEG-3481 A A T T A T C G G A A G C A G T G C C T T C C A T A A T T A T G A C A G T T A T A C T G T C G G T T T T T T T T A A A T N)
      (HUMTGC1-NEG-61 T G T G T C T G T G T G T G T G T G G G T C T G T G T G T G T G T G T G T G T G T G G T A G C T G T C T G T T T G A A A N)
      (HUMTGFB-NEG-541 T A G A C C C T T T C T C C T C C A G G A G A C G G A T C T C T C T C C G A C C T G C C A C A G A T C C C C T A T T C A N)
      (HUMTGFB2A-NEG-2401 A A A G A G G T C A T A T T A A T G G G A T G A A A A C C C A A G T G A G T T A T T A T A T G A C C G A G A A A G T C T N)
      (HUMTGFBG1-NEG-1801 A C C C C C G G T C C A A G C C T C C C C T C C A C C A C T G C G C C C T T C T C C C T G A G G A C C T C A G C T T T C N)
      (HUMTGFKA-NEG-1141 T C C G G C A A G A A C C C A C T A G C A A G T T T T G G T T T C C C T C A A G G A G G G G G C A C C C C A A G C G G G N)
      (HUMTGL7-NEG-181 A C T A C T C G G A A C A A A A G A G A A A A T G C A G A A A A T T C C C A T C A C T C T G T G A G T A G G A G G T G T N)
      (HUMTGLU-NEG-781 T C G T G G C G T T T G T G G C A A C C C C G G A C A C G G G G C A C C A G C C A G T C A G C G G A G C C T C C T C A C N)
      (HUMTGPL1-NEG-1201 T A A C T C T T T C C A C C A A T T T C A A A T A G T G C G G C T T A A A A G A T G A A G G A G A G C T A A A C A A A C N)
      (HUMTGTPV2-NEG-841 A T C T C G G C T C A C A G C A A C C T C C G C C T C C C A G G T T C A A G C C A T T C T C C T G C C T C A G G C T C C N)
      (HUMTHB-NEG-3601 C C A A C A T A G T G A A A C C C C C A A C C T C T A C T A A A A A T A C A A A A A T T A G C T G G G G T G T G G T G G N)
      (HUMTHB-NEG-8161 A A C T C C A C A C A G C A G C C A C A T G A G A T G G G T T G T T T A C T T C T T T T T T T T T T G T T T C T T A G A N)
      (HUMTHB-NEG-12721 T T A T T C A A A T T T T T G T T A G T C T T G C T A A T G T C T T T T A T A G G G A A A A A A A A A A A A A A A A G C N)
      (HUMTHB-NEG-17281 G G G A G G A G G A G G T T G C A G T G A G C C G A G A T G G T G C C A C T G C A C T C C A G C C T G G C A A C A G A G N)
      (HUMTHBNA-NEG-961 A C C T T T G G C T C G G G A G A G G C A G A C T G T G G G C T G C G A C C T C T G T T C G A G A A G A A G T C G C T G N)
      (HUMTHBNB-NEG-3541 G T G A A C T C T G G A C T G G A A G G A C C T A G T T A G G G G G T G C A A A A A G C A G G A G G C A G G T C A G G T N)
      (HUMTHEP2-NEG-121 T A T T C T G C C A A T C A C A T T T C T C T T C A A C T A T G C C T T G T G A T A T A G T T T G G C T C T G T C C C C N)
      (HUMTHMA-NEG-121 C T T G T T A C A G G G G T G C T G G C C T T C C C T G G C G C C T G C C C C T G T C G G C C C C G C C C G A G A A C C N)
      (HUMTHMOD-NEG-421 C A G C T G C C A C C C G G C T G C G G C G A C C C C A A G C G C C T C G G G C C C C T G C G C G G C T T C C A G T G G N)
      (HUMTHR-NEG-1501 G G A C A G C C C C C A G G C C G T G C G G C G C T C C C T G G A G G G T G T C C A G G A T G A G C T G G A C A C C C T N)
      (HUMTHRAA-NEG-361 G A A T T C T A G A G C T T G A C C A G T T T A A G G G G C A G C A G G G A C A A A A A C G T T T C C A A G A C A T G A N)
      (HUMTHROMPR-NEG-121 C A G C T T T C T C T A A T A A G A A A G C T C T T T C C T G C C A C C G T A T A G G T C A C C T T C T T A T T G G T A N)
      (HUMTHROMR-NEG-721 A G G T T T G T C T T T G G A A C C A C A C C A G A A G A C A T C C T C A G G A A C A A A G G C T G C T C C A G C T C T N)
      (HUMTHX-NEG-841 G C C T G C G G G G A G C A C C T G G A G G C C T T T G C T T T G C T G G A G C G C T T C A G C G G C T A C C G G G A A N)
      (HUMTHYB10-NEG-181 A G T G A A A T T T C C T A A G A T C C T G G A G G A T T T C C T A C C C C C G T C C T C T T C G A G A C C C C A G T C N)
      (HUMTHYR01-NEG-181 G C C A G G G G A C C T A G G G C A A G C A G T G G T T T C T C C T C C T T C C T C C C A G G A A G G G C C A G G A A A N)
      (HUMTHYRR-NEG-481 A G G T G T A T G G G A C C C G C C A G C T G G G G A G G C C A A A G C G A T G T C C A A G G A G C T G T G A A A T A A N)
      (HUMTHYRR-NEG-5041 G C C A T G G T C A A G A T T C T C C A G C T G T G T A T T T G A A A A A G G G C C A A G G A T C C A C C A C A A C A C N)
      (HUMTHYRR5-NEG-781 A T T T T T G C T G G C C T G G A C C T T C C T T C C A C C T T C A C T G A A A C C A C C C T G T A C C G G A T A C T G N)
      (HUMTIR-NEG-901 C G T C T G G T G G G G G G C A G C A G C A T C T G T G A A G G C A C C G T G G A G G T G C G C C A G G G G G C T C A G N)
      (HUMTKFER-NEG-1081 A C C A G T C T T G T C A C A G A G G A A A T A G T G A A T G T C C A T A A A G A G A T T C A A A T G T C G G T T G A A N)
      (HUMTKR-NEG-2641 G G G T A C C G G T T G C C C C C T C C T G T G G A C T G C C C T G C C C C T C T G T A T G A G C T C A T G A A G A A C N)
      (HUMTKRA-NEG-3721 A A A A T A C T G T T T C A C A C A T T C T T T C C A G A A C T C G A A G T A G G A T T A T A G C A A G G T A A T A A C N)
      (HUMTKRA-NEG-8281 G G G G A C A T G G C C C T C T C A G A A C A A G G A A G C T T C A G C T T T G G C A A G G C T C T C C C T C C T T C A N)
      (HUMTKRA-NEG-12841 A G G A A G T C G G G A G G C G T G G A G G G T G A C C A C A C C T T G G C C T T C T G G G A A C T C T C C T T T G T G N)
      (HUMTM-NEG-1441 C G C T T G G G A C T G C A G C G T G G A G A A C G G C G G C T G C G A G C A C G C G T G C A A T G C G A T C C C T G G N)
      (HUMTM30R-NEG-1441 A G T A A T T A A T A G A T G G T A A T T A A T T G A T C C T T G A T G T G A T G T T C T T T T G C A T A T T T C C T T N)
      (HUMTNFA-NEG-3241 T T T A A A A T A T T T A T C T G A T T A A G T T G T C T A A A C A A T G C T G A T T T G G T G A C C A A C T G T C A C N)
      (HUMTNFAB-NEG-2641 T A A T A G A A G A A C A T C C A A G G A G A A A C A G A G A C A G G C C C A A G A G A T G A A G A G T G A G A G G G C N)
      (HUMTNFB-NEG-121 A G A T G G A G G G C A T C C T T C A G G A G T G A G A T G A G A C C T C A T C A T A C T T G A C T G T C C A G C A T C N)
      (HUMTNFX-NEG-1681 T A G G A T T T G G G G A T T G A A G C C C G G C T G A T G G T A G G C A G A A C T T G G A G A C A A T G T G A G A A G N)
      (HUMTOPI-NEG-1261 T G C T A A C T T C A A G A T A G A G C C T C C T G G A C T T T T C C G T G G C C G C G G C A A C C A C C C C A A G A T N)
      (HUMTOPII-NEG-1081 G C A G T A A A A G C A C A T C A G G T G A A A A A T C A C A T G T G G A T T T T T G T A A A T G C C T T A A T T G A A N)
      (HUMTOPIIX-NEG-841 G T A G A A A G T A T C C T G A A C T G G G T G A A A T T T A A G G C T C A G A C T C A G C T G A A T A A G A A G T G T N)
      (HUMTP53B-NEG-1021 C C C A G G G A G C A C T A A G C G A G C A C T G C C C A A C A A C A C C A G C T C C T C T C C C C A G C C A A A G A A N)
      (HUMTPA-NEG-4201 A G A G C A C T A T T T G C T A G G T G C T G G G A G A G A G A A G C A G G T G G C T T T C A C A C C C C A C A T T A C N)
      (HUMTPA-NEG-8761 G A T G T G G G C A G T T T T T A T T T C A G C T G A G T C T C C A G A A G G C A G G G G A C A G G G A C T G G G A G G N)
      (HUMTPA-NEG-13321 C A G G A G A T T T T A T G C C T C A A A A T A T A G A T G C T T T T T G G A A G G A C A G C A C A T T A A T T A T T T N)
      (HUMTPA-NEG-17881 A G A C A G G A C A A C A T T G C G G C T T A T C C T C C T C T G T T G C C A T C A T G G A C C T C T C G C A C C C C G N)
      (HUMTPA-NEG-22441 C A C T T G A G C C C A G G A G T T G G A G G C T G C A G T A A T C T A C G A T T A T G C C A C T G C A T T T C A A C C N)
      (HUMTPA-NEG-27001 C T G C T T G A G C C C A G G A G T T T G A G A C C A G C C T G G G C A A C A A A G T G A G A C T C C A T C T C T A C A N)
      (HUMTPA-NEG-31561 G G C C T G T A A G T G G A A G G A A G C C T C G G C C C C A T C C T G T C T G C G G G A C A G C A G G G G A G G C T G N)
      (HUMTPA-NEG-36121 G A A T T G T A T C A T T T G A A C A A C T A G G C T T C A G C A T A T T T A T A G C A A T C C A T G T T A G T T T T T N)
      (HUMTPAR-NEG-361 C T G G G A A G T G C T G T G A A A T A G A T A C C A G G G C C A C G T G C T A C G A G G A C C A G G G C A T C A G C T N)
      (HUMTPI-NEG-61 A G G G T T C C C C T G A G C G C C G G A G C T C A C A G G T C T C G C C T T G T C C C G A A A G C C C C G C A A T C G N)
      (HUMTPIPSC-NEG-61 C A A C C T A G A A A T C A C A G A A G G C G A C A C T G A C C T T C A G T G C C T C A G C T C C A G C G C C A T G G C N)
      (HUMTPO-NEG-2401 G G A T T T C C A G C C T C C C C T C T G C A A A G A T G T G A A C G A G T G T G C A G A C G G T G C C C A C C C C C C N)
      (HUMTPO03-NEG-61 G G A G C A G G G C A G A G T G A G C A G G A A G A A A T G A T G C T G G G G A A T T T G T G T G C T C C T T G G G T G N)
      (HUMTPO04-NEG-3121 A G G A G G A C A C C T T G A C T T T G T G C A G G G G C T G C T T G C T C A G G G C A T G T T T T T T A C T T G A G A N)
      (HUMTPO06-NEG-1681 G G C T T T T T A A G C T C T C A G T A T T A T G A G A T T G T G A T T C T G T A A A C C C A T A T T T G C T C A G A A N)
      (HUMTPO08-NEG-601 G G C G A C C C T C C T C T G G T A T C C T G G G C C T C A C T G A G A T G C T T T T C C T A T C T G C A C A G A T C A N)
      (HUMTPO11-NEG-241 G C A C C C T C T A A A A T A G C T G G A T T T G C T G T C A T C A T T C T T G T T T T T A A C A C A G C A A T A C A C N)
      (HUMTPO13-NEG-1021 C T C A G G C C C C T C A C C A G A T G C T C T G G G G C C G G C T C C T G G G C T G C C T C T C T C C T C T G T C C C N)
      (HUMTPOA-NEG-841 G C T G A C T G C C A G A T G A C T T G T G A G A A C C A A A A C C C A T G T T T T C C C A T A C A A C T C C C G G A G N)
      (HUMTPOB-NEG-2401 G A T G G G A G A A C C T G C G T A G A C T C C G G G A G G C T C C C T C G G G C G A C T T G G A T C T C C A T G T C G N)
      (HUMTR211-NEG-901 T T G G A A A A A C T A A A G A T C T T T C T C A A A A T A G T A A T G A A A T G T C T A T G A T T G A A A G C T T A A N)
      (HUMTRA-NEG-781 G A C T C C A A T G A A T T T T C T G T A A T T G C T G A C C C A A G A G G A A A C A C T C T A G G A C G G G G A A C G N)
      (HUMTRANSB-NEG-181 T C T C C C T G G G A C T C T T G A T C A A A G C G C G G C C C T T T C C C C A G C C T T A G C G A G G C G C C C T G C N)
      (HUMTRD117-NEG-301 G C C C T G G T T T C A A A G A C A A T T T C C A A G G T G A C A T T G A T A T T G C A A A G A A C C T G G C T G T A C N)
      (HUMTRGC64-NEG-61 G T C T T C T G C T C C T C T T C G T C T G G T C C C T T A C T T C C A A G A C C C C A G A G A G G A A G G C A T G C T N)
      (HUMTRK2H-NEG-1081 A G C G A C G T G T G G A G C T T C G G C G T G G T G C T C T G G G A G A T C T T C A C C T A C G G C A A G C A G C C C N)
      (HUMTRKR-NEG-1201 C T G T G T T C A C C A C A T C A A G C G C C G G G A C A T C G T G C T C A A G T G G G A G C T G G G G G A G G G C G C N)
      (HUMTRO-NEG-181 G T G T T A C C G A G G G C A T T T C T A A C A G T C T T C T T A C T A C G G C C T C C G C C G A C C G C G C G C T C G N)
      (HUMTROPA3-NEG-901 T C T G A G C T C T G C A T T T G T C T A T T C T C C A G C T G A C C C T G G T T C T C T C T C T T A G C T A C C T G C N)
      (HUMTROPFB-NEG-421 C T G C A A A A G C T G G A A G A A G C A G A A A A A G C T G C T G G T G A G A G T G A G A G A G G T A T G A A G G T T N)
      (HUMTROPSR-NEG-721 A T A T G A G G A A G A A A T C A A G A T T C T T A C T G A T A A A C T C A A G G A G G C A G A G A C C C G T G C T G A N)
      (HUMTSG14A-NEG-301 G G A C G A C G T C C T G C G G G G C G A G C T G C A G A G G C T G C G G G A G G A G C T G G G C C G G C T C G C G G A N)
      (HUMTSHBA1-NEG-961 G G T A A T T T T A T T T T G A A A C A G A A G A G A G G A A A A T G C A T G C T T T A A T A A T G T C A G T T T C C A N)
      (HUMTSHX-NEG-241 C C C C A G C T T A C C G C C C A G T A C G C A G A C T C T G A A G C T T A T T G A G A C T C A C C T G A G A A C T A T N)
      (HUMTUBAFB-NEG-1 A T T G G C A A G G A G A T C A T T G A C C T C G T G T T G G A C C G A A T T C G C A A G C T G G C C G A C C A G T G C N)
      (HUMTUBAG-NEG-3361 T G A A C A G C T T T C T G T A G C A G A G A T C A C C A A T G C T T G C T T T G A G C C A G C C A A C C A G A T G G T N)
      (HUMTUBBM-NEG-2281 C A C C T G G T G T C T G C T A C C A T G A G T G G G G T C A C C A C C T G C C T G C G C T T C C C A G G C C A G C T C N)
      (HUMTYR-NEG-1141 G A T C G T A T C T T C C T T C T C A C C A T G C A T T T G T T G A C A G T A T T T T T G A G G C A G T G G C T C C A A N)
      (HUMU170SC-NEG-481 G C G G T G G C G A C A T G G C G G A G C C C T C C G A G G C G G G T G A C G C G C C C C C T G A T G A T G G G C C T C N)
      (HUMU3AA-NEG-961 T T T T G C G T T T T C T C C C A T T C T C G C T C C C T C T T T T G T C G C C G T T T C C C G C C C G C C A C T C C C N)
      (HUMUBIBP-NEG-481 A C T A C T C T G C A C T A A A G C C A T T T G C C C C A A T T T A A G T T T A T A A A T T A C C A G T T T C G G T A A N)
      (HUMUBPSE1-NEG-661 G T G G C T G T T A A T T C T C C A G T C T T G C A T T C G C A G T G C C C A G T G A T G G C A T T A C T C T G C C G T N)
      (HUMUDPGT-NEG-1801 T G T C A A G G A G G A A A A C A T T A G G G A A A A C A A A A A T G A T A T A A A G C C A T A T G A G G T T A T A T T N)
      (HUMUG2B-NEG-781 C T C T C T C T C T C T C T C T C T C T C T T T C T C T C T C T C T C T C T G T C T C T C C G T C T C T C T G T G T C T N)
      (HUMUG3PD-NEG-61 T G T T A C T A G A G A A G T T T C T C T G A A C G T G T A G A G C A C C G A G A A C C T A C A A A A T A C C A T G A A N)
      (HUMUGU4CA-NEG-121 A A C A A C A A G A A A C C T C C T A T G C A G A T G G G C C T T A A A T A C G G C T G G T G G A G T G G G A A C A C G N)
      (HUMUKA-NEG-1501 G A A C G A C A A T A G C T T T A C C C T C A G G C A T A G G C C T G G G T G C T G G C T G C C C A G A C C C C T C T G N)
      (HUMUKI3-NEG-2941 A A C C T C C A C T C C C A A C C C T A C C C C A G G T C T C C T A A T T T C A A T G G G A A G A C C A T A A T T C A C N)
      (HUMUKPM-NEG-781 C A T C G T C T A C C T G G G T C G C T C A A G G C T T A A C T C C A A C A C G C A A G G G G A G A T G A A G T T T G A N)
      (HUMUMOD-NEG-1621 C T C T A C G T G G G C A C C A T G T T G G A T G G G G G C G A C C T G T C C C G A T T T G C A C T G C T C A T G A C C N)
      (HUMUMPS-NEG-1561 A T T T T T C A G A T A C A A T G T G A A G A C A T T G A A G A T A T G T G G T C C T C C T G A A A G T C A C T G G C T N)
      (HUMUPAA-NEG-1501 T C G G A G C G G C G G G C C C C A G G C A A A C T T G C A C G A C G C C T G C C A G G G C G A T T C G G G A G G C C C N)
      (HUMUPAX-NEG-3541 A T G G C C T T G G G G A C A A G T C G T G C T T T G A G G C C T C T A G G G A G G G A A G G A A G A A G T G G C A T G N)
      (HUMUPIR1-NEG-841 T G T A G A T T T T T T T T T T T T G C A C C C C A T G C T G T T G A T T G C T A A A T G T A A C A G T C T G A T C G T N)
      (HUMVDR-NEG-1441 A G G G C C A C G T G C C A G G C C C G G G G C T G G C G G C T A C T C A G C A G C C C T C C T C A C C C G T C T G G G N)
      (HUMVIL2-NEG-1441 C C T G G T G A A G A C C A A G G A G G A G C T G C A C C T G G T G A T G A C A G C A C C C C C G C C C C C A C C A C C N)
      (HUMVILLR1-NEG-361 A C C C T A C C C T G A T T G T A G G G T C T C A T T T T C T C A C C G A T A T T A G T C C T A C A C C A A T T G A A G N)
      (HUMVIM06-NEG-1 T C C A A T G C C A A T C C A C A T G C C A A T G C A C C T G T G T G A A A T A G G C A C T G A A A G G T G A A C T C T N)
      (HUMVIP1-NEG-421 T T A T A T A A A T T A G G C A T A A T G A C A A T T A A G T A A G A A C T T C A A G C C C T A T T C A T C C C A T G G N)
      (HUMVIPMR5-NEG-121 A T T C T A G C T A A T G T A A T A A C T G T G A A G T T T A C A T T G T A A A T A G T A T T T G A G A G T T C T A A A N)
      (HUMVPF-NEG-661 C C T T G C T C A G A G C G G A G A A A G C A T T T G T T T G T A C A A G A T C C G C A G A C G T G T A A A T G T T C C N)
      (HUMVTNR-NEG-1081 T G T C T C T A C A G A G A G C T T C A G G A G A C T T C C A G A C G A C A A A G C T G A A T G G A T T T G A G G T C T N)
      (HUMVTNR-NEG-5641 A T T T T G A G A A A A A T A C A T G T G A G T C A T T T T T T C T G T T T C T C T T T T C T C T T A A C G A T T A T C N)
      (HUMVWF01-NEG-2101 A G C G A T T G T T A C C C T T G G G C C T G G C A C T G G C C A G G G G T T T T T T C G G G G G C C A G A A G T C C A N)
      (HUMVWFA-NEG-1 A C G A G T A T G T T G G A G A A A T A A A A T G T C G A T A G T G G G G A T T T T A T T T T A A G T T T G T T G G T G N)
      (HUMVWFA01-NEG-3961 T A T G G G G G C A C A G G A T G A G G A G G A A G G A A T C C A A G A C T T G G A T G G A T T A T T A G T T T T C G A N)
      (HUMVWFA04-NEG-301 G G C T G G A C C G A C C A C A G C G C G T G C A G T A A G T C G G C C C C C T G C C C C G T C C T G C C C T G C C G G N)
      (HUMVWFA17-NEG-301 A T G C C A C G T G C T C C A C G A T C G G C A T G G C C C A C T A C C T C A C C T T C G A C G G G C T C A A A T A C C N)
      (HUMVWFA24-NEG-781 G G C C C C A T G C C A A C C T C A A G C A G A T C C G C C T C A T C G A G A A G C A G G C C C C T G A G A A C A A G G N)
      (HUMVWFA29-NEG-661 G T C C T G G C T C C A G C C A C A T T C T A T G C C A T C T G C C A G C A G G A C A G T T G C C A C C A G G A G C A A N)
      (HUMVWFA31-NEG-3961 G T A A G G A C T G C T T G G C T A T T A A C T A T C A G T T A A T A G T T T A C T C A T T T A T T T A T T G C T G T C N)
      (HUMVWFA37-NEG-661 A A C T G G A A G A G A A T T C A G A A T C A T C A A A A T T G T T T C A G C C T G G T C A G G T A G G G T G G T C A A N)
      (HUMVWFM-NEG-541 G A A A T G C A A G A A A C G G G T C A C C A T C C T G G T G G A G G G A G G A G A G A T T G A G C T G T T T G A C G G N)
      (HUMVWFM-NEG-5101 T G T G G G C C A G T T C T G G G A G G A G G G C T G C G A T G T G T G C A C C T G C A C C G A C A T G G A G G A T G C N)
      (HUMVWFR-NEG-3301 C T G G G A A G T G A G C T C G C A G T G T G C T G A C A C C A G A A A A G T G C C T C T G G A C T C A T C C C C T G C N)
      (HUMVWFR1-NEG-3481 C A G A G C T G C G A G G A G A G G A A T C T C C G G G A G A A C G G G T A T G A G T G T G A G T G G C G C T A T A A C N)
      (HUMVWFR1-NEG-8041 G C T T G C A C C A T T C A G C T A A G A G G A G G A C A G A T C A T G A C A C T G A A G C G T G A T G A G A C G C T C N)
      (HUMXCGD-NEG-1201 G A A G A T G T G T T C A G C T A T G A G G T G G T G A T G T T A G T G G G A G C A G G G A T T G G G G T C A C A C C C N)
      (HUMXEH-NEG-1441 G T T C G T G G G G G C C A C T T T G C G G C C T T T G A G G A G C C G G A G C T G C T C G C C C A G G A C A T C C G C N)
      (HUMXYES2-NEG-1741 C T T C A C T G C T A C A G A G C C A T A G T A C C A G C C A G G A G A A A A C T T C T A A T T C A A G T A G C C T A T N)
      (HUMYTEST-NEG-301 G C C G C C C T C C C A T T G A T T G G C C A T G A G G G A A G G A A G T C G C C T G G G T G C C C C T T G G C C C T T N)
      (HUMZFX-NEG-781 G T A G T T T C A G A A G A A G T A T T G G T A G C A G A C T G T G C C T C T G A A G C A G T C A T A G A T G C C A A T N)
      (HUMZFY-NEG-2341 T T C C G A A G A C C T T C A G A A A A G A A C C A G C A C A T A A T G A G A C A C C A T A A A G A A G T T G G T C T G N)
      (HUMZNF8-NEG-661 C A G G A C A A A C C C T A C A A A T G T A C T G A C T G T G G G A A G T C G T T T A A C C A T A A C G C A C A C C T C N)
      (LEMHBDPS-NEG-1441 T T C A C C C C A C A G G T G C A G G C T G C C T A T C A G A A G G T G G T G G C T G G T G T G G C T A A T G C C C T G N)
      (LEMHBGA-NEG-361 G A T G G A A T G A A C C T G T G T A T G G C A G A A A T A C A G G A C A C T T C T C A G G A G T A A T G A C A A T T T N)
      (MACAPOA-NEG-961 G G C T T G A T C A G G A A C T A C T G C A G G A A T C C A G A T C C T G T G G C A G C C C C T T A T T G T T A T A C G N)
      (MACAPOE-NEG-181 C C A G C A G G C T G A G G G C C A G A G C G G C C A G C C C T G G G A G C T G G C A C T G G G T C G C T T T T G G G A N)
      (MACHBA-NEG-421 G C T G A G C G A C C T G C A C G C G C A C A A G C T T C G G G T G G A C C C G G T C A A C T T C A A G G T G A G C G G N)
      (MACHBB-NEG-4141 T G T G A G C C A C A C C C T A C A G T T G G C C A A T C T A C T C C C A G G A G C A G G G A G G G C A G G A G C C A G N)
      (MACHBDPS2-NEG-1 G A A T T C A T C C T A C A G G T G C A G G C T G C C T A T C A G A A G G T G G T G G C T G G T G T G G C T A A T G C C N)
      (MACHBPEA-NEG-2161 T G A C T T T G C A C C T G C T C T G T G A T T A T G A C T A T C C C A C A G T C T C C T G G T T G T C T A C C C A T G N)
      (MACHBPEA-NEG-6721 G A G A G A G A G A C C A G A A A T A A T C T T G C T T A T G C T T T C C C T C A G C C A G T G T T T A C C A T T G C A N)
      (MACHBPSBD-NEG-1141 T T A C C T C T A A T C A A C A G T T C A A T T A T G C T T G A A T T T G T C C C T G T C T A T T A A T C A C T T C T C N)
      (MACPEPSG-NEG-2161 G C T G G G G A G A A A C C C A A G G T A C C T A T G G G G C T G G C C T T C T C A A G G A A G C C C G G C T C C C C G N)
      (MACRSMB-NEG-1 A A A A G G A A A T A T C C T C A G A T G A A A T C T G G A A A G A A G C T T T C T G A G A A A C T G C T T A G T G T T N)
      (MNKHAPSE-NEG-901 A G G A A A T C T C C T T T G C T C A G A T A A G T A C A C T G A C C A C T A A A T G G A T T A A A A A A C A C T G A A N)
      (MNKHAPSE-NEG-5461 C A T A C T T G T G C T A T C C C C T G C C C T T C T A A A T C T C A T T G T G T A T T T T A A A T T A A G A G A A T A N)
      (MNKHBPSBD-NEG-961 C C T C A G T A C C A A A C T C A T A C A T C A A A C T G T G T A C T A G G C T T A T A T A T A T A G A T G T C C T A A N)
      (ORAHBA01-NEG-121 C C T G C C G A C A A G A C C A A C G T C A A G A C C G C C T G G G G G A A G G T C G G C G C G C A C G C C G G C G A C N)
      (ORAHBBE-NEG-2581 C T G G A A G C A C T G G A T G G A A T C T T T T C T G T C T G T C C T C T C T G G G G A A T C A C C C C A A G G T A T N)
      (ORAHBBPSE-NEG-2101 T G T T T C T G A A A G A G G G A T T A G C C C G T T G T C T T A C A T A G T C T G A C T T T G C A C C T G C T C T G T N)
      (ORAHBBPSE-NEG-6661 T A A A A A A G A C T C T C T G C T G T G G G A G A T C C C T T C A G A G A G A G A G A G A C C A G A A A T A A T C T T N)
      (ORAHBG2F-NEG-181 A T C A A T A A G C T C C T A G T C C A G A C G C C A T G G G T C A T T T C A C A G A G G A G G A C A A G G C T A C T A N)
      (ORAHBPSBD-NEG-2881 T C T C T T C C C T T C C C C T C T C T C T T T C T T T C T T T T C T C T C C T C T T C T C T T C T T T C C T C T C T T N)
      (ORAINVOL-NEG-2161 G A G C T C C C A G A G C A G C A A G A G G G C C A G C T G A A G C A C C T G G A G A A G C A G G A G G C A C A G C T G N)
      (ORARGIT-NEG-241 T C T C G G G G G C G G C C G G C G C G G C G G G G A G C G G T C C C C G G C C G C G G C C C C G A C G T G T G T G T C N)
      (TARHBB-NEG-541 A T T C T A C T T A G T A A A C A T A A T T T C T T G T G C T A G A T A A C C A A A T T A A G A A A A C C A A A A C A A N)
      (TARHBD-NEG-1981 A G G C T G C C T A T C A G A A G G T G G T G G C T G G T G T G G C T G C T G C T C T G G C T C A C A A G T A C C A T T N)
      )))
