;%
;% Notes: The large soybean database (soybean-large-data.arff) and it's
;%        corresponding test database (soybean-large-test.arff) combined
;%        into a single file (soybean-large.arff).
;%
;% 1. Title: Large Soybean Database
;%
;% 2. Sources:
;%      (a) R.S. Michalski and R.L. Chilausky "Learning by Being Told and
;%          Learning from Examples: An Experimental Comparison of the Two
;% 	 Methods of Knowledge Acquisition in the Context of Developing
;% 	 an Expert System for Soybean Disease Diagnosis", International
;% 	 Journal of Policy Analysis and Information Systems, Vol. 4,
;% 	 No. 2, 1980.
;%      (b) Donor: Ming Tan & Jeff Schlimmer (Jeff.Schlimmer%cs.cmu.edu)
;%      (c) Date: 11 July 1988
;%
;% 3. Past Usage:
;%     1. See above.
;%     2. Tan, M., & Eshelman, L. (1988). Using weighted networks to represent
;%        classification knowledge in noisy domains.  Proceedings of the Fifth
;%        International Conference on Machine Learning (pp. 121-134). Ann Arbor,
;%         Michigan: Morgan Kaufmann.
;%         -- IWN recorded a 97.1% classification accuracy
;%            -- 290 training and 340 test instances
;%      3. Fisher,D.H. & Schlimmer,J.C. (1988). Concept Simplification and
;%         Predictive Accuracy. Proceedings of the Fifth
;%         International Conference on Machine Learning (pp. 22-28). Ann Arbor,
;%         Michigan: Morgan Kaufmann.
;%         -- Notes why this database is highly predictable
;%
;% 4. Relevant Information Paragraph:
;%     There are 19 classes, only the first 15 of which have been used in prior
;%     work.  The folklore seems to be that the last four classes are
;%     unjustified by the data since they have so few examples.
;%     There are 35 categorical attributes, some nominal and some ordered.  The
;%     value ``dna'' means does not apply.  The values for attributes are
;%     encoded numerically, with the first value encoded as ``0,'' the second as
;%     ``1,'' and so forth.  An unknown values is encoded as ``?''.
;%
;% 5. Number of Instances: 683
;%
;% 6. Number of Attributes: 35 (all have been nominalized)
;%
;% 7. Attribute Information:
;%    -- 19 Classes
;%     diaporthe-stem-canker, charcoal-rot, rhizoctonia-root-rot,
;%     phytophthora-rot, brown-stem-rot, powdery-mildew,
;%     downy-mildew, brown-spot, bacterial-blight,
;%     bacterial-pustule, purple-seed-stain, anthracnose,
;%     phyllosticta-leaf-spot, alternarialeaf-spot,
;%     frog-eye-leaf-spot, diaporthe-pod-&-stem-blight,
;%     cyst-nematode, 2-4-d-injury, herbicide-injury.
;%
;%    1. date:		april,may,june,july,august,september,october,?.
;%    2. plant-stand:	normal,lt-normal,?.
;%    3. precip:		lt-norm,norm,gt-norm,?.
;%    4. temp:		lt-norm,norm,gt-norm,?.
;%    5. hail:		yes,no,?.
;%    6. crop-hist:	diff-lst-year,same-lst-yr,same-lst-two-yrs,
;%                        same-lst-sev-yrs,?.
;%    7. area-damaged:	scattered,low-areas,upper-areas,whole-field,?.
;%    8. severity:	minor,pot-severe,severe,?.
;%    9. seed-tmt:	none,fungicide,other,?.
;%   10. germination:	'90-100%','80-89%','lt-80%',?.
;%   11. plant-growth:	norm,abnorm,?.
;%   12. leaves:		norm,abnorm.
;%   13. leafspots-halo:	absent,yellow-halos,no-yellow-halos,?.
;%   14. leafspots-marg:	w-s-marg,no-w-s-marg,dna,?.
;%   15. leafspot-size:	lt-1/8,gt-1/8,dna,?.
;%   16. leaf-shread:	absent,present,?.
;%   17. leaf-malf:	absent,present,?.
;%   18. leaf-mild:	absent,upper-surf,lower-surf,?.
;%   19. stem:		norm,abnorm,?.
;%   20. lodging:    	yes,no,?.
;%   21. stem-cankers:	absent,below-soil,above-soil,above-sec-nde,?.
;%   22. canker-lesion:	dna,brown,dk-brown-blk,tan,?.
;%   23. fruiting-bodies:	absent,present,?.
;%   24. external decay:	absent,firm-and-dry,watery,?.
;%   25. mycelium:	absent,present,?.
;%   26. int-discolor:	none,brown,black,?.
;%   27. sclerotia:	absent,present,?.
;%   28. fruit-pods:	norm,diseased,few-present,dna,?.
;%   29. fruit spots:	absent,colored,brown-w/blk-specks,distort,dna,?.
;%   30. seed:		norm,abnorm,?.
;%   31. mold-growth:	absent,present,?.
;%   32. seed-discolor:	absent,present,?.
;%   33. seed-size:	norm,lt-norm,?.
;%   34. shriveling:	absent,present,?.
;%   35. roots:		norm,rotted,galls-cysts,?.
;%
;%
;%
(defun soybean ()
  (data
    :name 'soybean
    :columns '(date plant-stand precip temp hail crop-hist area-damaged severity seed-tmt germination plant-growth leaves leafspots-halo leafspots-marg leafspot-size leaf-shread leaf-malf leaf-mild stem lodging stem-cankers canker-lesion fruiting-bodies external-decay mycelium int-discolor sclerotia fruit-pods fruit-spots seed mold-growth seed-discolor seed-size shriveling roots class)
    :egs
    '(
      (october  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (july  normal  gt-norm  norm  yes  same-lst-yr  scattered  severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (july  normal  gt-norm  norm  yes  same-lst-yr  scattered  severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (october  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  none  lt-80  abnorm  abnorm  absent  dnxa  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (august  normal  gt-norm  norm  no  same-lst-yr  scattered  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (october  normal  lt-norm  gt-norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (august  normal  lt-norm  norm  no  same-lst-yr  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (july  normal  lt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (october  normal  lt-norm  norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (october  normal  lt-norm  gt-norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (september  normal  lt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (october  normal  lt-norm  gt-norm  no  diff-lst-year  upper-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (august  normal  lt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (july  normal  lt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (september  normal  lt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  present  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (july  normal  gt-norm  lt-norm  no  same-lst-sev-yrs  low-areas  severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  below-soil  brown  absent  firm-and-dry  present  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (april  lt-normal  gt-norm  lt-norm  yes  diff-lst-year  low-areas  pot-severe  fungicide  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (april  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  fungicide  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  low-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  diff-lst-year  low-areas  pot-severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (april  lt-normal  gt-norm  norm  no  same-lst-yr  low-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  gt-norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (april  lt-normal  norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (june  lt-normal  norm  norm  ?  diff-lst-year  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (april  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (april  lt-normal  norm  norm  no  same-lst-two-yrs  low-areas  severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (april  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (june  lt-normal  norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  no  same-lst-yr  low-areas  severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (april  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  yes  diff-lst-year  low-areas  severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  diff-lst-year  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  below-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  gt-norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  no  same-lst-sev-yrs  low-areas  severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  below-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  diff-lst-year  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  diff-lst-year  low-areas  severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  gt-norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  gt-norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  lt-norm  yes  same-lst-two-yrs  low-areas  severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  normal  lt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  lt-normal  lt-norm  lt-norm  yes  same-lst-sev-yrs  scattered  pot-severe  fungicide  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  no  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (october  normal  norm  norm  no  same-lst-two-yrs  scattered  pot-severe  fungicide  90-100  abnorm  norm  absent  dna  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  lt-normal  lt-norm  lt-norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  lt-normal  lt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  90-100  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  norm  lt-norm  no  same-lst-two-yrs  whole-field  pot-severe  fungicide  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  lt-normal  lt-norm  lt-norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  fungicide  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  lt-normal  lt-norm  lt-norm  yes  same-lst-two-yrs  scattered  severe  none  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  normal  lt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  no  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (october  normal  norm  lt-norm  no  diff-lst-year  scattered  minor  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (may  lt-normal  lt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  other  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (october  lt-normal  norm  lt-norm  yes  same-lst-two-yrs  upper-areas  minor  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (august  lt-normal  norm  lt-norm  yes  same-lst-two-yrs  upper-areas  minor  other  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (october  normal  lt-norm  norm  no  same-lst-yr  low-areas  pot-severe  none  lt-80  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (june  lt-normal  norm  lt-norm  yes  same-lst-two-yrs  upper-areas  minor  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (october  lt-normal  lt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (september  lt-normal  lt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (may  lt-normal  lt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  other  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (october  normal  gt-norm  lt-norm  no  same-lst-two-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (june  normal  gt-norm  norm  no  same-lst-yr  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (may  normal  gt-norm  norm  no  same-lst-sev-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (august  lt-normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  present  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (may  normal  gt-norm  lt-norm  no  diff-lst-year  scattered  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (june  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (august  lt-normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (august  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (may  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (april  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  pot-severe  other  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (april  lt-normal  norm  norm  no  same-lst-two-yrs  upper-areas  minor  other  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  norm  norm  no  same-lst-two-yrs  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  severe  other  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  present  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  low-areas  pot-severe  fungicide  90-100  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  normal  gt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  lt-normal  norm  norm  no  same-lst-two-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  colored  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  present  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  norm  norm  no  diff-lst-year  scattered  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  severe  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  present  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  severe  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  present  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  normal  gt-norm  norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  normal  gt-norm  gt-norm  no  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (june  normal  norm  norm  yes  diff-lst-year  scattered  minor  none  90-100  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  norm  norm  yes  same-lst-yr  upper-areas  minor  none  90-100  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  norm  norm  yes  same-lst-sev-yrs  upper-areas  minor  none  90-100  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  gt-norm  norm  no  same-lst-two-yrs  low-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  norm  norm  yes  same-lst-yr  scattered  minor  none  80-89  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  normal  gt-norm  norm  no  diff-lst-year  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (june  normal  norm  norm  yes  same-lst-sev-yrs  low-areas  minor  none  90-100  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  lt-normal  gt-norm  gt-norm  no  same-lst-two-yrs  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (june  lt-normal  norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  none  lt-80  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  galls-cysts  bacterial-pustule)
      (july  normal  gt-norm  lt-norm  no  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  no-yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  norm  absent  norm  bacterial-pustule)
      (june  normal  norm  lt-norm  yes  diff-lst-year  scattered  minor  none  90-100  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-pustule)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  lt-norm  absent  rotted  bacterial-pustule)
      (july  normal  gt-norm  norm  no  same-lst-yr  low-areas  pot-severe  none  80-89  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  lt-norm  absent  rotted  bacterial-pustule)
      (july  lt-normal  norm  lt-norm  yes  same-lst-two-yrs  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  no-w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  rotted  bacterial-pustule)
      (july  normal  norm  norm  no  same-lst-two-yrs  whole-field  minor  none  80-89  abnorm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  lt-norm  absent  norm  bacterial-pustule)
      (july  lt-normal  gt-norm  norm  yes  diff-lst-year  upper-areas  pot-severe  none  lt-80  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  lt-norm  absent  rotted  bacterial-pustule)
      (august  normal  norm  norm  no  same-lst-yr  whole-field  minor  none  80-89  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  lt-norm  absent  norm  bacterial-pustule)
      (september  lt-normal  norm  norm  yes  same-lst-two-yrs  scattered  minor  fungicide  lt-80  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  rotted  bacterial-pustule)
      (october  normal  gt-norm  lt-norm  no  same-lst-two-yrs  upper-areas  minor  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (october  normal  gt-norm  lt-norm  yes  same-lst-two-yrs  upper-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (august  normal  gt-norm  norm  no  same-lst-yr  low-areas  minor  fungicide  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (august  normal  gt-norm  norm  no  diff-lst-year  scattered  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  no  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (august  normal  gt-norm  lt-norm  yes  diff-lst-year  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (july  normal  gt-norm  lt-norm  no  diff-lst-year  scattered  minor  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  norm  no  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (july  normal  gt-norm  norm  no  same-lst-sev-yrs  whole-field  minor  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (september  normal  gt-norm  norm  yes  same-lst-yr  low-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (august  normal  gt-norm  norm  yes  diff-lst-year  scattered  minor  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  lt-normal  gt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  minor  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  norm  present  norm  anthracnose)
      (october  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (june  lt-normal  gt-norm  gt-norm  no  diff-lst-year  scattered  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  brown  absent  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  anthracnose)
      (july  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  norm  absent  norm  anthracnose)
      (august  lt-normal  gt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (october  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (may  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  anthracnose)
      (october  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  other  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  norm  absent  norm  anthracnose)
      (september  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (april  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  norm  absent  abnorm  present  absent  lt-norm  absent  norm  anthracnose)
      (october  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  absent  present  lt-norm  present  norm  anthracnose)
      (september  lt-normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (october  lt-normal  gt-norm  gt-norm  no  diff-lst-year  scattered  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (october  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  minor  other  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (september  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (july  lt-normal  norm  norm  yes  diff-lst-year  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (july  normal  lt-norm  norm  no  diff-lst-year  upper-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (july  lt-normal  norm  norm  yes  diff-lst-year  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (july  normal  lt-norm  norm  no  same-lst-two-yrs  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (july  lt-normal  norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  normal  lt-norm  norm  no  diff-lst-year  whole-field  minor  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (may  normal  lt-norm  gt-norm  no  same-lst-sev-yrs  upper-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  lt-normal  norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  normal  lt-norm  gt-norm  no  same-lst-sev-yrs  scattered  pot-severe  fungicide  90-100  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  lt-normal  norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (july  normal  gt-norm  norm  yes  diff-lst-year  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  norm  norm  no  same-lst-two-yrs  upper-areas  minor  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  norm  norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-yr  low-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  norm  yes  diff-lst-year  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  diff-lst-year  whole-field  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (july  normal  gt-norm  norm  yes  diff-lst-year  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  yes  diff-lst-year  whole-field  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  diff-lst-year  whole-field  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  norm  norm  yes  same-lst-two-yrs  low-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  diff-lst-year  low-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  absent  present  lt-norm  present  norm  frog-eye-leaf-spot)
      (september  normal  norm  norm  yes  same-lst-yr  whole-field  pot-severe  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  absent  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-yr  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  diff-lst-year  low-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  lt-normal  norm  gt-norm  yes  same-lst-yr  low-areas  minor  other  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  scattered  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  whole-field  ?  ?  90-100  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (october  normal  gt-norm  gt-norm  ?  same-lst-two-yrs  whole-field  ?  ?  80-89  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (september  normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  whole-field  ?  ?  90-100  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (may  lt-normal  norm  gt-norm  ?  same-lst-sev-yrs  scattered  ?  ?  lt-80  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (september  ?  gt-norm  gt-norm  ?  same-lst-two-yrs  whole-field  ?  ?  ?  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (september  normal  gt-norm  gt-norm  ?  same-lst-two-yrs  whole-field  ?  ?  90-100  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (june  ?  ?  ?  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (july  ?  ?  ?  ?  same-lst-sev-yrs  upper-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (august  ?  ?  ?  ?  same-lst-sev-yrs  upper-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (july  ?  ?  ?  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (july  ?  ?  ?  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (august  ?  ?  ?  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (may  lt-normal  ?  lt-norm  ?  same-lst-yr  scattered  ?  ?  ?  abnorm  abnorm  no-yellow-halos  no-w-s-marg  gt-1/8  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (april  lt-normal  ?  lt-norm  ?  diff-lst-year  whole-field  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (may  lt-normal  ?  lt-norm  ?  diff-lst-year  scattered  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (may  lt-normal  ?  lt-norm  ?  same-lst-yr  whole-field  ?  ?  ?  abnorm  abnorm  no-yellow-halos  no-w-s-marg  gt-1/8  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (october  normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (august  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (september  normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (july  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (august  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dna  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  norm  dna  norm  absent  absent  norm  absent  norm  diaporthe-stem-canker)
      (august  normal  lt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (august  normal  lt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (september  normal  lt-norm  gt-norm  yes  diff-lst-year  upper-areas  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (september  normal  lt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (july  normal  lt-norm  gt-norm  no  diff-lst-year  upper-areas  pot-severe  none  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (august  normal  lt-norm  gt-norm  no  same-lst-yr  whole-field  pot-severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (september  normal  lt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  none  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (october  normal  lt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (october  normal  lt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  black  present  norm  dna  norm  absent  absent  norm  absent  norm  charcoal-rot)
      (april  lt-normal  gt-norm  lt-norm  yes  diff-lst-year  low-areas  pot-severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  rotted  rhizoctonia-root-rot)
      (april  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  low-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (april  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  diff-lst-year  low-areas  pot-severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  low-areas  severe  none  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  present  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (august  normal  gt-norm  lt-norm  no  diff-lst-year  low-areas  severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  below-soil  brown  absent  firm-and-dry  present  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (april  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  present  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  low-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  brown  absent  firm-and-dry  present  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  rhizoctonia-root-rot)
      (june  lt-normal  norm  lt-norm  yes  same-lst-sev-yrs  low-areas  severe  none  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  below-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (may  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  absent  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  no  same-lst-sev-yrs  low-areas  severe  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  no  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  dk-brown-blk  absent  firm-and-dry  absent  none  absent  dna  dna  norm  absent  absent  norm  absent  norm  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (april  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  diff-lst-year  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  lt-normal  norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  below-soil  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  lt-normal  norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  lt-normal  norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  gt-norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (august  lt-normal  norm  norm  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (may  lt-normal  gt-norm  gt-norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-soil  dk-brown-blk  ?  watery  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (june  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  lt-normal  norm  norm  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  abnorm  ?  above-sec-nde  dk-brown-blk  ?  absent  absent  none  absent  ?  ?  ?  ?  ?  ?  ?  rotted  phytophthora-rot)
      (july  normal  lt-norm  lt-norm  no  same-lst-yr  scattered  severe  none  90-100  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  norm  lt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  normal  lt-norm  lt-norm  no  same-lst-sev-yrs  upper-areas  severe  none  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  no  same-lst-sev-yrs  scattered  pot-severe  none  90-100  abnorm  abnorm  no-yellow-halos  w-s-marg  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (october  normal  lt-norm  norm  no  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  norm  lt-norm  no  same-lst-sev-yrs  upper-areas  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  yes  same-lst-yr  scattered  pot-severe  fungicide  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  lt-normal  norm  lt-norm  yes  same-lst-two-yrs  scattered  severe  none  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  lt-normal  norm  norm  yes  same-lst-two-yrs  whole-field  severe  none  90-100  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  lt-normal  lt-norm  lt-norm  yes  same-lst-two-yrs  upper-areas  severe  none  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  lt-normal  norm  lt-norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  lt-80  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  lt-normal  norm  lt-norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  90-100  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (october  lt-normal  norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  abnorm  norm  absent  dna  dna  absent  absent  absent  abnorm  no  absent  tan  absent  absent  absent  brown  absent  norm  dna  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  normal  lt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (july  normal  lt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-two-yrs  scattered  pot-severe  fungicide  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (august  normal  lt-norm  norm  yes  same-lst-yr  scattered  pot-severe  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (september  normal  lt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  fungicide  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  dna  absent  absent  absent  brown  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-stem-rot)
      (may  normal  lt-norm  lt-norm  no  diff-lst-year  scattered  minor  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (june  normal  norm  norm  no  same-lst-yr  low-areas  pot-severe  fungicide  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (july  normal  gt-norm  lt-norm  no  same-lst-two-yrs  upper-areas  minor  none  lt-80  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (august  normal  lt-norm  norm  no  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (september  normal  norm  lt-norm  no  diff-lst-year  scattered  minor  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (august  normal  norm  lt-norm  no  same-lst-two-yrs  upper-areas  minor  fungicide  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (july  lt-normal  lt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (august  lt-normal  norm  lt-norm  yes  diff-lst-year  scattered  minor  other  90-100  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (june  lt-normal  norm  lt-norm  yes  diff-lst-year  scattered  minor  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (september  lt-normal  lt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  upper-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  powdery-mildew)
      (july  normal  gt-norm  lt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (august  normal  gt-norm  norm  no  same-lst-sev-yrs  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (september  normal  gt-norm  norm  no  same-lst-yr  scattered  pot-severe  none  80-89  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (june  normal  gt-norm  lt-norm  no  diff-lst-year  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (july  normal  gt-norm  norm  no  same-lst-yr  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (october  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (july  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (september  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (july  lt-normal  gt-norm  norm  yes  same-lst-yr  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (september  lt-normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  lower-surf  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  absent  norm  absent  norm  downy-mildew)
      (may  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  absent  tan  present  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  other  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  norm  norm  no  same-lst-two-yrs  upper-areas  pot-severe  fungicide  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  gt-norm  no  same-lst-yr  low-areas  minor  other  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  brown-spot)
      (april  normal  norm  norm  yes  diff-lst-year  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  none  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  absent  absent  none  absent  norm  colored  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  normal  norm  norm  yes  same-lst-yr  scattered  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  brown-spot)
      (april  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  other  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  norm  norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (april  normal  norm  norm  yes  same-lst-two-yrs  scattered  minor  other  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  low-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (august  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (may  normal  gt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  abnorm  yes  above-sec-nde  brown  present  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  brown-spot)
      (july  normal  gt-norm  norm  no  same-lst-yr  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  lt-normal  norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  lt-80  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (june  lt-normal  norm  norm  yes  same-lst-yr  scattered  minor  none  lt-80  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  normal  norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  minor  none  80-89  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (september  lt-normal  gt-norm  norm  no  same-lst-yr  whole-field  pot-severe  fungicide  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  norm  norm  yes  same-lst-two-yrs  scattered  minor  none  90-100  abnorm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  normal  gt-norm  norm  no  same-lst-sev-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  gt-norm  norm  no  same-lst-yr  upper-areas  pot-severe  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (august  lt-normal  norm  norm  yes  same-lst-two-yrs  whole-field  minor  none  lt-80  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (september  normal  gt-norm  norm  no  same-lst-sev-yrs  scattered  pot-severe  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  bacterial-blight)
      (july  normal  norm  lt-norm  no  same-lst-sev-yrs  whole-field  minor  none  80-89  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  norm  absent  norm  bacterial-pustule)
      (may  lt-normal  norm  norm  yes  same-lst-yr  scattered  minor  fungicide  lt-80  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  lt-norm  absent  rotted  bacterial-pustule)
      (june  normal  norm  gt-norm  no  same-lst-two-yrs  low-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  norm  absent  norm  bacterial-pustule)
      (july  lt-normal  norm  norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  rotted  bacterial-pustule)
      (june  normal  gt-norm  norm  no  same-lst-sev-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  norm  absent  norm  bacterial-pustule)
      (june  normal  gt-norm  norm  no  same-lst-yr  whole-field  pot-severe  none  80-89  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  norm  absent  norm  bacterial-pustule)
      (may  normal  norm  norm  no  same-lst-sev-yrs  low-areas  minor  fungicide  80-89  norm  abnorm  yellow-halos  w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  lt-norm  absent  norm  bacterial-pustule)
      (june  lt-normal  gt-norm  gt-norm  yes  same-lst-yr  upper-areas  pot-severe  fungicide  lt-80  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  rotted  bacterial-pustule)
      (september  normal  norm  gt-norm  no  diff-lst-year  low-areas  minor  none  80-89  abnorm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  absent  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  present  present  norm  absent  norm  bacterial-pustule)
      (june  lt-normal  gt-norm  lt-norm  yes  same-lst-yr  upper-areas  pot-severe  none  lt-80  norm  abnorm  yellow-halos  no-w-s-marg  lt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  rotted  bacterial-pustule)
      (september  normal  gt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  no  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (october  normal  gt-norm  lt-norm  no  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (september  normal  gt-norm  gt-norm  no  same-lst-yr  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (august  normal  gt-norm  gt-norm  no  diff-lst-year  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  norm  no  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (september  normal  gt-norm  lt-norm  yes  same-lst-yr  low-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (october  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (july  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (july  normal  gt-norm  lt-norm  yes  same-lst-sev-yrs  whole-field  minor  none  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  norm  yes  absent  tan  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  lt-1/8  absent  absent  absent  abnorm  yes  absent  tan  absent  absent  absent  none  absent  diseased  colored  abnorm  absent  present  norm  absent  norm  purple-seed-stain)
      (april  normal  gt-norm  norm  yes  diff-lst-year  scattered  minor  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  brown  absent  firm-and-dry  absent  none  absent  norm  absent  abnorm  absent  present  lt-norm  present  norm  anthracnose)
      (june  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  other  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  norm  absent  abnorm  absent  present  lt-norm  present  norm  anthracnose)
      (august  normal  gt-norm  norm  yes  diff-lst-year  scattered  minor  fungicide  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (may  normal  gt-norm  norm  yes  diff-lst-year  scattered  minor  other  80-89  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-soil  brown  absent  firm-and-dry  absent  none  absent  norm  absent  abnorm  absent  present  norm  present  norm  anthracnose)
      (august  lt-normal  gt-norm  gt-norm  no  same-lst-yr  low-areas  pot-severe  none  90-100  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  absent  norm  anthracnose)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (october  lt-normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (october  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (september  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  lt-80  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (july  lt-normal  gt-norm  gt-norm  no  same-lst-yr  low-areas  minor  fungicide  lt-80  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (august  lt-normal  gt-norm  gt-norm  no  same-lst-yr  low-areas  minor  fungicide  90-100  abnorm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  no  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  lt-normal  gt-norm  gt-norm  no  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  brown  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (october  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  firm-and-dry  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (august  normal  gt-norm  norm  yes  same-lst-yr  low-areas  severe  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (august  lt-normal  gt-norm  norm  yes  same-lst-yr  low-areas  severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (october  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  absent  lt-norm  present  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  pot-severe  none  90-100  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  lt-normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (september  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  none  80-89  norm  norm  absent  dna  dna  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  absent  absent  norm  absent  norm  anthracnose)
      (may  normal  lt-norm  norm  no  diff-lst-year  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (july  normal  lt-norm  norm  no  same-lst-two-yrs  whole-field  minor  none  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (may  lt-normal  norm  norm  yes  same-lst-two-yrs  whole-field  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  lt-normal  norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  normal  lt-norm  gt-norm  no  same-lst-yr  upper-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  normal  lt-norm  gt-norm  no  same-lst-yr  whole-field  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (july  lt-normal  norm  gt-norm  yes  same-lst-yr  scattered  minor  none  90-100  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (august  lt-normal  norm  gt-norm  yes  same-lst-yr  upper-areas  minor  fungicide  80-89  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (june  lt-normal  norm  gt-norm  yes  same-lst-sev-yrs  scattered  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (august  lt-normal  norm  gt-norm  yes  same-lst-yr  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  present  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  phyllosticta-leaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  present  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  norm  no  diff-lst-year  scattered  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  norm  no  same-lst-yr  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  norm  no  diff-lst-year  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  norm  gt-norm  no  same-lst-yr  low-areas  minor  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  norm  norm  no  diff-lst-year  scattered  minor  other  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  norm  no  same-lst-two-yrs  upper-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (october  normal  norm  gt-norm  no  same-lst-sev-yrs  whole-field  minor  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  gt-norm  yes  diff-lst-year  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  norm  gt-norm  no  diff-lst-year  scattered  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-yr  low-areas  minor  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  norm  gt-norm  no  same-lst-two-yrs  upper-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  abnorm  absent  present  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-yr  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (july  normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  scattered  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  alternarialeaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  norm  yes  same-lst-yr  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-two-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  norm  norm  no  same-lst-sev-yrs  low-areas  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  norm  norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  norm  norm  no  diff-lst-year  low-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dna  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  norm  no  diff-lst-year  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  no  same-lst-two-yrs  upper-areas  minor  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  no  above-sec-nde  brown  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  lt-normal  gt-norm  norm  no  diff-lst-year  scattered  pot-severe  fungicide  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  no  above-soil  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  no  same-lst-two-yrs  upper-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  no  same-lst-yr  scattered  pot-severe  other  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  no  same-lst-sev-yrs  upper-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  lt-normal  gt-norm  gt-norm  no  same-lst-two-yrs  scattered  pot-severe  none  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  lt-normal  gt-norm  gt-norm  no  same-lst-sev-yrs  scattered  pot-severe  other  lt-80  abnorm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  no  above-sec-nde  brown  absent  firm-and-dry  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  norm  yes  absent  dna  absent  absent  absent  none  absent  norm  absent  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-yr  low-areas  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  gt-norm  norm  yes  same-lst-yr  scattered  minor  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  pot-severe  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  pot-severe  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  minor  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  scattered  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  low-areas  pot-severe  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  scattered  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (july  normal  gt-norm  norm  yes  same-lst-yr  low-areas  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-two-yrs  upper-areas  pot-severe  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  whole-field  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  scattered  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  low-areas  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  lt-normal  gt-norm  norm  yes  same-lst-sev-yrs  upper-areas  minor  none  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  gt-norm  yes  same-lst-yr  whole-field  pot-severe  fungicide  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  norm  yes  same-lst-two-yrs  scattered  minor  none  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  lt-normal  gt-norm  gt-norm  yes  same-lst-sev-yrs  low-areas  minor  fungicide  lt-80  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (august  normal  gt-norm  norm  yes  same-lst-yr  upper-areas  pot-severe  none  90-100  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (september  normal  gt-norm  gt-norm  yes  same-lst-two-yrs  whole-field  minor  fungicide  80-89  norm  abnorm  no-yellow-halos  w-s-marg  gt-1/8  absent  absent  absent  abnorm  yes  above-sec-nde  dk-brown-blk  absent  firm-and-dry  absent  none  absent  diseased  colored  norm  absent  absent  norm  absent  norm  frog-eye-leaf-spot)
      (october  ?  gt-norm  gt-norm  ?  same-lst-two-yrs  whole-field  ?  ?  ?  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (october  ?  gt-norm  gt-norm  ?  same-lst-yr  whole-field  ?  ?  ?  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (september  ?  gt-norm  gt-norm  ?  same-lst-yr  whole-field  ?  ?  ?  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (october  ?  gt-norm  gt-norm  ?  same-lst-sev-yrs  whole-field  ?  ?  ?  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (october  ?  gt-norm  gt-norm  ?  diff-lst-year  whole-field  ?  ?  ?  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (may  lt-normal  norm  gt-norm  ?  diff-lst-year  scattered  ?  ?  lt-80  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  norm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (september  normal  gt-norm  gt-norm  ?  same-lst-yr  whole-field  ?  ?  90-100  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (september  normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  whole-field  ?  ?  90-100  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (october  normal  gt-norm  gt-norm  ?  same-lst-sev-yrs  whole-field  ?  ?  80-89  norm  norm  ?  ?  ?  ?  ?  ?  abnorm  ?  absent  dna  present  absent  absent  none  absent  diseased  brown-w/blk-specks  abnorm  present  present  lt-norm  present  ?  diaporthe-pod-&-stem-blight)
      (june  ?  ?  ?  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (july  ?  ?  ?  ?  same-lst-two-yrs  upper-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (august  ?  ?  ?  ?  same-lst-yr  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (june  ?  ?  ?  ?  same-lst-two-yrs  upper-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (july  ?  ?  ?  ?  same-lst-two-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (august  ?  ?  ?  ?  same-lst-sev-yrs  upper-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (august  ?  ?  ?  ?  same-lst-sev-yrs  low-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (july  ?  ?  ?  ?  same-lst-sev-yrs  upper-areas  ?  ?  ?  abnorm  abnorm  ?  ?  ?  ?  ?  ?  norm  ?  ?  ?  ?  ?  ?  ?  ?  few-present  ?  abnorm  absent  ?  lt-norm  ?  galls-cysts  cyst-nematode)
      (september  ?  ?  ?  ?  ?  low-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (april  ?  ?  ?  ?  ?  scattered  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (may  ?  ?  ?  ?  ?  low-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (june  ?  ?  ?  ?  ?  upper-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (july  ?  ?  ?  ?  ?  whole-field  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (august  ?  ?  ?  ?  ?  scattered  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (october  ?  ?  ?  ?  ?  upper-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (april  ?  ?  ?  ?  ?  whole-field  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (may  ?  ?  ?  ?  ?  scattered  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (june  ?  ?  ?  ?  ?  low-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (july  ?  ?  ?  ?  ?  upper-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (august  ?  ?  ?  ?  ?  whole-field  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (september  ?  ?  ?  ?  ?  scattered  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (october  ?  ?  ?  ?  ?  low-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (april  ?  ?  ?  ?  ?  upper-areas  ?  ?  ?  ?  abnorm  absent  dna  dna  ?  present  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  ?  2-4-d-injury)
      (april  lt-normal  ?  lt-norm  ?  diff-lst-year  scattered  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (june  lt-normal  ?  lt-norm  ?  diff-lst-year  scattered  ?  ?  ?  abnorm  abnorm  absent  dna  dna  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (april  lt-normal  ?  lt-norm  ?  same-lst-yr  whole-field  ?  ?  ?  abnorm  abnorm  no-yellow-halos  no-w-s-marg  gt-1/8  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      (june  lt-normal  ?  lt-norm  ?  same-lst-yr  whole-field  ?  ?  ?  abnorm  abnorm  no-yellow-halos  no-w-s-marg  gt-1/8  absent  present  ?  abnorm  ?  ?  ?  ?  ?  ?  ?  ?  dna  ?  ?  ?  ?  ?  ?  rotted  herbicide-injury)
      )))
